ActiveLearningConfig class final

Parameters that configure the active learning pipeline. Active learning will label the data incrementally by several iterations. For every iteration, it will select a batch of data based on the sampling strategy.

Constructors

ActiveLearningConfig({int? maxDataItemCount, int? maxDataItemPercentage, SampleConfig? sampleConfig, TrainingConfig? trainingConfig})
ActiveLearningConfig.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxDataItemCount → int?
Max number of human labeled DataItems.
final
maxDataItemPercentage → int?
Max percent of total DataItems for human labeling.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sampleConfig → SampleConfig?
Active learning data sampling config. For every active learning labeling iteration, it will select a batch of data based on the sampling strategy.
final
trainingConfig → TrainingConfig?
CMLE training config. For every active learning labeling iteration, system will train a machine learning model on CMLE. The trained model will be used by data sampling algorithm to select DataItems.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String