agentId property
Required. Unique identifier of the agent.
This ID is used to refer to this agent, e.g., in AgentEvent.author, or in
the sub_agents field. It must be unique within the agents map.
Implementation
final String? agentId;
Required. Unique identifier of the agent.
This ID is used to refer to this agent, e.g., in AgentEvent.author, or in
the sub_agents field. It must be unique within the agents map.
final String? agentId;