AgentEvent class final

Represents a single event in the execution trace.

Constructors

AgentEvent({required String? author, required Content? content, Timestamp? eventTime, Struct? stateDelta, List<Tool> activeTools = const []})
AgentEvent.fromJson(Object? j)
factory

Properties

activeTools → List<Tool>
Optional. The list of tools that were active/available to the agent at the time of this event. This overrides the AgentConfig.tools if set.
final
author → String?
Required. The ID of the agent or entity that generated this event. Use "user" to denote events generated by the end-user.
final
content → Content?
Required. The content of the event (e.g., text response, tool call, tool response).
final
eventTime → Timestamp?
Optional. The timestamp when the event occurred.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stateDelta → Struct?
Optional. The change in the session state caused by this event. This is a key-value map of fields that were modified or added by the event.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String