AggregationResult class final

The aggregation result for a single metric.

Constructors

AggregationResult({PointwiseMetricResult? pointwiseMetricResult, PairwiseMetricResult? pairwiseMetricResult, ExactMatchMetricValue? exactMatchMetricValue, BleuMetricValue? bleuMetricValue, RougeMetricValue? rougeMetricValue, CustomCodeExecutionResult? customCodeExecutionResult, Metric_AggregationMetric aggregationMetric = Metric_AggregationMetric.$default})
AggregationResult.fromJson(Object? j)
factory

Properties

aggregationMetric → Metric_AggregationMetric
Aggregation metric.
final
bleuMetricValue → BleuMetricValue?
Results for bleu metric.
final
customCodeExecutionResult → CustomCodeExecutionResult?
Result for code execution metric.
final
exactMatchMetricValue → ExactMatchMetricValue?
Results for exact match metric.
final
hashCode → int
The hash code for this object.
no setterinherited
pairwiseMetricResult → PairwiseMetricResult?
Result for pairwise metric.
final
pointwiseMetricResult → PointwiseMetricResult?
Result for pointwise metric.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
rougeMetricValue → RougeMetricValue?
Results for rouge metric.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String