AnnotationSpec class final

Identifies a concept with which DataItems may be annotated with.

Constructors

AnnotationSpec({String name = '', required String displayName, Timestamp? createTime, Timestamp? updateTime, String etag = ''})
AnnotationSpec.fromJson(Object? j)
factory

Properties

createTime → Timestamp?
Output only. Timestamp when this AnnotationSpec was created.
final
displayName → String
Required. The user-defined name of the AnnotationSpec. The name can be up to 128 characters long and can consist of any UTF-8 characters.
final
etag → String
Optional. Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
Output only. Resource name of the AnnotationSpec.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateTime → Timestamp?
Output only. Timestamp when AnnotationSpec was last updated.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String