AssembleDataRequest class final

Request message for DatasetService.AssembleData. Used only for MULTIMODAL datasets.

Constructors

AssembleDataRequest({required String name, GeminiRequestReadConfig? geminiRequestReadConfig})
AssembleDataRequest.fromJson(Object? j)
factory

Properties

geminiRequestReadConfig → GeminiRequestReadConfig?
Optional. The read config for the dataset.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
Required. The name of the Dataset resource (used only for MULTIMODAL datasets). Format: projects/{project}/locations/{location}/datasets/{dataset}
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String