AsyncQueryReasoningEngineRequest class final
Request message for
ReasoningEngineExecutionService.AsyncQueryReasoningEngine.
Constructors
- AsyncQueryReasoningEngineRequest({required String name, String inputGcsUri = '', String outputGcsUri = ''})
- AsyncQueryReasoningEngineRequest.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputGcsUri → String
-
Optional. Input Cloud Storage URI for the Async query.
final
- name → String
-
Required. The name of the ReasoningEngine resource to use.
Format:
projects/{project}/locations/{location}/reasoningEngines/{reasoning_engine}final - outputGcsUri → String
-
Optional. Output Cloud Storage URI for the Async query.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String