AsyncRetrieveContextsRequest class final

Request message for VertexRagService.AsyncRetrieveContexts.

Constructors

AsyncRetrieveContextsRequest({required String parent, required RagQuery? query, List<Tool> tools = const []})
AsyncRetrieveContextsRequest.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
parent → String
Required. The resource name of the Location from which to retrieve RagContexts. The users must have permission to make a call in the project. Format: projects/{project}/locations/{location}.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
query → RagQuery?
Required. Single RAG retrieve query.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tools → List<Tool>
Optional. The tools to use for AskContexts.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String