AuthConfig_ApiKeyConfig class final

Config for authentication with API key.

Constructors

AuthConfig_ApiKeyConfig({required String name, required String apiKeySecret, required HttpElementLocation httpElementLocation})
AuthConfig_ApiKeyConfig.fromJson(Object? j)
factory

Properties

apiKeySecret → String
Required. The name of the SecretManager secret version resource storing the API key. Format: projects/{project}/secrets/{secrete}/versions/{version}
final
hashCode → int
The hash code for this object.
no setterinherited
httpElementLocation → HttpElementLocation
Required. The location of the API key.
final
name → String
Required. The parameter name of the API key. E.g. If the API request is "https://example.com/act?api_key=
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String