AutoraterConfig class final

The configs for autorater. This is applicable to both EvaluateInstances and EvaluateDataset.

Constructors

AutoraterConfig({int? samplingCount, bool? flipEnabled, String autoraterModel = '', GenerationConfig? generationConfig})
AutoraterConfig.fromJson(Object? j)
factory

Properties

autoraterModel → String
Optional. The fully qualified name of the publisher model or tuned autorater endpoint to use.
final
flipEnabled → bool?
Optional. Default is true. Whether to flip the candidate and baseline responses. This is only applicable to the pairwise metric. If enabled, also provide PairwiseMetricSpec.candidate_response_field_name and PairwiseMetricSpec.baseline_response_field_name. When rendering PairwiseMetricSpec.metric_prompt_template, the candidate and baseline fields will be flipped for half of the samples to reduce bias.
final
generationConfig → GenerationConfig?
Optional. Configuration options for model generation and outputs.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
samplingCount → int?
Optional. Number of samples for each instance in the dataset. If not specified, the default is 4. Minimum value is 1, maximum value is 32.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String