BatchDedicatedResources class final

A description of resources that are used for performing batch operations, are dedicated to a Model, and need manual configuration.

Constructors

BatchDedicatedResources({required MachineSpec? machineSpec, int startingReplicaCount = 0, int maxReplicaCount = 0, FlexStart? flexStart, bool spot = false})
BatchDedicatedResources.fromJson(Object? j)
factory

Properties

flexStart → FlexStart?
Optional. Immutable. If set, use DWS resource to schedule the deployment workload. reference: (https://cloud.google.com/blog/products/compute/introducing-dynamic-workload-scheduler)
final
hashCode → int
The hash code for this object.
no setterinherited
machineSpec → MachineSpec?
Required. Immutable. The specification of a single machine.
final
maxReplicaCount → int
Immutable. The maximum number of machine replicas the batch operation may be scaled to. The default value is 10.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spot → bool
Optional. If true, schedule the deployment workload on spot VMs.
final
startingReplicaCount → int
Immutable. The number of machine replicas used at the start of the batch operation. If not set, Vertex AI decides starting number, not greater than max_replica_count
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String