BatchDeleteRagMetadataRequest class final
Request message for
VertexRagDataService.BatchDeleteRagMetadata.
Constructors
-
BatchDeleteRagMetadataRequest({required String parent, required List<
String> names}) - BatchDeleteRagMetadataRequest.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
names
→ List<
String> -
Required. The RagMetadata to delete.
A maximum of 500 rag metadata can be deleted in a batch.
final
- parent → String
-
Required. The resource name of the RagFile from which to delete the
RagMetadata. Format:
projects/{project}/locations/{location}/ragCorpora/{rag_corpus}/ragFiles/{rag_file}final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String