BatchMigrateResourcesRequest class final

Request message for MigrationService.BatchMigrateResources.

Constructors

BatchMigrateResourcesRequest({required String parent, required List<MigrateResourceRequest> migrateResourceRequests})
BatchMigrateResourcesRequest.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
migrateResourceRequests → List<MigrateResourceRequest>
Required. The request messages specifying the resources to migrate. They must be in the same location as the destination. Up to 50 resources can be migrated in one batch.
final
parent → String
Required. The location of the migrated resource will live in. Format: projects/{project}/locations/{location}
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String