endpoint property

String endpoint
final

For Bring-Your-Own-Endpoint (BYOE), the name of the Endpoint resource that produces the predictions via this job, must share the same ancestor Location. Exactly one of model, unmanaged_container_model, or endpoint must be set. Example: projects/193595526740/locations/us-central1/endpoints/4203439000301600768

Implementation

final String endpoint;