BatchPredictionJob_InstanceConfig class final

Configuration defining how to transform batch prediction input instances to the instances that the Model accepts.

Constructors

BatchPredictionJob_InstanceConfig({String instanceType = '', String keyField = '', List<String> includedFields = const [], List<String> excludedFields = const []})
BatchPredictionJob_InstanceConfig.fromJson(Object? j)
factory

Properties

excludedFields → List<String>
Fields that will be excluded in the prediction instance that is sent to the Model.
final
hashCode → int
The hash code for this object.
no setterinherited
includedFields → List<String>
Fields that will be included in the prediction instance that is sent to the Model.
final
instanceType → String
The format of the instance that the Model accepts. Vertex AI will convert compatible google.cloud.aiplatform.v1beta1.BatchPredictionJob.InputConfig.instances_format to the specified format.
final
keyField → String
The name of the field that is considered as a key.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String