vertexMultimodalDatasetDestination property
The details for a Vertex Multimodal Dataset that will be created for the output.
Implementation
final VertexMultimodalDatasetDestination? vertexMultimodalDatasetDestination;
The details for a Vertex Multimodal Dataset that will be created for the output.
final VertexMultimodalDatasetDestination? vertexMultimodalDatasetDestination;