BatchPredictionJob_OutputInfo class final

Further describes this job's output. Supplements output_config.

Constructors

BatchPredictionJob_OutputInfo({String? gcsOutputDirectory, String? bigqueryOutputDataset, String? vertexMultimodalDatasetName, String bigqueryOutputTable = ''})
BatchPredictionJob_OutputInfo.fromJson(Object? j)
factory

Properties

bigqueryOutputDataset → String?
Output only. The path of the BigQuery dataset created, in bq://projectId.bqDatasetId format, into which the prediction output is written.
final
bigqueryOutputTable → String
Output only. The name of the BigQuery table created, in predictions_<timestamp> format, into which the prediction output is written. Can be used by UI to generate the BigQuery output path, for example.
final
gcsOutputDirectory → String?
Output only. The full path of the Cloud Storage directory created, into which the prediction output is written.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vertexMultimodalDatasetName → String?
Output only. The resource name of the Vertex Managed Dataset created, into which the prediction output is written. Format: projects/{project}/locations/{location}/datasets/{dataset}
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String