CachedContent_UsageMetadata class final

Metadata on the usage of the cached content.

Constructors

CachedContent_UsageMetadata({int totalTokenCount = 0, int textCount = 0, int imageCount = 0, int videoDurationSeconds = 0, int audioDurationSeconds = 0})
CachedContent_UsageMetadata.fromJson(Object? j)
factory

Properties

audioDurationSeconds → int
Duration of audio in seconds.
final
hashCode → int
The hash code for this object.
no setterinherited
imageCount → int
Number of images.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textCount → int
Number of text characters.
final
totalTokenCount → int
Total number of tokens that the cached content consumes.
final
videoDurationSeconds → int
Duration of video in seconds.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String