stop constant
Candidate_FinishReason
const stop
Token generation reached a natural stopping point or a configured stop sequence.
Implementation
static const stop = Candidate_FinishReason('STOP');
Token generation reached a natural stopping point or a configured stop sequence.
static const stop = Candidate_FinishReason('STOP');