Checkpoint class final

Describes the machine learning model version checkpoint.

Constructors

Checkpoint({String checkpointId = '', int epoch = 0, int step = 0})
Checkpoint.fromJson(Object? j)
factory

Properties

checkpointId → String
The ID of the checkpoint.
final
epoch → int
The epoch of the checkpoint.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
step → int
The step of the checkpoint.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String