Citation class final

Source attributions for content.

Constructors

Citation({int startIndex = 0, int endIndex = 0, String uri = '', String title = '', String license = '', Date? publicationDate})
Citation.fromJson(Object? j)
factory

Properties

endIndex → int
Output only. End index into the content.
final
hashCode → int
The hash code for this object.
no setterinherited
license → String
Output only. License of the attribution.
final
publicationDate → Date?
Output only. Publication date of the attribution.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startIndex → int
Output only. Start index into the content.
final
title → String
Output only. Title of the attribution.
final
uri → String
Output only. Url reference of the attribution.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String