ColabImage class final

Colab image of the runtime.

Constructors

ColabImage({String releaseName = '', String description = ''})
ColabImage.fromJson(Object? j)
factory

Properties

description → String
Output only. A human-readable description of the specified colab image release, populated by the system. Example: "Python 3.10", "Latest - current Python 3.11"
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
releaseName → String
Optional. The release name of the NotebookRuntime Colab image, e.g. "py310". If not specified, detault to the latest release.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String