CometSpec_CometVersion class final

Comet version options.

Constructors

CometSpec_CometVersion(String value)
const
CometSpec_CometVersion.fromJson(Object? json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isNotDefault → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object?
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$default → const CometSpec_CometVersion
The default value for CometSpec_CometVersion.
comet22SrcRef → const CometSpec_CometVersion
Comet 22 for translation + source + reference (source-reference-combined).
cometVersionUnspecified → const CometSpec_CometVersion
Comet version unspecified.