CompletionStats class final

Success and error statistics of processing multiple entities (for example, DataItems or structured data rows) in batch.

Constructors

CompletionStats({int successfulCount = 0, int failedCount = 0, int incompleteCount = 0, int successfulForecastPointCount = 0})
CompletionStats.fromJson(Object? j)
factory

Properties

failedCount → int
Output only. The number of entities for which any error was encountered.
final
hashCode → int
The hash code for this object.
no setterinherited
incompleteCount → int
Output only. In cases when enough errors are encountered a job, pipeline, or operation may be failed as a whole. Below is the number of entities for which the processing had not been finished (either in successful or failed state). Set to -1 if the number is unknown (for example, the operation failed before the total entity number could be collected).
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
successfulCount → int
Output only. The number of entities that had been processed successfully.
final
successfulForecastPointCount → int
Output only. The number of the successful forecast points that are generated by the forecasting model. This is ONLY used by the forecasting batch prediction.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String