ComputationBasedMetricSpec class final

Specification for a computation based metric.

Inheritance
  • Object
  • ProtoMessage
  • ComputationBasedMetricSpec

Properties

hashCode int
The hash code for this object.
no setterinherited
parameters → Struct?
Optional. A map of parameters for the metric, e.g. {"rouge_type": "rougeL"}.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type ComputationBasedMetricSpec_ComputationBasedMetricType?
Required. The type of the computation based metric.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String