ComputeTokensRequest class final

Request message for ComputeTokens RPC call.

Constructors

ComputeTokensRequest({required String endpoint, List<Value> instances = const [], String model = '', List<Content> contents = const []})
ComputeTokensRequest.fromJson(Object? j)
factory

Properties

contents → List<Content>
Optional. Input content.
final
endpoint → String
Required. The name of the Endpoint requested to get lists of tokens and token ids.
final
hashCode → int
The hash code for this object.
no setterinherited
instances → List<Value>
Optional. The instances that are the input to token computing API call. Schema is identical to the prediction schema of the text model, even for the non-text models, like chat models, or Codey models.
final
model → String
Optional. The name of the publisher model requested to serve the prediction. Format: projects/{project}/locations/{location}/publishers//models/
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String