ContainerRegistryDestination class final

The Container Registry location for the container image.

Constructors

ContainerRegistryDestination({required String outputUri})
ContainerRegistryDestination.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
outputUri → String
Required. Container Registry URI of a container image. Only Google Container Registry and Artifact Registry are supported now. Accepted forms:
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String