ContentsExample class final

A single example of a conversation with the model.

Constructors

ContentsExample({required List<Content> contents, required List<ContentsExample_ExpectedContent> expectedContents})
ContentsExample.fromJson(Object? j)
factory

Properties

contents → List<Content>
Required. The content of the conversation with the model that resulted in the expected output.
final
expectedContents → List<ContentsExample_ExpectedContent>
Required. The expected output for the given contents. To represent multi-step reasoning, this is a repeated field that contains the iterative steps of the expected output.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String