Context class final

Instance of a general context.

Constructors

Context({String name = '', String displayName = '', String etag = '', Map<String, String> labels = const {}, Timestamp? createTime, Timestamp? updateTime, List<String> parentContexts = const [], String schemaTitle = '', String schemaVersion = '', Struct? metadata, String description = ''})
Context.fromJson(Object? j)
factory

Properties

createTime → Timestamp?
Output only. Timestamp when this Context was created.
final
description → String
Description of the Context
final
displayName → String
User provided display name of the Context. May be up to 128 Unicode characters.
final
etag → String
An eTag used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens.
final
hashCode → int
The hash code for this object.
no setterinherited
labels → Map<String, String>
The labels with user-defined metadata to organize your Contexts.
final
metadata → Struct?
Properties of the Context. Top level metadata keys' heading and trailing spaces will be trimmed. The size of this field should not exceed 200KB.
final
name → String
Immutable. The resource name of the Context.
final
parentContexts → List<String>
Output only. A list of resource names of Contexts that are parents of this Context. A Context may have at most 10 parent_contexts.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemaTitle → String
The title of the schema describing the metadata.
final
schemaVersion → String
The version of the schema in schema_name to use.
final
updateTime → Timestamp?
Output only. Timestamp when this Context was last updated.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String