CopyModelRequest class final
Request message for
ModelService.CopyModel.
Constructors
- CopyModelRequest({String? modelId, String? parentModel, required String parent, required String sourceModel, EncryptionSpec? encryptionSpec, String customServiceAccount = ''})
- CopyModelRequest.fromJson(Object? j)
-
factory
Properties
- customServiceAccount → String
-
Optional. The user-provided custom service account to use to do the copy
model. If empty, Vertex AI Service
Agent
will be used to access resources needed to upload the model. This account
must belong to the destination project where the model is copied to,
i.e., the project specified in the
parentfield of this request and have the Vertex AI Service Agent role in the source project.final - encryptionSpec → EncryptionSpec?
-
Customer-managed encryption key options. If this is set,
then the Model copy will be encrypted with the provided encryption key.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- modelId → String?
-
Optional. Copy source_model into a new Model with this ID. The ID will
become the final component of the model resource name.
final
- parent → String
-
Required. The resource name of the Location into which to copy the Model.
Format:
projects/{project}/locations/{location}final - parentModel → String?
-
Optional. Specify this field to copy source_model into this existing
Model as a new version. Format:
projects/{project}/locations/{location}/models/{model}final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceModel → String
-
Required. The resource name of the Model to copy. That Model must be in the
same Project. Format:
projects/{project}/locations/{location}/models/{model}final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String