customServiceAccount property

String customServiceAccount
final

Optional. The user-provided custom service account to use to do the copy model. If empty, Vertex AI Service Agent will be used to access resources needed to upload the model. This account must belong to the destination project where the model is copied to, i.e., the project specified in the parent field of this request and have the Vertex AI Service Agent role in the source project.

Requires the user copying the Model to have the iam.serviceAccounts.actAs permission on this service account.

Implementation

final String customServiceAccount;