CorroborateContentRequest class final

Request message for CorroborateContent.

Constructors

CorroborateContentRequest({required String parent, Content? content, List<Fact> facts = const [], CorroborateContentRequest_Parameters? parameters})
CorroborateContentRequest.fromJson(Object? j)
factory

Properties

content → Content?
Optional. Input content to corroborate, only text format is supported for now.
final
facts → List<Fact>
Optional. Facts used to generate the text can also be used to corroborate the text.
final
hashCode → int
The hash code for this object.
no setterinherited
parameters → CorroborateContentRequest_Parameters?
Optional. Parameters that can be set to override default settings per request.
final
parent → String
Required. The resource name of the Location from which to corroborate text. The users must have permission to make a call in the project. Format: projects/{project}/locations/{location}.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String