CountTokensResponse class final

Response message for PredictionService.CountTokens.

Constructors

CountTokensResponse({int totalTokens = 0, int totalBillableCharacters = 0, List<ModalityTokenCount> promptTokensDetails = const []})
CountTokensResponse.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
promptTokensDetails → List<ModalityTokenCount>
Output only. List of modalities that were processed in the request input.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalBillableCharacters → int
The total number of billable characters counted across all instances from the request.
final
totalTokens → int
The total number of tokens counted across all instances from the request.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String