CreateDeploymentResourcePoolRequest class final

Request message for CreateDeploymentResourcePool method.

Constructors

CreateDeploymentResourcePoolRequest({required String parent, required DeploymentResourcePool? deploymentResourcePool, required String deploymentResourcePoolId})
CreateDeploymentResourcePoolRequest.fromJson(Object? j)
factory

Properties

deploymentResourcePool → DeploymentResourcePool?
Required. The DeploymentResourcePool to create.
final
deploymentResourcePoolId → String
Required. The ID to use for the DeploymentResourcePool, which will become the final component of the DeploymentResourcePool's resource name.
final
hashCode → int
The hash code for this object.
no setterinherited
parent → String
Required. The parent location resource where this DeploymentResourcePool will be created. Format: projects/{project}/locations/{location}
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String