CreateExampleStoreRequest class final

Request message for ExampleStoreService.CreateExampleStore.

Constructors

CreateExampleStoreRequest({required String parent, required ExampleStore? exampleStore})
CreateExampleStoreRequest.fromJson(Object? j)
factory

Properties

exampleStore → ExampleStore?
Required. The Example Store to be created.
final
hashCode → int
The hash code for this object.
no setterinherited
parent → String
Required. The resource name of the Location to create the ExampleStore in. Format: projects/{project}/locations/{location}
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String