CreateIndexRequest class final

Request message for IndexService.CreateIndex.

Constructors

CreateIndexRequest({required String parent, required Index? index})
CreateIndexRequest.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → Index?
Required. The Index to create.
final
parent → String
Required. The resource name of the Location to create the Index in. Format: projects/{project}/locations/{location}
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String