CreateMemoryRequest class final

Request message for MemoryBankService.CreateMemory.

Constructors

CreateMemoryRequest({required String parent, required Memory? memory, String memoryId = ''})
CreateMemoryRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
memory Memory?
Required. The Memory to be created.
final
memoryId String
Optional. The user defined ID to use for memory, which will become the final component of the memory resource name. If not provided, Vertex AI will generate a value for this ID.
final
parent String
Required. The resource name of the ReasoningEngine to create the Memory under. Format: projects/{project}/locations/{location}/reasoningEngines/{reasoning_engine}
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String