CreateOnlineEvaluatorRequest class final
Request message for CreateOnlineEvaluator.
Constructors
- CreateOnlineEvaluatorRequest({required String parent, required OnlineEvaluator? onlineEvaluator})
- CreateOnlineEvaluatorRequest.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onlineEvaluator → OnlineEvaluator?
-
Required. The OnlineEvaluator to create.
final
- parent → String
-
Required. The parent resource where the OnlineEvaluator will be created.
Format: projects/{project}/locations/{location}.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String