CreatePersistentResourceRequest class final

Request message for PersistentResourceService.CreatePersistentResource.

Constructors

CreatePersistentResourceRequest({required String parent, required PersistentResource? persistentResource, required String persistentResourceId})
CreatePersistentResourceRequest.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
parent → String
Required. The resource name of the Location to create the PersistentResource in. Format: projects/{project}/locations/{location}
final
persistentResource → PersistentResource?
Required. The PersistentResource to create.
final
persistentResourceId → String
Required. The ID to use for the PersistentResource, which become the final component of the PersistentResource's resource name.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String