CreatePipelineJobRequest class final

Request message for PipelineService.CreatePipelineJob.

Constructors

CreatePipelineJobRequest({required String parent, required PipelineJob? pipelineJob, String pipelineJobId = ''})
CreatePipelineJobRequest.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
parent → String
Required. The resource name of the Location to create the PipelineJob in. Format: projects/{project}/locations/{location}
final
pipelineJob → PipelineJob?
Required. The PipelineJob to create.
final
pipelineJobId → String
The ID to use for the PipelineJob, which will become the final component of the PipelineJob name. If not provided, an ID will be automatically generated.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String