CreateRagDataSchemaRequest class final

Request message for VertexRagDataService.CreateRagDataSchema.

Constructors

CreateRagDataSchemaRequest({required String parent, required RagDataSchema? ragDataSchema, String? ragDataSchemaId})
CreateRagDataSchemaRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
parent String
Required. The resource name of the RagCorpus to create the RagDataSchema in. Format: projects/{project}/locations/{location}/ragCorpora/{rag_corpus}
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
ragDataSchema RagDataSchema?
Required. The RagDataSchema to create.
final
ragDataSchemaId String?
Optional. The ID to use for the RagDataSchema, which will become the final component of the RagDataSchema's resource name if the user chooses to specify. Otherwise, RagDataSchema id will be generated by system.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String