ragDataSchemaId property

String? ragDataSchemaId
final

Optional. The ID to use for the RagDataSchema, which will become the final component of the RagDataSchema's resource name if the user chooses to specify. Otherwise, RagDataSchema id will be generated by system.

This value should be up to 63 characters, and valid characters are /0-9-/. The first character must be a letter, the last could be a letter or a number.

Implementation

final String? ragDataSchemaId;