parent property
Required. The parent resource where this metadata will be created.
Format:
projects/{project_number}/locations/{location_id}/ragCorpora/{rag_corpus}/ragFiles/{rag_file}
Implementation
final String parent;
Required. The parent resource where this metadata will be created.
Format:
projects/{project_number}/locations/{location_id}/ragCorpora/{rag_corpus}/ragFiles/{rag_file}
final String parent;