CreateSessionRequest class final

Request message for SessionService.CreateSession.

Constructors

CreateSessionRequest({required String parent, required Session? session, String sessionId = ''})
CreateSessionRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
parent String
Required. The resource name of the location to create the session in. Format: projects/{project}/locations/{location}/reasoningEngines/{reasoning_engine}
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
session Session?
Required. The session to create.
final
sessionId String
Optional. The user defined ID to use for session, which will become the final component of the session resource name. If not provided, Vertex AI will generate a value for this ID.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String