CreateTensorboardRunRequest class final

Request message for TensorboardService.CreateTensorboardRun.

Constructors

CreateTensorboardRunRequest({required String parent, required TensorboardRun? tensorboardRun, required String tensorboardRunId})
CreateTensorboardRunRequest.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
parent → String
Required. The resource name of the TensorboardExperiment to create the TensorboardRun in. Format: projects/{project}/locations/{location}/tensorboards/{tensorboard}/experiments/{experiment}
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tensorboardRun → TensorboardRun?
Required. The TensorboardRun to create.
final
tensorboardRunId → String
Required. The ID to use for the Tensorboard run, which becomes the final component of the Tensorboard run's resource name.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String