CustomCodeExecutionSpec class final

Specificies a metric that is populated by evaluating user-defined Python code.

Constructors

CustomCodeExecutionSpec({required String? evaluationFunction})
CustomCodeExecutionSpec.fromJson(Object? j)
factory

Properties

evaluationFunction String?
Required. Python function. Expected user to define the following function, e.g.: def evaluate(instance: dictstr, Any) -> float: Please include this function signature in the code snippet. Instance is the evaluation instance, any fields populated in the instance are available to the function as instancefield_name.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String