CustomJob class final

Represents a job that runs custom workloads such as a Docker container or a Python package. A CustomJob can have multiple worker pools and each worker pool can have its own machine and input spec. A CustomJob will be cleaned up once the job enters terminal state (failed or succeeded).

Constructors

CustomJob({String name = '', required String displayName, required CustomJobSpec? jobSpec, JobState state = JobState.$default, Timestamp? createTime, Timestamp? startTime, Timestamp? endTime, Timestamp? updateTime, Status? error, Map<String, String> labels = const {}, EncryptionSpec? encryptionSpec, Map<String, String> webAccessUris = const {}, bool satisfiesPzs = false, bool satisfiesPzi = false})
CustomJob.fromJson(Object? j)
factory

Properties

createTime → Timestamp?
Output only. Time when the CustomJob was created.
final
displayName → String
Required. The display name of the CustomJob. The name can be up to 128 characters long and can consist of any UTF-8 characters.
final
encryptionSpec → EncryptionSpec?
Customer-managed encryption key options for a CustomJob. If this is set, then all resources created by the CustomJob will be encrypted with the provided encryption key.
final
endTime → Timestamp?
Output only. Time when the CustomJob entered any of the following states: JOB_STATE_SUCCEEDED, JOB_STATE_FAILED, JOB_STATE_CANCELLED.
final
error → Status?
Output only. Only populated when job's state is JOB_STATE_FAILED or JOB_STATE_CANCELLED.
final
hashCode → int
The hash code for this object.
no setterinherited
jobSpec → CustomJobSpec?
Required. Job spec.
final
labels → Map<String, String>
The labels with user-defined metadata to organize CustomJobs.
final
name → String
Output only. Resource name of a CustomJob.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
satisfiesPzi → bool
Output only. Reserved for future use.
final
satisfiesPzs → bool
Output only. Reserved for future use.
final
startTime → Timestamp?
Output only. Time when the CustomJob for the first time entered the JOB_STATE_RUNNING state.
final
state → JobState
Output only. The detailed state of the job.
final
updateTime → Timestamp?
Output only. Time when the CustomJob was most recently updated.
final
webAccessUris → Map<String, String>
Output only. URIs for accessing interactive shells (one URI for each training node). Only available if job_spec.enable_web_access is true.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String