DataLabelingJob class final

DataLabelingJob is used to trigger a human labeling job on unlabeled data from the following Dataset:

Constructors

DataLabelingJob({String name = '', required String displayName, required List<String> datasets, Map<String, String> annotationLabels = const {}, required int labelerCount, required String instructionUri, required String inputsSchemaUri, required Value? inputs, JobState state = JobState.$default, int labelingProgress = 0, Money? currentSpend, Timestamp? createTime, Timestamp? updateTime, Status? error, Map<String, String> labels = const {}, List<String> specialistPools = const [], EncryptionSpec? encryptionSpec, ActiveLearningConfig? activeLearningConfig})
DataLabelingJob.fromJson(Object? j)
factory

Properties

activeLearningConfig → ActiveLearningConfig?
Parameters that configure the active learning pipeline. Active learning will label the data incrementally via several iterations. For every iteration, it will select a batch of data based on the sampling strategy.
final
annotationLabels → Map<String, String>
Labels to assign to annotations generated by this DataLabelingJob.
final
createTime → Timestamp?
Output only. Timestamp when this DataLabelingJob was created.
final
currentSpend → Money?
Output only. Estimated cost(in US dollars) that the DataLabelingJob has incurred to date.
final
datasets → List<String>
Required. Dataset resource names. Right now we only support labeling from a single Dataset. Format: projects/{project}/locations/{location}/datasets/{dataset}
final
displayName → String
Required. The user-defined name of the DataLabelingJob. The name can be up to 128 characters long and can consist of any UTF-8 characters. Display name of a DataLabelingJob.
final
encryptionSpec → EncryptionSpec?
Customer-managed encryption key spec for a DataLabelingJob. If set, this DataLabelingJob will be secured by this key.
final
error → Status?
Output only. DataLabelingJob errors. It is only populated when job's state is JOB_STATE_FAILED or JOB_STATE_CANCELLED.
final
hashCode → int
The hash code for this object.
no setterinherited
inputs → Value?
Required. Input config parameters for the DataLabelingJob.
final
inputsSchemaUri → String
Required. Points to a YAML file stored on Google Cloud Storage describing the config for a specific type of DataLabelingJob. The schema files that can be used here are found in the https://storage.googleapis.com/google-cloud-aiplatform bucket in the /schema/datalabelingjob/inputs/ folder.
final
instructionUri → String
Required. The Google Cloud Storage location of the instruction pdf. This pdf is shared with labelers, and provides detailed description on how to label DataItems in Datasets.
final
labelerCount → int
Required. Number of labelers to work on each DataItem.
final
labelingProgress → int
Output only. Current labeling job progress percentage scaled in interval 0, 100, indicating the percentage of DataItems that has been finished.
final
labels → Map<String, String>
The labels with user-defined metadata to organize your DataLabelingJobs.
final
name → String
Output only. Resource name of the DataLabelingJob.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
specialistPools → List<String>
The SpecialistPools' resource names associated with this job.
final
state → JobState
Output only. The detailed state of the job.
final
updateTime → Timestamp?
Output only. Timestamp when this DataLabelingJob was updated most recently.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String