maxReplicaCount property
Immutable. The maximum number of replicas that may be deployed on when the
traffic against it increases. If the requested value is too large, the
deployment will error, but if deployment succeeds then the ability to scale
to that many replicas is guaranteed (barring service outages). If traffic
increases beyond what its replicas at maximum may handle, a portion of the
traffic will be dropped. If this value is not provided, will use
min_replica_count
as the default value.
The value of this field impacts the charge against Vertex CPU and GPU quotas. Specifically, you will be charged for (max_replica_count * number of cores in the selected machine type) and (max_replica_count * number of GPUs per replica in the selected machine type).
Implementation
final int maxReplicaCount;