DeleteFeatureGroupRequest class final

Request message for FeatureRegistryService.DeleteFeatureGroup.

Constructors

DeleteFeatureGroupRequest({required String name, bool force = false})
DeleteFeatureGroupRequest.fromJson(Object? j)
factory

Properties

force → bool
If set to true, any Features under this FeatureGroup will also be deleted. (Otherwise, the request will only work if the FeatureGroup has no Features.)
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
Required. The name of the FeatureGroup to be deleted. Format: projects/{project}/locations/{location}/featureGroups/{feature_group}
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String