DeleteFeatureValuesResponse class final

Response message for FeaturestoreService.DeleteFeatureValues.

Properties

hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectEntity DeleteFeatureValuesResponse_SelectEntity?
Response for request specifying the entities to delete
final
selectTimeRangeAndFeature DeleteFeatureValuesResponse_SelectTimeRangeAndFeature?
Response for request specifying time range and feature
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String