DeleteFeaturestoreRequest class final

Request message for FeaturestoreService.DeleteFeaturestore.

Constructors

DeleteFeaturestoreRequest({required String name, bool force = false})
DeleteFeaturestoreRequest.fromJson(Object? j)
factory

Properties

force → bool
If set to true, any EntityTypes and Features for this Featurestore will also be deleted. (Otherwise, the request will only work if the Featurestore has no EntityTypes.)
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
Required. The name of the Featurestore to be deleted. Format: projects/{project}/locations/{location}/featurestores/{featurestore}
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String