DeleteRagCorpusRequest class final

Request message for VertexRagDataService.DeleteRagCorpus.

Constructors

DeleteRagCorpusRequest({required String name, bool force = false, bool forceDelete = false})
DeleteRagCorpusRequest.fromJson(Object? j)
factory

Properties

force → bool
Optional. If set to true, any RagFiles in this RagCorpus will also be deleted. Otherwise, the request will only work if the RagCorpus has no RagFiles.
final
forceDelete → bool
Optional. If set to true, any errors generated by external vector database during the deletion will be ignored. The default value is false.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
Required. The name of the RagCorpus resource to be deleted. Format: projects/{project}/locations/{location}/ragCorpora/{rag_corpus}
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String