DeleteRagFileRequest class final

Request message for VertexRagDataService.DeleteRagFile.

Constructors

DeleteRagFileRequest({required String name, bool forceDelete = false})
DeleteRagFileRequest.fromJson(Object? j)
factory

Properties

forceDelete → bool
Optional. If set to true, any errors generated by external vector database during the deletion will be ignored. The default value is false.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
Required. The name of the RagFile resource to be deleted. Format: projects/{project}/locations/{location}/ragCorpora/{rag_corpus}/ragFiles/{rag_file}
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String