DeleteReasoningEngineRequest class final

Request message for ReasoningEngineService.DeleteReasoningEngine.

Constructors

DeleteReasoningEngineRequest({required String name, bool force = false})
DeleteReasoningEngineRequest.fromJson(Object? j)
factory

Properties

force → bool
Optional. If set to true, child resources of this reasoning engine will also be deleted. Otherwise, the request will fail with FAILED_PRECONDITION error when the reasoning engine has undeleted child resources.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
Required. The name of the ReasoningEngine resource to be deleted. Format: projects/{project}/locations/{location}/reasoningEngines/{reasoning_engine}
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String