DeployPublisherModelOperationMetadata class final

Runtime operation information for ModelGardenService.DeployPublisherModel.

Constructors

DeployPublisherModelOperationMetadata({GenericOperationMetadata? genericMetadata, String publisherModel = '', String destination = '', int projectNumber = 0})
DeployPublisherModelOperationMetadata.fromJson(Object? j)
factory

Properties

destination → String
Output only. The resource name of the Location to deploy the model in. Format: projects/{project}/locations/{location}
final
genericMetadata → GenericOperationMetadata?
The operation generic information.
final
hashCode → int
The hash code for this object.
no setterinherited
projectNumber → int
Output only. The project number where the deploy model request is sent.
final
publisherModel → String
Output only. The name of the PublisherModel resource. Format: publishers/{publisher}/models/{publisher_model}@{version_id}, or publishers/hf-{hugging-face-author}/models/{hugging-face-model-name}@001
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String