DeployRequest class final

Request message for ModelGardenService.Deploy.

Constructors

DeployRequest({String? publisherModelName, String? huggingFaceModelId, DeployRequest_CustomModel? customModel, required String destination, DeployRequest_ModelConfig? modelConfig, DeployRequest_EndpointConfig? endpointConfig, DeployRequest_DeployConfig? deployConfig})
DeployRequest.fromJson(Object? j)
factory

Properties

customModel → DeployRequest_CustomModel?
The custom model to deploy from a Google Cloud Storage URI.
final
deployConfig → DeployRequest_DeployConfig?
Optional. The deploy config to use for the deployment. If not specified, the default deploy config will be used.
final
destination → String
Required. The resource name of the Location to deploy the model in. Format: projects/{project}/locations/{location}
final
endpointConfig → DeployRequest_EndpointConfig?
Optional. The endpoint config to use for the deployment. If not specified, the default endpoint config will be used.
final
hashCode → int
The hash code for this object.
no setterinherited
huggingFaceModelId → String?
The Hugging Face model to deploy. Format: Hugging Face model ID like google/gemma-2-2b-it.
final
modelConfig → DeployRequest_ModelConfig?
Optional. The model config to use for the deployment. If not specified, the default model config will be used.
final
publisherModelName → String?
The Model Garden model to deploy. Format: publishers/{publisher}/models/{publisher_model}@{version_id}, or publishers/hf-{hugging-face-author}/models/{hugging-face-model-name}@001.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String