DeployRequest_DeployConfig class final

The deploy config to use for the deployment.

Constructors

DeployRequest_DeployConfig({DedicatedResources? dedicatedResources, bool fastTryoutEnabled = false, Map<String, String> systemLabels = const {}})
DeployRequest_DeployConfig.fromJson(Object? j)
factory

Properties

dedicatedResources → DedicatedResources?
Optional. The dedicated resources to use for the endpoint. If not set, the default resources will be used.
final
fastTryoutEnabled → bool
Optional. If true, enable the QMT fast tryout feature for this model if possible.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
systemLabels → Map<String, String>
Optional. System labels for Model Garden deployments. These labels are managed by Google and for tracking purposes only.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String