DeployedIndexAuthConfig_AuthProvider class final

Configuration for an authentication provider, including support for JSON Web Token (JWT).

Constructors

DeployedIndexAuthConfig_AuthProvider({List<String> audiences = const [], List<String> allowedIssuers = const []})
DeployedIndexAuthConfig_AuthProvider.fromJson(Object? j)
factory

Properties

allowedIssuers → List<String>
A list of allowed JWT issuers. Each entry must be a valid Google service account, in the following format:
final
audiences → List<String>
The list of JWT audiences. that are allowed to access. A JWT containing any of these audiences will be accepted.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String