DeployedIndexRef class final

Points to a DeployedIndex.

Constructors

DeployedIndexRef({String indexEndpoint = '', String deployedIndexId = '', String displayName = ''})
DeployedIndexRef.fromJson(Object? j)
factory

Properties

deployedIndexId → String
Immutable. The ID of the DeployedIndex in the above IndexEndpoint.
final
displayName → String
Output only. The display name of the DeployedIndex.
final
hashCode → int
The hash code for this object.
no setterinherited
indexEndpoint → String
Immutable. A resource name of the IndexEndpoint.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String