DeployedModel_Status class final

Runtime status of the deployed model.

Constructors

DeployedModel_Status({String message = '', Timestamp? lastUpdateTime, int availableReplicaCount = 0})
DeployedModel_Status.fromJson(Object? j)
factory

Properties

availableReplicaCount → int
Output only. The number of available replicas of the deployed model.
final
hashCode → int
The hash code for this object.
no setterinherited
lastUpdateTime → Timestamp?
Output only. The time at which the status was last updated.
final
message → String
Output only. The latest deployed model's status message (if any).
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String