DeploymentResourcePoolService class final

A service that manages the DeploymentResourcePool resource.

Implementers

Constructors

DeploymentResourcePoolService({required Client client, Uri? endPoint, String? gcclVersion})
Creates a DeploymentResourcePoolService using client for transport.
DeploymentResourcePoolService.fromApiKey([String? apiKey])
Creates a DeploymentResourcePoolService that does authentication through an API key.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancelOperation(CancelOperationRequest request) → Future<void>
Provides the Operations service functionality in this service.
close() → void
Closes the client and cleans up any resources associated with it.
createDeploymentResourcePool(CreateDeploymentResourcePoolRequest request) → Future<Operation<DeploymentResourcePool, CreateDeploymentResourcePoolOperationMetadata>>
Create a DeploymentResourcePool.
deleteDeploymentResourcePool(DeleteDeploymentResourcePoolRequest request) → Future<Operation<Empty, DeleteOperationMetadata>>
Delete a DeploymentResourcePool.
deleteOperation(DeleteOperationRequest request) → Future<void>
Provides the Operations service functionality in this service.
getDeploymentResourcePool(GetDeploymentResourcePoolRequest request) → Future<DeploymentResourcePool>
Get a DeploymentResourcePool.
getIamPolicy(GetIamPolicyRequest request) → Future<Policy>
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
getLocation(GetLocationRequest request) → Future<Location>
Gets information about a location.
getOperation<T extends ProtoMessage, S extends ProtoMessage>(Operation<T, S> request) → Future<Operation<T, S>>
Provides the Operations service functionality in this service.
listDeploymentResourcePools(ListDeploymentResourcePoolsRequest request) → Future<ListDeploymentResourcePoolsResponse>
List DeploymentResourcePools in a location.
listLocations(ListLocationsRequest request) → Future<ListLocationsResponse>
Lists information about the supported locations for this service.
listOperations(ListOperationsRequest request) → Future<ListOperationsResponse>
Provides the Operations service functionality in this service.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryDeployedModels(QueryDeployedModelsRequest request) → Future<QueryDeployedModelsResponse>
List DeployedModels that have been deployed on this DeploymentResourcePool.
setIamPolicy(SetIamPolicyRequest request) → Future<Policy>
Sets the access control policy on the specified resource. Replaces any existing policy.
testIamPermissions(TestIamPermissionsRequest request) → Future<TestIamPermissionsResponse>
Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a NOT_FOUND error.
toString() → String
A string representation of this object.
inherited
updateDeploymentResourcePool(UpdateDeploymentResourcePoolRequest request) → Future<Operation<DeploymentResourcePool, UpdateDeploymentResourcePoolOperationMetadata>>
Update a DeploymentResourcePool.
waitOperation(WaitOperationRequest request) → Future<Operation<ProtoMessage, ProtoMessage>>
Provides the Operations service functionality in this service.

Operators

operator ==(Object other) → bool
The equality operator.
inherited