DirectRawPredictRequest class final

Request message for PredictionService.DirectRawPredict.

Constructors

DirectRawPredictRequest({required String endpoint, String methodName = '', Uint8List? input})
DirectRawPredictRequest.fromJson(Object? j)
factory

Properties

endpoint → String
Required. The name of the Endpoint requested to serve the prediction. Format: projects/{project}/locations/{location}/endpoints/{endpoint}
final
hashCode → int
The hash code for this object.
no setterinherited
input → Uint8List
The prediction input.
final
methodName → String
Fully qualified name of the API method being invoked to perform predictions.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String