DynamicRetrievalConfig class final

Describes the options to customize dynamic retrieval.

Constructors

DynamicRetrievalConfig({DynamicRetrievalConfig_Mode mode = DynamicRetrievalConfig_Mode.$default, double? dynamicThreshold})
DynamicRetrievalConfig.fromJson(Object? j)
factory

Properties

dynamicThreshold → double?
Optional. The threshold to be used in dynamic retrieval. If not set, a system default value is used.
final
hashCode → int
The hash code for this object.
no setterinherited
mode → DynamicRetrievalConfig_Mode
The mode of the predictor to be used in dynamic retrieval.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String