DynamicRetrievalConfig_Mode class final

The mode of the predictor to be used in dynamic retrieval.

Properties

hashCode → int
The hash code for this object.
no setterinherited
isNotDefault → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object?
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$default → const DynamicRetrievalConfig_Mode
The default value for DynamicRetrievalConfig_Mode.
modeDynamic → const DynamicRetrievalConfig_Mode
Run retrieval only when system decides it is necessary.
modeUnspecified → const DynamicRetrievalConfig_Mode
Always trigger retrieval.