autoTruncate property
Optional. Whether to silently truncate the input content if it's longer than the maximum sequence length.
Only applicable to text-only embedding models.
Implementation
final bool? autoTruncate;
Optional. Whether to silently truncate the input content if it's longer than the maximum sequence length.
Only applicable to text-only embedding models.
final bool? autoTruncate;