EmbedContentResponse class final

Response message for PredictionService.EmbedContent.

Constructors

EmbedContentResponse({EmbedContentResponse_Embedding? embedding, UsageMetadata? usageMetadata, bool truncated = false})
EmbedContentResponse.fromJson(Object? j)
factory

Properties

embedding → EmbedContentResponse_Embedding?
The embedding generated from the input content.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
truncated → bool
Whether the input content was truncated before generating the embedding.
final
usageMetadata → UsageMetadata?
Usage metadata about the response(s).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String