Endpoint class final

Models are deployed into it, and afterwards Endpoint is called to obtain predictions and explanations.

Constructors

Endpoint({String name = '', required String displayName, String description = '', List<DeployedModel> deployedModels = const [], Map<String, int> trafficSplit = const {}, String etag = '', Map<String, String> labels = const {}, Timestamp? createTime, Timestamp? updateTime, EncryptionSpec? encryptionSpec, String network = '', bool enablePrivateServiceConnect = false, PrivateServiceConnectConfig? privateServiceConnectConfig, String modelDeploymentMonitoringJob = '', PredictRequestResponseLoggingConfig? predictRequestResponseLoggingConfig, bool dedicatedEndpointEnabled = false, String dedicatedEndpointDns = '', ClientConnectionConfig? clientConnectionConfig, bool satisfiesPzs = false, bool satisfiesPzi = false, GenAiAdvancedFeaturesConfig? genAiAdvancedFeaturesConfig, bool privateModelServerEnabled = false})
Endpoint.fromJson(Object? j)
factory

Properties

clientConnectionConfig → ClientConnectionConfig?
Configurations that are applied to the endpoint for online prediction.
final
createTime → Timestamp?
Output only. Timestamp when this Endpoint was created.
final
dedicatedEndpointDns → String
Output only. DNS of the dedicated endpoint. Will only be populated if dedicated_endpoint_enabled is true. Depending on the features enabled, uid might be a random number or a string. For example, if fast_tryout is enabled, uid will be fasttryout. Format: https://{endpoint_id}.{region}-{uid}.prediction.vertexai.goog.
final
dedicatedEndpointEnabled → bool
If true, the endpoint will be exposed through a dedicated DNS Endpoint.dedicated_endpoint_dns. Your request to the dedicated DNS will be isolated from other users' traffic and will have better performance and reliability. Note: Once you enabled dedicated endpoint, you won't be able to send request to the shared DNS {region}-aiplatform.googleapis.com. The limitation will be removed soon.
final
deployedModels → List<DeployedModel>
Output only. The models deployed in this Endpoint. To add or remove DeployedModels use EndpointService.DeployModel and EndpointService.UndeployModel respectively.
final
description → String
The description of the Endpoint.
final
displayName → String
Required. The display name of the Endpoint. The name can be up to 128 characters long and can consist of any UTF-8 characters.
final
enablePrivateServiceConnect → bool
Deprecated: If true, expose the Endpoint via private service connect.
final
encryptionSpec → EncryptionSpec?
Customer-managed encryption key spec for an Endpoint. If set, this Endpoint and all sub-resources of this Endpoint will be secured by this key.
final
etag → String
Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens.
final
genAiAdvancedFeaturesConfig → GenAiAdvancedFeaturesConfig?
Optional. Configuration for GenAiAdvancedFeatures. If the endpoint is serving GenAI models, advanced features like native RAG integration can be configured. Currently, only Model Garden models are supported.
final
hashCode → int
The hash code for this object.
no setterinherited
labels → Map<String, String>
The labels with user-defined metadata to organize your Endpoints.
final
modelDeploymentMonitoringJob → String
Output only. Resource name of the Model Monitoring job associated with this Endpoint if monitoring is enabled by JobService.CreateModelDeploymentMonitoringJob. Format: projects/{project}/locations/{location}/modelDeploymentMonitoringJobs/{model_deployment_monitoring_job}
final
name → String
Output only. The resource name of the Endpoint.
final
network → String
Optional. The full name of the Google Compute Engine network to which the Endpoint should be peered.
final
predictRequestResponseLoggingConfig → PredictRequestResponseLoggingConfig?
Configures the request-response logging for online prediction.
final
privateModelServerEnabled → bool
If true, the model server will be isolated from the external internet.
final
privateServiceConnectConfig → PrivateServiceConnectConfig?
Optional. Configuration for private service connect.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
satisfiesPzi → bool
Output only. Reserved for future use.
final
satisfiesPzs → bool
Output only. Reserved for future use.
final
trafficSplit → Map<String, int>
A map from a DeployedModel's ID to the percentage of this Endpoint's traffic that should be forwarded to that DeployedModel.
final
updateTime → Timestamp?
Output only. Timestamp when this Endpoint was last updated.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String