ErrorAnalysisAnnotation class final

Model error analysis for each annotation.

Constructors

ErrorAnalysisAnnotation({List<ErrorAnalysisAnnotation_AttributedItem> attributedItems = const [], ErrorAnalysisAnnotation_QueryType queryType = ErrorAnalysisAnnotation_QueryType.$default, double outlierScore = 0, double outlierThreshold = 0})
ErrorAnalysisAnnotation.fromJson(Object? j)
factory

Properties

attributedItems → List<ErrorAnalysisAnnotation_AttributedItem>
Attributed items for a given annotation, typically representing neighbors from the training sets constrained by the query type.
final
hashCode → int
The hash code for this object.
no setterinherited
outlierScore → double
The outlier score of this annotated item. Usually defined as the min of all distances from attributed items.
final
outlierThreshold → double
The threshold used to determine if this annotation is an outlier or not.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
queryType → ErrorAnalysisAnnotation_QueryType
The query type used for finding the attributed items.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String