ErrorAnalysisAnnotation_AttributedItem class final

Attributed items for a given annotation, typically representing neighbors from the training sets constrained by the query type.

Constructors

ErrorAnalysisAnnotation_AttributedItem({String annotationResourceName = '', double distance = 0})
ErrorAnalysisAnnotation_AttributedItem.fromJson(Object? j)
factory

Properties

annotationResourceName → String
The unique ID for each annotation. Used by FE to allocate the annotation in DB.
final
distance → double
The distance of this item to the annotation.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String