EvaluateDatasetRequest class final

Request message for EvaluationService.EvaluateDataset.

Constructors

EvaluateDatasetRequest({required String location, required EvaluationDataset? dataset, required List<Metric> metrics, required OutputConfig? outputConfig, AutoraterConfig? autoraterConfig})
EvaluateDatasetRequest.fromJson(Object? j)
factory

Properties

autoraterConfig → AutoraterConfig?
Optional. Autorater config used for evaluation. Currently only publisher Gemini models are supported. Format: projects/{PROJECT}/locations/{LOCATION}/publishers/google/models/{MODEL}.
final
dataset → EvaluationDataset?
Required. The dataset used for evaluation.
final
hashCode → int
The hash code for this object.
no setterinherited
location → String
Required. The resource name of the Location to evaluate the dataset. Format: projects/{project}/locations/{location}
final
metrics → List<Metric>
Required. The metrics used for evaluation.
final
outputConfig → OutputConfig?
Required. Config for evaluation output.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String