EvaluateDatasetRun class final

Evaluate Dataset Run Result for Tuning Job.

Constructors

EvaluateDatasetRun({String operationName = '', String evaluationRun = '', String checkpointId = '', EvaluateDatasetResponse? evaluateDatasetResponse, Status? error})
EvaluateDatasetRun.fromJson(Object? j)
factory

Properties

checkpointId → String
Output only. The checkpoint id used in the evaluation run. Only populated when evaluating checkpoints.
final
error → Status?
Output only. The error of the evaluation run if any.
final
evaluateDatasetResponse → EvaluateDatasetResponse?
Output only. Results for EvaluationService.
final
evaluationRun → String
Output only. The resource name of the evaluation run. Format: projects/{project}/locations/{location}/evaluationRuns/{evaluation_run_id}.
final
hashCode → int
The hash code for this object.
no setterinherited
operationName → String
Output only. The operation ID of the evaluation run. Format: projects/{project}/locations/{location}/operations/{operation_id}.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String