EvaluateInstancesResponse class final
Response message for EvaluationService.EvaluateInstances.
Constructors
-
EvaluateInstancesResponse({ExactMatchResults? exactMatchResults, BleuResults? bleuResults, RougeResults? rougeResults, FluencyResult? fluencyResult, CoherenceResult? coherenceResult, SafetyResult? safetyResult, GroundednessResult? groundednessResult, FulfillmentResult? fulfillmentResult, SummarizationQualityResult? summarizationQualityResult, PairwiseSummarizationQualityResult? pairwiseSummarizationQualityResult, SummarizationHelpfulnessResult? summarizationHelpfulnessResult, SummarizationVerbosityResult? summarizationVerbosityResult, QuestionAnsweringQualityResult? questionAnsweringQualityResult, PairwiseQuestionAnsweringQualityResult? pairwiseQuestionAnsweringQualityResult, QuestionAnsweringRelevanceResult? questionAnsweringRelevanceResult, QuestionAnsweringHelpfulnessResult? questionAnsweringHelpfulnessResult, QuestionAnsweringCorrectnessResult? questionAnsweringCorrectnessResult, PointwiseMetricResult? pointwiseMetricResult, PairwiseMetricResult? pairwiseMetricResult, ToolCallValidResults? toolCallValidResults, ToolNameMatchResults? toolNameMatchResults, ToolParameterKeyMatchResults? toolParameterKeyMatchResults, ToolParameterKvmatchResults? toolParameterKvMatchResults, CometResult? cometResult, MetricxResult? metricxResult, TrajectoryExactMatchResults? trajectoryExactMatchResults, TrajectoryInOrderMatchResults? trajectoryInOrderMatchResults, TrajectoryAnyOrderMatchResults? trajectoryAnyOrderMatchResults, TrajectoryPrecisionResults? trajectoryPrecisionResults, TrajectoryRecallResults? trajectoryRecallResults, TrajectorySingleToolUseResults? trajectorySingleToolUseResults, RubricBasedInstructionFollowingResult? rubricBasedInstructionFollowingResult, List<
MetricResult> metricResults = const []}) - EvaluateInstancesResponse.fromJson(Object? j)
-
factory
Properties
- bleuResults → BleuResults?
-
Results for bleu metric.
final
- coherenceResult → CoherenceResult?
-
Result for coherence metric.
final
- cometResult → CometResult?
-
Translation metrics.
Result for Comet metric.
final
- exactMatchResults → ExactMatchResults?
-
Auto metric evaluation results.
Results for exact match metric.
final
- fluencyResult → FluencyResult?
-
LLM-based metric evaluation result.
General text generation metrics, applicable to other categories.
Result for fluency metric.
final
- fulfillmentResult → FulfillmentResult?
-
Result for fulfillment metric.
final
- groundednessResult → GroundednessResult?
-
Result for groundedness metric.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
metricResults
→ List<
MetricResult> -
Metric results for each instance.
The order of the metric results is guaranteed to be the same as the order
of the instances in the request.
final
- metricxResult → MetricxResult?
-
Result for Metricx metric.
final
- pairwiseMetricResult → PairwiseMetricResult?
-
Result for pairwise metric.
final
- pairwiseQuestionAnsweringQualityResult → PairwiseQuestionAnsweringQualityResult?
-
Result for pairwise question answering quality metric.
final
- pairwiseSummarizationQualityResult → PairwiseSummarizationQualityResult?
-
Result for pairwise summarization quality metric.
final
- pointwiseMetricResult → PointwiseMetricResult?
-
Generic metrics.
Result for pointwise metric.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - questionAnsweringCorrectnessResult → QuestionAnsweringCorrectnessResult?
-
Result for question answering correctness metric.
final
- questionAnsweringHelpfulnessResult → QuestionAnsweringHelpfulnessResult?
-
Result for question answering helpfulness metric.
final
- questionAnsweringQualityResult → QuestionAnsweringQualityResult?
-
Question answering only metrics.
Result for question answering quality metric.
final
- questionAnsweringRelevanceResult → QuestionAnsweringRelevanceResult?
-
Result for question answering relevance metric.
final
- rougeResults → RougeResults?
-
Results for rouge metric.
final
- rubricBasedInstructionFollowingResult → RubricBasedInstructionFollowingResult?
-
Result for rubric based instruction following metric.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- safetyResult → SafetyResult?
-
Result for safety metric.
final
- summarizationHelpfulnessResult → SummarizationHelpfulnessResult?
-
Result for summarization helpfulness metric.
final
- summarizationQualityResult → SummarizationQualityResult?
-
Summarization only metrics.
Result for summarization quality metric.
final
- summarizationVerbosityResult → SummarizationVerbosityResult?
-
Result for summarization verbosity metric.
final
- toolCallValidResults → ToolCallValidResults?
-
Tool call metrics.
Results for tool call valid metric.
final
- toolNameMatchResults → ToolNameMatchResults?
-
Results for tool name match metric.
final
- toolParameterKeyMatchResults → ToolParameterKeyMatchResults?
-
Results for tool parameter key match metric.
final
- toolParameterKvMatchResults → ToolParameterKvmatchResults?
-
Results for tool parameter key value match metric.
final
- trajectoryAnyOrderMatchResults → TrajectoryAnyOrderMatchResults?
-
Result for trajectory any order match metric.
final
- trajectoryExactMatchResults → TrajectoryExactMatchResults?
-
Result for trajectory exact match metric.
final
- trajectoryInOrderMatchResults → TrajectoryInOrderMatchResults?
-
Result for trajectory in order match metric.
final
- trajectoryPrecisionResults → TrajectoryPrecisionResults?
-
Result for trajectory precision metric.
final
- trajectoryRecallResults → TrajectoryRecallResults?
-
Results for trajectory recall metric.
final
- trajectorySingleToolUseResults → TrajectorySingleToolUseResults?
-
Results for trajectory single tool use metric.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String