EvaluatedAnnotation class final

True positive, false positive, or false negative.

EvaluatedAnnotation is only available under ModelEvaluationSlice with slice of annotationSpec dimension.

Constructors

EvaluatedAnnotation({EvaluatedAnnotation_EvaluatedAnnotationType type = EvaluatedAnnotation_EvaluatedAnnotationType.$default, List<Value> predictions = const [], List<Value> groundTruths = const [], Value? dataItemPayload, String evaluatedDataItemViewId = '', List<EvaluatedAnnotationExplanation> explanations = const [], List<ErrorAnalysisAnnotation> errorAnalysisAnnotations = const []})
EvaluatedAnnotation.fromJson(Object? j)
factory

Properties

dataItemPayload → Value?
Output only. The data item payload that the Model predicted this EvaluatedAnnotation on.
final
errorAnalysisAnnotations → List<ErrorAnalysisAnnotation>
Annotations of model error analysis results.
final
evaluatedDataItemViewId → String
Output only. ID of the EvaluatedDataItemView under the same ancestor ModelEvaluation. The EvaluatedDataItemView consists of all ground truths and predictions on data_item_payload.
final
explanations → List<EvaluatedAnnotationExplanation>
Explanations of predictions. Each element of the explanations indicates the explanation for one explanation Method.
final
groundTruths → List<Value>
Output only. The ground truth Annotations, i.e. the Annotations that exist in the test data the Model is evaluated on.
final
hashCode → int
The hash code for this object.
no setterinherited
predictions → List<Value>
Output only. The model predicted annotations.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → EvaluatedAnnotation_EvaluatedAnnotationType
Output only. Type of the EvaluatedAnnotation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String