EvaluationConfig class final

Evaluation Config for Tuning Job.

Inheritance
  • Object
  • ProtoMessage
  • EvaluationConfig

Constructors

EvaluationConfig({required List<Metric> metrics, required OutputConfig? outputConfig, AutoraterConfig? autoraterConfig, GenerationConfig? inferenceGenerationConfig})
EvaluationConfig.fromJson(Object? j)
factory

Properties

autoraterConfig AutoraterConfig?
Optional. Autorater config for evaluation.
final
hashCode int
The hash code for this object.
no setterinherited
inferenceGenerationConfig GenerationConfig?
Optional. Configuration options for inference generation and outputs. If not set, default generation parameters are used.
final
metrics List<Metric>
Required. The metrics used for evaluation.
final
outputConfig OutputConfig?
Required. Config for evaluation output.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String