EvaluationInstance class final

A single instance to be evaluated. Instances are used to specify the input data for evaluation, from simple string comparisons to complex, multi-turn model evaluations

Properties

agentData EvaluationInstance_DeprecatedAgentData?
Optional. Deprecated: Use agent_eval_data instead. Data used for agent evaluation.
final
agentEvalData AgentData?
Optional. Data used for agent evaluation.
final
hashCode int
The hash code for this object.
no setterinherited
otherData EvaluationInstance_MapInstance?
Optional. Other data used to populate placeholders based on their key. If a key conflicts with a field in the EvaluationInstance (e.g. prompt), the value of the field will take precedence over the value in other_data.
final
prompt EvaluationInstance_InstanceData?
Optional. Data used to populate placeholder prompt in a metric prompt template.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
reference EvaluationInstance_InstanceData?
Optional. Data used to populate placeholder reference in a metric prompt template.
final
response EvaluationInstance_InstanceData?
Optional. Data used to populate placeholder response in a metric prompt template.
final
rubricGroups Map<String, RubricGroup>
Optional. Named groups of rubrics associated with the prompt. This is used for rubric-based evaluations where rubrics can be referenced by a key. The key could represent versions, associated metrics, etc.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String