otherData property

Optional. Other data used to populate placeholders based on their key. If a key conflicts with a field in the EvaluationInstance (e.g. prompt), the value of the field will take precedence over the value in other_data.

Implementation

final EvaluationInstance_MapInstance? otherData;