EvaluationInstance_DeprecatedAgentConfig class final

Deprecated: Use google.cloud.aiplatform.master.AgentConfig in agent_eval_data instead. Configuration for an Agent.

Constructors

EvaluationInstance_DeprecatedAgentConfig({String? toolsText, EvaluationInstance_DeprecatedAgentConfig_Tools? tools, String agentId = '', String agentType = '', String description = '', List<String> subAgents = const [], EvaluationInstance_InstanceData? developerInstruction})
EvaluationInstance_DeprecatedAgentConfig.fromJson(Object? j)
factory

Properties

agentId → String
Optional. Unique identifier of the agent. This ID is used to refer to this agent, e.g., in AgentEvent.author, or in the sub_agents field. It must be unique within the agents map.
final
agentType → String
Optional. The type or class of the agent (e.g., "LlmAgent", "RouterAgent", "ToolUseAgent"). Useful for the autorater to understand the expected behavior of the agent.
final
description → String
Optional. A high-level description of the agent's role and responsibilities. Critical for evaluating if the agent is routing tasks correctly.
final
developerInstruction → EvaluationInstance_InstanceData?
Optional. Contains instructions from the developer for the agent. Can be static or a dynamic prompt template used with the AgentEvent.state_delta field.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subAgents → List<String>
Optional. The list of valid agent IDs (names) that this agent can delegate to. This defines the directed edges in the agent system graph topology.
final
tools → EvaluationInstance_DeprecatedAgentConfig_Tools?
List of tools.
final
toolsText → String?
A JSON string containing a list of tools available to an agent with info such as name, description, parameters and required parameters.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String