EvaluationInstance_DeprecatedAgentData_Events class final
Represents a list of events for an agent.
Constructors
-
EvaluationInstance_DeprecatedAgentData_Events({List<
Content> event = const []}) - EvaluationInstance_DeprecatedAgentData_Events.fromJson(Object? j)
-
factory
Properties
-
event
→ List<
Content> -
Optional. A list of events.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String