EvaluationInstance_InstanceData class final
Instance data used to populate placeholders in a metric prompt template.
Constructors
- EvaluationInstance_InstanceData({String? text, EvaluationInstance_InstanceData_Contents? contents})
- EvaluationInstance_InstanceData.fromJson(Object? j)
-
factory
Properties
- contents → EvaluationInstance_InstanceData_Contents?
-
List of Gemini content data.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String?
-
Text data.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String