EvaluationInstance_MapInstance class final
Instance data specified as a map.
Constructors
-
EvaluationInstance_MapInstance({Map<
String, EvaluationInstance_InstanceData> mapInstance = const {}}) - EvaluationInstance_MapInstance.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
mapInstance
→ Map<
String, EvaluationInstance_InstanceData> -
Optional. Map of instance data.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String