EvaluationParserConfig_CustomCodeParserConfig class final

Configuration for parsing the LLM response using custom code.

Properties

hashCode int
The hash code for this object.
no setterinherited
parsingFunction String?
Required. Python function for parsing results. The function should be defined within this string.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String