Event class final

An edge describing the relationship between an Artifact and an Execution in a lineage graph.

Constructors

Event({required String artifact, String execution = '', Timestamp? eventTime, required Event_Type type, Map<String, String> labels = const {}})
Event.fromJson(Object? j)
factory

Properties

artifact → String
Required. The relative resource name of the Artifact in the Event.
final
eventTime → Timestamp?
Output only. Time the Event occurred.
final
execution → String
Output only. The relative resource name of the Execution in the Event.
final
hashCode → int
The hash code for this object.
no setterinherited
labels → Map<String, String>
The labels with user-defined metadata to annotate Events.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → Event_Type
Required. The type of the Event.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String