Example class final

A single example to upload or read from the Example Store.

Constructors

Example({StoredContentsExample? storedContentsExample, String displayName = '', String exampleId = '', Timestamp? createTime})
Example.fromJson(Object? j)
factory

Properties

createTime → Timestamp?
Output only. Timestamp when this Example was created.
final
displayName → String
Optional. The display name for Example.
final
exampleId → String
Optional. Immutable. Unique identifier of an example. If not specified when upserting new examples, the example_id will be generated.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storedContentsExample → StoredContentsExample?
An example of chat history and its expected outcome to be used with GenerateContent.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String