ExampleStore class final

Represents an executable service to manage and retrieve examples.

Constructors

ExampleStore({String name = '', required String displayName, String description = '', Timestamp? createTime, Timestamp? updateTime, required ExampleStoreConfig? exampleStoreConfig})
ExampleStore.fromJson(Object? j)
factory

Properties

createTime → Timestamp?
Output only. Timestamp when this ExampleStore was created.
final
description → String
Optional. Description of the ExampleStore.
final
displayName → String
Required. Display name of the ExampleStore.
final
exampleStoreConfig → ExampleStoreConfig?
Required. Example Store config.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
Identifier. The resource name of the ExampleStore. This is a unique identifier. Format: projects/{project}/locations/{location}/exampleStores/{example_store}
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateTime → Timestamp?
Output only. Timestamp when this ExampleStore was most recently updated.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String