ExamplesOverride class final

Overrides for example-based explanations.

Constructors

ExamplesOverride({int neighborCount = 0, int crowdingCount = 0, List<ExamplesRestrictionsNamespace> restrictions = const [], bool returnEmbeddings = false, ExamplesOverride_DataFormat dataFormat = ExamplesOverride_DataFormat.$default})
ExamplesOverride.fromJson(Object? j)
factory

Properties

crowdingCount → int
The number of neighbors to return that have the same crowding tag.
final
dataFormat → ExamplesOverride_DataFormat
The format of the data being provided with each call.
final
hashCode → int
The hash code for this object.
no setterinherited
neighborCount → int
The number of neighbors to return.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
restrictions → List<ExamplesRestrictionsNamespace>
Restrict the resulting nearest neighbors to respect these constraints.
final
returnEmbeddings → bool
If true, return the embeddings instead of neighbors.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String