ExamplesRestrictionsNamespace class final

Restrictions namespace for example-based explanations overrides.

Constructors

ExamplesRestrictionsNamespace({String namespaceName = '', List<String> allow = const [], List<String> deny = const []})
ExamplesRestrictionsNamespace.fromJson(Object? j)
factory

Properties

allow → List<String>
The list of allowed tags.
final
deny → List<String>
The list of deny tags.
final
hashCode → int
The hash code for this object.
no setterinherited
namespaceName → String
The namespace name.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String