Examples_ExampleGcsSource class final

The Cloud Storage input instances.

Constructors

Examples_ExampleGcsSource({Examples_ExampleGcsSource_DataFormat dataFormat = Examples_ExampleGcsSource_DataFormat.$default, GcsSource? gcsSource})
Examples_ExampleGcsSource.fromJson(Object? j)
factory

Properties

dataFormat → Examples_ExampleGcsSource_DataFormat
The format in which instances are given, if not specified, assume it's JSONL format. Currently only JSONL format is supported.
final
gcsSource → GcsSource?
The Cloud Storage location for the input instances.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String