ExecutableCode_Language class final

Supported programming languages for the generated code.

Constructors

ExecutableCode_Language(String value)
const
ExecutableCode_Language.fromJson(Object? json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isNotDefault → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object?
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$default → const ExecutableCode_Language
The default value for ExecutableCode_Language.
languageUnspecified → const ExecutableCode_Language
Unspecified language. This value should not be used.
python → const ExecutableCode_Language
Python >= 3.10, with numpy and simpy available.