Execution_State class final

Describes the state of the Execution.

Constructors

Execution_State(String value)
const
Execution_State.fromJson(Object? json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isNotDefault → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object?
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$default → const Execution_State
The default value for Execution_State.
cached → const Execution_State
The Execution completed through Cache hit.
cancelled → const Execution_State
The Execution was cancelled.
complete → const Execution_State
The Execution has finished running
failed → const Execution_State
The Execution has failed
new$ → const Execution_State
The Execution is new
running → const Execution_State
The Execution is running
stateUnspecified → const Execution_State
Unspecified Execution state