ExplanationMetadata class final

Metadata describing the Model's input and output for explanation.

Constructors

ExplanationMetadata({required Map<String, ExplanationMetadata_InputMetadata> inputs, required Map<String, ExplanationMetadata_OutputMetadata> outputs, String featureAttributionsSchemaUri = '', String latentSpaceSource = ''})
ExplanationMetadata.fromJson(Object? j)
factory

Properties

featureAttributionsSchemaUri → String
Points to a YAML file stored on Google Cloud Storage describing the format of the google.cloud.aiplatform.v1beta1.Attribution.feature_attributions. The schema is defined as an OpenAPI 3.0.2 Schema Object. AutoML tabular Models always have this field populated by Vertex AI. Note: The URI given on output may be different, including the URI scheme, than the one given on input. The output URI will point to a location where the user only has a read access.
final
hashCode → int
The hash code for this object.
no setterinherited
inputs → Map<String, ExplanationMetadata_InputMetadata>
Required. Map from feature names to feature input metadata. Keys are the name of the features. Values are the specification of the feature.
final
latentSpaceSource → String
Name of the source to generate embeddings for example based explanations.
final
outputs → Map<String, ExplanationMetadata_OutputMetadata>
Required. Map from output names to output metadata.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String