ExplanationMetadata_InputMetadata_FeatureValueDomain class final

Domain details of the input feature value. Provides numeric information about the feature, such as its range (min, max). If the feature has been pre-processed, for example with z-scoring, then it provides information about how to recover the original feature. For example, if the input feature is an image and it has been pre-processed to obtain 0-mean and stddev = 1 values, then original_mean, and original_stddev refer to the mean and stddev of the original feature (e.g. image tensor) from which input feature (with mean = 0 and stddev = 1) was obtained.

Constructors

ExplanationMetadata_InputMetadata_FeatureValueDomain({double minValue = 0, double maxValue = 0, double originalMean = 0, double originalStddev = 0})
ExplanationMetadata_InputMetadata_FeatureValueDomain.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxValue → double
The maximum permissible value for this feature.
final
minValue → double
The minimum permissible value for this feature.
final
originalMean → double
If this input feature has been normalized to a mean value of 0, the original_mean specifies the mean value of the domain prior to normalization.
final
originalStddev → double
If this input feature has been normalized to a standard deviation of 1.0, the original_stddev specifies the standard deviation of the domain prior to normalization.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String