ExplanationMetadata_InputMetadata_Visualization class final

Visualization configurations for image explanation.

Constructors

ExplanationMetadata_InputMetadata_Visualization({ExplanationMetadata_InputMetadata_Visualization_Type type = ExplanationMetadata_InputMetadata_Visualization_Type.$default, ExplanationMetadata_InputMetadata_Visualization_Polarity polarity = ExplanationMetadata_InputMetadata_Visualization_Polarity.$default, ExplanationMetadata_InputMetadata_Visualization_ColorMap colorMap = ExplanationMetadata_InputMetadata_Visualization_ColorMap.$default, double clipPercentUpperbound = 0, double clipPercentLowerbound = 0, ExplanationMetadata_InputMetadata_Visualization_OverlayType overlayType = ExplanationMetadata_InputMetadata_Visualization_OverlayType.$default})
ExplanationMetadata_InputMetadata_Visualization.fromJson(Object? j)
factory

Properties

clipPercentLowerbound → double
Excludes attributions below the specified percentile, from the highlighted areas. Defaults to 62.
final
clipPercentUpperbound → double
Excludes attributions above the specified percentile from the highlighted areas. Using the clip_percent_upperbound and clip_percent_lowerbound together can be useful for filtering out noise and making it easier to see areas of strong attribution. Defaults to 99.9.
final
colorMap → ExplanationMetadata_InputMetadata_Visualization_ColorMap
The color scheme used for the highlighted areas.
final
hashCode → int
The hash code for this object.
no setterinherited
overlayType → ExplanationMetadata_InputMetadata_Visualization_OverlayType
How the original image is displayed in the visualization. Adjusting the overlay can help increase visual clarity if the original image makes it difficult to view the visualization. Defaults to NONE.
final
polarity → ExplanationMetadata_InputMetadata_Visualization_Polarity
Whether to only highlight pixels with positive contributions, negative or both. Defaults to POSITIVE.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → ExplanationMetadata_InputMetadata_Visualization_Type
Type of the image visualization. Only applicable to google.cloud.aiplatform.v1beta1.ExplanationParameters.integrated_gradients_attribution. OUTLINES shows regions of attribution, while PIXELS shows per-pixel attribution. Defaults to OUTLINES.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String