ExplanationMetadata_InputMetadata_Visualization_Polarity class final

Whether to only highlight pixels with positive contributions, negative or both. Defaults to POSITIVE.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const ExplanationMetadata_InputMetadata_Visualization_Polarity
The default value for ExplanationMetadata_InputMetadata_Visualization_Polarity.
both → const ExplanationMetadata_InputMetadata_Visualization_Polarity
Shows both positive and negative attributions.
negative → const ExplanationMetadata_InputMetadata_Visualization_Polarity
Setting polarity to negative highlights areas that does not lead to the models's current prediction.
polarityUnspecified → const ExplanationMetadata_InputMetadata_Visualization_Polarity
Default value. This is the same as POSITIVE.
positive → const ExplanationMetadata_InputMetadata_Visualization_Polarity
Highlights the pixels/outlines that were most influential to the model's prediction.