ExplanationMetadata_OutputMetadata class final

Metadata of the prediction output to be explained.

Constructors

ExplanationMetadata_OutputMetadata({Value? indexDisplayNameMapping, String? displayNameMappingKey, String outputTensorName = ''})
ExplanationMetadata_OutputMetadata.fromJson(Object? j)
factory

Properties

displayNameMappingKey → String?
Specify a field name in the prediction to look for the display name.
final
hashCode → int
The hash code for this object.
no setterinherited
indexDisplayNameMapping → Value?
Static mapping between the index and display name.
final
outputTensorName → String
Name of the output tensor. Required and is only applicable to Vertex AI provided images for Tensorflow.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String