ExplanationParameters class final

Parameters to configure explaining for Model's predictions.

Constructors

ExplanationParameters({SampledShapleyAttribution? sampledShapleyAttribution, IntegratedGradientsAttribution? integratedGradientsAttribution, XraiAttribution? xraiAttribution, Examples? examples, int topK = 0, ListValue? outputIndices})
ExplanationParameters.fromJson(Object? j)
factory

Properties

examples → Examples?
Example-based explanations that returns the nearest neighbors from the provided dataset.
final
hashCode → int
The hash code for this object.
no setterinherited
integratedGradientsAttribution → IntegratedGradientsAttribution?
An attribution method that computes Aumann-Shapley values taking advantage of the model's fully differentiable structure. Refer to this paper for more details: https://arxiv.org/abs/1703.01365
final
outputIndices → ListValue?
If populated, only returns attributions that have output_index contained in output_indices. It must be an ndarray of integers, with the same shape of the output it's explaining.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sampledShapleyAttribution → SampledShapleyAttribution?
An attribution method that approximates Shapley values for features that contribute to the label being predicted. A sampling strategy is used to approximate the value rather than considering all subsets of features. Refer to this paper for model details: https://arxiv.org/abs/1306.4265.
final
topK → int
If populated, returns attributions for top K indices of outputs (defaults to 1). Only applies to Models that predicts more than one outputs (e,g, multi-class Models). When set to -1, returns explanations for all outputs.
final
xraiAttribution → XraiAttribution?
An attribution method that redistributes Integrated Gradients attribution to segmented regions, taking advantage of the model's fully differentiable structure. Refer to this paper for more details: https://arxiv.org/abs/1906.02825
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String