ExplanationSpec class final

Specification of Model explanation.

Constructors

ExplanationSpec({required ExplanationParameters? parameters, ExplanationMetadata? metadata})
ExplanationSpec.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
metadata → ExplanationMetadata?
Optional. Metadata describing the Model's input and output for explanation.
final
parameters → ExplanationParameters?
Required. Parameters that configure explaining of the Model's predictions.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String