ExplanationSpecOverride class final

The ExplanationSpec entries that can be overridden at google.cloud.aiplatform.v1beta1.PredictionService.Explain time.

Properties

examplesOverride → ExamplesOverride?
The example-based explanations parameter overrides.
final
hashCode → int
The hash code for this object.
no setterinherited
metadata → ExplanationMetadataOverride?
The metadata to be overridden. If not specified, no metadata is overridden.
final
parameters → ExplanationParameters?
The parameters to be overridden. Note that the attribution method cannot be changed. If not specified, no parameter is overridden.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String