ExportDataOperationMetadata class final

Runtime operation information for DatasetService.ExportData.

Constructors

ExportDataOperationMetadata({GenericOperationMetadata? genericMetadata, String gcsOutputDirectory = ''})
ExportDataOperationMetadata.fromJson(Object? j)
factory

Properties

gcsOutputDirectory → String
A Google Cloud Storage directory which path ends with '/'. The exported data is stored in the directory.
final
genericMetadata → GenericOperationMetadata?
The common part of the operation metadata.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String