ExportDataRequest class final

Request message for DatasetService.ExportData.

Constructors

ExportDataRequest({required String name, required ExportDataConfig? exportConfig})
ExportDataRequest.fromJson(Object? j)
factory

Properties

exportConfig → ExportDataConfig?
Required. The desired output location.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
Required. The name of the Dataset resource. Format: projects/{project}/locations/{location}/datasets/{dataset}
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String