ExportModelRequest_OutputConfig class final

Output configuration for the Model export.

Constructors

ExportModelRequest_OutputConfig({String exportFormatId = '', GcsDestination? artifactDestination, ContainerRegistryDestination? imageDestination})
ExportModelRequest_OutputConfig.fromJson(Object? j)
factory

Properties

artifactDestination → GcsDestination?
The Cloud Storage location where the Model artifact is to be written to. Under the directory given as the destination a new one with name "model-export-<model-display-name>-<timestamp-of-export-call>", where timestamp is in YYYY-MM-DDThh:mm:ss.sssZ ISO-8601 format, will be created. Inside, the Model and any of its supporting files will be written. This field should only be set when the exportableContent field of the Model.supported_export_formats object contains ARTIFACT.
final
exportFormatId → String
The ID of the format in which the Model must be exported. Each Model lists the google.cloud.aiplatform.v1beta1.Model.supported_export_formats. If no value is provided here, then the first from the list of the Model's supported formats is used by default.
final
hashCode → int
The hash code for this object.
no setterinherited
imageDestination → ContainerRegistryDestination?
The Google Container Registry or Artifact Registry uri where the Model container image will be copied to. This field should only be set when the exportableContent field of the Model.supported_export_formats object contains IMAGE.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String