Extension class final

Extensions are tools for large language models to access external data, run computations, etc.

Constructors

Extension({String name = '', required String displayName, String description = '', Timestamp? createTime, Timestamp? updateTime, String etag = '', required ExtensionManifest? manifest, List<ExtensionOperation> extensionOperations = const [], RuntimeConfig? runtimeConfig, List<ToolUseExample> toolUseExamples = const [], ExtensionPrivateServiceConnectConfig? privateServiceConnectConfig})
Extension.fromJson(Object? j)
factory

Properties

createTime → Timestamp?
Output only. Timestamp when this Extension was created.
final
description → String
Optional. The description of the Extension.
final
displayName → String
Required. The display name of the Extension. The name can be up to 128 characters long and can consist of any UTF-8 characters.
final
etag → String
Optional. Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens.
final
extensionOperations → List<ExtensionOperation>
Output only. Supported operations.
final
hashCode → int
The hash code for this object.
no setterinherited
manifest → ExtensionManifest?
Required. Manifest of the Extension.
final
name → String
Identifier. The resource name of the Extension.
final
privateServiceConnectConfig → ExtensionPrivateServiceConnectConfig?
Optional. The PrivateServiceConnect config for the extension. If specified, the service endpoints associated with the Extension should be registered with private network access in the provided Service Directory (https://cloud.google.com/service-directory/docs/configuring-private-network-access).
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeConfig → RuntimeConfig?
Optional. Runtime config controlling the runtime behavior of this Extension.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toolUseExamples → List<ToolUseExample>
Optional. Examples to illustrate the usage of the extension as a tool.
final
updateTime → Timestamp?
Output only. Timestamp when this Extension was most recently updated.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String