ExtensionPrivateServiceConnectConfig class final

PrivateExtensionConfig configuration for the extension.

Properties

hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceDirectory String
Required. The Service Directory resource name in which the service endpoints associated to the extension are registered. Format: projects/{project_id}/locations/{location_id}/namespaces/{namespace_id}/services/{service_id}
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String