Fact class final

The fact used in grounding.

Constructors

Fact({String? query, String? title, String? uri, String? summary, double? vectorDistance, double? score, RagChunk? chunk})
Fact.fromJson(Object? j)
factory

Properties

chunk → RagChunk?
If present, chunk properties.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
query → String?
Query that is used to retrieve this fact.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
score → double?
If present, according to the underlying Vector DB and the selected metric type, the score can be either the distance or the similarity between the query and the fact and its range depends on the metric type.
final
summary → String?
If present, the summary/snippet of the fact.
final
title → String?
If present, it refers to the title of this fact.
final
uri → String?
If present, this uri links to the source of the fact.
final
vectorDistance → double?
If present, the distance between the query vector and this fact vector.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String