Feature class final

Feature Metadata information. For example, color is a feature that describes an apple.

Constructors

Feature({String name = '', String description = '', Feature_ValueType valueType = Feature_ValueType.$default, Timestamp? createTime, Timestamp? updateTime, Map<String, String> labels = const {}, String etag = '', FeaturestoreMonitoringConfig? monitoringConfig, bool disableMonitoring = false, List<FeatureStatsAnomaly> monitoringStats = const [], List<Feature_MonitoringStatsAnomaly> monitoringStatsAnomalies = const [], List<FeatureStatsAndAnomaly> featureStatsAndAnomaly = const [], String versionColumnName = '', String pointOfContact = ''})
Feature.fromJson(Object? j)
factory

Properties

createTime → Timestamp?
Output only. Only applicable for Vertex AI Feature Store (Legacy). Timestamp when this EntityType was created.
final
description → String
Description of the Feature.
final
disableMonitoring → bool
Optional. Only applicable for Vertex AI Feature Store (Legacy). If not set, use the monitoring_config defined for the EntityType this Feature belongs to. Only Features with type (Feature.ValueType) BOOL, STRING, DOUBLE or INT64 can enable monitoring.
final
etag → String
Used to perform a consistent read-modify-write updates. If not set, a blind "overwrite" update happens.
final
featureStatsAndAnomaly → List<FeatureStatsAndAnomaly>
Output only. Only applicable for Vertex AI Feature Store. The list of historical stats and anomalies.
final
hashCode → int
The hash code for this object.
no setterinherited
labels → Map<String, String>
Optional. The labels with user-defined metadata to organize your Features.
final
monitoringConfig → FeaturestoreMonitoringConfig?
Optional. Only applicable for Vertex AI Feature Store (Legacy). Deprecated: The custom monitoring configuration for this Feature, if not set, use the monitoring_config defined for the EntityType this Feature belongs to. Only Features with type (Feature.ValueType) BOOL, STRING, DOUBLE or INT64 can enable monitoring.
final
monitoringStats → List<FeatureStatsAnomaly>
Output only. Only applicable for Vertex AI Feature Store (Legacy). A list of historical SnapshotAnalysis stats requested by user, sorted by FeatureStatsAnomaly.start_time descending.
final
monitoringStatsAnomalies → List<Feature_MonitoringStatsAnomaly>
Output only. Only applicable for Vertex AI Feature Store (Legacy). The list of historical stats and anomalies with specified objectives.
final
name → String
Immutable. Name of the Feature. Format: projects/{project}/locations/{location}/featurestores/{featurestore}/entityTypes/{entity_type}/features/{feature} projects/{project}/locations/{location}/featureGroups/{feature_group}/features/{feature}
final
pointOfContact → String
Entity responsible for maintaining this feature. Can be comma separated list of email addresses or URIs.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateTime → Timestamp?
Output only. Only applicable for Vertex AI Feature Store (Legacy). Timestamp when this EntityType was most recently updated.
final
valueType → Feature_ValueType
Immutable. Only applicable for Vertex AI Feature Store (Legacy). Type of Feature value.
final
versionColumnName → String
Only applicable for Vertex AI Feature Store. The name of the BigQuery Table/View column hosting data for this version. If no value is provided, will use feature_id.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String