FeatureNoiseSigma_NoiseSigmaForFeature class final

Noise sigma for a single feature.

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the input feature for which noise sigma is provided. The features are defined in google.cloud.aiplatform.v1beta1.ExplanationMetadata.inputs.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sigma → double
This represents the standard deviation of the Gaussian kernel that will be used to add noise to the feature prior to computing gradients. Similar to noise_sigma but represents the noise added to the current feature. Defaults to 0.1.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String