generateFetchAccessToken method

RPC to generate an access token for the given feature view. FeatureViews under the same FeatureOnlineStore share the same access token.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<GenerateFetchAccessTokenResponse> generateFetchAccessToken(
  GenerateFetchAccessTokenRequest request,
) async {
  final url = _endPoint.replace(
    path: '/v1beta1/${request.featureView}:generateFetchAccessToken',
  );
  final response = await _client.post(url, body: request);
  return GenerateFetchAccessTokenResponse.fromJson(response);
}