FeatureOnlineStore_Bigtable class final

Constructors

FeatureOnlineStore_Bigtable({required FeatureOnlineStore_Bigtable_AutoScaling? autoScaling, bool enableDirectBigtableAccess = false, FeatureOnlineStore_Bigtable_BigtableMetadata? bigtableMetadata, String zone = ''})
FeatureOnlineStore_Bigtable.fromJson(Object? j)
factory

Properties

autoScaling → FeatureOnlineStore_Bigtable_AutoScaling?
Required. Autoscaling config applied to Bigtable Instance.
final
bigtableMetadata → FeatureOnlineStore_Bigtable_BigtableMetadata?
Metadata of the Bigtable instance. Output only.
final
enableDirectBigtableAccess → bool
If true, enable direct access to the Bigtable instance.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
zone → String
Optional. The zone where the underlying Bigtable cluster for the primary Bigtable instance will be provisioned. Only the zone must be provided. For example, only "us-central1-a" should be provided.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String