FeatureOnlineStore_Bigtable_BigtableMetadata class final

Metadata of the Bigtable instance. This is used by direct read access to the Bigtable in tenant project.

Constructors

FeatureOnlineStore_Bigtable_BigtableMetadata({String tenantProjectId = '', String instanceId = '', String tableId = ''})
FeatureOnlineStore_Bigtable_BigtableMetadata.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
instanceId → String
The Cloud Bigtable instance id.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tableId → String
The Cloud Bigtable table id.
final
tenantProjectId → String
Tenant project ID.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String