FeatureOnlineStore_DedicatedServingEndpoint class final

The dedicated serving endpoint for this FeatureOnlineStore. Only need to set when you choose Optimized storage type. Public endpoint is provisioned by default.

Constructors

FeatureOnlineStore_DedicatedServingEndpoint({String publicEndpointDomainName = '', PrivateServiceConnectConfig? privateServiceConnectConfig, String serviceAttachment = ''})
FeatureOnlineStore_DedicatedServingEndpoint.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
privateServiceConnectConfig → PrivateServiceConnectConfig?
Optional. Private service connect config. The private service connection is available only for Optimized storage type, not for embedding management now. If PrivateServiceConnectConfig.enable_private_service_connect set to true, customers will use private service connection to send request. Otherwise, the connection will set to public endpoint.
final
publicEndpointDomainName → String
Output only. This field will be populated with the domain name to use for this FeatureOnlineStore
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAttachment → String
Output only. The name of the service attachment resource. Populated if private service connect is enabled and after FeatureViewSync is created.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String