createFeatureGroup method

Creates a new FeatureGroup in a given project and location.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

Future<Operation<FeatureGroup, CreateFeatureGroupOperationMetadata>>
createFeatureGroup(CreateFeatureGroupRequest request) async {
  final url = _endPoint.replace(
    path: '/v1beta1/${request.parent}/featureGroups',
    queryParameters: {
      if (request.featureGroupId case final $1 when $1.isNotDefault)
        'featureGroupId': $1,
    },
  );
  final response = await _client.post(url, body: request.featureGroup);
  return Operation.fromJson(
    response,
    OperationHelper(
      FeatureGroup.fromJson,
      CreateFeatureGroupOperationMetadata.fromJson,
    ),
  );
}