FeatureValue class final

Value for a feature.

Constructors

FeatureValue({bool? boolValue, double? doubleValue, int? int64Value, String? stringValue, BoolArray? boolArrayValue, DoubleArray? doubleArrayValue, Int64Array? int64ArrayValue, StringArray? stringArrayValue, Uint8List? bytesValue, StructValue? structValue, FeatureValue_Metadata? metadata})
FeatureValue.fromJson(Object? j)
factory

Properties

boolArrayValue → BoolArray?
A list of bool type feature value.
final
boolValue → bool?
Bool type feature value.
final
bytesValue → Uint8List?
Bytes feature value.
final
doubleArrayValue → DoubleArray?
A list of double type feature value.
final
doubleValue → double?
Double type feature value.
final
hashCode → int
The hash code for this object.
no setterinherited
int64ArrayValue → Int64Array?
A list of int64 type feature value.
final
int64Value → int?
Int64 feature value.
final
metadata → FeatureValue_Metadata?
Metadata of feature value.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringArrayValue → StringArray?
A list of string type feature value.
final
stringValue → String?
String feature value.
final
structValue → StructValue?
A struct type feature value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String