FeatureValueDestination class final

A destination location for Feature values and format.

Constructors

FeatureValueDestination({BigQueryDestination? bigqueryDestination, TfrecordDestination? tfrecordDestination, CsvDestination? csvDestination})
FeatureValueDestination.fromJson(Object? j)
factory

Properties

bigqueryDestination → BigQueryDestination?
Output in BigQuery format. BigQueryDestination.output_uri in FeatureValueDestination.bigquery_destination must refer to a table.
final
csvDestination → CsvDestination?
Output in CSV format. Array Feature value types are not allowed in CSV format.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tfrecordDestination → TfrecordDestination?
Output in TFRecord format.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String