FeatureViewDataFormat class final

Format of the data in the Feature View.

Constructors

FeatureViewDataFormat(String value)
const
FeatureViewDataFormat.fromJson(Object? json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isNotDefault → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object?
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$default → const FeatureViewDataFormat
The default value for FeatureViewDataFormat.
featureViewDataFormatUnspecified → const FeatureViewDataFormat
Not set. Will be treated as the KeyValue format.
keyValue → const FeatureViewDataFormat
Return response data in key-value format.
protoStruct → const FeatureViewDataFormat
Return response data in proto Struct format.