FeatureViewDirectWriteRequest_DataKeyAndFeatureValues_Feature class final

Feature name & value pair.

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
Feature short name.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → FeatureValue?
Feature value. A user provided timestamp may be set in the FeatureValue.metadata.generate_time field.
final
valueAndTimestamp → FeatureViewDirectWriteRequest_DataKeyAndFeatureValues_Feature_FeatureValueAndTimestamp?
Feature value and timestamp.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String