FeatureViewSync class final

FeatureViewSync is a representation of sync operation which copies data from data source to Feature View in Online Store.

Constructors

FeatureViewSync({String name = '', Timestamp? createTime, Interval? runTime, Status? finalStatus, FeatureViewSync_SyncSummary? syncSummary, bool satisfiesPzs = false, bool satisfiesPzi = false})
FeatureViewSync.fromJson(Object? j)
factory

Properties

createTime → Timestamp?
Output only. Time when this FeatureViewSync is created. Creation of a FeatureViewSync means that the job is pending / waiting for sufficient resources but may not have started the actual data transfer yet.
final
finalStatus → Status?
Output only. Final status of the FeatureViewSync.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
Identifier. Name of the FeatureViewSync. Format: projects/{project}/locations/{location}/featureOnlineStores/{feature_online_store}/featureViews/{feature_view}/featureViewSyncs/{feature_view_sync}
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runTime → Interval?
Output only. Time when this FeatureViewSync is finished.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
satisfiesPzi → bool
Output only. Reserved for future use.
final
satisfiesPzs → bool
Output only. Reserved for future use.
final
syncSummary → FeatureViewSync_SyncSummary?
Output only. Summary of the sync job.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String