FeatureViewSync_SyncSummary class final

Summary from the Sync job. For continuous syncs, the summary is updated periodically. For batch syncs, it gets updated on completion of the sync.

Constructors

FeatureViewSync_SyncSummary({int rowSynced = 0, int totalSlot = 0, Timestamp? systemWatermarkTime})
FeatureViewSync_SyncSummary.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
rowSynced → int
Output only. Total number of rows synced.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
systemWatermarkTime → Timestamp?
Lower bound of the system time watermark for the sync job. This is only set for continuously syncing feature views.
final
totalSlot → int
Output only. BigQuery slot milliseconds consumed for the sync job.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String