FeatureView_IndexConfig_TreeAhconfig class final

Configuration options for the tree-AH algorithm.

Properties

hashCode → int
The hash code for this object.
no setterinherited
leafNodeEmbeddingCount → int?
Optional. Number of embeddings on each leaf node. The default value is 1000 if not set.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String