FeaturestoreMonitoringConfig class final

Configuration of how features in Featurestore are monitored.

Properties

categoricalThresholdConfig → FeaturestoreMonitoringConfig_ThresholdConfig?
Threshold for categorical features of anomaly detection. This is shared by all types of Featurestore Monitoring for categorical features (i.e. Features with type (Feature.ValueType) BOOL or STRING).
final
hashCode → int
The hash code for this object.
no setterinherited
importFeaturesAnalysis → FeaturestoreMonitoringConfig_ImportFeaturesAnalysis?
The config for ImportFeatures Analysis Based Feature Monitoring.
final
numericalThresholdConfig → FeaturestoreMonitoringConfig_ThresholdConfig?
Threshold for numerical features of anomaly detection. This is shared by all objectives of Featurestore Monitoring for numerical features (i.e. Features with type (Feature.ValueType) DOUBLE or INT64).
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snapshotAnalysis → FeaturestoreMonitoringConfig_SnapshotAnalysis?
The config for Snapshot Analysis Based Feature Monitoring.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String