FeaturestoreMonitoringConfig_ImportFeaturesAnalysis class final

Configuration of the Featurestore's ImportFeature Analysis Based Monitoring. This type of analysis generates statistics for values of each Feature imported by every ImportFeatureValues operation.

Constructors

FeaturestoreMonitoringConfig_ImportFeaturesAnalysis({FeaturestoreMonitoringConfig_ImportFeaturesAnalysis_State state = FeaturestoreMonitoringConfig_ImportFeaturesAnalysis_State.$default, FeaturestoreMonitoringConfig_ImportFeaturesAnalysis_Baseline anomalyDetectionBaseline = FeaturestoreMonitoringConfig_ImportFeaturesAnalysis_Baseline.$default})
FeaturestoreMonitoringConfig_ImportFeaturesAnalysis.fromJson(Object? j)
factory

Properties

anomalyDetectionBaseline → FeaturestoreMonitoringConfig_ImportFeaturesAnalysis_Baseline
The baseline used to do anomaly detection for the statistics generated by import features analysis.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → FeaturestoreMonitoringConfig_ImportFeaturesAnalysis_State
Whether to enable / disable / inherite default hebavior for import features analysis.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String