FeaturestoreMonitoringConfig_SnapshotAnalysis class final

Configuration of the Featurestore's Snapshot Analysis Based Monitoring. This type of analysis generates statistics for each Feature based on a snapshot of the latest feature value of each entities every monitoring_interval.

Constructors

FeaturestoreMonitoringConfig_SnapshotAnalysis({bool disabled = false, Duration? monitoringInterval, int monitoringIntervalDays = 0, int stalenessDays = 0})
FeaturestoreMonitoringConfig_SnapshotAnalysis.fromJson(Object? j)
factory

Properties

disabled → bool
The monitoring schedule for snapshot analysis. For EntityType-level config: unset / disabled = true indicates disabled by default for Features under it; otherwise by default enable snapshot analysis monitoring with monitoring_interval for Features under it. Feature-level config: disabled = true indicates disabled regardless of the EntityType-level config; unset monitoring_interval indicates going with EntityType-level config; otherwise run snapshot analysis monitoring with monitoring_interval regardless of the EntityType-level config. Explicitly Disable the snapshot analysis based monitoring.
final
hashCode → int
The hash code for this object.
no setterinherited
monitoringInterval → Duration?
Configuration of the snapshot analysis based monitoring pipeline running interval. The value is rolled up to full day. If both monitoring_interval_days and the deprecated monitoring_interval field are set when creating/updating EntityTypes/Features, monitoring_interval_days will be used.
final
monitoringIntervalDays → int
Configuration of the snapshot analysis based monitoring pipeline running interval. The value indicates number of days.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stalenessDays → int
Customized export features time window for snapshot analysis. Unit is one day. Default value is 3 weeks. Minimum value is 1 day. Maximum value is 4000 days.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String