FileStatus_State class final

RagFile state.

Constructors

FileStatus_State(String value)
const
FileStatus_State.fromJson(Object? json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isNotDefault → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object?
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$default → const FileStatus_State
The default value for FileStatus_State.
active → const FileStatus_State
RagFile resource has been created and indexed successfully.
error → const FileStatus_State
RagFile resource is in a problematic state. See error_message field for details.
stateUnspecified → const FileStatus_State
RagFile state is unspecified.