FindNeighborsResponse_Neighbor class final

A neighbor of the query vector.

Constructors

FindNeighborsResponse_Neighbor({IndexDatapoint? datapoint, double distance = 0, double sparseDistance = 0})
FindNeighborsResponse_Neighbor.fromJson(Object? j)
factory

Properties

datapoint → IndexDatapoint?
The datapoint of the neighbor. Note that full datapoints are returned only when "return_full_datapoint" is set to true. Otherwise, only the "datapoint_id" and "crowding_tag" fields are populated.
final
distance → double
The distance between the neighbor and the dense embedding query.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sparseDistance → double
The distance between the neighbor and the query sparse_embedding.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String