FunctionCall class final

A predicted FunctionCall returned from the model that contains a string representing the FunctionDeclaration.name and a structured JSON object containing the parameters and their values.

Constructors

FunctionCall({String id = '', String name = '', Struct? args, List<PartialArg> partialArgs = const [], bool willContinue = false})
FunctionCall.fromJson(Object? j)
factory

Properties

args → Struct?
Optional. The function parameters and values in JSON object format. See FunctionDeclaration.parameters for parameter details.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
Optional. The unique id of the function call. If populated, the client to execute the function_call and return the response with the matching id.
final
name → String
Optional. The name of the function to call. Matches FunctionDeclaration.name.
final
partialArgs → List<PartialArg>
Optional. The partial argument value of the function call. If provided, represents the arguments/fields that are streamed incrementally.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
willContinue → bool
Optional. Whether this is the last part of the FunctionCall. If true, another partial message for the current FunctionCall is expected to follow.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String