FunctionResponseBlob class final

Raw media bytes for function response.

Text should not be sent as raw bytes, use the 'text' field.

Constructors

FunctionResponseBlob({required String mimeType, required Uint8List data, String displayName = ''})
FunctionResponseBlob.fromJson(Object? j)
factory

Properties

data → Uint8List
Required. Raw bytes.
final
displayName → String
Optional. Display name of the blob.
final
hashCode → int
The hash code for this object.
no setterinherited
mimeType → String
Required. The IANA standard MIME type of the source data.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String