GeminiExample class final

Format for Gemini examples used for Vertex Multimodal datasets.

Constructors

GeminiExample({String model = '', required List<Content> contents, Content? systemInstruction, String cachedContent = '', List<Tool> tools = const [], ToolConfig? toolConfig, Map<String, String> labels = const {}, List<SafetySetting> safetySettings = const [], ModelArmorConfig? modelArmorConfig, GenerationConfig? generationConfig})
GeminiExample.fromJson(Object? j)
factory

Properties

cachedContent → String
Optional. The name of the cached content used as context to serve the prediction. Note: only used in explicit caching, where users can have control over caching (e.g. what content to cache) and enjoy guaranteed cost savings. Format: projects/{project}/locations/{location}/cachedContents/{cachedContent}
final
contents → List<Content>
Required. The content of the current conversation with the model.
final
generationConfig → GenerationConfig?
Optional. Generation config.
final
hashCode → int
The hash code for this object.
no setterinherited
labels → Map<String, String>
Optional. The labels with user-defined metadata for the request. It is used for billing and reporting only.
final
model → String
Optional. The fully qualified name of the publisher model or tuned model endpoint to use.
final
modelArmorConfig → ModelArmorConfig?
Optional. Settings for prompt and response sanitization using the Model Armor service. If supplied, safety_settings must not be supplied.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
safetySettings → List<SafetySetting>
Optional. Per request settings for blocking unsafe content. Enforced on GenerateContentResponse.candidates.
final
systemInstruction → Content?
Optional. The user provided system instructions for the model. Note: only text should be used in parts and content in each part will be in a separate paragraph.
final
toolConfig → ToolConfig?
Optional. Tool config. This config is shared for all tools provided in the request.
final
tools → List<Tool>
Optional. A list of Tools the model may use to generate the next response.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String