GeminiTemplateConfig class final

Template configuration to create Gemini examples from a multimodal dataset.

Constructors

GeminiTemplateConfig({required GeminiExample? geminiExample, required Map<String, String> fieldMapping})
GeminiTemplateConfig.fromJson(Object? j)
factory

Properties

fieldMapping → Map<String, String>
Required. Map of template parameters to the columns in the dataset table.
final
geminiExample → GeminiExample?
Required. The template that will be used for assembling the request to use for downstream applications.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String