GenerateContentResponse_PromptFeedback class final

Content filter results for a prompt sent in the request.

Constructors

GenerateContentResponse_PromptFeedback({GenerateContentResponse_PromptFeedback_BlockedReason blockReason = GenerateContentResponse_PromptFeedback_BlockedReason.$default, List<SafetyRating> safetyRatings = const [], String blockReasonMessage = ''})
GenerateContentResponse_PromptFeedback.fromJson(Object? j)
factory

Properties

blockReason → GenerateContentResponse_PromptFeedback_BlockedReason
Output only. Blocked reason.
final
blockReasonMessage → String
Output only. A readable block reason message.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
safetyRatings → List<SafetyRating>
Output only. Safety ratings.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String