GenerateContentResponse_UsageMetadata class final

Usage metadata about response(s).

Constructors

GenerateContentResponse_UsageMetadata({int promptTokenCount = 0, int candidatesTokenCount = 0, int thoughtsTokenCount = 0, int totalTokenCount = 0, int cachedContentTokenCount = 0, List<ModalityTokenCount> promptTokensDetails = const [], List<ModalityTokenCount> cacheTokensDetails = const [], List<ModalityTokenCount> candidatesTokensDetails = const []})
GenerateContentResponse_UsageMetadata.fromJson(Object? j)
factory

Properties

cachedContentTokenCount → int
Output only. Number of tokens in the cached part in the input (the cached content).
final
cacheTokensDetails → List<ModalityTokenCount>
Output only. List of modalities of the cached content in the request input.
final
candidatesTokenCount → int
Number of tokens in the response(s).
final
candidatesTokensDetails → List<ModalityTokenCount>
Output only. List of modalities that were returned in the response.
final
hashCode → int
The hash code for this object.
no setterinherited
promptTokenCount → int
Number of tokens in the request. When cached_content is set, this is still the total effective prompt size meaning this includes the number of tokens in the cached content.
final
promptTokensDetails → List<ModalityTokenCount>
Output only. List of modalities that were processed in the request input.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thoughtsTokenCount → int
Output only. Number of tokens present in thoughts output.
final
totalTokenCount → int
Total token count for prompt and response candidates.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String