GenerateInstanceRubricsRequest class final

Request message for EvaluationService.GenerateInstanceRubrics.

Constructors

GenerateInstanceRubricsRequest({required String location, required List<Content> contents, PredefinedMetricSpec? predefinedRubricGenerationSpec, RubricGenerationSpec? rubricGenerationSpec, EvaluationInstance_DeprecatedAgentConfig? agentConfig})
GenerateInstanceRubricsRequest.fromJson(Object? j)
factory

Properties

agentConfig EvaluationInstance_DeprecatedAgentConfig?
Optional. Agent configuration, required for agent-based rubric generation.
final
contents List<Content>
Required. The prompt to generate rubrics from. For single-turn queries, this is a single instance. For multi-turn queries, this is a repeated field that contains conversation history + latest request.
final
hashCode int
The hash code for this object.
no setterinherited
location String
Required. The resource name of the Location to generate rubrics from. Format: projects/{project}/locations/{location}
final
predefinedRubricGenerationSpec PredefinedMetricSpec?
Optional. Specification for using the rubric generation configs of a pre-defined metric, e.g. "generic_quality_v1" and "instruction_following_v1". Some of the configs may be only used in rubric generation and not supporting evaluation, e.g. "fully_customized_generic_quality_v1". If this field is set, the rubric_generation_spec field will be ignored.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
rubricGenerationSpec RubricGenerationSpec?
Optional. Specification for how the rubrics should be generated.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String