GenerateMemoriesRequest_DirectMemoriesSource class final

Defines a direct source of memories that should be uploaded to Memory Bank with consolidation.

Properties

directMemories → List<GenerateMemoriesRequest_DirectMemoriesSource_DirectMemory>
Required. The direct memories to upload to Memory Bank. At most 5 direct memories are allowed per request.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String