GenerateMemoriesResponse_GeneratedMemory class final

A memory generated by the operation.

Constructors

GenerateMemoriesResponse_GeneratedMemory({Memory? memory, GenerateMemoriesResponse_GeneratedMemory_Action action = GenerateMemoriesResponse_GeneratedMemory_Action.$default})
GenerateMemoriesResponse_GeneratedMemory.fromJson(Object? j)
factory

Properties

action → GenerateMemoriesResponse_GeneratedMemory_Action
The action that was performed on the Memory.
final
hashCode → int
The hash code for this object.
no setterinherited
memory → Memory?
The generated Memory.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String