GenerateMemoriesResponse_GeneratedMemory_Action class final

Actions that can be performed on a Memory.

Properties

hashCode → int
The hash code for this object.
no setterinherited
isNotDefault → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object?
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$default → const GenerateMemoriesResponse_GeneratedMemory_Action
The default value for GenerateMemoriesResponse_GeneratedMemory_Action.
actionUnspecified → const GenerateMemoriesResponse_GeneratedMemory_Action
Action is unspecified.
created → const GenerateMemoriesResponse_GeneratedMemory_Action
The memory was created.
deleted → const GenerateMemoriesResponse_GeneratedMemory_Action
The memory was deleted.
updated → const GenerateMemoriesResponse_GeneratedMemory_Action
The memory was updated. The fact field may not be updated if the existing fact is still accurate.