GenerationConfig_MediaResolution class final

Media resolution for the input media.

Properties

hashCode → int
The hash code for this object.
no setterinherited
isNotDefault → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object?
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$default → const GenerationConfig_MediaResolution
The default value for GenerationConfig_MediaResolution.
mediaResolutionHigh → const GenerationConfig_MediaResolution
Media resolution set to high (zoomed reframing with 256 tokens).
mediaResolutionLow → const GenerationConfig_MediaResolution
Media resolution set to low (64 tokens).
mediaResolutionMedium → const GenerationConfig_MediaResolution
Media resolution set to medium (256 tokens).
mediaResolutionUnspecified → const GenerationConfig_MediaResolution
Media resolution has not been set.