GenerationConfig_Modality class final

The modalities of the response.

Properties

hashCode → int
The hash code for this object.
no setterinherited
isNotDefault → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object?
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$default → const GenerationConfig_Modality
The default value for GenerationConfig_Modality.
audio → const GenerationConfig_Modality
Audio modality.
image → const GenerationConfig_Modality
Image modality.
modalityUnspecified → const GenerationConfig_Modality
Unspecified modality. Will be processed as text.
text → const GenerationConfig_Modality
Text modality.