GenerationConfig_ModelConfig_FeatureSelectionPreference class final

Options for feature selection preference.

Properties

hashCode → int
The hash code for this object.
no setterinherited
isNotDefault → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object?
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited