GenerationConfig_RoutingConfig_AutoRoutingMode class final

When automated routing is specified, the routing will be determined by the pretrained routing model and customer provided model routing preference.

Properties

hashCode int
The hash code for this object.
no setterinherited
modelRoutingPreference GenerationConfig_RoutingConfig_AutoRoutingMode_ModelRoutingPreference?
The model routing preference.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String