GenerationConfig_RoutingConfig_ManualRoutingMode class final

When manual routing is set, the specified model will be used directly.

Properties

hashCode int
The hash code for this object.
no setterinherited
modelName String?
The model name to use. Only the public LLM models are accepted. e.g. 'gemini-1.5-pro-001'.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String