GenerationConfig_ThinkingConfig class final

Config for thinking features.

Constructors

GenerationConfig_ThinkingConfig({bool? includeThoughts, int? thinkingBudget})
GenerationConfig_ThinkingConfig.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
includeThoughts → bool?
Indicates whether to include thoughts in the response. If true, thoughts are returned only when available.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thinkingBudget → int?
Optional. Indicates the thinking budget in tokens. This is only applied when enable_thinking is true.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String