GetPublisherModelRequest class final

Request message for ModelGardenService.GetPublisherModel

Constructors

GetPublisherModelRequest({required String name, String languageCode = '', PublisherModelView view = PublisherModelView.$default, bool isHuggingFaceModel = false, String huggingFaceToken = '', bool includeEquivalentModelGardenModelDeploymentConfigs = false})
GetPublisherModelRequest.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
huggingFaceToken → String
Optional. Token used to access Hugging Face gated models.
final
includeEquivalentModelGardenModelDeploymentConfigs → bool
Optional. Whether to cnclude the deployment configs from the equivalent Model Garden model if the requested model is a Hugging Face model.
final
isHuggingFaceModel → bool
Optional. Boolean indicates whether the requested model is a Hugging Face model.
final
languageCode → String
Optional. The IETF BCP-47 language code representing the language in which the publisher model's text information should be written in.
final
name → String
Required. The name of the PublisherModel resource. Format: publishers/{publisher}/models/{publisher_model}
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
view → PublisherModelView
Optional. PublisherModel view specifying which fields to read.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String