GoogleMaps class final

Tool to retrieve public maps data for grounding, powered by Google.

Constructors

GoogleMaps({bool enableWidget = false})
GoogleMaps.fromJson(Object? j)
factory

Properties

enableWidget → bool
If true, include the widget context token in the response.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String