GroundingChunk_Maps class final

A Maps chunk is a piece of evidence that comes from Google Maps, containing information about places or routes. This is used to provide the user with rich, location-based information.

Constructors

GroundingChunk_Maps({String? uri, String? title, String? text, String? placeId, GroundingChunk_Maps_PlaceAnswerSources? placeAnswerSources, GroundingChunk_Maps_Route? route})
GroundingChunk_Maps.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
placeAnswerSources → GroundingChunk_Maps_PlaceAnswerSources?
Sources used to generate the place answer. This includes review snippets and photos that were used to generate the answer, as well as uris to flag content.
final
placeId → String?
This Place's resource name, in places/{place_id} format. Can be used to look up the Place.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
route → GroundingChunk_Maps_Route?
Output only. Route information.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String?
Text of the chunk.
final
title → String?
Title of the chunk.
final
uri → String?
URI reference of the chunk.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String