GroundingChunk_Maps_Route class final

Route information from Google Maps.

Constructors

GroundingChunk_Maps_Route({int distanceMeters = 0, Duration? duration, String encodedPolyline = ''})
GroundingChunk_Maps_Route.fromJson(Object? j)
factory

Properties

distanceMeters int
The total distance of the route, in meters.
final
duration → Duration?
The total duration of the route.
final
encodedPolyline String
An encoded polyline of the route. See https://developers.google.com/maps/documentation/utilities/polylinealgorithm
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String