HarmCategory class final

Harm categories that will block the content.

Constructors

HarmCategory(String value)
const
HarmCategory.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const HarmCategory
The default value for HarmCategory.
harmCategoryCivicIntegrity → const HarmCategory
Deprecated: Election filter is not longer supported. The harm category is civic integrity.
harmCategoryDangerousContent → const HarmCategory
The harm category is dangerous content.
harmCategoryHarassment → const HarmCategory
The harm category is harassment.
harmCategoryHateSpeech → const HarmCategory
The harm category is hate speech.
harmCategoryJailbreak → const HarmCategory
The harm category is for jailbreak prompts.
harmCategorySexuallyExplicit → const HarmCategory
The harm category is sexually explicit content.
harmCategoryUnspecified → const HarmCategory
The harm category is unspecified.