HttpElementLocation class final

Enum of location an HTTP element can be.

Constructors

HttpElementLocation(String value)
const
HttpElementLocation.fromJson(Object? json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isNotDefault → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object?
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$default → const HttpElementLocation
The default value for HttpElementLocation.
httpInBody → const HttpElementLocation
Element is in the HTTP request body.
httpInCookie → const HttpElementLocation
Element is in the HTTP request cookie.
httpInHeader → const HttpElementLocation
Element is in the HTTP request header.
httpInPath → const HttpElementLocation
Element is in the HTTP request path.
httpInQuery → const HttpElementLocation
Element is in the HTTP request query.
httpInUnspecified → const HttpElementLocation