HyperparameterTuningJob class final

Represents a HyperparameterTuningJob. A HyperparameterTuningJob has a Study specification and multiple CustomJobs with identical CustomJob specification.

Constructors

HyperparameterTuningJob({String name = '', required String displayName, required StudySpec? studySpec, required int maxTrialCount, required int parallelTrialCount, int maxFailedTrialCount = 0, required CustomJobSpec? trialJobSpec, List<Trial> trials = const [], JobState state = JobState.$default, Timestamp? createTime, Timestamp? startTime, Timestamp? endTime, Timestamp? updateTime, Status? error, Map<String, String> labels = const {}, EncryptionSpec? encryptionSpec, bool satisfiesPzs = false, bool satisfiesPzi = false})
HyperparameterTuningJob.fromJson(Object? j)
factory

Properties

createTime → Timestamp?
Output only. Time when the HyperparameterTuningJob was created.
final
displayName → String
Required. The display name of the HyperparameterTuningJob. The name can be up to 128 characters long and can consist of any UTF-8 characters.
final
encryptionSpec → EncryptionSpec?
Customer-managed encryption key options for a HyperparameterTuningJob. If this is set, then all resources created by the HyperparameterTuningJob will be encrypted with the provided encryption key.
final
endTime → Timestamp?
Output only. Time when the HyperparameterTuningJob entered any of the following states: JOB_STATE_SUCCEEDED, JOB_STATE_FAILED, JOB_STATE_CANCELLED.
final
error → Status?
Output only. Only populated when job's state is JOB_STATE_FAILED or JOB_STATE_CANCELLED.
final
hashCode → int
The hash code for this object.
no setterinherited
labels → Map<String, String>
The labels with user-defined metadata to organize HyperparameterTuningJobs.
final
maxFailedTrialCount → int
The number of failed Trials that need to be seen before failing the HyperparameterTuningJob.
final
maxTrialCount → int
Required. The desired total number of Trials.
final
name → String
Output only. Resource name of the HyperparameterTuningJob.
final
parallelTrialCount → int
Required. The desired number of Trials to run in parallel.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
satisfiesPzi → bool
Output only. Reserved for future use.
final
satisfiesPzs → bool
Output only. Reserved for future use.
final
startTime → Timestamp?
Output only. Time when the HyperparameterTuningJob for the first time entered the JOB_STATE_RUNNING state.
final
state → JobState
Output only. The detailed state of the job.
final
studySpec → StudySpec?
Required. Study configuration of the HyperparameterTuningJob.
final
trialJobSpec → CustomJobSpec?
Required. The spec of a trial job. The same spec applies to the CustomJobs created in all the trials.
final
trials → List<Trial>
Output only. Trials of the HyperparameterTuningJob.
final
updateTime → Timestamp?
Output only. Time when the HyperparameterTuningJob was most recently updated.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String