ImportFeatureValuesOperationMetadata class final

Details of operations that perform import Feature values.

Constructors

ImportFeatureValuesOperationMetadata({GenericOperationMetadata? genericMetadata, int importedEntityCount = 0, int importedFeatureValueCount = 0, List<String> sourceUris = const [], int invalidRowCount = 0, int timestampOutsideRetentionRowsCount = 0, List<int> blockingOperationIds = const []})
ImportFeatureValuesOperationMetadata.fromJson(Object? j)
factory

Properties

blockingOperationIds → List<int>
List of ImportFeatureValues operations running under a single EntityType that are blocking this operation.
final
genericMetadata → GenericOperationMetadata?
Operation metadata for Featurestore import Feature values.
final
hashCode → int
The hash code for this object.
no setterinherited
importedEntityCount → int
Number of entities that have been imported by the operation.
final
importedFeatureValueCount → int
Number of Feature values that have been imported by the operation.
final
invalidRowCount → int
The number of rows in input source that weren't imported due to either
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceUris → List<String>
The source URI from where Feature values are imported.
final
timestampOutsideRetentionRowsCount → int
The number rows that weren't ingested due to having timestamps outside the retention boundary.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String