ImportFeatureValuesResponse class final

Response message for FeaturestoreService.ImportFeatureValues.

Constructors

ImportFeatureValuesResponse({int importedEntityCount = 0, int importedFeatureValueCount = 0, int invalidRowCount = 0, int timestampOutsideRetentionRowsCount = 0})
ImportFeatureValuesResponse.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
importedEntityCount → int
Number of entities that have been imported by the operation.
final
importedFeatureValueCount → int
Number of Feature values that have been imported by the operation.
final
invalidRowCount → int
The number of rows in input source that weren't imported due to either
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestampOutsideRetentionRowsCount → int
The number rows that weren't ingested due to having feature timestamps outside the retention boundary.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String