ImportIndexRequest_ConnectorConfig_BigQuerySourceConfig class final

Configuration for importing data from a BigQuery table.

Properties

datapointFieldMapping → ImportIndexRequest_ConnectorConfig_DatapointFieldMapping?
Required. Mapping of datapoint fields to BigQuery column names.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tablePath → String
Required. The path to the BigQuery table containing the index data, in the format of bq://<project_id>.<dataset_id>.<table>.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String