ImportIndexRequest_ConnectorConfig_DatapointFieldMapping class final

Mapping of datapoint fields to column names for columnar data sources.

Properties

embeddingColumn → String
Required. The column with the vector embeddings for each data point.
final
hashCode → int
The hash code for this object.
no setterinherited
idColumn → String
Required. The column with unique identifiers for each data point.
final
metadataColumns → List<String>
Optional. List of columns containing metadata to be included in the index.
final
numericRestricts → List<ImportIndexRequest_ConnectorConfig_DatapointFieldMapping_NumericRestrict>
Optional. List of restricts for numeric values.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
restricts → List<ImportIndexRequest_ConnectorConfig_DatapointFieldMapping_Restrict>
Optional. List of restricts for string values.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String