ImportRagFilesResponse class final

Response message for VertexRagDataService.ImportRagFiles.

Constructors

ImportRagFilesResponse({String? partialFailuresGcsPath, String? partialFailuresBigqueryTable, int importedRagFilesCount = 0, int failedRagFilesCount = 0, int skippedRagFilesCount = 0})
ImportRagFilesResponse.fromJson(Object? j)
factory

Properties

failedRagFilesCount → int
The number of RagFiles that had failed while importing into the RagCorpus.
final
hashCode → int
The hash code for this object.
no setterinherited
importedRagFilesCount → int
The number of RagFiles that had been imported into the RagCorpus.
final
partialFailuresBigqueryTable → String?
The BigQuery table into which the partial failures were written.
final
partialFailuresGcsPath → String?
The Google Cloud Storage path into which the partial failures were written.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skippedRagFilesCount → int
The number of RagFiles that was skipped while importing into the RagCorpus.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String