IndexDatapoint_NumericRestriction_Operator class final

Which comparison operator to use. Should be specified for queries only; specifying this for a datapoint is an error.

Datapoints for which Operator is true relative to the query's Value field will be allowlisted.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const IndexDatapoint_NumericRestriction_Operator
The default value for IndexDatapoint_NumericRestriction_Operator.
equal → const IndexDatapoint_NumericRestriction_Operator
Datapoints are eligible iff their value is == the query's.
greater → const IndexDatapoint_NumericRestriction_Operator
Datapoints are eligible iff their value is > the query's.
greaterEqual → const IndexDatapoint_NumericRestriction_Operator
Datapoints are eligible iff their value is >= the query's.
less → const IndexDatapoint_NumericRestriction_Operator
Datapoints are eligible iff their value is < the query's.
lessEqual → const IndexDatapoint_NumericRestriction_Operator
Datapoints are eligible iff their value is <= the query's.
notEqual → const IndexDatapoint_NumericRestriction_Operator
Datapoints are eligible iff their value is != the query's.
operatorUnspecified → const IndexDatapoint_NumericRestriction_Operator
Default value of the enum.