IndexDatapoint_SparseEmbedding class final

Feature embedding vector for sparse index. An array of numbers whose values are located in the specified dimensions.

Constructors

IndexDatapoint_SparseEmbedding({required List<double> values, required List<int> dimensions})
IndexDatapoint_SparseEmbedding.fromJson(Object? j)
factory

Properties

dimensions → List<int>
Required. The list of indexes for the embedding values of the sparse vector.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
values → List<double>
Required. The list of embedding values of the sparse vector.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String