IndexEndpointService class final

A service for managing Vertex AI's IndexEndpoints.

Implementers

Constructors

IndexEndpointService({required Client client, Uri? endPoint, String? gcclVersion})
Creates a IndexEndpointService using client for transport.
IndexEndpointService.fromApiKey([String? apiKey])
Creates a IndexEndpointService that does authentication through an API key.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancelOperation(CancelOperationRequest request) → Future<void>
Provides the Operations service functionality in this service.
close() → void
Closes the client and cleans up any resources associated with it.
createIndexEndpoint(CreateIndexEndpointRequest request) → Future<Operation<IndexEndpoint, CreateIndexEndpointOperationMetadata>>
Creates an IndexEndpoint.
deleteIndexEndpoint(DeleteIndexEndpointRequest request) → Future<Operation<Empty, DeleteOperationMetadata>>
Deletes an IndexEndpoint.
deleteOperation(DeleteOperationRequest request) → Future<void>
Provides the Operations service functionality in this service.
deployIndex(DeployIndexRequest request) → Future<Operation<DeployIndexResponse, DeployIndexOperationMetadata>>
Deploys an Index into this IndexEndpoint, creating a DeployedIndex within it. Only non-empty Indexes can be deployed.
getIamPolicy(GetIamPolicyRequest request) → Future<Policy>
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
getIndexEndpoint(GetIndexEndpointRequest request) → Future<IndexEndpoint>
Gets an IndexEndpoint.
getLocation(GetLocationRequest request) → Future<Location>
Gets information about a location.
getOperation<T extends ProtoMessage, S extends ProtoMessage>(Operation<T, S> request) → Future<Operation<T, S>>
Provides the Operations service functionality in this service.
listIndexEndpoints(ListIndexEndpointsRequest request) → Future<ListIndexEndpointsResponse>
Lists IndexEndpoints in a Location.
listLocations(ListLocationsRequest request) → Future<ListLocationsResponse>
Lists information about the supported locations for this service.
listOperations(ListOperationsRequest request) → Future<ListOperationsResponse>
Provides the Operations service functionality in this service.
mutateDeployedIndex(MutateDeployedIndexRequest request) → Future<Operation<MutateDeployedIndexResponse, MutateDeployedIndexOperationMetadata>>
Update an existing DeployedIndex under an IndexEndpoint.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setIamPolicy(SetIamPolicyRequest request) → Future<Policy>
Sets the access control policy on the specified resource. Replaces any existing policy.
testIamPermissions(TestIamPermissionsRequest request) → Future<TestIamPermissionsResponse>
Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a NOT_FOUND error.
toString() → String
A string representation of this object.
inherited
undeployIndex(UndeployIndexRequest request) → Future<Operation<UndeployIndexResponse, UndeployIndexOperationMetadata>>
Undeploys an Index from an IndexEndpoint, removing a DeployedIndex from it, and freeing all resources it's using.
updateIndexEndpoint(UpdateIndexEndpointRequest request) → Future<IndexEndpoint>
Updates an IndexEndpoint.
waitOperation(WaitOperationRequest request) → Future<Operation<ProtoMessage, ProtoMessage>>
Provides the Operations service functionality in this service.

Operators

operator ==(Object other) → bool
The equality operator.
inherited