IndexStats class final

Stats of the Index.

Constructors

IndexStats({int vectorsCount = 0, int sparseVectorsCount = 0, int shardsCount = 0})
IndexStats.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shardsCount → int
Output only. The number of shards in the Index.
final
sparseVectorsCount → int
Output only. The number of sparse vectors in the Index.
final
vectorsCount → int
Output only. The number of dense vectors in the Index.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String