Index_IndexUpdateMethod class final

The update method of an Index.

Constructors

Index_IndexUpdateMethod(String value)
const
Index_IndexUpdateMethod.fromJson(Object? json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isNotDefault → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object?
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$default → const Index_IndexUpdateMethod
The default value for Index_IndexUpdateMethod.
batchUpdate → const Index_IndexUpdateMethod
BatchUpdate: user can call UpdateIndex with files on Cloud Storage of Datapoints to update.
indexUpdateMethodUnspecified → const Index_IndexUpdateMethod
Should not be used.
streamUpdate → const Index_IndexUpdateMethod
StreamUpdate: user can call UpsertDatapoints/DeleteDatapoints to update the Index and the updates will be applied in corresponding DeployedIndexes in nearly real-time.