IntegratedGradientsAttribution class final

An attribution method that computes the Aumann-Shapley value taking advantage of the model's fully differentiable structure. Refer to this paper for more details: https://arxiv.org/abs/1703.01365

Constructors

IntegratedGradientsAttribution({required int stepCount, SmoothGradConfig? smoothGradConfig, BlurBaselineConfig? blurBaselineConfig})
IntegratedGradientsAttribution.fromJson(Object? j)
factory

Properties

blurBaselineConfig → BlurBaselineConfig?
Config for IG with blur baseline.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
smoothGradConfig → SmoothGradConfig?
Config for SmoothGrad approximation of gradients.
final
stepCount → int
Required. The number of steps for approximating the path integral. A good value to start is 50 and gradually increase until the sum to diff property is within the desired error range.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String