LineageSubgraph class final

A subgraph of the overall lineage graph. Event edges connect Artifact and Execution nodes.

Constructors

LineageSubgraph({List<Artifact> artifacts = const [], List<Execution> executions = const [], List<Event> events = const []})
LineageSubgraph.fromJson(Object? j)
factory

Properties

artifacts → List<Artifact>
The Artifact nodes in the subgraph.
final
events → List<Event>
The Event edges between Artifacts and Executions in the subgraph.
final
executions → List<Execution>
The Execution nodes in the subgraph.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String