ListDataItemsRequest class final

Request message for DatasetService.ListDataItems.

Constructors

ListDataItemsRequest({required String parent, String filter = '', int pageSize = 0, String pageToken = '', FieldMask? readMask, String orderBy = ''})
ListDataItemsRequest.fromJson(Object? j)
factory

Properties

filter → String
The standard list filter.
final
hashCode → int
The hash code for this object.
no setterinherited
orderBy → String
A comma-separated list of fields to order by, sorted in ascending order. Use "desc" after a field name for descending.
final
pageSize → int
The standard list page size.
final
pageToken → String
The standard list page token.
final
parent → String
Required. The resource name of the Dataset to list DataItems from. Format: projects/{project}/locations/{location}/datasets/{dataset}
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
readMask → FieldMask?
Mask specifying which fields to read.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String