ListFeatureViewSyncsRequest class final

Request message for FeatureOnlineStoreAdminService.ListFeatureViewSyncs.

Constructors

ListFeatureViewSyncsRequest({required String parent, String filter = '', int pageSize = 0, String pageToken = '', String orderBy = ''})
ListFeatureViewSyncsRequest.fromJson(Object? j)
factory

Properties

filter → String
Lists the FeatureViewSyncs that match the filter expression. The following filters are supported:
final
hashCode → int
The hash code for this object.
no setterinherited
orderBy → String
A comma-separated list of fields to order by, sorted in ascending order. Use "desc" after a field name for descending.
final
pageSize → int
The maximum number of FeatureViewSyncs to return. The service may return fewer than this value. If unspecified, at most 1000 FeatureViewSyncs will be returned. The maximum value is 1000; any value greater than 1000 will be coerced to 1000.
final
pageToken → String
A page token, received from a previous FeatureOnlineStoreAdminService.ListFeatureViewSyncs call. Provide this to retrieve the subsequent page.
final
parent → String
Required. The resource name of the FeatureView to list FeatureViewSyncs. Format: projects/{project}/locations/{location}/featureOnlineStores/{feature_online_store}/featureViews/{feature_view}
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String