ListFeatureViewsResponse class final

Response message for FeatureOnlineStoreAdminService.ListFeatureViews.

Constructors

ListFeatureViewsResponse({List<FeatureView> featureViews = const [], String nextPageToken = ''})
ListFeatureViewsResponse.fromJson(Object? j)
factory

Properties

featureViews → List<FeatureView>
The FeatureViews matching the request.
final
hashCode → int
The hash code for this object.
no setterinherited
nextPageToken → String
A token, which can be sent as ListFeatureViewsRequest.page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String