ListFeaturesRequest class final

Request message for FeaturestoreService.ListFeatures. Request message for FeatureRegistryService.ListFeatures.

Constructors

ListFeaturesRequest({required String parent, String filter = '', int pageSize = 0, String pageToken = '', String orderBy = '', FieldMask? readMask, int latestStatsCount = 0})
ListFeaturesRequest.fromJson(Object? j)
factory

Properties

filter → String
Lists the Features that match the filter expression. The following filters are supported:
final
hashCode → int
The hash code for this object.
no setterinherited
latestStatsCount → int
Only applicable for Vertex AI Feature Store (Legacy). If set, return the most recent ListFeaturesRequest.latest_stats_count of stats for each Feature in response. Valid value is 0, 10. If number of stats exists < ListFeaturesRequest.latest_stats_count, return all existing stats.
final
orderBy → String
A comma-separated list of fields to order by, sorted in ascending order. Use "desc" after a field name for descending. Supported fields:
final
pageSize → int
The maximum number of Features to return. The service may return fewer than this value. If unspecified, at most 1000 Features will be returned. The maximum value is 1000; any value greater than 1000 will be coerced to 1000.
final
pageToken → String
A page token, received from a previous FeaturestoreService.ListFeatures call or FeatureRegistryService.ListFeatures call. Provide this to retrieve the subsequent page.
final
parent → String
Required. The resource name of the Location to list Features. Format for entity_type as parent: projects/{project}/locations/{location}/featurestores/{featurestore}/entityTypes/{entity_type} Format for feature_group as parent: projects/{project}/locations/{location}/featureGroups/{feature_group}
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
readMask → FieldMask?
Mask specifying which fields to read.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String