ListMetadataStoresRequest class final

Request message for MetadataService.ListMetadataStores.

Constructors

ListMetadataStoresRequest({required String parent, int pageSize = 0, String pageToken = ''})
ListMetadataStoresRequest.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
pageSize → int
The maximum number of Metadata Stores to return. The service may return fewer. Must be in range 1-1000, inclusive. Defaults to 100.
final
pageToken → String
A page token, received from a previous MetadataService.ListMetadataStores call. Provide this to retrieve the subsequent page.
final
parent → String
Required. The Location whose MetadataStores should be listed. Format: projects/{project}/locations/{location}
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String