ListModelVersionsRequest class final

Request message for ModelService.ListModelVersions.

Constructors

ListModelVersionsRequest({required String name, int pageSize = 0, String pageToken = '', String filter = '', FieldMask? readMask, String orderBy = ''})
ListModelVersionsRequest.fromJson(Object? j)
factory

Properties

filter → String
An expression for filtering the results of the request. For field names both snake_case and camelCase are supported.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
Required. The name of the model to list versions for.
final
orderBy → String
A comma-separated list of fields to order by, sorted in ascending order. Use "desc" after a field name for descending. Supported fields:
final
pageSize → int
The standard list page size.
final
pageToken → String
The standard list page token. Typically obtained via next_page_token of the previous ListModelVersions call.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
readMask → FieldMask?
Mask specifying which fields to read.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String