ListNasTrialDetailsRequest class final

Request message for JobService.ListNasTrialDetails.

Constructors

ListNasTrialDetailsRequest({required String parent, int pageSize = 0, String pageToken = ''})
ListNasTrialDetailsRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
pageSize int
The standard list page size.
final
pageToken String
The standard list page token. Typically obtained via ListNasTrialDetailsResponse.next_page_token of the previous JobService.ListNasTrialDetails call.
final
parent String
Required. The name of the NasJob resource. Format: projects/{project}/locations/{location}/nasJobs/{nas_job}
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String