ListOptimalTrialsResponse class final

Response message for VizierService.ListOptimalTrials.

Constructors

ListOptimalTrialsResponse({List<Trial> optimalTrials = const []})
ListOptimalTrialsResponse.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
optimalTrials → List<Trial>
The pareto-optimal Trials for multiple objective Study or the optimal trial for single objective Study. The definition of pareto-optimal can be checked in wiki page. https://en.wikipedia.org/wiki/Pareto_efficiency
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String