ListPublisherModelsRequest class final

Request message for ModelGardenService.ListPublisherModels.

Constructors

ListPublisherModelsRequest({required String parent, String filter = '', int pageSize = 0, String pageToken = '', PublisherModelView view = PublisherModelView.$default, String orderBy = '', String languageCode = '', bool listAllVersions = false})
ListPublisherModelsRequest.fromJson(Object? j)
factory

Properties

filter → String
Optional. The standard list filter.
final
hashCode → int
The hash code for this object.
no setterinherited
languageCode → String
Optional. The IETF BCP-47 language code representing the language in which the publisher models' text information should be written in. If not set, by default English (en).
final
listAllVersions → bool
Optional. List all publisher model versions if the flag is set to true.
final
orderBy → String
Optional. A comma-separated list of fields to order by, sorted in ascending order. Use "desc" after a field name for descending.
final
pageSize → int
Optional. The standard list page size.
final
pageToken → String
Optional. The standard list page token. Typically obtained via ListPublisherModelsResponse.next_page_token of the previous ModelGardenService.ListPublisherModels call.
final
parent → String
Required. The name of the Publisher from which to list the PublisherModels. Format: publishers/{publisher}
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
view → PublisherModelView
Optional. PublisherModel view specifying which fields to read.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String