ListRagDataSchemasRequest class final

Request message for VertexRagDataService.ListRagDataSchemas.

Constructors

ListRagDataSchemasRequest({required String parent, int pageSize = 0, String pageToken = ''})
ListRagDataSchemasRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
pageSize int
Optional. The standard list page size. The maximum value is 100. If not specified, a default value of 100 will be used.
final
pageToken String
Optional. The standard list page token. Typically obtained via ListRagDataSchemasResponse.next_page_token of the previous VertexRagDataService.ListRagDataSchemas call.
final
parent String
Required. The resource name of the RagCorpus from which to list the RagDataSchemas. Format: projects/{project}/locations/{location}/ragCorpora/{rag_corpus}
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String