ListReasoningEngineRuntimeRevisionsRequest class final

Request message for ReasoningEngineRuntimeRevisionService.ListReasoningEngineRuntimeRevisions.

Constructors

ListReasoningEngineRuntimeRevisionsRequest({required String parent, String filter = '', int pageSize = 0, String pageToken = ''})
ListReasoningEngineRuntimeRevisionsRequest.fromJson(Object? j)
factory

Properties

filter String
Optional. The standard list filter. More detail in AIP-160.
final
hashCode int
The hash code for this object.
no setterinherited
pageSize int
Optional. The maximum number of ReasoningEngineRuntimeRevisions to return. The service may return fewer than this value.
final
pageToken String
Optional. The standard list page token.
final
parent String
Required. The resource name of the ReasoningEngine to list the ReasoningEngineRuntimeRevisions from. Format: projects/{project}/locations/{location}/reasoningEngines/{reasoning_engine}
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String