ListSessionsRequest class final

Request message for SessionService.ListSessions.

Constructors

ListSessionsRequest({required String parent, int pageSize = 0, String pageToken = '', String filter = '', String orderBy = ''})
ListSessionsRequest.fromJson(Object? j)
factory

Properties

filter → String
Optional. The standard list filter. Supported fields:
final
hashCode → int
The hash code for this object.
no setterinherited
orderBy → String
Optional. A comma-separated list of fields to order by, sorted in ascending order. Use "desc" after a field name for descending. Supported fields:
final
pageSize → int
Optional. The maximum number of sessions to return. The service may return fewer than this value. If unspecified, at most 100 sessions will be returned.
final
pageToken → String
Optional. The next_page_token value returned from a previous list SessionService.ListSessions call.
final
parent → String
Required. The resource name of the location to list sessions from. Format: projects/{project}/locations/{location}/reasoningEngines/{reasoning_engine}
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String