ListStudiesRequest class final

Request message for VizierService.ListStudies.

Constructors

ListStudiesRequest({required String parent, String pageToken = '', int pageSize = 0})
ListStudiesRequest.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
pageSize → int
Optional. The maximum number of studies to return per "page" of results. If unspecified, service will pick an appropriate default.
final
pageToken → String
Optional. A page token to request the next page of results. If unspecified, there are no subsequent pages.
final
parent → String
Required. The resource name of the Location to list the Study from. Format: projects/{project}/locations/{location}
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String