ListTensorboardExperimentsRequest class final

Request message for TensorboardService.ListTensorboardExperiments.

Constructors

ListTensorboardExperimentsRequest({required String parent, String filter = '', int pageSize = 0, String pageToken = '', String orderBy = '', FieldMask? readMask})
ListTensorboardExperimentsRequest.fromJson(Object? j)
factory

Properties

filter → String
Lists the TensorboardExperiments that match the filter expression.
final
hashCode → int
The hash code for this object.
no setterinherited
orderBy → String
Field to use to sort the list.
final
pageSize → int
The maximum number of TensorboardExperiments to return. The service may return fewer than this value. If unspecified, at most 50 TensorboardExperiments are returned. The maximum value is 1000; values above 1000 are coerced to 1000.
final
pageToken → String
A page token, received from a previous TensorboardService.ListTensorboardExperiments call. Provide this to retrieve the subsequent page.
final
parent → String
Required. The resource name of the Tensorboard to list TensorboardExperiments. Format: projects/{project}/locations/{location}/tensorboards/{tensorboard}
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
readMask → FieldMask?
Mask specifying which fields to read.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String