LustreMount class final

Represents a mount configuration for Lustre file system.

Constructors

LustreMount({required String instanceIp, required String volumeHandle, required String filesystem, required String mountPoint})
LustreMount.fromJson(Object? j)
factory

Properties

filesystem → String
Required. The name of the Lustre filesystem.
final
hashCode → int
The hash code for this object.
no setterinherited
instanceIp → String
Required. IP address of the Lustre instance.
final
mountPoint → String
Required. Destination mount path. The Lustre file system will be mounted for the user under /mnt/lustre/<mount_point>
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
volumeHandle → String
Required. The unique identifier of the Lustre volume.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String