mountPoint property
Required. Destination mount path. The Lustre file system will be mounted for the user under /mnt/lustre/<mount_point>
Implementation
final String mountPoint;
Required. Destination mount path. The Lustre file system will be mounted for the user under /mnt/lustre/<mount_point>
final String mountPoint;