Measurement_Metric class final

A message representing a metric in the measurement.

Constructors

Measurement_Metric({String metricId = '', double value = 0})
Measurement_Metric.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
metricId → String
Output only. The ID of the Metric. The Metric should be defined in google.cloud.aiplatform.v1beta1.StudySpec.metrics.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → double
Output only. The value for this metric.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String