Memory class final

A memory.

Constructors

Memory({Timestamp? expireTime, Duration? ttl, String name = '', String displayName = '', String description = '', Timestamp? createTime, Timestamp? updateTime, required String fact, required Map<String, String> scope})
Memory.fromJson(Object? j)
factory

Properties

createTime → Timestamp?
Output only. Timestamp when this Memory was created.
final
description → String
Optional. Description of the Memory.
final
displayName → String
Optional. Display name of the Memory.
final
expireTime → Timestamp?
Optional. Timestamp of when this resource is considered expired. This is always provided on output, regardless of what expiration was sent on input.
final
fact → String
Required. Semantic knowledge extracted from the source content.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
Identifier. The resource name of the Memory. Format: projects/{project}/locations/{location}/reasoningEngines/{reasoning_engine}/memories/{memory}
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → Map<String, String>
Required. Immutable. The scope of the Memory. Memories are isolated within their scope. The scope is defined when creating or generating memories. Scope values cannot contain the wildcard character '*'.
final
ttl → Duration?
Optional. Input only. The TTL for this resource. The expiration time is computed: now + TTL.
final
updateTime → Timestamp?
Output only. Timestamp when this Memory was most recently updated.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String