MetadataSchema class final

Instance of a general MetadataSchema.

Constructors

MetadataSchema({String name = '', String schemaVersion = '', required String schema, MetadataSchema_MetadataSchemaType schemaType = MetadataSchema_MetadataSchemaType.$default, Timestamp? createTime, String description = ''})
MetadataSchema.fromJson(Object? j)
factory

Properties

createTime → Timestamp?
Output only. Timestamp when this MetadataSchema was created.
final
description → String
Description of the Metadata Schema
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
Output only. The resource name of the MetadataSchema.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schema → String
Required. The raw YAML string representation of the MetadataSchema. The combination of MetadataSchema.version and the schema name given by title in MetadataSchema.schema must be unique within a MetadataStore.
final
schemaType → MetadataSchema_MetadataSchemaType
The type of the MetadataSchema. This is a property that identifies which metadata types will use the MetadataSchema.
final
schemaVersion → String
The version of the MetadataSchema. The version's format must match the following regular expression: ^[0-9]+[.][0-9]+[.][0-9]+$, which would allow to order/compare different versions. Example: 1.0.0, 1.0.1, etc.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String