MetadataStore_MetadataStoreState class final

Represents state information for a MetadataStore.

Constructors

MetadataStore_MetadataStoreState({int diskUtilizationBytes = 0})
MetadataStore_MetadataStoreState.fromJson(Object? j)
factory

Properties

diskUtilizationBytes int
The disk utilization of the MetadataStore in bytes.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String