Metric class final

The metric used for running evaluations.

Constructors

Metric({PredefinedMetricSpec? predefinedMetricSpec, ComputationBasedMetricSpec? computationBasedMetricSpec, LlmbasedMetricSpec? llmBasedMetricSpec, CustomCodeExecutionSpec? customCodeExecutionSpec, PointwiseMetricSpec? pointwiseMetricSpec, PairwiseMetricSpec? pairwiseMetricSpec, ExactMatchSpec? exactMatchSpec, BleuSpec? bleuSpec, RougeSpec? rougeSpec, List<Metric_AggregationMetric> aggregationMetrics = const [], MetricMetadata? metadata})
Metric.fromJson(Object? j)
factory

Properties

aggregationMetrics → List<Metric_AggregationMetric>
Optional. The aggregation metrics to use.
final
bleuSpec → BleuSpec?
Spec for bleu metric.
final
computationBasedMetricSpec → ComputationBasedMetricSpec?
Spec for a computation based metric.
final
customCodeExecutionSpec → CustomCodeExecutionSpec?
Spec for Custom Code Execution metric.
final
exactMatchSpec → ExactMatchSpec?
Spec for exact match metric.
final
hashCode → int
The hash code for this object.
no setterinherited
llmBasedMetricSpec → LlmbasedMetricSpec?
Spec for an LLM based metric.
final
metadata → MetricMetadata?
Optional. Metadata about the metric, used for visualization and organization.
final
pairwiseMetricSpec → PairwiseMetricSpec?
Spec for pairwise metric.
final
pointwiseMetricSpec → PointwiseMetricSpec?
Spec for pointwise metric.
final
predefinedMetricSpec → PredefinedMetricSpec?
The spec for a pre-defined metric.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
rougeSpec → RougeSpec?
Spec for rouge metric.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String