MetricMetadata class final

Metadata about the metric, used for visualization and organization.

Constructors

MetricMetadata({String title = '', MetricMetadata_ScoreRange? scoreRange, Struct? otherMetadata})
MetricMetadata.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
otherMetadata → Struct?
Optional. Flexible metadata for user-defined attributes.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scoreRange MetricMetadata_ScoreRange?
Optional. The range of possible scores for this metric, used for plotting.
final
title String
Optional. The user-friendly name for the metric. If not set for a registered metric, it will default to the metric's display name.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String