title property
Optional. The user-friendly name for the metric. If not set for a registered metric, it will default to the metric's display name.
Implementation
final String title;
Optional. The user-friendly name for the metric. If not set for a registered metric, it will default to the metric's display name.
final String title;