MetricMetadata_ScoreRange class final

The range of possible scores for this metric, used for plotting.

Constructors

MetricMetadata_ScoreRange({required double? min, required double? max, double? step, String description = ''})
MetricMetadata_ScoreRange.fromJson(Object? j)
factory

Properties

description String
Optional. The description of the score explaining the directionality etc.
final
hashCode int
The hash code for this object.
no setterinherited
max double?
Required. The maximum value of the score range (inclusive).
final
min double?
Required. The minimum value of the score range (inclusive).
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
step double?
Optional. The distance between discrete steps in the range. If unset, the range is assumed to be continuous.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String