MetricResult class final

Result for a single metric on a single instance.

Constructors

MetricResult({double? score, List<RubricVerdict> rubricVerdicts = const [], String? explanation, Status? error})
MetricResult.fromJson(Object? j)
factory

Properties

error → Status?
Output only. The error status for the metric result.
final
explanation → String?
Output only. The explanation for the metric result.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
rubricVerdicts → List<RubricVerdict>
Output only. For rubric-based metrics, the verdicts for each rubric.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
score → double?
Output only. The score for the metric. Please refer to each metric's documentation for the meaning of the score.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String