MetricxInstance class final

Spec for MetricX instance - The fields used for evaluation are dependent on the MetricX version.

Constructors

MetricxInstance({required String? prediction, String? reference, String? source})
MetricxInstance.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
prediction → String?
Required. Output of the evaluated model.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
reference → String?
Optional. Ground truth used to compare against the prediction.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → String?
Optional. Source text in original language.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String