MigratableResource_DataLabelingDataset class final

Represents one Dataset in datalabeling.googleapis.com.

Constructors

MigratableResource_DataLabelingDataset({String dataset = '', String datasetDisplayName = '', List<MigratableResource_DataLabelingDataset_DataLabelingAnnotatedDataset> dataLabelingAnnotatedDatasets = const []})
MigratableResource_DataLabelingDataset.fromJson(Object? j)
factory

Properties

dataLabelingAnnotatedDatasets → List<MigratableResource_DataLabelingDataset_DataLabelingAnnotatedDataset>
The migratable AnnotatedDataset in datalabeling.googleapis.com belongs to the data labeling Dataset.
final
dataset → String
Full resource name of data labeling Dataset. Format: projects/{project}/datasets/{dataset}.
final
datasetDisplayName → String
The Dataset's display name in datalabeling.googleapis.com.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String