MigratableResource_DataLabelingDataset_DataLabelingAnnotatedDataset class final

Represents one AnnotatedDataset in datalabeling.googleapis.com.

Properties

annotatedDataset → String
Full resource name of data labeling AnnotatedDataset. Format: projects/{project}/datasets/{dataset}/annotatedDatasets/{annotated_dataset}.
final
annotatedDatasetDisplayName → String
The AnnotatedDataset's display name in datalabeling.googleapis.com.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String