MigrateResourceRequest_MigrateDataLabelingDatasetConfig class final

Config for migrating Dataset in datalabeling.googleapis.com to Vertex AI's Dataset.

Properties

dataset → String
Required. Full resource name of data labeling Dataset. Format: projects/{project}/datasets/{dataset}.
final
datasetDisplayName → String
Optional. Display name of the Dataset in Vertex AI. System will pick a display name if unspecified.
final
hashCode → int
The hash code for this object.
no setterinherited
migrateDataLabelingAnnotatedDatasetConfigs → List<MigrateResourceRequest_MigrateDataLabelingDatasetConfig_MigrateDataLabelingAnnotatedDatasetConfig>
Optional. Configs for migrating AnnotatedDataset in datalabeling.googleapis.com to Vertex AI's SavedQuery. The specified AnnotatedDatasets have to belong to the datalabeling Dataset.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String