ModelDeploymentMonitoringJob_LatestMonitoringPipelineMetadata class final

All metadata of most recent monitoring pipelines.

Properties

hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runTime → Timestamp?
The time that most recent monitoring pipelines that is related to this run.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status → Status?
The status of the most recent monitoring pipeline.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String