ModelExplanation class final

Aggregated explanation metrics for a Model over a set of instances.

Constructors

ModelExplanation({List<Attribution> meanAttributions = const []})
ModelExplanation.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
meanAttributions → List<Attribution>
Output only. Aggregated attributions explaining the Model's prediction outputs over the set of instances. The attributions are grouped by outputs.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String