ModelGardenService class final

The interface of Model Garden Service.

Implementers

Constructors

ModelGardenService({required Client client, Uri? endPoint, String? gcclVersion})
Creates a ModelGardenService using client for transport.
ModelGardenService.fromApiKey([String? apiKey])
Creates a ModelGardenService that does authentication through an API key.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

acceptPublisherModelEula(AcceptPublisherModelEulaRequest request) → Future<PublisherModelEulaAcceptance>
Accepts the EULA acceptance status of a publisher model.
cancelOperation(CancelOperationRequest request) → Future<void>
Provides the Operations service functionality in this service.
checkPublisherModelEulaAcceptance(CheckPublisherModelEulaAcceptanceRequest request) → Future<PublisherModelEulaAcceptance>
Checks the EULA acceptance status of a publisher model.
close() → void
Closes the client and cleans up any resources associated with it.
deleteOperation(DeleteOperationRequest request) → Future<void>
Provides the Operations service functionality in this service.
deploy(DeployRequest request) → Future<Operation<DeployResponse, DeployOperationMetadata>>
Deploys a model to a new endpoint.
deployPublisherModel(DeployPublisherModelRequest request) → Future<Operation<DeployPublisherModelResponse, DeployPublisherModelOperationMetadata>>
Deploys publisher models.
exportPublisherModel(ExportPublisherModelRequest request) → Future<Operation<ExportPublisherModelResponse, ExportPublisherModelOperationMetadata>>
Exports a publisher model to a user provided Google Cloud Storage bucket.
getIamPolicy(GetIamPolicyRequest request) → Future<Policy>
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
getLocation(GetLocationRequest request) → Future<Location>
Gets information about a location.
getOperation<T extends ProtoMessage, S extends ProtoMessage>(Operation<T, S> request) → Future<Operation<T, S>>
Provides the Operations service functionality in this service.
getPublisherModel(GetPublisherModelRequest request) → Future<PublisherModel>
Gets a Model Garden publisher model.
listLocations(ListLocationsRequest request) → Future<ListLocationsResponse>
Lists information about the supported locations for this service.
listOperations(ListOperationsRequest request) → Future<ListOperationsResponse>
Provides the Operations service functionality in this service.
listPublisherModels(ListPublisherModelsRequest request) → Future<ListPublisherModelsResponse>
Lists publisher models in Model Garden.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setIamPolicy(SetIamPolicyRequest request) → Future<Policy>
Sets the access control policy on the specified resource. Replaces any existing policy.
testIamPermissions(TestIamPermissionsRequest request) → Future<TestIamPermissionsResponse>
Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a NOT_FOUND error.
toString() → String
A string representation of this object.
inherited
waitOperation(WaitOperationRequest request) → Future<Operation<ProtoMessage, ProtoMessage>>
Provides the Operations service functionality in this service.

Operators

operator ==(Object other) → bool
The equality operator.
inherited