ModelMonitor_ModelMonitoringTarget class final

The monitoring target refers to the entity that is subject to analysis. e.g. Vertex AI Model version.

Properties

hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vertexModel ModelMonitor_ModelMonitoringTarget_VertexModelSource?
Model in Vertex AI Model Registry.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String