ModelMonitoringAlert class final

Represents a single monitoring alert. This is currently used in the SearchModelMonitoringAlerts api, thus the alert wrapped in this message belongs to the resource asked in the request.

Constructors

ModelMonitoringAlert({String statsName = '', String objectiveType = '', Timestamp? alertTime, ModelMonitoringAnomaly? anomaly})
ModelMonitoringAlert.fromJson(Object? j)
factory

Properties

alertTime → Timestamp?
Alert creation time.
final
anomaly → ModelMonitoringAnomaly?
Anomaly details.
final
hashCode → int
The hash code for this object.
no setterinherited
objectiveType → String
One of the supported monitoring objectives: raw-feature-drift prediction-output-drift feature-attribution
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statsName → String
The stats name.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String