ModelMonitoringAnomaly class final

Represents a single model monitoring anomaly.

Constructors

ModelMonitoringAnomaly({ModelMonitoringAnomaly_TabularAnomaly? tabularAnomaly, String modelMonitoringJob = '', String algorithm = ''})
ModelMonitoringAnomaly.fromJson(Object? j)
factory

Properties

algorithm → String
Algorithm used to calculated the metrics, eg: jensen_shannon_divergence, l_infinity.
final
hashCode → int
The hash code for this object.
no setterinherited
modelMonitoringJob → String
Model monitoring job resource name.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tabularAnomaly → ModelMonitoringAnomaly_TabularAnomaly?
Tabular anomaly.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String