ModelMonitoringAnomaly_TabularAnomaly class final

Tabular anomaly details.

Constructors

ModelMonitoringAnomaly_TabularAnomaly({String anomalyUri = '', String summary = '', Value? anomaly, Timestamp? triggerTime, ModelMonitoringAlertCondition? condition})
ModelMonitoringAnomaly_TabularAnomaly.fromJson(Object? j)
factory

Properties

anomaly → Value?
Anomaly body.
final
anomalyUri → String
Additional anomaly information. e.g. Google Cloud Storage uri.
final
condition → ModelMonitoringAlertCondition?
The alert condition associated with this anomaly.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
summary → String
Overview of this anomaly.
final
triggerTime → Timestamp?
The time the anomaly was triggered.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String