ModelMonitoringInput_BatchPredictionOutput class final

Data from Vertex AI Batch prediction job output.

Properties

batchPredictionJob String
Vertex AI Batch prediction job resource name. The job must match the model version specified in ModelMonitor.model_monitoring_target.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String