ModelMonitoringJob class final

Represents a model monitoring job that analyze dataset using different monitoring algorithm.

Constructors

ModelMonitoringJob({String name = '', String displayName = '', ModelMonitoringSpec? modelMonitoringSpec, Timestamp? createTime, Timestamp? updateTime, JobState state = JobState.$default, String schedule = '', ModelMonitoringJobExecutionDetail? jobExecutionDetail, Timestamp? scheduleTime})
ModelMonitoringJob.fromJson(Object? j)
factory

Properties

createTime → Timestamp?
Output only. Timestamp when this ModelMonitoringJob was created.
final
displayName → String
The display name of the ModelMonitoringJob. The name can be up to 128 characters long and can consist of any UTF-8.
final
hashCode → int
The hash code for this object.
no setterinherited
jobExecutionDetail → ModelMonitoringJobExecutionDetail?
Output only. Execution results for all the monitoring objectives.
final
modelMonitoringSpec → ModelMonitoringSpec?
Monitoring monitoring job spec. It outlines the specifications for monitoring objectives, notifications, and result exports. If left blank, the default monitoring specifications from the top-level resource 'ModelMonitor' will be applied. If provided, we will use the specification defined here rather than the default one.
final
name → String
Output only. Resource name of a ModelMonitoringJob. Format: projects/{project_id}/locations/{location_id}/modelMonitors/{model_monitor_id}/modelMonitoringJobs/{model_monitoring_job_id}
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schedule → String
Output only. Schedule resource name. It will only appear when this job is triggered by a schedule.
final
scheduleTime → Timestamp?
Output only. Timestamp when this ModelMonitoringJob was scheduled. It will only appear when this job is triggered by a schedule.
final
state → JobState
Output only. The state of the monitoring job.
final
updateTime → Timestamp?
Output only. Timestamp when this ModelMonitoringJob was updated most recently.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String