ModelMonitoringObjectiveConfig_PredictionDriftDetectionConfig class final

The config for Prediction data drift detection.

Constructors

ModelMonitoringObjectiveConfig_PredictionDriftDetectionConfig({Map<String, ThresholdConfig> driftThresholds = const {}, Map<String, ThresholdConfig> attributionScoreDriftThresholds = const {}, ThresholdConfig? defaultDriftThreshold})
ModelMonitoringObjectiveConfig_PredictionDriftDetectionConfig.fromJson(Object? j)
factory

Properties

attributionScoreDriftThresholds → Map<String, ThresholdConfig>
Key is the feature name and value is the threshold. The threshold here is against attribution score distance between different time windows.
final
defaultDriftThreshold → ThresholdConfig?
Drift anomaly detection threshold used by all features. When the per-feature thresholds are not set, this field can be used to specify a threshold for all features.
final
driftThresholds → Map<String, ThresholdConfig>
Key is the feature name and value is the threshold. If a feature needs to be monitored for drift, a value threshold must be configured for that feature. The threshold here is against feature distribution distance between different time windws.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String