ModelMonitoringObjectiveConfig_TrainingPredictionSkewDetectionConfig class final

The config for Training & Prediction data skew detection. It specifies the training dataset sources and the skew detection parameters.

Properties

attributionScoreSkewThresholds → Map<String, ThresholdConfig>
Key is the feature name and value is the threshold. The threshold here is against attribution score distance between the training and prediction feature.
final
defaultSkewThreshold → ThresholdConfig?
Skew anomaly detection threshold used by all features. When the per-feature thresholds are not set, this field can be used to specify a threshold for all features.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skewThresholds → Map<String, ThresholdConfig>
Key is the feature name and value is the threshold. If a feature needs to be monitored for skew, a value threshold must be configured for that feature. The threshold here is against feature distribution distance between the training and prediction feature.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String