ModelMonitoringObjectiveSpec_FeatureAttributionSpec class final

Feature attribution monitoring spec.

Constructors

ModelMonitoringObjectiveSpec_FeatureAttributionSpec({List<String> features = const [], ModelMonitoringAlertCondition? defaultAlertCondition, Map<String, ModelMonitoringAlertCondition> featureAlertConditions = const {}, BatchDedicatedResources? batchExplanationDedicatedResources})
ModelMonitoringObjectiveSpec_FeatureAttributionSpec.fromJson(Object? j)
factory

Properties

batchExplanationDedicatedResources → BatchDedicatedResources?
The config of resources used by the Model Monitoring during the batch explanation for non-AutoML models. If not set, n1-standard-2 machine type will be used by default.
final
defaultAlertCondition → ModelMonitoringAlertCondition?
Default alert condition for all the features.
final
featureAlertConditions → Map<String, ModelMonitoringAlertCondition>
Per feature alert condition will override default alert condition.
final
features → List<String>
Feature names interested in monitoring. These should be a subset of the input feature names specified in the monitoring schema. If the field is not specified all features outlied in the monitoring schema will be used.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String