ModelMonitoringSchema_FieldSchema class final

Schema field definition.

Constructors

ModelMonitoringSchema_FieldSchema({String name = '', String dataType = '', bool repeated = false})
ModelMonitoringSchema_FieldSchema.fromJson(Object? j)
factory

Properties

dataType → String
Supported data types are: float integer boolean string categorical
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
Field name.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
repeated → bool
Describes if the schema field is an array of given data type.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String