ModelMonitoringStatsAnomalies class final

Statistics and anomalies generated by Model Monitoring.

Constructors

ModelMonitoringStatsAnomalies({ModelDeploymentMonitoringObjectiveType objective = ModelDeploymentMonitoringObjectiveType.$default, String deployedModelId = '', int anomalyCount = 0, List<ModelMonitoringStatsAnomalies_FeatureHistoricStatsAnomalies> featureStats = const []})
ModelMonitoringStatsAnomalies.fromJson(Object? j)
factory

Properties

anomalyCount → int
Number of anomalies within all stats.
final
deployedModelId → String
Deployed Model ID.
final
featureStats → List<ModelMonitoringStatsAnomalies_FeatureHistoricStatsAnomalies>
A list of historical Stats and Anomalies generated for all Features.
final
hashCode → int
The hash code for this object.
no setterinherited
objective → ModelDeploymentMonitoringObjectiveType
Model Monitoring Objective those stats and anomalies belonging to.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String