ModelMonitoringStatsDataPoint class final

Represents a single statistics data point.

Constructors

ModelMonitoringStatsDataPoint({ModelMonitoringStatsDataPoint_TypedValue? currentStats, ModelMonitoringStatsDataPoint_TypedValue? baselineStats, double thresholdValue = 0, bool hasAnomaly = false, String modelMonitoringJob = '', String schedule = '', Timestamp? createTime, String algorithm = ''})
ModelMonitoringStatsDataPoint.fromJson(Object? j)
factory

Properties

algorithm → String
Algorithm used to calculated the metrics, eg: jensen_shannon_divergence, l_infinity.
final
baselineStats → ModelMonitoringStatsDataPoint_TypedValue?
Statistics from baseline dataset.
final
createTime → Timestamp?
Statistics create time.
final
currentStats → ModelMonitoringStatsDataPoint_TypedValue?
Statistics from current dataset.
final
hasAnomaly → bool
Indicate if the statistics has anomaly.
final
hashCode → int
The hash code for this object.
no setterinherited
modelMonitoringJob → String
Model monitoring job resource name.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schedule → String
Schedule resource name.
final
thresholdValue → double
Threshold value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String