ModelMonitoringTabularStats class final

A collection of data points that describes the time-varying values of a tabular metric.

Constructors

ModelMonitoringTabularStats({String statsName = '', String objectiveType = '', List<ModelMonitoringStatsDataPoint> dataPoints = const []})
ModelMonitoringTabularStats.fromJson(Object? j)
factory

Properties

dataPoints → List<ModelMonitoringStatsDataPoint>
The data points of this time series. When listing time series, points are returned in reverse time order.
final
hashCode → int
The hash code for this object.
no setterinherited
objectiveType → String
One of the supported monitoring objectives: raw-feature-drift prediction-output-drift feature-attribution
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statsName → String
The stats name.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String