ModelSourceInfo class final

Detail description of the source information of the model.

Constructors

ModelSourceInfo({ModelSourceInfo_ModelSourceType sourceType = ModelSourceInfo_ModelSourceType.$default, bool copy = false})
ModelSourceInfo.fromJson(Object? j)
factory

Properties

copy → bool
If this Model is copy of another Model. If true then source_type pertains to the original.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceType → ModelSourceInfo_ModelSourceType
Type of the model source.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String