Model_ExportFormat class final

Represents export format supported by the Model. All formats export to Google Cloud Storage.

Constructors

Model_ExportFormat({String id = '', List<Model_ExportFormat_ExportableContent> exportableContents = const []})
Model_ExportFormat.fromJson(Object? j)
factory

Properties

exportableContents → List<Model_ExportFormat_ExportableContent>
Output only. The content of this Model that may be exported.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
Output only. The ID of the export format. The possible format IDs are:
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String