NasJob class final

Represents a Neural Architecture Search (NAS) job.

Constructors

NasJob({String name = '', required String displayName, required NasJobSpec? nasJobSpec, NasJobOutput? nasJobOutput, JobState state = JobState.$default, Timestamp? createTime, Timestamp? startTime, Timestamp? endTime, Timestamp? updateTime, Status? error, Map<String, String> labels = const {}, EncryptionSpec? encryptionSpec, bool enableRestrictedImageTraining = false, bool satisfiesPzs = false, bool satisfiesPzi = false})
NasJob.fromJson(Object? j)
factory

Properties

createTime → Timestamp?
Output only. Time when the NasJob was created.
final
displayName → String
Required. The display name of the NasJob. The name can be up to 128 characters long and can consist of any UTF-8 characters.
final
enableRestrictedImageTraining → bool
Optional. Enable a separation of Custom model training and restricted image training for tenant project.
final
encryptionSpec → EncryptionSpec?
Customer-managed encryption key options for a NasJob. If this is set, then all resources created by the NasJob will be encrypted with the provided encryption key.
final
endTime → Timestamp?
Output only. Time when the NasJob entered any of the following states: JOB_STATE_SUCCEEDED, JOB_STATE_FAILED, JOB_STATE_CANCELLED.
final
error → Status?
Output only. Only populated when job's state is JOB_STATE_FAILED or JOB_STATE_CANCELLED.
final
hashCode → int
The hash code for this object.
no setterinherited
labels → Map<String, String>
The labels with user-defined metadata to organize NasJobs.
final
name → String
Output only. Resource name of the NasJob.
final
nasJobOutput → NasJobOutput?
Output only. Output of the NasJob.
final
nasJobSpec → NasJobSpec?
Required. The specification of a NasJob.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
satisfiesPzi → bool
Output only. Reserved for future use.
final
satisfiesPzs → bool
Output only. Reserved for future use.
final
startTime → Timestamp?
Output only. Time when the NasJob for the first time entered the JOB_STATE_RUNNING state.
final
state → JobState
Output only. The detailed state of the job.
final
updateTime → Timestamp?
Output only. Time when the NasJob was most recently updated.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String