NasJobSpec class final

Represents the spec of a NasJob.

Constructors

NasJobSpec({NasJobSpec_MultiTrialAlgorithmSpec? multiTrialAlgorithmSpec, String resumeNasJobId = '', String searchSpaceSpec = ''})
NasJobSpec.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
multiTrialAlgorithmSpec → NasJobSpec_MultiTrialAlgorithmSpec?
The spec of multi-trial algorithms.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
resumeNasJobId → String
The ID of the existing NasJob in the same Project and Location which will be used to resume search. search_space_spec and nas_algorithm_spec are obtained from previous NasJob hence should not provide them again for this NasJob.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchSpaceSpec → String
It defines the search space for Neural Architecture Search (NAS).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String