NasJobSpec_MultiTrialAlgorithmSpec_MetricSpec class final

Represents a metric to optimize.

Properties

goal → NasJobSpec_MultiTrialAlgorithmSpec_MetricSpec_GoalType
Required. The optimization goal of the metric.
final
hashCode → int
The hash code for this object.
no setterinherited
metricId → String
Required. The ID of the metric. Must not contain whitespaces.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String