NasJobSpec_MultiTrialAlgorithmSpec_SearchTrialSpec class final

Represent spec for search trials.

Constructors

NasJobSpec_MultiTrialAlgorithmSpec_SearchTrialSpec({required CustomJobSpec? searchTrialJobSpec, required int maxTrialCount, required int maxParallelTrialCount, int maxFailedTrialCount = 0})
NasJobSpec_MultiTrialAlgorithmSpec_SearchTrialSpec.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxFailedTrialCount → int
The number of failed trials that need to be seen before failing the NasJob.
final
maxParallelTrialCount → int
Required. The maximum number of trials to run in parallel.
final
maxTrialCount → int
Required. The maximum number of Neural Architecture Search (NAS) trials to run.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchTrialJobSpec → CustomJobSpec?
Required. The spec of a search trial job. The same spec applies to all search trials.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String