NasJobSpec_MultiTrialAlgorithmSpec_TrainTrialSpec class final

Represent spec for train trials.

Constructors

NasJobSpec_MultiTrialAlgorithmSpec_TrainTrialSpec({required CustomJobSpec? trainTrialJobSpec, required int maxParallelTrialCount, required int frequency})
NasJobSpec_MultiTrialAlgorithmSpec_TrainTrialSpec.fromJson(Object? j)
factory

Properties

frequency → int
Required. Frequency of search trials to start train stage. Top N TrainTrialSpec.max_parallel_trial_count search trials will be trained for every M TrainTrialSpec.frequency trials searched.
final
hashCode → int
The hash code for this object.
no setterinherited
maxParallelTrialCount → int
Required. The maximum number of trials to run in parallel.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trainTrialJobSpec → CustomJobSpec?
Required. The spec of a train trial job. The same spec applies to all train trials.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String