NearestNeighbors_Neighbor class final

A neighbor of the query vector.

Constructors

NearestNeighbors_Neighbor({String entityId = '', double distance = 0, FetchFeatureValuesResponse? entityKeyValues})
NearestNeighbors_Neighbor.fromJson(Object? j)
factory

Properties

distance → double
The distance between the neighbor and the query vector.
final
entityId → String
The id of the similar entity.
final
entityKeyValues → FetchFeatureValuesResponse?
The attributes of the neighbor, e.g. filters, crowding and metadata Note that full entities are returned only when "return_full_entity" is set to true. Otherwise, only the "entity_id" and "distance" fields are populated.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String