NfsMount class final

Represents a mount configuration for Network File System (NFS) to mount.

Constructors

NfsMount({required String server, required String path, required String mountPoint})
NfsMount.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
mountPoint → String
Required. Destination mount path. The NFS will be mounted for the user under /mnt/nfs/<mount_point>
final
path → String
Required. Source path exported from NFS server. Has to start with '/', and combined with the ip address, it indicates the source mount path in the form of server:path
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
server → String
Required. IP address of the NFS server.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String