NotebookExecutionJob class final

NotebookExecutionJob represents an instance of a notebook execution.

Constructors

NotebookExecutionJob({NotebookExecutionJob_DataformRepositorySource? dataformRepositorySource, NotebookExecutionJob_GcsNotebookSource? gcsNotebookSource, NotebookExecutionJob_DirectNotebookSource? directNotebookSource, String? notebookRuntimeTemplateResourceName, NotebookExecutionJob_CustomEnvironmentSpec? customEnvironmentSpec, String? gcsOutputUri, String? executionUser, String? serviceAccount, NotebookExecutionJob_WorkbenchRuntime? workbenchRuntime, String name = '', String displayName = '', Duration? executionTimeout, String scheduleResourceName = '', JobState jobState = JobState.$default, Status? status, Timestamp? createTime, Timestamp? updateTime, Map<String, String> labels = const {}, String kernelName = '', EncryptionSpec? encryptionSpec})
NotebookExecutionJob.fromJson(Object? j)
factory

Properties

createTime → Timestamp?
Output only. Timestamp when this NotebookExecutionJob was created.
final
customEnvironmentSpec → NotebookExecutionJob_CustomEnvironmentSpec?
The custom compute configuration for an execution job.
final
dataformRepositorySource → NotebookExecutionJob_DataformRepositorySource?
The Dataform Repository pointing to a single file notebook repository.
final
directNotebookSource → NotebookExecutionJob_DirectNotebookSource?
The contents of an input notebook file.
final
displayName → String
The display name of the NotebookExecutionJob. The name can be up to 128 characters long and can consist of any UTF-8 characters.
final
encryptionSpec → EncryptionSpec?
Customer-managed encryption key spec for the notebook execution job. This field is auto-populated if the NotebookRuntimeTemplate has an encryption spec.
final
executionTimeout → Duration?
Max running time of the execution job in seconds (default 86400s / 24 hrs).
final
executionUser → String?
The user email to run the execution as. Only supported by Colab runtimes.
final
gcsNotebookSource → NotebookExecutionJob_GcsNotebookSource?
The Cloud Storage url pointing to the ipynb file. Format: gs://bucket/notebook_file.ipynb
final
gcsOutputUri → String?
The Cloud Storage location to upload the result to. Format: gs://bucket-name
final
hashCode → int
The hash code for this object.
no setterinherited
jobState → JobState
Output only. The state of the NotebookExecutionJob.
final
kernelName → String
The name of the kernel to use during notebook execution. If unset, the default kernel is used.
final
labels → Map<String, String>
The labels with user-defined metadata to organize NotebookExecutionJobs.
final
name → String
Output only. The resource name of this NotebookExecutionJob. Format: projects/{project_id}/locations/{location}/notebookExecutionJobs/{job_id}
final
notebookRuntimeTemplateResourceName → String?
The NotebookRuntimeTemplate to source compute configuration from.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheduleResourceName → String
The Schedule resource name if this job is triggered by one. Format: projects/{project_id}/locations/{location}/schedules/{schedule_id}
final
serviceAccount → String?
The service account to run the execution as.
final
status → Status?
Output only. Populated when the NotebookExecutionJob is completed. When there is an error during notebook execution, the error details are populated.
final
updateTime → Timestamp?
Output only. Timestamp when this NotebookExecutionJob was most recently updated.
final
workbenchRuntime → NotebookExecutionJob_WorkbenchRuntime?
The Workbench runtime configuration to use for the notebook execution.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String