NotebookExecutionJob_DataformRepositorySource class final

The Dataform Repository containing the input notebook.

Constructors

NotebookExecutionJob_DataformRepositorySource({String dataformRepositoryResourceName = '', String commitSha = ''})
NotebookExecutionJob_DataformRepositorySource.fromJson(Object? j)
factory

Properties

commitSha → String
The commit SHA to read repository with. If unset, the file will be read at HEAD.
final
dataformRepositoryResourceName → String
The resource name of the Dataform Repository. Format: projects/{project_id}/locations/{location}/repositories/{repository_id}
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String