NotebookRuntime class final

A runtime is a virtual machine allocated to a particular user for a particular Notebook file on temporary basis with lifetime. Default runtimes have a lifetime of 18 hours, while custom runtimes last for 6 months from their creation or last upgrade.

Constructors

NotebookRuntime({String name = '', required String runtimeUser, NotebookRuntimeTemplateRef? notebookRuntimeTemplateRef, String proxyUri = '', Timestamp? createTime, Timestamp? updateTime, NotebookRuntime_HealthState healthState = NotebookRuntime_HealthState.$default, required String displayName, String description = '', String serviceAccount = '', NotebookRuntime_RuntimeState runtimeState = NotebookRuntime_RuntimeState.$default, bool isUpgradable = false, Map<String, String> labels = const {}, Timestamp? expirationTime, String version = '', NotebookRuntimeType notebookRuntimeType = NotebookRuntimeType.$default, MachineSpec? machineSpec, PersistentDiskSpec? dataPersistentDiskSpec, NetworkSpec? networkSpec, NotebookIdleShutdownConfig? idleShutdownConfig, NotebookEucConfig? eucConfig, ShieldedVmConfig? shieldedVmConfig, List<String> networkTags = const [], NotebookSoftwareConfig? softwareConfig, EncryptionSpec? encryptionSpec, bool satisfiesPzs = false, bool satisfiesPzi = false})
NotebookRuntime.fromJson(Object? j)
factory

Properties

createTime → Timestamp?
Output only. Timestamp when this NotebookRuntime was created.
final
dataPersistentDiskSpec → PersistentDiskSpec?
Output only. The specification of https://cloud.google.com/compute/docs/disks/persistent-disks attached to the notebook runtime as data disk storage.
final
description → String
The description of the NotebookRuntime.
final
displayName → String
Required. The display name of the NotebookRuntime. The name can be up to 128 characters long and can consist of any UTF-8 characters.
final
encryptionSpec → EncryptionSpec?
Output only. Customer-managed encryption key spec for the notebook runtime.
final
eucConfig → NotebookEucConfig?
Output only. EUC configuration of the notebook runtime.
final
expirationTime → Timestamp?
Output only. Timestamp when this NotebookRuntime will be expired:
final
hashCode → int
The hash code for this object.
no setterinherited
healthState → NotebookRuntime_HealthState
Output only. The health state of the NotebookRuntime.
final
idleShutdownConfig → NotebookIdleShutdownConfig?
Output only. The idle shutdown configuration of the notebook runtime.
final
isUpgradable → bool
Output only. Whether NotebookRuntime is upgradable.
final
labels → Map<String, String>
The labels with user-defined metadata to organize your NotebookRuntime.
final
machineSpec → MachineSpec?
Output only. The specification of a single machine used by the notebook runtime.
final
name → String
Output only. The resource name of the NotebookRuntime.
final
networkSpec → NetworkSpec?
Output only. Network spec of the notebook runtime.
final
networkTags → List<String>
Optional. The Compute Engine tags to add to runtime (see Tagging instances).
final
notebookRuntimeTemplateRef → NotebookRuntimeTemplateRef?
Output only. The pointer to NotebookRuntimeTemplate this NotebookRuntime is created from.
final
notebookRuntimeType → NotebookRuntimeType
Output only. The type of the notebook runtime.
final
proxyUri → String
Output only. The proxy endpoint used to access the NotebookRuntime.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeState → NotebookRuntime_RuntimeState
Output only. The runtime (instance) state of the NotebookRuntime.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
runtimeUser → String
Required. The user email of the NotebookRuntime.
final
satisfiesPzi → bool
Output only. Reserved for future use.
final
satisfiesPzs → bool
Output only. Reserved for future use.
final
serviceAccount → String
Output only. Deprecated: This field is no longer used and the "Vertex AI Notebook Service Account" (service-PROJECT_NUMBER@gcp-sa-aiplatform-vm.iam.gserviceaccount.com) is used for the runtime workload identity. See https://cloud.google.com/iam/docs/service-agents#vertex-ai-notebook-service-account for more details.
final
shieldedVmConfig → ShieldedVmConfig?
Output only. Runtime Shielded VM spec.
final
softwareConfig → NotebookSoftwareConfig?
Output only. Software config of the notebook runtime.
final
updateTime → Timestamp?
Output only. Timestamp when this NotebookRuntime was most recently updated.
final
version → String
Output only. The VM os image version of NotebookRuntime.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String