NotebookRuntimeTemplate class final

A template that specifies runtime configurations such as machine type, runtime version, network configurations, etc. Multiple runtimes can be created from a runtime template.

Constructors

NotebookRuntimeTemplate({String name = '', required String displayName, String description = '', bool isDefault = false, MachineSpec? machineSpec, PersistentDiskSpec? dataPersistentDiskSpec, NetworkSpec? networkSpec, String serviceAccount = '', String etag = '', Map<String, String> labels = const {}, NotebookIdleShutdownConfig? idleShutdownConfig, NotebookEucConfig? eucConfig, Timestamp? createTime, Timestamp? updateTime, NotebookRuntimeType notebookRuntimeType = NotebookRuntimeType.$default, ShieldedVmConfig? shieldedVmConfig, List<String> networkTags = const [], EncryptionSpec? encryptionSpec, NotebookSoftwareConfig? softwareConfig})
NotebookRuntimeTemplate.fromJson(Object? j)
factory

Properties

createTime → Timestamp?
Output only. Timestamp when this NotebookRuntimeTemplate was created.
final
dataPersistentDiskSpec → PersistentDiskSpec?
Optional. The specification of https://cloud.google.com/compute/docs/disks/persistent-disks attached to the runtime as data disk storage.
final
description → String
The description of the NotebookRuntimeTemplate.
final
displayName → String
Required. The display name of the NotebookRuntimeTemplate. The name can be up to 128 characters long and can consist of any UTF-8 characters.
final
encryptionSpec → EncryptionSpec?
Customer-managed encryption key spec for the notebook runtime.
final
etag → String
Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens.
final
eucConfig → NotebookEucConfig?
EUC configuration of the NotebookRuntimeTemplate.
final
hashCode → int
The hash code for this object.
no setterinherited
idleShutdownConfig → NotebookIdleShutdownConfig?
The idle shutdown configuration of NotebookRuntimeTemplate. This config will only be set when idle shutdown is enabled.
final
isDefault → bool
Output only. Deprecated: This field has no behavior. Use notebook_runtime_type = 'ONE_CLICK' instead.
final
labels → Map<String, String>
The labels with user-defined metadata to organize the NotebookRuntimeTemplates.
final
machineSpec → MachineSpec?
Optional. Immutable. The specification of a single machine for the template.
final
name → String
The resource name of the NotebookRuntimeTemplate.
final
networkSpec → NetworkSpec?
Optional. Network spec.
final
networkTags → List<String>
Optional. The Compute Engine tags to add to runtime (see Tagging instances).
final
notebookRuntimeType → NotebookRuntimeType
Optional. Immutable. The type of the notebook runtime template.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAccount → String
Deprecated: This field is ignored and the "Vertex AI Notebook Service Account" (service-PROJECT_NUMBER@gcp-sa-aiplatform-vm.iam.gserviceaccount.com) is used for the runtime workload identity. See https://cloud.google.com/iam/docs/service-agents#vertex-ai-notebook-service-account for more details. For NotebookExecutionJob, use NotebookExecutionJob.service_account instead.
final
shieldedVmConfig → ShieldedVmConfig?
Optional. Immutable. Runtime Shielded VM spec.
final
softwareConfig → NotebookSoftwareConfig?
Optional. The notebook software configuration of the notebook runtime.
final
updateTime → Timestamp?
Output only. Timestamp when this NotebookRuntimeTemplate was most recently updated.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String