NotebookService class final

The interface for Vertex Notebook service (a.k.a. Colab on Workbench).

Implementers

Constructors

NotebookService({required Client client, Uri? endPoint, String? gcclVersion})
Creates a NotebookService using client for transport.
NotebookService.fromApiKey([String? apiKey])
Creates a NotebookService that does authentication through an API key.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

assignNotebookRuntime(AssignNotebookRuntimeRequest request) → Future<Operation<NotebookRuntime, AssignNotebookRuntimeOperationMetadata>>
Assigns a NotebookRuntime to a user for a particular Notebook file. This method will either returns an existing assignment or generates a new one.
cancelOperation(CancelOperationRequest request) → Future<void>
Provides the Operations service functionality in this service.
close() → void
Closes the client and cleans up any resources associated with it.
createNotebookExecutionJob(CreateNotebookExecutionJobRequest request) → Future<Operation<NotebookExecutionJob, CreateNotebookExecutionJobOperationMetadata>>
Creates a NotebookExecutionJob.
createNotebookRuntimeTemplate(CreateNotebookRuntimeTemplateRequest request) → Future<Operation<NotebookRuntimeTemplate, CreateNotebookRuntimeTemplateOperationMetadata>>
Creates a NotebookRuntimeTemplate.
deleteNotebookExecutionJob(DeleteNotebookExecutionJobRequest request) → Future<Operation<Empty, DeleteOperationMetadata>>
Deletes a NotebookExecutionJob.
deleteNotebookRuntime(DeleteNotebookRuntimeRequest request) → Future<Operation<Empty, DeleteOperationMetadata>>
Deletes a NotebookRuntime.
deleteNotebookRuntimeTemplate(DeleteNotebookRuntimeTemplateRequest request) → Future<Operation<Empty, DeleteOperationMetadata>>
Deletes a NotebookRuntimeTemplate.
deleteOperation(DeleteOperationRequest request) → Future<void>
Provides the Operations service functionality in this service.
getIamPolicy(GetIamPolicyRequest request) → Future<Policy>
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
getLocation(GetLocationRequest request) → Future<Location>
Gets information about a location.
getNotebookExecutionJob(GetNotebookExecutionJobRequest request) → Future<NotebookExecutionJob>
Gets a NotebookExecutionJob.
getNotebookRuntime(GetNotebookRuntimeRequest request) → Future<NotebookRuntime>
Gets a NotebookRuntime.
getNotebookRuntimeTemplate(GetNotebookRuntimeTemplateRequest request) → Future<NotebookRuntimeTemplate>
Gets a NotebookRuntimeTemplate.
getOperation<T extends ProtoMessage, S extends ProtoMessage>(Operation<T, S> request) → Future<Operation<T, S>>
Provides the Operations service functionality in this service.
listLocations(ListLocationsRequest request) → Future<ListLocationsResponse>
Lists information about the supported locations for this service.
listNotebookExecutionJobs(ListNotebookExecutionJobsRequest request) → Future<ListNotebookExecutionJobsResponse>
Lists NotebookExecutionJobs in a Location.
listNotebookRuntimes(ListNotebookRuntimesRequest request) → Future<ListNotebookRuntimesResponse>
Lists NotebookRuntimes in a Location.
listNotebookRuntimeTemplates(ListNotebookRuntimeTemplatesRequest request) → Future<ListNotebookRuntimeTemplatesResponse>
Lists NotebookRuntimeTemplates in a Location.
listOperations(ListOperationsRequest request) → Future<ListOperationsResponse>
Provides the Operations service functionality in this service.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setIamPolicy(SetIamPolicyRequest request) → Future<Policy>
Sets the access control policy on the specified resource. Replaces any existing policy.
startNotebookRuntime(StartNotebookRuntimeRequest request) → Future<Operation<StartNotebookRuntimeResponse, StartNotebookRuntimeOperationMetadata>>
Starts a NotebookRuntime.
stopNotebookRuntime(StopNotebookRuntimeRequest request) → Future<Operation<StopNotebookRuntimeResponse, StopNotebookRuntimeOperationMetadata>>
Stops a NotebookRuntime.
testIamPermissions(TestIamPermissionsRequest request) → Future<TestIamPermissionsResponse>
Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a NOT_FOUND error.
toString() → String
A string representation of this object.
inherited
updateNotebookRuntimeTemplate(UpdateNotebookRuntimeTemplateRequest request) → Future<NotebookRuntimeTemplate>
Updates a NotebookRuntimeTemplate.
upgradeNotebookRuntime(UpgradeNotebookRuntimeRequest request) → Future<Operation<UpgradeNotebookRuntimeResponse, UpgradeNotebookRuntimeOperationMetadata>>
Upgrades a NotebookRuntime.
waitOperation(WaitOperationRequest request) → Future<Operation<ProtoMessage, ProtoMessage>>
Provides the Operations service functionality in this service.

Operators

operator ==(Object other) → bool
The equality operator.
inherited