OnlineEvaluator_Config class final

Configuration for sampling behavior of the OnlineEvaluator. The OnlineEvaluator runs at a fixed interval of 10 minutes.

Constructors

OnlineEvaluator_Config({OnlineEvaluator_Config_RandomSampling? randomSampling, int maxEvaluatedSamplesPerRun = 0})
OnlineEvaluator_Config.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
maxEvaluatedSamplesPerRun int
Optional. The maximum number of evaluations to perform per run. If set to 0, the number is unbounded.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
randomSampling OnlineEvaluator_Config_RandomSampling?
Random sampling method.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String