OnlineEvaluator_Config_RandomSampling class final

Configuration for random sampling.

Properties

hashCode int
The hash code for this object.
no setterinherited
percentage int
Required. The percentage of traces to sample for evaluation. Must be an integer between 1 and 100.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String