OutputInfo class final

Describes the info for output of EvaluationService.

Constructors

OutputInfo({String? gcsOutputDirectory})
OutputInfo.fromJson(Object? j)
factory

Properties

gcsOutputDirectory → String?
Output only. The full path of the Cloud Storage directory created, into which the evaluation results and aggregation results are written.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String