PairwiseMetricInput class final

Input for pairwise metric.

Constructors

PairwiseMetricInput({required PairwiseMetricSpec? metricSpec, required PairwiseMetricInstance? instance})
PairwiseMetricInput.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
instance → PairwiseMetricInstance?
Required. Pairwise metric instance.
final
metricSpec → PairwiseMetricSpec?
Required. Spec for pairwise metric.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String