PairwiseMetricResult class final

Spec for pairwise metric result.

Inheritance
  • Object
  • ProtoMessage
  • PairwiseMetricResult

Constructors

PairwiseMetricResult({PairwiseChoice pairwiseChoice = PairwiseChoice.$default, String explanation = '', CustomOutput? customOutput})
PairwiseMetricResult.fromJson(Object? j)
factory

Properties

customOutput CustomOutput?
Output only. Spec for custom output.
final
explanation String
Output only. Explanation for pairwise metric score.
final
hashCode int
The hash code for this object.
no setterinherited
pairwiseChoice PairwiseChoice
Output only. Pairwise metric choice.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String