Part class final

A datatype containing media that is part of a multi-part Content message.

A Part consists of data which has an associated datatype. A Part can only contain one of the accepted types in Part.data.

A Part must have a fixed IANA MIME type identifying the type and subtype of the media if inline_data or file_data field is filled with raw bytes.

Constructors

Part({String? text, Blob? inlineData, FileData? fileData, FunctionCall? functionCall, FunctionResponse? functionResponse, ExecutableCode? executableCode, CodeExecutionResult? codeExecutionResult, VideoMetadata? videoMetadata, bool thought = false, Uint8List? thoughtSignature})
Part.fromJson(Object? j)
factory

Properties

codeExecutionResult → CodeExecutionResult?
Optional. Result of executing the ExecutableCode.
final
executableCode → ExecutableCode?
Optional. Code generated by the model that is meant to be executed.
final
fileData → FileData?
Optional. URI based data.
final
functionCall → FunctionCall?
Optional. A predicted FunctionCall returned from the model that contains a string representing the FunctionDeclaration.name with the parameters and their values.
final
functionResponse → FunctionResponse?
Optional. The result output of a FunctionCall that contains a string representing the FunctionDeclaration.name and a structured JSON object containing any output from the function call. It is used as context to the model.
final
hashCode → int
The hash code for this object.
no setterinherited
inlineData → Blob?
Optional. Inlined bytes data.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String?
Optional. Text part (can be code).
final
thought → bool
Indicates if the part is thought from the model.
final
thoughtSignature → Uint8List
An opaque signature for the thought so it can be reused in subsequent requests.
final
videoMetadata → VideoMetadata?
Optional. Video metadata. The metadata should only be specified while the video data is presented in inline_data or file_data.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String