PartnerModelTuningSpec class final

Tuning spec for Partner models.

Constructors

PartnerModelTuningSpec({required String trainingDatasetUri, String validationDatasetUri = '', Map<String, Value> hyperParameters = const {}})
PartnerModelTuningSpec.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
hyperParameters → Map<String, Value>
Hyperparameters for tuning. The accepted hyper_parameters and their valid range of values will differ depending on the base model.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trainingDatasetUri → String
Required. Cloud Storage path to file containing training dataset for tuning. The dataset must be formatted as a JSONL file.
final
validationDatasetUri → String
Optional. Cloud Storage path to file containing validation dataset for tuning. The dataset must be formatted as a JSONL file.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String