PersistentResource class final

Represents long-lasting resources that are dedicated to users to runs custom workloads. A PersistentResource can have multiple node pools and each node pool can have its own machine spec.

Constructors

PersistentResource({String name = '', String displayName = '', required List<ResourcePool> resourcePools, PersistentResource_State state = PersistentResource_State.$default, Status? error, Timestamp? createTime, Timestamp? startTime, Timestamp? updateTime, Map<String, String> labels = const {}, String network = '', PscInterfaceConfig? pscInterfaceConfig, EncryptionSpec? encryptionSpec, ResourceRuntimeSpec? resourceRuntimeSpec, ResourceRuntime? resourceRuntime, List<String> reservedIpRanges = const [], bool satisfiesPzs = false, bool satisfiesPzi = false})
PersistentResource.fromJson(Object? j)
factory

Properties

createTime → Timestamp?
Output only. Time when the PersistentResource was created.
final
displayName → String
Optional. The display name of the PersistentResource. The name can be up to 128 characters long and can consist of any UTF-8 characters.
final
encryptionSpec → EncryptionSpec?
Optional. Customer-managed encryption key spec for a PersistentResource. If set, this PersistentResource and all sub-resources of this PersistentResource will be secured by this key.
final
error → Status?
Output only. Only populated when persistent resource's state is STOPPING or ERROR.
final
hashCode → int
The hash code for this object.
no setterinherited
labels → Map<String, String>
Optional. The labels with user-defined metadata to organize PersistentResource.
final
name → String
Immutable. Resource name of a PersistentResource.
final
network → String
Optional. The full name of the Compute Engine network to peered with Vertex AI to host the persistent resources. For example, projects/12345/global/networks/myVPC. Format is of the form projects/{project}/global/networks/{network}. Where {project} is a project number, as in 12345, and {network} is a network name.
final
pscInterfaceConfig → PscInterfaceConfig?
Optional. Configuration for PSC-I for PersistentResource.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
reservedIpRanges → List<String>
Optional. A list of names for the reserved IP ranges under the VPC network that can be used for this persistent resource.
final
resourcePools → List<ResourcePool>
Required. The spec of the pools of different resources.
final
resourceRuntime → ResourceRuntime?
Output only. Runtime information of the Persistent Resource.
final
resourceRuntimeSpec → ResourceRuntimeSpec?
Optional. Persistent Resource runtime spec. For example, used for Ray cluster configuration.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
satisfiesPzi → bool
Output only. Reserved for future use.
final
satisfiesPzs → bool
Output only. Reserved for future use.
final
startTime → Timestamp?
Output only. Time when the PersistentResource for the first time entered the RUNNING state.
final
state → PersistentResource_State
Output only. The detailed state of a Study.
final
updateTime → Timestamp?
Output only. Time when the PersistentResource was most recently updated.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String