PipelineFailurePolicy class final

Represents the failure policy of a pipeline. Currently, the default of a pipeline is that the pipeline will continue to run until no more tasks can be executed, also known as PIPELINE_FAILURE_POLICY_FAIL_SLOW. However, if a pipeline is set to PIPELINE_FAILURE_POLICY_FAIL_FAST, it will stop scheduling any new tasks when a task has failed. Any scheduled tasks will continue to completion.

Constructors

PipelineFailurePolicy(String value)
const
PipelineFailurePolicy.fromJson(Object? json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isNotDefault → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object?
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$default → const PipelineFailurePolicy
The default value for PipelineFailurePolicy.
pipelineFailurePolicyFailFast → const PipelineFailurePolicy
Indicates that the pipeline should stop scheduling new tasks after a task has failed.
pipelineFailurePolicyFailSlow → const PipelineFailurePolicy
Indicates that the pipeline should continue to run until all possible tasks have been scheduled and completed.
pipelineFailurePolicyUnspecified → const PipelineFailurePolicy
Default value, and follows fail slow behavior.