PipelineJob class final

An instance of a machine learning PipelineJob.

Constructors

PipelineJob({String name = '', String displayName = '', Timestamp? createTime, Timestamp? startTime, Timestamp? endTime, Timestamp? updateTime, Struct? pipelineSpec, PipelineState state = PipelineState.$default, PipelineJobDetail? jobDetail, Status? error, Map<String, String> labels = const {}, PipelineJob_RuntimeConfig? runtimeConfig, EncryptionSpec? encryptionSpec, String serviceAccount = '', String network = '', List<String> reservedIpRanges = const [], PscInterfaceConfig? pscInterfaceConfig, String templateUri = '', PipelineTemplateMetadata? templateMetadata, String scheduleName = '', bool preflightValidations = false, bool satisfiesPzs = false, bool satisfiesPzi = false, int originalPipelineJobId = 0, List<PipelineTaskRerunConfig> pipelineTaskRerunConfigs = const []})
PipelineJob.fromJson(Object? j)
factory

Properties

createTime → Timestamp?
Output only. Pipeline creation time.
final
displayName → String
The display name of the Pipeline. The name can be up to 128 characters long and can consist of any UTF-8 characters.
final
encryptionSpec → EncryptionSpec?
Customer-managed encryption key spec for a pipelineJob. If set, this PipelineJob and all of its sub-resources will be secured by this key.
final
endTime → Timestamp?
Output only. Pipeline end time.
final
error → Status?
Output only. The error that occurred during pipeline execution. Only populated when the pipeline's state is FAILED or CANCELLED.
final
hashCode → int
The hash code for this object.
no setterinherited
jobDetail → PipelineJobDetail?
Output only. The details of pipeline run. Not available in the list view.
final
labels → Map<String, String>
The labels with user-defined metadata to organize PipelineJob.
final
name → String
Output only. The resource name of the PipelineJob.
final
network → String
The full name of the Compute Engine network to which the Pipeline Job's workload should be peered. For example, projects/12345/global/networks/myVPC. Format is of the form projects/{project}/global/networks/{network}. Where {project} is a project number, as in 12345, and {network} is a network name.
final
originalPipelineJobId → int
Optional. The original pipeline job id if this pipeline job is a rerun of a previous pipeline job.
final
pipelineSpec → Struct?
The spec of the pipeline.
final
pipelineTaskRerunConfigs → List<PipelineTaskRerunConfig>
Optional. The rerun configs for each task in the pipeline job. By default, the rerun will:
final
preflightValidations → bool
Optional. Whether to do component level validations before job creation.
final
pscInterfaceConfig → PscInterfaceConfig?
Optional. Configuration for PSC-I for PipelineJob.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
reservedIpRanges → List<String>
A list of names for the reserved ip ranges under the VPC network that can be used for this Pipeline Job's workload.
final
runtimeConfig → PipelineJob_RuntimeConfig?
Runtime config of the pipeline.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
satisfiesPzi → bool
Output only. Reserved for future use.
final
satisfiesPzs → bool
Output only. Reserved for future use.
final
scheduleName → String
Output only. The schedule resource name. Only returned if the Pipeline is created by Schedule API.
final
serviceAccount → String
The service account that the pipeline workload runs as. If not specified, the Compute Engine default service account in the project will be used. See https://cloud.google.com/compute/docs/access/service-accounts#default_service_account
final
startTime → Timestamp?
Output only. Pipeline start time.
final
state → PipelineState
Output only. The detailed state of the job.
final
templateMetadata → PipelineTemplateMetadata?
Output only. Pipeline template metadata. Will fill up fields if PipelineJob.template_uri is from supported template registry.
final
templateUri → String
A template uri from where the PipelineJob.pipeline_spec, if empty, will be downloaded. Currently, only uri from Vertex Template Registry & Gallery is supported. Reference to https://cloud.google.com/vertex-ai/docs/pipelines/create-pipeline-template.
final
updateTime → Timestamp?
Output only. Timestamp when this PipelineJob was most recently updated.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String