PipelineJobDetail class final

The runtime detail of PipelineJob.

Constructors

PipelineJobDetail({Context? pipelineContext, Context? pipelineRunContext, List<PipelineTaskDetail> taskDetails = const []})
PipelineJobDetail.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
pipelineContext → Context?
Output only. The context of the pipeline.
final
pipelineRunContext → Context?
Output only. The context of the current pipeline run.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
taskDetails → List<PipelineTaskDetail>
Output only. The runtime details of the tasks under the pipeline.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String