PipelineTaskExecutorDetail_ContainerDetail class final

The detail of a container execution. It contains the job names of the lifecycle of a container execution.

Constructors

PipelineTaskExecutorDetail_ContainerDetail({String mainJob = '', String preCachingCheckJob = '', List<String> failedMainJobs = const [], List<String> failedPreCachingCheckJobs = const []})
PipelineTaskExecutorDetail_ContainerDetail.fromJson(Object? j)
factory

Properties

failedMainJobs → List<String>
Output only. The names of the previously failed CustomJob for the main container executions. The list includes the all attempts in chronological order.
final
failedPreCachingCheckJobs → List<String>
Output only. The names of the previously failed CustomJob for the pre-caching-check container executions. This job will be available if the PipelineJob.pipeline_spec specifies the pre_caching_check hook in the lifecycle events. The list includes the all attempts in chronological order.
final
hashCode → int
The hash code for this object.
no setterinherited
mainJob → String
Output only. The name of the CustomJob for the main container execution.
final
preCachingCheckJob → String
Output only. The name of the CustomJob for the pre-caching-check container execution. This job will be available if the PipelineJob.pipeline_spec specifies the pre_caching_check hook in the lifecycle events.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String