PipelineTaskExecutorDetail_CustomJobDetail class final

The detailed info for a custom job executor.

Properties

failedJobs → List<String>
Output only. The names of the previously failed CustomJob. The list includes the all attempts in chronological order.
final
hashCode → int
The hash code for this object.
no setterinherited
job → String
Output only. The name of the CustomJob.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String