PipelineTaskRerunConfig class final

User provided rerun config to submit a rerun pipelinejob. This includes

  1. Which task to rerun
  2. User override input parameters and artifacts.

Constructors

PipelineTaskRerunConfig({int taskId = 0, String taskName = '', PipelineTaskRerunConfig_Inputs? inputs, bool skipTask = false, bool skipDownstreamTasks = false})
PipelineTaskRerunConfig.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
inputs → PipelineTaskRerunConfig_Inputs?
Optional. The runtime input of the task overridden by the user.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skipDownstreamTasks → bool
Optional. Whether to skip downstream tasks. Default value is False.
final
skipTask → bool
Optional. Whether to skip this task. Default value is False.
final
taskId → int
Optional. The system generated ID of the task. Retrieved from original run.
final
taskName → String
Optional. The name of the task.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String