PipelineTaskRerunConfig_Inputs class final

Runtime inputs data of the task.

Constructors

PipelineTaskRerunConfig_Inputs({Map<String, PipelineTaskRerunConfig_ArtifactList> artifacts = const {}, Map<String, Value> parameterValues = const {}})
PipelineTaskRerunConfig_Inputs.fromJson(Object? j)
factory

Properties

artifacts → Map<String, PipelineTaskRerunConfig_ArtifactList>
Optional. Input artifacts.
final
hashCode → int
The hash code for this object.
no setterinherited
parameterValues → Map<String, Value>
Optional. Input parameters.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String