PointwiseMetricInput class final

Input for pointwise metric.

Constructors

PointwiseMetricInput({required PointwiseMetricSpec? metricSpec, required PointwiseMetricInstance? instance})
PointwiseMetricInput.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
instance → PointwiseMetricInstance?
Required. Pointwise metric instance.
final
metricSpec → PointwiseMetricSpec?
Required. Spec for pointwise metric.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String