PointwiseMetricSpec class final

Spec for pointwise metric.

Constructors

PointwiseMetricSpec({required String? metricPromptTemplate, String? systemInstruction, CustomOutputFormatConfig? customOutputFormatConfig})
PointwiseMetricSpec.fromJson(Object? j)
factory

Properties

customOutputFormatConfig → CustomOutputFormatConfig?
Optional. CustomOutputFormatConfig allows customization of metric output. By default, metrics return a score and explanation. When this config is set, the default output is replaced with either:
final
hashCode → int
The hash code for this object.
no setterinherited
metricPromptTemplate → String?
Required. Metric prompt template for pointwise metric.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
systemInstruction → String?
Optional. System instructions for pointwise metric.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String