PostStartupScriptConfig class final

Post-startup script config.

Constructors

PostStartupScriptConfig({String postStartupScript = '', String postStartupScriptUrl = '', PostStartupScriptConfig_PostStartupScriptBehavior postStartupScriptBehavior = PostStartupScriptConfig_PostStartupScriptBehavior.$default})
PostStartupScriptConfig.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
postStartupScript → String
Optional. Post-startup script to run after runtime is started.
final
postStartupScriptBehavior → PostStartupScriptConfig_PostStartupScriptBehavior
Optional. Post-startup script behavior that defines download and execution behavior.
final
postStartupScriptUrl → String
Optional. Post-startup script url to download. Example: https://bucket/script.sh
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String