PreTunedModel class final

A pre-tuned model for continuous tuning.

Constructors

PreTunedModel({String tunedModelName = '', String checkpointId = '', String baseModel = ''})
PreTunedModel.fromJson(Object? j)
factory

Properties

baseModel → String
Output only. The name of the base model this PreTunedModel was tuned from.
final
checkpointId → String
Optional. The source checkpoint id. If not specified, the default checkpoint will be used.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tunedModelName → String
The resource name of the Model. E.g., a model resource name with a specified version id or alias:
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String