PredefinedMetricSpec class final
The spec for a pre-defined metric.
- Inheritance
-
- Object
- ProtoMessage
- PredefinedMetricSpec
Constructors
- PredefinedMetricSpec({required String metricSpecName, Struct? metricSpecParameters})
- PredefinedMetricSpec.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- metricSpecName → String
-
Required. The name of a pre-defined metric, such as
"instruction_following_v1" or "text_quality_v1".
final
- metricSpecParameters → Struct?
-
Optional. The parameters needed to run the pre-defined metric.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String