Presets_Modality class final

Preset option controlling parameters for different modalities

Constructors

Presets_Modality(String value)
const
Presets_Modality.fromJson(Object? json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isNotDefault → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object?
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$default → const Presets_Modality
The default value for Presets_Modality.
image → const Presets_Modality
IMAGE modality
modalityUnspecified → const Presets_Modality
Should not be set. Added as a recommended best practice for enums
tabular → const Presets_Modality
TABULAR modality
text → const Presets_Modality
TEXT modality