PrivateEndpoints class final

PrivateEndpoints proto is used to provide paths for users to send requests privately. To send request via private service access, use predict_http_uri, explain_http_uri or health_http_uri. To send request via private service connect, use service_attachment.

Constructors

PrivateEndpoints({String predictHttpUri = '', String explainHttpUri = '', String healthHttpUri = '', String serviceAttachment = ''})
PrivateEndpoints.fromJson(Object? j)
factory

Properties

explainHttpUri → String
Output only. Http(s) path to send explain requests.
final
hashCode → int
The hash code for this object.
no setterinherited
healthHttpUri → String
Output only. Http(s) path to send health check requests.
final
predictHttpUri → String
Output only. Http(s) path to send prediction requests.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAttachment → String
Output only. The name of the service attachment resource. Populated if private service connect is enabled.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String