Probe_HttpGetAction class final

HttpGetAction describes an action based on HTTP Get requests.

Constructors

Probe_HttpGetAction({String path = '', int port = 0, String host = '', String scheme = '', List<Probe_HttpHeader> httpHeaders = const []})
Probe_HttpGetAction.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
host → String
Host name to connect to, defaults to the model serving container's IP. You probably want to set "Host" in httpHeaders instead.
final
httpHeaders → List<Probe_HttpHeader>
Custom headers to set in the request. HTTP allows repeated headers.
final
path → String
Path to access on the HTTP server.
final
port → int
Number of the port to access on the container. Number must be in the range 1 to 65535.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheme → String
Scheme to use for connecting to the host. Defaults to HTTP. Acceptable values are "HTTP" or "HTTPS".
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String