PscAutomatedEndpoints class final

PscAutomatedEndpoints defines the output of the forwarding rule automatically created by each PscAutomationConfig.

Constructors

PscAutomatedEndpoints({String projectId = '', String network = '', String matchAddress = ''})
PscAutomatedEndpoints.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
matchAddress → String
Ip Address created by the automated forwarding rule.
final
network → String
Corresponding network in pscAutomationConfigs.
final
projectId → String
Corresponding project_id in pscAutomationConfigs
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String