PscautomationConfig class final

PSC config that is used to automatically create PSC endpoints in the user projects.

Constructors

PscautomationConfig({required String projectId, required String network, String ipAddress = '', String forwardingRule = '', PscautomationState state = PscautomationState.$default, String errorMessage = ''})
PscautomationConfig.fromJson(Object? j)
factory

Properties

errorMessage → String
Output only. Error message if the PSC service automation failed.
final
forwardingRule → String
Output only. Forwarding rule created by the PSC service automation.
final
hashCode → int
The hash code for this object.
no setterinherited
ipAddress → String
Output only. IP address rule created by the PSC service automation.
final
network → String
Required. The full name of the Google Compute Engine network. Format: projects/{project}/global/networks/{network}.
final
projectId → String
Required. Project id used to create forwarding rule.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → PscautomationState
Output only. The state of the PSC service automation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String