PscautomationState class final

The state of the PSC service automation.

Constructors

PscautomationState(String value)
const
PscautomationState.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const PscautomationState
The default value for PscautomationState.
pscAutomationStateFailed → const PscautomationState
The PSC service automation has failed.
pscAutomationStateSuccessful → const PscautomationState
The PSC service automation is successful.
pscAutomationStateUnspecified → const PscautomationState
Should not be used.