PublisherModel class final

A Model Garden Publisher Model.

Constructors

PublisherModel({String name = '', String versionId = '', required PublisherModel_OpenSourceCategory openSourceCategory, PublisherModel_Parent? parent, PublisherModel_CallToAction? supportedActions, List<String> frameworks = const [], PublisherModel_LaunchStage launchStage = PublisherModel_LaunchStage.$default, PublisherModel_VersionState versionState = PublisherModel_VersionState.$default, String publisherModelTemplate = '', PredictSchemata? predictSchemata})
PublisherModel.fromJson(Object? j)
factory

Properties

frameworks → List<String>
Optional. Additional information about the model's Frameworks.
final
hashCode → int
The hash code for this object.
no setterinherited
launchStage → PublisherModel_LaunchStage
Optional. Indicates the launch stage of the model.
final
name → String
Output only. The resource name of the PublisherModel.
final
openSourceCategory → PublisherModel_OpenSourceCategory
Required. Indicates the open source category of the publisher model.
final
parent → PublisherModel_Parent?
Optional. The parent that this model was customized from. E.g., Vision API, Natural Language API, LaMDA, T5, etc. Foundation models don't have parents.
final
predictSchemata → PredictSchemata?
Optional. The schemata that describes formats of the PublisherModel's predictions and explanations as given and returned via PredictionService.Predict.
final
publisherModelTemplate → String
Optional. Output only. Immutable. Used to indicate this model has a publisher model and provide the template of the publisher model resource name.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportedActions → PublisherModel_CallToAction?
Optional. Supported call-to-action options.
final
versionId → String
Output only. Immutable. The version ID of the PublisherModel. A new version is committed when a new model version is uploaded under an existing model id. It is an auto-incrementing decimal number in string representation.
final
versionState → PublisherModel_VersionState
Optional. Indicates the state of the model version.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String