PublisherModelConfig class final

This message contains configs of a publisher model.

Constructors

PublisherModelConfig({PredictRequestResponseLoggingConfig? loggingConfig, PublisherModelConfig_ModelProvider dataSharingEnabledProvider = PublisherModelConfig_ModelProvider.$default})
PublisherModelConfig.fromJson(Object? j)
factory

Properties

dataSharingEnabledProvider PublisherModelConfig_ModelProvider
Optional. The model provider (publisher) for which the customer has enabled data sharing. For publisher models that are configured to require data sharing, a prediction request is only allowed when the model's publisher matches this provider. Otherwise, the request is rejected.
final
hashCode int
The hash code for this object.
no setterinherited
loggingConfig PredictRequestResponseLoggingConfig?
The prediction request/response logging config.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String