PublisherModelEulaAcceptance class final

Response message for ModelGardenService.UpdatePublisherModelEula.

Constructors

PublisherModelEulaAcceptance({int projectNumber = 0, String publisherModel = '', bool publisherModelEulaAcked = false})
PublisherModelEulaAcceptance.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
projectNumber → int
The project number requesting access for named model.
final
publisherModel → String
The publisher model resource name.
final
publisherModelEulaAcked → bool
The EULA content acceptance status.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String