PublisherModelView class final

View enumeration of PublisherModel.

Constructors

PublisherModelView(String value)
const
PublisherModelView.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const PublisherModelView
The default value for PublisherModelView.
publisherModelVersionViewBasic → const PublisherModelView
Include: VersionId, ModelVersionExternalName, and SupportedActions.
publisherModelViewBasic → const PublisherModelView
Include basic metadata about the publisher model, but not the full contents.
publisherModelViewFull → const PublisherModelView
Include everything.
publisherModelViewUnspecified → const PublisherModelView
The default / unset value. The API will default to the BASIC view.