PublisherModel_CallToAction_Deploy class final

Model metadata that is needed for UploadModel or DeployModel/CreateEndpoint requests.

Constructors

PublisherModel_CallToAction_Deploy({DedicatedResources? dedicatedResources, AutomaticResources? automaticResources, String? sharedResources, String modelDisplayName = '', LargeModelReference? largeModelReference, ModelContainerSpec? containerSpec, String artifactUri = '', String? deployTaskName, PublisherModel_CallToAction_Deploy_DeployMetadata? deployMetadata, required String title, String publicArtifactUri = ''})
PublisherModel_CallToAction_Deploy.fromJson(Object? j)
factory

Properties

artifactUri → String
Optional. The path to the directory containing the Model artifact and any of its supporting files.
final
automaticResources → AutomaticResources?
A description of resources that to large degree are decided by Vertex AI, and require only a modest additional configuration.
final
containerSpec → ModelContainerSpec?
Optional. The specification of the container that is to be used when deploying this Model in Vertex AI. Not present for Large Models.
final
dedicatedResources → DedicatedResources?
A description of resources that are dedicated to the DeployedModel, and that need a higher degree of manual configuration.
final
deployMetadata → PublisherModel_CallToAction_Deploy_DeployMetadata?
Optional. Metadata information about this deployment config.
final
deployTaskName → String?
Optional. The name of the deploy task (e.g., "text to image generation").
final
hashCode → int
The hash code for this object.
no setterinherited
largeModelReference → LargeModelReference?
Optional. Large model reference. When this is set, model_artifact_spec is not needed.
final
modelDisplayName → String
Optional. Default model display name.
final
publicArtifactUri → String
Optional. The signed URI for ephemeral Cloud Storage access to model artifact.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sharedResources → String?
The resource name of the shared DeploymentResourcePool to deploy on. Format: projects/{project}/locations/{location}/deploymentResourcePools/{deployment_resource_pool}
final
title → String
Required. The title of the regional resource reference.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String