PublisherModel_CallToAction_Deploy_DeployMetadata class final

Metadata information about the deployment for managing deployment config.

Properties

hashCode → int
The hash code for this object.
no setterinherited
labels → Map<String, String>
Optional. Labels for the deployment config. For managing deployment config like verifying, source of deployment config, etc.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sampleRequest → String
Optional. Sample request for deployed endpoint.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String