PublisherModel_Parent class final

The information about the parent of a model.

Constructors

PublisherModel_Parent({required String displayName, PublisherModel_ResourceReference? reference})
PublisherModel_Parent.fromJson(Object? j)
factory

Properties

displayName → String
Required. The display name of the parent. E.g., LaMDA, T5, Vision API, Natural Language API.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
reference → PublisherModel_ResourceReference?
Optional. The Google Cloud resource name or the URI reference.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String