PublisherModel_ResourceReference class final

Reference to a resource.

Constructors

PublisherModel_ResourceReference({String? uri, String? resourceName, String? useCase, String? description})
PublisherModel_ResourceReference.fromJson(Object? j)
factory

Properties

description → String?
Description of the resource.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
resourceName → String?
The resource name of the Google Cloud resource.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri → String?
The URI of the resource.
final
useCase → String?
Use case (CUJ) of the resource.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String