PythonPackageSpec class final

The spec of a Python packaged code.

Constructors

PythonPackageSpec({required String executorImageUri, required List<String> packageUris, required String pythonModule, List<String> args = const [], List<EnvVar> env = const []})
PythonPackageSpec.fromJson(Object? j)
factory

Properties

args → List<String>
Command line arguments to be passed to the Python task.
final
env → List<EnvVar>
Environment variables to be passed to the python module. Maximum limit is 100.
final
executorImageUri → String
Required. The URI of a container image in Artifact Registry that will run the provided Python package. Vertex AI provides a wide range of executor images with pre-installed packages to meet users' various use cases. See the list of pre-built containers for training. You must use an image from this list.
final
hashCode → int
The hash code for this object.
no setterinherited
packageUris → List<String>
Required. The Google Cloud Storage location of the Python package files which are the training program and its dependent packages. The maximum number of package URIs is 100.
final
pythonModule → String
Required. The Python module name to run after installing the packages.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String