QueryDeployedModelsResponse class final

Response message for QueryDeployedModels method.

Constructors

QueryDeployedModelsResponse({List<DeployedModel> deployedModels = const [], String nextPageToken = '', List<DeployedModelRef> deployedModelRefs = const [], int totalDeployedModelCount = 0, int totalEndpointCount = 0})
QueryDeployedModelsResponse.fromJson(Object? j)
factory

Properties

deployedModelRefs → List<DeployedModelRef>
References to the DeployedModels that share the specified deploymentResourcePool.
final
deployedModels → List<DeployedModel>
DEPRECATED Use deployed_model_refs instead.
final
hashCode → int
The hash code for this object.
no setterinherited
nextPageToken → String
A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalDeployedModelCount → int
The total number of DeployedModels on this DeploymentResourcePool.
final
totalEndpointCount → int
The total number of Endpoints that have DeployedModels on this DeploymentResourcePool.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String