QueryExtensionResponse class final

Response message for ExtensionExecutionService.QueryExtension.

Constructors

QueryExtensionResponse({List<Content> steps = const [], String failureMessage = ''})
QueryExtensionResponse.fromJson(Object? j)
factory

Properties

failureMessage → String
Failure message if any.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
steps → List<Content>
Steps of extension or LLM interaction, can contain function call, function response, or text response. The last step contains the final response to the query.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String