QueryReasoningEngineRequest class final

Request message for ReasoningEngineExecutionService.Query.

Constructors

QueryReasoningEngineRequest({required String name, Struct? input, String classMethod = ''})
QueryReasoningEngineRequest.fromJson(Object? j)
factory

Properties

classMethod → String
Optional. Class method to be used for the query. It is optional and defaults to "query" if unspecified.
final
hashCode → int
The hash code for this object.
no setterinherited
input → Struct?
Optional. Input content provided by users in JSON object format. Examples include text query, function calling parameters, media bytes, etc.
final
name → String
Required. The name of the ReasoningEngine resource to use. Format: projects/{project}/locations/{location}/reasoningEngines/{reasoning_engine}
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String