QuestionAnsweringCorrectnessInstance class final

Spec for question answering correctness instance.

Constructors

QuestionAnsweringCorrectnessInstance({required String? prediction, String? reference, String? context, required String? instruction})
QuestionAnsweringCorrectnessInstance.fromJson(Object? j)
factory

Properties

context → String?
Optional. Text provided as context to answer the question.
final
hashCode → int
The hash code for this object.
no setterinherited
instruction → String?
Required. The question asked and other instruction in the inference prompt.
final
prediction → String?
Required. Output of the evaluated model.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
reference → String?
Optional. Ground truth used to compare against the prediction.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String