QuestionAnsweringRelevanceInput class final

Input for question answering relevance metric.

Properties

hashCode → int
The hash code for this object.
no setterinherited
instance → QuestionAnsweringRelevanceInstance?
Required. Question answering relevance instance.
final
metricSpec → QuestionAnsweringRelevanceSpec?
Required. Spec for question answering relevance score metric.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String