RagChunk class final

A RagChunk includes the content of a chunk of a RagFile, and associated metadata.

Constructors

RagChunk({String text = '', RagChunk_PageSpan? pageSpan, String fileId = '', String chunkId = ''})
RagChunk.fromJson(Object? j)
factory

Properties

chunkId String
The ID of the chunk.
final
fileId String
The ID of the file that the chunk belongs to.
final
hashCode int
The hash code for this object.
no setterinherited
pageSpan RagChunk_PageSpan?
If populated, represents where the chunk starts and ends in the document.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
The content of the chunk.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String