key property

String key
final

Required. The key of this data schema. This key should be matching the key of user specified metadata and unique inside corpus. This value can be up to 63 characters, and valid characters are /0-9-/. The first character must be a letter, the last could be a letter or a number.

Implementation

final String key;