RagEmbeddingModelConfig_HybridSearchConfig class final

Config for hybrid search.

Properties

denseEmbeddingModelPredictionEndpoint → RagEmbeddingModelConfig_VertexPredictionEndpoint?
Required. The Vertex AI Prediction Endpoint that hosts the embedding model for dense embedding generations.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sparseEmbeddingConfig → RagEmbeddingModelConfig_SparseEmbeddingConfig?
Optional. The configuration for sparse embedding generation. This field is optional the default behavior depends on the vector database choice on the RagCorpus.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String