RagEmbeddingModelConfig_VertexPredictionEndpoint class final

Config representing a model hosted on Vertex Prediction Endpoint.

Constructors

RagEmbeddingModelConfig_VertexPredictionEndpoint({required String endpoint, String model = '', String modelVersionId = ''})
RagEmbeddingModelConfig_VertexPredictionEndpoint.fromJson(Object? j)
factory

Properties

endpoint → String
Required. The endpoint resource name. Format: projects/{project}/locations/{location}/publishers/{publisher}/models/{model} or projects/{project}/locations/{location}/endpoints/{endpoint}
final
hashCode → int
The hash code for this object.
no setterinherited
model → String
Output only. The resource name of the model that is deployed on the endpoint. Present only when the endpoint is not a publisher model. Pattern: projects/{project}/locations/{location}/models/{model}
final
modelVersionId → String
Output only. Version ID of the model that is deployed on the endpoint. Present only when the endpoint is not a publisher model.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String