RagFile class final

A RagFile contains user data for chunking, embedding and indexing.

Constructors

RagFile({GcsSource? gcsSource, GoogleDriveSource? googleDriveSource, DirectUploadSource? directUploadSource, SlackSource? slackSource, JiraSource? jiraSource, SharePointSources? sharePointSources, String name = '', required String displayName, String description = '', int sizeBytes = 0, RagFile_RagFileType ragFileType = RagFile_RagFileType.$default, Timestamp? createTime, Timestamp? updateTime, FileStatus? fileStatus, String userMetadata = ''})
RagFile.fromJson(Object? j)
factory

Properties

createTime → Timestamp?
Output only. Timestamp when this RagFile was created.
final
description → String
Optional. The description of the RagFile.
final
directUploadSource → DirectUploadSource?
Output only. The RagFile is encapsulated and uploaded in the UploadRagFile request.
final
displayName → String
Required. The display name of the RagFile. The name can be up to 128 characters long and can consist of any UTF-8 characters.
final
fileStatus → FileStatus?
Output only. State of the RagFile.
final
gcsSource → GcsSource?
Output only. Google Cloud Storage location of the RagFile. It does not support wildcards in the Cloud Storage uri for now.
final
googleDriveSource → GoogleDriveSource?
Output only. Google Drive location. Supports importing individual files as well as Google Drive folders.
final
hashCode → int
The hash code for this object.
no setterinherited
jiraSource → JiraSource?
The RagFile is imported from a Jira query.
final
name → String
Output only. The resource name of the RagFile.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
ragFileType → RagFile_RagFileType
Output only. The type of the RagFile.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sharePointSources → SharePointSources?
The RagFile is imported from a SharePoint source.
final
sizeBytes → int
Output only. The size of the RagFile in bytes.
final
slackSource → SlackSource?
The RagFile is imported from a Slack channel.
final
updateTime → Timestamp?
Output only. Timestamp when this RagFile was last updated.
final
userMetadata → String
Output only. The metadata for metadata search. The user_metadata Needs to be in JSON format.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String