RagFileChunkingConfig class final

Specifies the size and overlap of chunks for RagFiles.

Constructors

RagFileChunkingConfig({RagFileChunkingConfig_FixedLengthChunking? fixedLengthChunking, int chunkSize = 0, int chunkOverlap = 0})
RagFileChunkingConfig.fromJson(Object? j)
factory

Properties

chunkOverlap → int
The overlap between chunks.
final
chunkSize → int
The size of the chunks.
final
fixedLengthChunking → RagFileChunkingConfig_FixedLengthChunking?
Specifies the fixed length chunking config.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String