RagFileMetadataConfig class final

Metadata config for RagFile.

Constructors

RagFileMetadataConfig({GcsSource? gcsMetadataSchemaSource, GoogleDriveSource? googleDriveMetadataSchemaSource, String? inlineMetadataSchemaSource, GcsSource? gcsMetadataSource, GoogleDriveSource? googleDriveMetadataSource, String? inlineMetadataSource})
RagFileMetadataConfig.fromJson(Object? j)
factory

Properties

gcsMetadataSchemaSource → GcsSource?
Google Cloud Storage location. Supports importing individual files as well as entire Google Cloud Storage directories. Sample formats:
final
gcsMetadataSource → GcsSource?
Google Cloud Storage location. Supports importing individual files as well as entire Google Cloud Storage directories. Sample formats:
final
googleDriveMetadataSchemaSource → GoogleDriveSource?
Google Drive location. Supports importing individual files as well as Google Drive folders. If the user provides a folder, the metadata schema will be read from the files that ends with "metadata_schema.json" in the directory.
final
googleDriveMetadataSource → GoogleDriveSource?
Google Drive location. Supports importing individual files as well as Google Drive folders. If the user provides a directory, the metadata will be read from the files that ends with "metadata.json" in the directory.
final
hashCode → int
The hash code for this object.
no setterinherited
inlineMetadataSchemaSource → String?
Inline metadata schema source. Must be a JSON string.
final
inlineMetadataSource → String?
Inline metadata source. Must be a JSON string.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String