RagFileParsingConfig_LayoutParser class final

Document AI Layout Parser config.

Constructors

RagFileParsingConfig_LayoutParser({String processorName = '', int maxParsingRequestsPerMin = 0, int globalMaxParsingRequestsPerMin = 0})
RagFileParsingConfig_LayoutParser.fromJson(Object? j)
factory

Properties

globalMaxParsingRequestsPerMin → int
The maximum number of requests the job is allowed to make to the Document AI processor per minute in this project. Consult https://cloud.google.com/document-ai/quotas and the Quota page for your project to set an appropriate value here. If this value is not specified, max_parsing_requests_per_min will be used by indexing pipeline as the global limit.
final
hashCode → int
The hash code for this object.
no setterinherited
maxParsingRequestsPerMin → int
The maximum number of requests the job is allowed to make to the Document AI processor per minute. Consult https://cloud.google.com/document-ai/quotas and the Quota page for your project to set an appropriate value here. If unspecified, a default value of 120 QPM would be used.
final
processorName → String
The full resource name of a Document AI processor or processor version. The processor must have type LAYOUT_PARSER_PROCESSOR. If specified, the additional_config.parse_as_scanned_pdf field must be false. Format:
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String