RagFileParsingConfig_LlmParser class final

Specifies the LLM parsing for RagFiles.

Constructors

RagFileParsingConfig_LlmParser({String modelName = '', int maxParsingRequestsPerMin = 0, int globalMaxParsingRequestsPerMin = 0, String customParsingPrompt = ''})
RagFileParsingConfig_LlmParser.fromJson(Object? j)
factory

Properties

customParsingPrompt → String
The prompt to use for parsing. If not specified, a default prompt will be used.
final
globalMaxParsingRequestsPerMin → int
The maximum number of requests the job is allowed to make to the LLM model per minute in this project. Consult https://cloud.google.com/vertex-ai/generative-ai/docs/quotas and your document size to set an appropriate value here. If this value is not specified, max_parsing_requests_per_min will be used by indexing pipeline job as the global limit.
final
hashCode → int
The hash code for this object.
no setterinherited
maxParsingRequestsPerMin → int
The maximum number of requests the job is allowed to make to the LLM model per minute. Consult https://cloud.google.com/vertex-ai/generative-ai/docs/quotas and your document size to set an appropriate value here. If unspecified, a default value of 5000 QPM would be used.
final
modelName → String
The name of a LLM model used for parsing. Format:
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String