basic property
Deprecated: Use mode instead to set the tier under Spanner.
Sets the RagManagedDb to the Basic tier.
Implementation
final RagManagedDbConfig_Basic? basic;
Deprecated: Use mode instead to set the tier under Spanner.
Sets the RagManagedDb to the Basic tier.
final RagManagedDbConfig_Basic? basic;