serverless property
Sets the backend to be the serverless mode offered by RAG Engine.
Implementation
final RagManagedDbConfig_Serverless? serverless;
Sets the backend to be the serverless mode offered by RAG Engine.
final RagManagedDbConfig_Serverless? serverless;