RagManagedDbConfig_Spanner class final

Message to configure the Spanner database used by RagManagedDb.

Properties

basic → RagManagedDbConfig_Basic?
Sets the RagManagedDb to the Basic tier. This is the default tier for Spanner mode if not explicitly chosen.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaled → RagManagedDbConfig_Scaled?
Sets the RagManagedDb to the Scaled tier.
final
unprovisioned → RagManagedDbConfig_Unprovisioned?
Sets the RagManagedDb to the Unprovisioned tier.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String