basic property
Sets the RagManagedDb to the Basic tier. This is the default tier for Spanner mode if not explicitly chosen.
Implementation
final RagManagedDbConfig_Basic? basic;
Sets the RagManagedDb to the Basic tier. This is the default tier for Spanner mode if not explicitly chosen.
final RagManagedDbConfig_Basic? basic;