RagMetadata class final

Metadata for RagFile provided by users.

Constructors

RagMetadata({String name = '', UserSpecifiedMetadata? userSpecifiedMetadata})
RagMetadata.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Identifier. Resource name of the RagMetadata. Format: projects/{project}/locations/{location}/ragCorpora/{rag_corpus}/ragFiles/{rag_file}/ragMetadata/{rag_metadata}
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userSpecifiedMetadata UserSpecifiedMetadata?
User provided metadata.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String