searchStrategy property
The search strategy for the metadata value of the key.
Implementation
final RagMetadataSchemaDetails_SearchStrategy? searchStrategy;
The search strategy for the metadata value of the key.
final RagMetadataSchemaDetails_SearchStrategy? searchStrategy;