RagQuery class final

A query to retrieve relevant contexts.

Constructors

RagQuery({String? text, int similarityTopK = 0, RagQuery_Ranking? ranking, RagRetrievalConfig? ragRetrievalConfig})
RagQuery.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
ragRetrievalConfig → RagRetrievalConfig?
Optional. The retrieval config for the query.
final
ranking → RagQuery_Ranking?
Optional. Configurations for hybrid search results ranking.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
similarityTopK → int
Optional. The number of contexts to retrieve.
final
text → String?
Optional. The query in text format to get relevant contexts.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String