RagQuery_Ranking class final

Configurations for hybrid search results ranking.

Constructors

RagQuery_Ranking({double? alpha})
RagQuery_Ranking.fromJson(Object? j)
factory

Properties

alpha → double?
Optional. Alpha value controls the weight between dense and sparse vector search results. The range is 0, 1, while 0 means sparse vector search only and 1 means dense vector search only. The default value is 0.5 which balances sparse and dense vector search equally.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String