RagRetrievalConfig_Ranking class final

Config for ranking and reranking.

Properties

hashCode → int
The hash code for this object.
no setterinherited
llmRanker → RagRetrievalConfig_Ranking_LlmRanker?
Optional. Config for LlmRanker.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
rankService → RagRetrievalConfig_Ranking_RankService?
Optional. Config for Rank Service.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String