RagVectorDbConfig class final

Config for the Vector DB to use for RAG.

Properties

apiAuth → ApiAuth?
Authentication config for the chosen Vector DB.
final
hashCode → int
The hash code for this object.
no setterinherited
pinecone → RagVectorDbConfig_Pinecone?
The config for the Pinecone.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
ragEmbeddingModelConfig → RagEmbeddingModelConfig?
Optional. Immutable. The embedding model config of the Vector DB.
final
ragManagedDb → RagVectorDbConfig_RagManagedDb?
The config for the RAG-managed Vector DB.
final
ragManagedVertexVectorSearch → RagVectorDbConfig_RagManagedVertexVectorSearch?
The config for the RAG-managed Vertex Vector Search 2.0.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vertexFeatureStore → RagVectorDbConfig_VertexFeatureStore?
The config for the Vertex Feature Store.
final
vertexVectorSearch → RagVectorDbConfig_VertexVectorSearch?
The config for the Vertex Vector Search.
final
weaviate → RagVectorDbConfig_Weaviate?
The config for the Weaviate.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String