RagVectorDbConfig_Weaviate class final

The config for the Weaviate.

Constructors

RagVectorDbConfig_Weaviate({String httpEndpoint = '', String collectionName = ''})
RagVectorDbConfig_Weaviate.fromJson(Object? j)
factory

Properties

collectionName → String
The corresponding collection this corpus maps to. This value cannot be changed after it's set.
final
hashCode → int
The hash code for this object.
no setterinherited
httpEndpoint → String
Weaviate DB instance HTTP endpoint. e.g. 34.56.78.90:8080 Vertex RAG only supports HTTP connection to Weaviate. This value cannot be changed after it's set.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String