ReadFeatureValuesResponse_Header class final

Response header with metadata for the requested ReadFeatureValuesRequest.entity_type and Features.

Properties

entityType String
The resource name of the EntityType from the ReadFeatureValuesRequest. Value format: projects/{project}/locations/{location}/featurestores/{featurestore}/entityTypes/{entityType}.
final
featureDescriptors List<ReadFeatureValuesResponse_FeatureDescriptor>
List of Feature metadata corresponding to each piece of ReadFeatureValuesResponse.EntityView.data.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String