ReadIndexDatapointsRequest class final

The request message for MatchService.ReadIndexDatapoints.

Constructors

ReadIndexDatapointsRequest({required String indexEndpoint, String deployedIndexId = '', List<String> ids = const []})
ReadIndexDatapointsRequest.fromJson(Object? j)
factory

Properties

deployedIndexId → String
The ID of the DeployedIndex that will serve the request.
final
hashCode → int
The hash code for this object.
no setterinherited
ids → List<String>
IDs of the datapoints to be searched for.
final
indexEndpoint → String
Required. The name of the index endpoint. Format: projects/{project}/locations/{location}/indexEndpoints/{index_endpoint}
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String