ReasoningEngine class final

ReasoningEngine provides a customizable runtime for models to determine which actions to take and in which order.

Constructors

ReasoningEngine({String name = '', required String displayName, String description = '', ReasoningEngineSpec? spec, Timestamp? createTime, Timestamp? updateTime, String etag = '', ReasoningEngineContextSpec? contextSpec, EncryptionSpec? encryptionSpec, Map<String, String> labels = const {}, ReasoningEngine_TrafficConfig? trafficConfig})
ReasoningEngine.fromJson(Object? j)
factory

Properties

contextSpec → ReasoningEngineContextSpec?
Optional. Configuration for how Agent Engine sub-resources should manage context.
final
createTime → Timestamp?
Output only. Timestamp when this ReasoningEngine was created.
final
description → String
Optional. The description of the ReasoningEngine.
final
displayName → String
Required. The display name of the ReasoningEngine.
final
encryptionSpec → EncryptionSpec?
Customer-managed encryption key spec for a ReasoningEngine. If set, this ReasoningEngine and all sub-resources of this ReasoningEngine will be secured by this key.
final
etag → String
Optional. Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens.
final
hashCode → int
The hash code for this object.
no setterinherited
labels → Map<String, String>
Labels for the ReasoningEngine.
final
name → String
Identifier. The resource name of the ReasoningEngine. Format: projects/{project}/locations/{location}/reasoningEngines/{reasoning_engine}
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spec → ReasoningEngineSpec?
Optional. Configurations of the ReasoningEngine
final
trafficConfig → ReasoningEngine_TrafficConfig?
Optional. Traffic distribution configuration for the Reasoning Engine.
final
updateTime → Timestamp?
Output only. Timestamp when this ReasoningEngine was most recently updated.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String