ReasoningEngineContextSpec_MemoryBankConfig class final

Specification for a Memory Bank.

Properties

generationConfig → ReasoningEngineContextSpec_MemoryBankConfig_GenerationConfig?
Optional. Configuration for how to generate memories for the Memory Bank.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
similaritySearchConfig → ReasoningEngineContextSpec_MemoryBankConfig_SimilaritySearchConfig?
Optional. Configuration for how to perform similarity search on memories. If not set, the Memory Bank will use the default embedding model text-embedding-005.
final
ttlConfig → ReasoningEngineContextSpec_MemoryBankConfig_TtlConfig?
Optional. Configuration for automatic TTL ("time-to-live") of the memories in the Memory Bank. If not set, TTL will not be applied automatically. The TTL can be explicitly set by modifying the expire_time of each Memory resource.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String