ReasoningEngineContextSpec_MemoryBankConfig_TtlConfig class final

Configuration for automatically setting the TTL ("time-to-live") of the memories in the Memory Bank.

Properties

defaultTtl → Duration?
Optional. The default TTL duration of the memories in the Memory Bank. This applies to all operations that create or update a memory.
final
granularTtlConfig → ReasoningEngineContextSpec_MemoryBankConfig_TtlConfig_GranularTtlConfig?
Optional. The granular TTL configuration of the memories in the Memory Bank.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String