ReasoningEngineExecutionService class final

A service for executing queries on Reasoning Engine.

Implementers

Constructors

ReasoningEngineExecutionService({required Client client, Uri? endPoint, String? gcclVersion})
Creates a ReasoningEngineExecutionService using client for transport.
ReasoningEngineExecutionService.fromApiKey([String? apiKey])
Creates a ReasoningEngineExecutionService that does authentication through an API key.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

asyncQueryReasoningEngine(AsyncQueryReasoningEngineRequest request) → Future<Operation<AsyncQueryReasoningEngineResponse, AsyncQueryReasoningEngineOperationMetadata>>
Async query using a reasoning engine.
cancelAsyncQueryReasoningEngine(CancelAsyncQueryReasoningEngineRequest request) → Future<CancelAsyncQueryReasoningEngineResponse>
Cancels an AsyncQueryReasoningEngine operation.
cancelOperation(CancelOperationRequest request) → Future<void>
Provides the Operations service functionality in this service.
close() → void
Closes the client and cleans up any resources associated with it.
deleteOperation(DeleteOperationRequest request) → Future<void>
Provides the Operations service functionality in this service.
getIamPolicy(GetIamPolicyRequest request) → Future<Policy>
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
getLocation(GetLocationRequest request) → Future<Location>
Gets information about a location.
getOperation<T extends ProtoMessage, S extends ProtoMessage>(Operation<T, S> request) → Future<Operation<T, S>>
Provides the Operations service functionality in this service.
listLocations(ListLocationsRequest request) → Future<ListLocationsResponse>
Lists information about the supported locations for this service.
listOperations(ListOperationsRequest request) → Future<ListOperationsResponse>
Provides the Operations service functionality in this service.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryReasoningEngine(QueryReasoningEngineRequest request) → Future<QueryReasoningEngineResponse>
Queries using a reasoning engine.
setIamPolicy(SetIamPolicyRequest request) → Future<Policy>
Sets the access control policy on the specified resource. Replaces any existing policy.
streamQueryReasoningEngine(StreamQueryReasoningEngineRequest request) → Stream<HttpBody>
Streams queries using a reasoning engine.
testIamPermissions(TestIamPermissionsRequest request) → Future<TestIamPermissionsResponse>
Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a NOT_FOUND error.
toString() → String
A string representation of this object.
inherited
waitOperation(WaitOperationRequest request) → Future<Operation<ProtoMessage, ProtoMessage>>
Provides the Operations service functionality in this service.

Operators

operator ==(Object other) → bool
The equality operator.
inherited