ReasoningEngineRuntimeRevision class final

ReasoningEngineRuntimeRevision is a specific version of the runtime related part of ReasoningEngine. Contains only the fields that are revision specific.

Constructors

ReasoningEngineRuntimeRevision({String name = '', ReasoningEngineSpec? spec, Timestamp? createTime, ReasoningEngineRuntimeRevision_State state = ReasoningEngineRuntimeRevision_State.$default})
ReasoningEngineRuntimeRevision.fromJson(Object? j)
factory

Properties

createTime → Timestamp?
Output only. Timestamp when this ReasoningEngineRuntimeRevision was created.
final
hashCode int
The hash code for this object.
no setterinherited
name String
Identifier. The resource name of the ReasoningEngineRuntimeRevision. Format: projects/{project}/locations/{location}/reasoningEngines/{reasoning_engine}/runtimeRevisions/{runtime_revision}
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spec ReasoningEngineSpec?
Immutable. Configurations of the ReasoningEngineRuntimeRevision. Contains only revision specific fields.
final
state ReasoningEngineRuntimeRevision_State
Output only. The state of the revision.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String