ReasoningEngineRuntimeRevisionService constructor

ReasoningEngineRuntimeRevisionService({
  1. required Client client,
  2. Uri? endPoint,
})

Creates a ReasoningEngineRuntimeRevisionService using client for transport.

The provided http.Client must be configured to provide whatever authentication is required by ReasoningEngineRuntimeRevisionService. You can do that using package:googleapis_auth.

If endPoint is provided then its scheme, host, and port are used for all API requests. For example, Uri.http('127.0.0.1:8080') could be used to force the Firestore service to communicate with the local emulator.

Implementation

ReasoningEngineRuntimeRevisionService({
  required http.Client client,
  Uri? endPoint,
}) : _client = ServiceClient(client: client),
     _endPoint = endPoint == null
         ? Uri.https(_defaultHost, '')
         : Uri(
             scheme: endPoint.scheme,
             host: endPoint.host,
             port: endPoint.port,
           );