ReasoningEngineRuntimeRevision_State class final
Possible values of the state of the revision.
Constructors
- ReasoningEngineRuntimeRevision_State(String value)
-
const
- ReasoningEngineRuntimeRevision_State.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const ReasoningEngineRuntimeRevision_State
- The default value for ReasoningEngineRuntimeRevision_State.
- active → const ReasoningEngineRuntimeRevision_State
- Is deployed and ready to be used.
- deprecated → const ReasoningEngineRuntimeRevision_State
- Is deprecated, may not be used, only preserved for historical purposes.
- stateUnspecified → const ReasoningEngineRuntimeRevision_State
- The unspecified state.