ReasoningEngineSpec_BuildSpec class final

Specification for building container image.

Constructors

ReasoningEngineSpec_BuildSpec({String workerPool = '', String serviceAccount = ''})
ReasoningEngineSpec_BuildSpec.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceAccount String
Optional. The service account that Cloud Build uses to run the build.
final
workerPool String
Optional. The resource name of the Cloud Build WorkerPool to use for the build. Format: projects/{project}/locations/{location}/workerPools/{worker_pool}
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String