ReasoningEngineSpec_SourceCodeSpec_DeveloperConnectSource class final

Specifies source code to be fetched from a Git repository managed through the Developer Connect service.

Properties

config → ReasoningEngineSpec_SourceCodeSpec_DeveloperConnectConfig?
Required. The Developer Connect configuration that defines the specific repository, revision, and directory to use as the source code root.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String