ReasoningEngineSpec_SourceCodeSpec_ImageSpec class final
The image spec for building an image (within a single build step), based on the config file (i.e. Dockerfile) in the source directory.
- Inheritance
-
- Object
- ProtoMessage
- ReasoningEngineSpec_SourceCodeSpec_ImageSpec
Constructors
-
ReasoningEngineSpec_SourceCodeSpec_ImageSpec({Map<
String, String> buildArgs = const {}}) - ReasoningEngineSpec_SourceCodeSpec_ImageSpec.fromJson(Object? j)
-
factory
Properties
-
buildArgs
→ Map<
String, String> -
Optional. Build arguments to be used. They will be passed through
--build-arg flags.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String