ReasoningEngineSpec_SourceCodeSpec_PythonSpec class final

Specification for running a Python application from source.

Constructors

ReasoningEngineSpec_SourceCodeSpec_PythonSpec({String version = '', String entrypointModule = '', String entrypointObject = '', String requirementsFile = ''})
ReasoningEngineSpec_SourceCodeSpec_PythonSpec.fromJson(Object? j)
factory

Properties

entrypointModule → String
Optional. The Python module to load as the entrypoint, specified as a fully qualified module name. For example: path.to.agent. If not specified, defaults to "agent".
final
entrypointObject → String
Optional. The name of the callable object within the entrypoint_module to use as the application If not specified, defaults to "root_agent".
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
requirementsFile → String
Optional. The path to the requirements file, relative to the source root. If not specified, defaults to "requirements.txt".
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → String
Optional. The version of Python to use. Support version includes 3.9, 3.10, 3.11, 3.12, 3.13. If not specified, default value is 3.10.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String