targets property
A list of traffic targets for the Runtimes Revisions. The sum of percentages must equal to 100.
Implementation
final List<ReasoningEngine_TrafficConfig_TrafficSplitManual_Target> targets;
A list of traffic targets for the Runtimes Revisions. The sum of percentages must equal to 100.
final List<ReasoningEngine_TrafficConfig_TrafficSplitManual_Target> targets;