runtimeRevisionName property
Required. The Runtime Revision name to which to send this portion of traffic, if traffic allocation is by Runtime Revision.
Implementation
final String runtimeRevisionName;
Required. The Runtime Revision name to which to send this portion of traffic, if traffic allocation is by Runtime Revision.
final String runtimeRevisionName;