RebaseTunedModelRequest class final

Request message for GenAiTuningService.RebaseTunedModel.

Constructors

RebaseTunedModelRequest({required String parent, required TunedModelRef? tunedModelRef, TuningJob? tuningJob, GcsDestination? artifactDestination, bool deployToSameEndpoint = false})
RebaseTunedModelRequest.fromJson(Object? j)
factory

Properties

artifactDestination → GcsDestination?
Optional. The Google Cloud Storage location to write the artifacts.
final
deployToSameEndpoint → bool
Optional. By default, bison to gemini migration will always create new model/endpoint, but for gemini-1.0 to gemini-1.5 migration, we default deploy to the same endpoint. See details in this Section.
final
hashCode → int
The hash code for this object.
no setterinherited
parent → String
Required. The resource name of the Location into which to rebase the Model. Format: projects/{project}/locations/{location}
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tunedModelRef → TunedModelRef?
Required. TunedModel reference to retrieve the legacy model information.
final
tuningJob → TuningJob?
Optional. The TuningJob to be updated. Users can use this TuningJob field to overwrite tuning configs.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String