RecommendSpecResponse class final

Response message for ModelService.RecommendSpec.

Properties

baseModel → String
Output only. The base model used to finetune the custom model.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
recommendations → List<RecommendSpecResponse_Recommendation>
Output only. Recommendations of deployment options for the given custom weights model.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
specs → List<RecommendSpecResponse_MachineAndModelContainerSpec>
Output only. The machine and model container specs.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String