RecommendSpecResponse_Recommendation class final

Recommendation of one deployment option for the given custom weights model in one region. Contains the machine and container spec, and user accelerator quota state.

Constructors

RecommendSpecResponse_Recommendation({String region = '', RecommendSpecResponse_MachineAndModelContainerSpec? spec, RecommendSpecResponse_Recommendation_QuotaState userQuotaState = RecommendSpecResponse_Recommendation_QuotaState.$default})
RecommendSpecResponse_Recommendation.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
region → String
The region for the deployment spec (machine).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spec → RecommendSpecResponse_MachineAndModelContainerSpec?
Output only. The machine and model container specs.
final
userQuotaState → RecommendSpecResponse_Recommendation_QuotaState
Output only. The user accelerator quota state.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String