RemoveContextChildrenRequest class final

Request message for MetadataService.DeleteContextChildrenRequest.

Constructors

RemoveContextChildrenRequest({required String context, List<String> childContexts = const []})
RemoveContextChildrenRequest.fromJson(Object? j)
factory

Properties

childContexts → List<String>
The resource names of the child Contexts.
final
context → String
Required. The resource name of the parent Context.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String