RemoveDatapointsRequest class final

Request message for IndexService.RemoveDatapoints

Constructors

RemoveDatapointsRequest({required String index, List<String> datapointIds = const []})
RemoveDatapointsRequest.fromJson(Object? j)
factory

Properties

datapointIds → List<String>
A list of datapoint ids to be deleted.
final
hashCode → int
The hash code for this object.
no setterinherited
index → String
Required. The name of the Index resource to be updated. Format: projects/{project}/locations/{location}/indexes/{index}
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String