ReservationAffinity class final

A ReservationAffinity can be used to configure a Vertex AI resource (e.g., a DeployedModel) to draw its Compute Engine resources from a Shared Reservation, or exclusively from on-demand capacity.

Constructors

ReservationAffinity({required ReservationAffinity_Type reservationAffinityType, String key = '', List<String> values = const []})
ReservationAffinity.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → String
Optional. Corresponds to the label key of a reservation resource. To target a SPECIFIC_RESERVATION by name, use compute.googleapis.com/reservation-name as the key and specify the name of your reservation as its value.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
reservationAffinityType → ReservationAffinity_Type
Required. Specifies the reservation affinity type.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
values → List<String>
Optional. Corresponds to the label values of a reservation resource. This must be the full resource name of the reservation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String