ResourcePool class final

Represents the spec of a group of resources of the same type, for example machine type, disk, and accelerators, in a PersistentResource.

Constructors

ResourcePool({String id = '', required MachineSpec? machineSpec, int? replicaCount, DiskSpec? diskSpec, int usedReplicaCount = 0, ResourcePool_AutoscalingSpec? autoscalingSpec})
ResourcePool.fromJson(Object? j)
factory

Properties

autoscalingSpec → ResourcePool_AutoscalingSpec?
Optional. Optional spec to configure GKE or Ray-on-Vertex autoscaling
final
diskSpec → DiskSpec?
Optional. Disk spec for the machine in this node pool.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
Immutable. The unique ID in a PersistentResource for referring to this resource pool. User can specify it if necessary. Otherwise, it's generated automatically.
final
machineSpec → MachineSpec?
Required. Immutable. The specification of a single machine.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
replicaCount → int?
Optional. The total number of machines to use for this resource pool.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
usedReplicaCount → int
Output only. The number of machines currently in use by training jobs for this resource pool. Will replace idle_replica_count.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String