ResourceRuntimeSpec class final

Configuration for the runtime on a PersistentResource instance, including but not limited to:

  • Service accounts used to run the workloads.
  • Whether to make it a dedicated Ray Cluster.

Constructors

ResourceRuntimeSpec({ServiceAccountSpec? serviceAccountSpec, RaySpec? raySpec})
ResourceRuntimeSpec.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
raySpec → RaySpec?
Optional. Ray cluster configuration. Required when creating a dedicated RayCluster on the PersistentResource.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAccountSpec → ServiceAccountSpec?
Optional. Configure the use of workload identity on the PersistentResource
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String