Retrieval class final

Defines a retrieval tool that model can call to access external knowledge.

Constructors

Retrieval({VertexAisearch? vertexAiSearch, VertexRagStore? vertexRagStore, bool disableAttribution = false})
Retrieval.fromJson(Object? j)
factory

Properties

disableAttribution → bool
Optional. Deprecated. This option is no longer supported.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vertexAiSearch → VertexAisearch?
Set to use data source powered by Vertex AI Search.
final
vertexRagStore → VertexRagStore?
Set to use data source powered by Vertex RAG store. User data is uploaded via the VertexRagDataService.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String