RetrieveMemoriesRequest_SimpleRetrievalParams class final

Parameters for simple (non-similarity search) retrieval.

Properties

hashCode → int
The hash code for this object.
no setterinherited
pageSize → int
Optional. The maximum number of memories to return. The service may return fewer than this value. If unspecified, at most 3 memories will be returned. The maximum value is 100; values above 100 will be coerced to 100.
final
pageToken → String
Optional. A page token, received from a previous RetrieveMemories call. Provide this to retrieve the subsequent page.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String