RetrieveMemoriesResponse class final

Response message for MemoryBankService.RetrieveMemories.

Constructors

RetrieveMemoriesResponse({List<RetrieveMemoriesResponse_RetrievedMemory> retrievedMemories = const [], String nextPageToken = ''})
RetrieveMemoriesResponse.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken → String
A token that can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. This token is not set if similarity search was used for retrieval.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
retrievedMemories → List<RetrieveMemoriesResponse_RetrievedMemory>
The retrieved memories.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String