RolloutOptions class final

Configuration for rolling deployments.

Constructors

RolloutOptions({int? maxUnavailableReplicas, int? maxUnavailablePercentage, int? maxSurgeReplicas, int? maxSurgePercentage, String previousDeployedModel = '', int revisionNumber = 0})
RolloutOptions.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxSurgePercentage → int?
Percentage of allowed additional replicas. For autoscaling deployments, this refers to the target replica count.
final
maxSurgeReplicas → int?
Absolute count of allowed additional replicas.
final
maxUnavailablePercentage → int?
Percentage of replicas allowed to be unavailable. For autoscaling deployments, this refers to the target replica count.
final
maxUnavailableReplicas → int?
Absolute count of replicas allowed to be unavailable.
final
previousDeployedModel → String
ID of the DeployedModel that this deployment should replace.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
revisionNumber → int
Output only. Read-only. Revision number determines the relative priority of DeployedModels in the same rollout. The DeployedModel with the largest revision number specifies the intended state of the deployment.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String