RougeSpec class final

Spec for rouge score metric - calculates the recall of n-grams in prediction as compared to reference - returns a score ranging between 0 and 1.

Constructors

RougeSpec({String rougeType = '', bool useStemmer = false, bool splitSummaries = false})
RougeSpec.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
rougeType → String
Optional. Supported rouge types are rougen1-9, rougeL, and rougeLsum.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
splitSummaries → bool
Optional. Whether to split summaries while using rougeLsum.
final
useStemmer → bool
Optional. Whether to use stemmer to compute rouge score.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String