RubricBasedInstructionFollowingResult class final

Result for RubricBasedInstructionFollowing metric.

Properties

hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
rubricCritiqueResults List<RubricCritiqueResult>
Output only. List of per rubric critique results.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
score double?
Output only. Overall score for the instruction following.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String