promptTemplate property
Template for the prompt used to generate rubrics. The details should be updated based on the most-recent recipe requirements.
Implementation
final String promptTemplate;
Template for the prompt used to generate rubrics. The details should be updated based on the most-recent recipe requirements.
final String promptTemplate;