RubricGroup class final

A group of rubrics, used for grouping rubrics based on a metric or a version.

Constructors

RubricGroup({String groupId = '', String displayName = '', List<Rubric> rubrics = const []})
RubricGroup.fromJson(Object? j)
factory

Properties

displayName → String
Human-readable name for the group. This should be unique within a given context if used for display or selection. Example: "Instruction Following V1", "Content Quality - Summarization Task".
final
groupId → String
Unique identifier for the group.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
rubrics → List<Rubric>
Rubrics that are part of this group.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String