Rubric_Content_Property class final
Defines criteria based on a specific property.
Constructors
- Rubric_Content_Property({String description = ''})
- Rubric_Content_Property.fromJson(Object? j)
-
factory
Properties
- description → String
-
Description of the property being evaluated.
Example: "The model's response is grammatically correct."
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String