Rubric_Importance class final

Importance level of the rubric.

Constructors

Rubric_Importance(String value)
const
Rubric_Importance.fromJson(Object? json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isNotDefault → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object?
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$default → const Rubric_Importance
The default value for Rubric_Importance.
high → const Rubric_Importance
High importance.
importanceUnspecified → const Rubric_Importance
Importance is not specified.
low → const Rubric_Importance
Low importance.
medium → const Rubric_Importance
Medium importance.