RuntimeArtifact class final

The definition of a runtime artifact.

Constructors

RuntimeArtifact({String name = '', ArtifactTypeSchema? type, String uri = '', Map<String, Value> properties = const {}, Map<String, Value> customProperties = const {}, Struct? metadata})
RuntimeArtifact.fromJson(Object? j)
factory

Properties

customProperties → Map<String, Value>
The custom properties of the artifact. Deprecated. Use RuntimeArtifact.metadata instead.
final
hashCode → int
The hash code for this object.
no setterinherited
metadata → Struct?
Properties of the Artifact.
final
name → String
The name of an artifact.
final
properties → Map<String, Value>
The properties of the artifact. Deprecated. Use RuntimeArtifact.metadata instead.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → ArtifactTypeSchema?
The type of the artifact.
final
uri → String
The URI of the artifact.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String