SafetyRating class final

Safety rating corresponding to the generated content.

Constructors

SafetyRating({HarmCategory category = HarmCategory.$default, SafetyRating_HarmProbability probability = SafetyRating_HarmProbability.$default, double probabilityScore = 0, SafetyRating_HarmSeverity severity = SafetyRating_HarmSeverity.$default, double severityScore = 0, bool blocked = false})
SafetyRating.fromJson(Object? j)
factory

Properties

blocked → bool
Output only. Indicates whether the content was filtered out because of this rating.
final
category → HarmCategory
Output only. Harm category.
final
hashCode → int
The hash code for this object.
no setterinherited
probability → SafetyRating_HarmProbability
Output only. Harm probability levels in the content.
final
probabilityScore → double
Output only. Harm probability score.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severity → SafetyRating_HarmSeverity
Output only. Harm severity levels in the content.
final
severityScore → double
Output only. Harm severity score.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String