SafetyRating_HarmProbability class final

Harm probability levels in the content.

Properties

hashCode → int
The hash code for this object.
no setterinherited
isNotDefault → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object?
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$default → const SafetyRating_HarmProbability
The default value for SafetyRating_HarmProbability.
harmProbabilityUnspecified → const SafetyRating_HarmProbability
Harm probability unspecified.
high → const SafetyRating_HarmProbability
High level of harm.
low → const SafetyRating_HarmProbability
Low level of harm.
medium → const SafetyRating_HarmProbability
Medium level of harm.
negligible → const SafetyRating_HarmProbability
Negligible level of harm.