SafetySetting class final

Safety settings.

Constructors

SafetySetting({required HarmCategory category, required SafetySetting_HarmBlockThreshold threshold, SafetySetting_HarmBlockMethod method = SafetySetting_HarmBlockMethod.$default})
SafetySetting.fromJson(Object? j)
factory

Properties

category → HarmCategory
Required. Harm category.
final
hashCode → int
The hash code for this object.
no setterinherited
method → SafetySetting_HarmBlockMethod
Optional. Specify if the threshold is used for probability or severity score. If not specified, the threshold is used for probability score.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
threshold → SafetySetting_HarmBlockThreshold
Required. The harm block threshold.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String