SafetySetting_HarmBlockMethod class final

Probability vs severity.

Properties

hashCode → int
The hash code for this object.
no setterinherited
isNotDefault → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object?
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$default → const SafetySetting_HarmBlockMethod
The default value for SafetySetting_HarmBlockMethod.
harmBlockMethodUnspecified → const SafetySetting_HarmBlockMethod
The harm block method is unspecified.
probability → const SafetySetting_HarmBlockMethod
The harm block method uses the probability score.
severity → const SafetySetting_HarmBlockMethod
The harm block method uses both probability and severity scores.