SampleConfig class final

Active learning data sampling config. For every active learning labeling iteration, it will select a batch of data based on the sampling strategy.

Constructors

SampleConfig({int? initialBatchSamplePercentage, int? followingBatchSamplePercentage, SampleConfig_SampleStrategy sampleStrategy = SampleConfig_SampleStrategy.$default})
SampleConfig.fromJson(Object? j)
factory

Properties

followingBatchSamplePercentage → int?
The percentage of data needed to be labeled in each following batch (except the first batch).
final
hashCode → int
The hash code for this object.
no setterinherited
initialBatchSamplePercentage → int?
The percentage of data needed to be labeled in the first batch.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sampleStrategy → SampleConfig_SampleStrategy
Field to choose sampling strategy. Sampling strategy will decide which data should be selected for human labeling in every batch.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String