SampleConfig_SampleStrategy class final

Sample strategy decides which subset of DataItems should be selected for human labeling in every batch.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const SampleConfig_SampleStrategy
The default value for SampleConfig_SampleStrategy.
sampleStrategyUnspecified → const SampleConfig_SampleStrategy
Default will be treated as UNCERTAINTY.
uncertainty → const SampleConfig_SampleStrategy
Sample the most uncertain data to label.