Schedule_RunResponse class final

Status of a scheduled run.

Constructors

Schedule_RunResponse({Timestamp? scheduledRunTime, String runResponse = ''})
Schedule_RunResponse.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runResponse → String
The response of the scheduled run.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheduledRunTime → Timestamp?
The scheduled run time based on the user-specified schedule.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String