Schedule_State class final

Possible state of the schedule.

Constructors

Schedule_State(String value)
const
Schedule_State.fromJson(Object? json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isNotDefault → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object?
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$default → const Schedule_State
The default value for Schedule_State.
active → const Schedule_State
The Schedule is active. Runs are being scheduled on the user-specified timespec.
completed → const Schedule_State
The Schedule is completed. No new runs will be scheduled. Already started runs will be allowed to complete. Schedules in completed state cannot be paused or resumed.
paused → const Schedule_State
The schedule is paused. No new runs will be created until the schedule is resumed. Already started runs will be allowed to complete.
stateUnspecified → const Schedule_State
Unspecified.