Scheduling class final

All parameters related to queuing and scheduling of custom jobs.

Constructors

Scheduling({Duration? timeout, bool restartJobOnWorkerRestart = false, Scheduling_Strategy strategy = Scheduling_Strategy.$default, bool disableRetries = false, Duration? maxWaitDuration})
Scheduling.fromJson(Object? j)
factory

Properties

disableRetries → bool
Optional. Indicates if the job should retry for internal errors after the job starts running. If true, overrides Scheduling.restart_job_on_worker_restart to false.
final
hashCode → int
The hash code for this object.
no setterinherited
maxWaitDuration → Duration?
Optional. This is the maximum duration that a job will wait for the requested resources to be provisioned if the scheduling strategy is set to Strategy.DWS_FLEX_START. If set to 0, the job will wait indefinitely. The default is 24 hours.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
restartJobOnWorkerRestart → bool
Optional. Restarts the entire CustomJob if a worker gets restarted. This feature can be used by distributed training jobs that are not resilient to workers leaving and joining a job.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strategy → Scheduling_Strategy
Optional. This determines which type of scheduling strategy to use.
final
timeout → Duration?
Optional. The maximum job running time. The default is 7 days.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String