SearchEntryPoint class final

Google search entry point.

Constructors

SearchEntryPoint({String renderedContent = '', Uint8List? sdkBlob})
SearchEntryPoint.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
renderedContent → String
Optional. Web content snippet that can be embedded in a web page or an app webview.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sdkBlob → Uint8List
Optional. Base64 encoded JSON representing array of <search term, search url> tuple.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String