SearchFeaturesRequest class final

Request message for FeaturestoreService.SearchFeatures.

Constructors

SearchFeaturesRequest({required String location, String query = '', int pageSize = 0, String pageToken = ''})
SearchFeaturesRequest.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
location → String
Required. The resource name of the Location to search Features. Format: projects/{project}/locations/{location}
final
pageSize → int
The maximum number of Features to return. The service may return fewer than this value. If unspecified, at most 100 Features will be returned. The maximum value is 100; any value greater than 100 will be coerced to 100.
final
pageToken → String
A page token, received from a previous FeaturestoreService.SearchFeatures call. Provide this to retrieve the subsequent page.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
query → String
Query string that is a conjunction of field-restricted queries and/or field-restricted filters. Field-restricted queries and filters can be combined using AND to form a conjunction.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String