SearchMigratableResourcesRequest class final

Request message for MigrationService.SearchMigratableResources.

Constructors

SearchMigratableResourcesRequest({required String parent, int pageSize = 0, String pageToken = '', String filter = ''})
SearchMigratableResourcesRequest.fromJson(Object? j)
factory

Properties

filter → String
A filter for your search. You can use the following types of filters:
final
hashCode → int
The hash code for this object.
no setterinherited
pageSize → int
The standard page size. The default and maximum value is 100.
final
pageToken → String
The standard page token.
final
parent → String
Required. The location that the migratable resources should be searched from. It's the Vertex AI location that the resources can be migrated to, not the resources' original location. Format: projects/{project}/locations/{location}
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String