SearchModelDeploymentMonitoringStatsAnomaliesRequest class final

Request message for JobService.SearchModelDeploymentMonitoringStatsAnomalies.

Constructors

SearchModelDeploymentMonitoringStatsAnomaliesRequest({required String modelDeploymentMonitoringJob, required String deployedModelId, String featureDisplayName = '', required List<SearchModelDeploymentMonitoringStatsAnomaliesRequest_StatsAnomaliesObjective> objectives, int pageSize = 0, String pageToken = '', Timestamp? startTime, Timestamp? endTime})
SearchModelDeploymentMonitoringStatsAnomaliesRequest.fromJson(Object? j)
factory

Properties

deployedModelId → String
Required. The DeployedModel ID of the ModelDeploymentMonitoringObjectiveConfig.deployed_model_id.
final
endTime → Timestamp?
The latest timestamp of stats being generated. If not set, indicates feching stats till the latest possible one.
final
featureDisplayName → String
The feature display name. If specified, only return the stats belonging to this feature. Format: ModelMonitoringStatsAnomalies.FeatureHistoricStatsAnomalies.feature_display_name, example: "user_destination".
final
hashCode → int
The hash code for this object.
no setterinherited
modelDeploymentMonitoringJob → String
Required. ModelDeploymentMonitoring Job resource name. Format: projects/{project}/locations/{location}/modelDeploymentMonitoringJobs/{model_deployment_monitoring_job}
final
objectives → List<SearchModelDeploymentMonitoringStatsAnomaliesRequest_StatsAnomaliesObjective>
Required. Objectives of the stats to retrieve.
final
pageSize → int
The standard list page size.
final
pageToken → String
A page token received from a previous JobService.SearchModelDeploymentMonitoringStatsAnomalies call.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime → Timestamp?
The earliest timestamp of stats being generated. If not set, indicates fetching stats till the earliest possible one.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String