SearchModelDeploymentMonitoringStatsAnomaliesRequest_StatsAnomaliesObjective class final
Stats requested for specific objective.
Constructors
- SearchModelDeploymentMonitoringStatsAnomaliesRequest_StatsAnomaliesObjective({ModelDeploymentMonitoringObjectiveType type = ModelDeploymentMonitoringObjectiveType.$default, int topFeatureCount = 0})
- SearchModelDeploymentMonitoringStatsAnomaliesRequest_StatsAnomaliesObjective.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- topFeatureCount → int
-
If set, all attribution scores between
SearchModelDeploymentMonitoringStatsAnomaliesRequest.start_timeandSearchModelDeploymentMonitoringStatsAnomaliesRequest.end_timeare fetched, and page token doesn't take effect in this case. Only used to retrieve attribution score for the top Features which has the highest attribution score in the latest monitoring run.final - type → ModelDeploymentMonitoringObjectiveType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String