SearchModelMonitoringAlertsResponse class final

Response message for ModelMonitoringService.SearchModelMonitoringAlerts.

Constructors

SearchModelMonitoringAlertsResponse({List<ModelMonitoringAlert> modelMonitoringAlerts = const [], int totalNumberAlerts = 0, String nextPageToken = ''})
SearchModelMonitoringAlertsResponse.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
modelMonitoringAlerts → List<ModelMonitoringAlert>
Alerts retrieved for the requested objectives. Sorted by alert time descendingly.
final
nextPageToken → String
The page token that can be used by the next ModelMonitoringService.SearchModelMonitoringAlerts call.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalNumberAlerts → int
The total number of alerts retrieved by the requested objectives.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String