SearchNearestEntitiesRequest class final

The request message for FeatureOnlineStoreService.SearchNearestEntities.

Constructors

SearchNearestEntitiesRequest({required String featureView, required NearestNeighborQuery? query, bool returnFullEntity = false})
SearchNearestEntitiesRequest.fromJson(Object? j)
factory

Properties

featureView → String
Required. FeatureView resource format projects/{project}/locations/{location}/featureOnlineStores/{featureOnlineStore}/featureViews/{featureView}
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
query → NearestNeighborQuery?
Required. The query.
final
returnFullEntity → bool
Optional. If set to true, the full entities (including all vector values and metadata) of the nearest neighbors are returned; otherwise only entity id of the nearest neighbors will be returned. Note that returning full entities will significantly increase the latency and cost of the query.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String