SecretEnvVar class final

Represents an environment variable where the value is a secret in Cloud Secret Manager.

Constructors

SecretEnvVar({required String name, required SecretRef? secretRef})
SecretEnvVar.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
Required. Name of the secret environment variable.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretRef → SecretRef?
Required. Reference to a secret stored in the Cloud Secret Manager that will provide the value for this environment variable.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String