Session class final
A session contains a set of actions between users and Vertex agents.
- Inheritance
-
- Object
- ProtoMessage
- Session
Constructors
Properties
- createTime → Timestamp?
-
Output only. Timestamp when the session was created.
final
- displayName → String
-
Optional. The display name of the session.
final
- expireTime → Timestamp?
-
Optional. Timestamp of when this session is considered expired.
This is always provided on output, regardless of what was sent
on input.
The minimum value is 24 hours from the time of creation.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
labels
→ Map<
String, String> -
The labels with user-defined metadata to organize your Sessions.
final
- name → String
-
Identifier. The resource name of the session.
Format:
'projects/{project}/locations/{location}/reasoningEngines/{reasoning_engine}/sessions/{session}'.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionState → Struct?
-
Optional. Session specific memory which stores key conversation points.
final
- ttl → Duration?
-
Optional. Input only. The TTL for this session.
The minimum value is 24 hours.
final
- updateTime → Timestamp?
-
Output only. Timestamp when the session was updated.
final
- userId → String
-
Required. Immutable. String id provided by the user
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String