SharePointSources_SharePointSource class final

An individual SharePointSource.

Constructors

SharePointSources_SharePointSource({String? sharepointFolderPath, String? sharepointFolderId, String? driveName, String? driveId, String clientId = '', ApiAuth_ApiKeyConfig? clientSecret, String tenantId = '', String sharepointSiteName = '', String fileId = ''})
SharePointSources_SharePointSource.fromJson(Object? j)
factory

Properties

clientId → String
The Application ID for the app registered in Microsoft Azure Portal. The application must also be configured with MS Graph permissions "Files.ReadAll", "Sites.ReadAll" and BrowserSiteLists.Read.All.
final
clientSecret → ApiAuth_ApiKeyConfig?
The application secret for the app registered in Azure.
final
driveId → String?
The ID of the drive to download from.
final
driveName → String?
The name of the drive to download from.
final
fileId → String
Output only. The SharePoint file id. Output only.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sharepointFolderId → String?
The ID of the SharePoint folder to download from.
final
sharepointFolderPath → String?
The path of the SharePoint folder to download from.
final
sharepointSiteName → String
The name of the SharePoint site to download from. This can be the site name or the site id.
final
tenantId → String
Unique identifier of the Azure Active Directory Instance.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String