SlackSource_SlackChannels_SlackChannel class final

SlackChannel contains the Slack channel ID and the time range to import.

Constructors

SlackSource_SlackChannels_SlackChannel({required String channelId, Timestamp? startTime, Timestamp? endTime})
SlackSource_SlackChannels_SlackChannel.fromJson(Object? j)
factory

Properties

channelId → String
Required. The Slack channel ID.
final
endTime → Timestamp?
Optional. The ending timestamp for messages to import.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime → Timestamp?
Optional. The starting timestamp for messages to import.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String