StoredContentsExample class final

A ContentsExample to be used with GenerateContent alongside information required for storage and retrieval with Example Store.

Constructors

StoredContentsExample({String searchKey = '', required ContentsExample? contentsExample, StoredContentsExample_SearchKeyGenerationMethod? searchKeyGenerationMethod})
StoredContentsExample.fromJson(Object? j)
factory

Properties

contentsExample → ContentsExample?
Required. The example to be used with GenerateContent.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchKey → String
Optional. (Optional) the search key used for retrieval. If not provided at upload-time, the search key will be generated from contents_example.contents using the method provided by search_key_generation_method. The generated search key will be included in retrieved examples.
final
searchKeyGenerationMethod → StoredContentsExample_SearchKeyGenerationMethod?
Optional. The method used to generate the search key from contents_example.contents. This is ignored when uploading an example if search_key is provided.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String