Study class final

A message representing a Study.

Constructors

Study({String name = '', required String displayName, required StudySpec? studySpec, Study_State state = Study_State.$default, Timestamp? createTime, String inactiveReason = ''})
Study.fromJson(Object? j)
factory

Properties

createTime → Timestamp?
Output only. Time at which the study was created.
final
displayName → String
Required. Describes the Study, default value is empty string.
final
hashCode → int
The hash code for this object.
no setterinherited
inactiveReason → String
Output only. A human readable reason why the Study is inactive. This should be empty if a study is ACTIVE or COMPLETED.
final
name → String
Output only. The name of a study. The study's globally unique identifier. Format: projects/{project}/locations/{location}/studies/{study}
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → Study_State
Output only. The detailed state of a Study.
final
studySpec → StudySpec?
Required. Configuration of the Study.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String