StudySpec_Algorithm class final

The available search algorithms for the Study.

Constructors

StudySpec_Algorithm(String value)
const
StudySpec_Algorithm.fromJson(Object? json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isNotDefault → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object?
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$default → const StudySpec_Algorithm
The default value for StudySpec_Algorithm.
algorithmUnspecified → const StudySpec_Algorithm
The default algorithm used by Vertex AI for hyperparameter tuning and Vertex AI Vizier.
gridSearch → const StudySpec_Algorithm
Simple grid search within the feasible space. To use grid search, all parameters must be INTEGER, CATEGORICAL, or DISCRETE.
randomSearch → const StudySpec_Algorithm
Simple random search within the feasible space.