StudySpec_ParameterSpec_ConditionalParameterSpec_DiscreteValueCondition class final

Represents the spec to match discrete values from parent parameter.

Properties

hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values List<double>
Required. Matches values of the parent parameter of 'DISCRETE' type. All values must exist in discrete_value_spec of parent parameter.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String