StudySpec_ParameterSpec_DoubleValueSpec class final

Value specification for a parameter in DOUBLE type.

Constructors

StudySpec_ParameterSpec_DoubleValueSpec({required double minValue, required double maxValue, double? defaultValue})
StudySpec_ParameterSpec_DoubleValueSpec.fromJson(Object? j)
factory

Properties

defaultValue → double?
A default value for a DOUBLE parameter that is assumed to be a relatively good starting point. Unset value signals that there is no offered starting point.
final
hashCode → int
The hash code for this object.
no setterinherited
maxValue → double
Required. Inclusive maximum value of the parameter.
final
minValue → double
Required. Inclusive minimum value of the parameter.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String