StudySpec_ParameterSpec_IntegerValueSpec class final

Value specification for a parameter in INTEGER type.

Constructors

StudySpec_ParameterSpec_IntegerValueSpec({required int minValue, required int maxValue, int? defaultValue})
StudySpec_ParameterSpec_IntegerValueSpec.fromJson(Object? j)
factory

Properties

defaultValue → int?
A default value for an INTEGER parameter that is assumed to be a relatively good starting point. Unset value signals that there is no offered starting point.
final
hashCode → int
The hash code for this object.
no setterinherited
maxValue → int
Required. Inclusive maximum value of the parameter.
final
minValue → int
Required. Inclusive minimum value of the parameter.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String