Study_State class final

Describes the Study state.

Constructors

Study_State(String value)
const
Study_State.fromJson(Object? json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isNotDefault → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object?
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$default → const Study_State
The default value for Study_State.
active → const Study_State
The study is active.
completed → const Study_State
The study is done when the service exhausts the parameter search space or max_trial_count is reached.
inactive → const Study_State
The study is stopped due to an internal error.
stateUnspecified → const Study_State
The study state is unspecified.