SuggestTrialsRequest class final

Request message for VizierService.SuggestTrials.

Constructors

SuggestTrialsRequest({required String parent, required int suggestionCount, required String clientId, List<TrialContext> contexts = const []})
SuggestTrialsRequest.fromJson(Object? j)
factory

Properties

clientId → String
Required. The identifier of the client that is requesting the suggestion.
final
contexts → List<TrialContext>
Optional. This allows you to specify the "context" for a Trial; a context is a slice (a subspace) of the search space.
final
hashCode → int
The hash code for this object.
no setterinherited
parent → String
Required. The project and location that the Study belongs to. Format: projects/{project}/locations/{location}/studies/{study}
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suggestionCount → int
Required. The number of suggestions requested. It must be positive.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String