SuggestTrialsResponse class final

Response message for VizierService.SuggestTrials.

Constructors

SuggestTrialsResponse({List<Trial> trials = const [], Study_State studyState = Study_State.$default, Timestamp? startTime, Timestamp? endTime})
SuggestTrialsResponse.fromJson(Object? j)
factory

Properties

endTime → Timestamp?
The time at which operation processing completed.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime → Timestamp?
The time at which the operation was started.
final
studyState → Study_State
The state of the Study.
final
trials → List<Trial>
A list of Trials.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String