SummarizationHelpfulnessInstance class final

Spec for summarization helpfulness instance.

Constructors

SummarizationHelpfulnessInstance({required String? prediction, String? reference, required String? context, String? instruction})
SummarizationHelpfulnessInstance.fromJson(Object? j)
factory

Properties

context → String?
Required. Text to be summarized.
final
hashCode → int
The hash code for this object.
no setterinherited
instruction → String?
Optional. Summarization prompt for LLM.
final
prediction → String?
Required. Output of the evaluated model.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
reference → String?
Optional. Ground truth used to compare against the prediction.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String