SupervisedHyperParameters class final

Hyperparameters for SFT.

Constructors

SupervisedHyperParameters({int epochCount = 0, double learningRateMultiplier = 0, double learningRate = 0, SupervisedHyperParameters_AdapterSize adapterSize = SupervisedHyperParameters_AdapterSize.$default, int batchSize = 0})
SupervisedHyperParameters.fromJson(Object? j)
factory

Properties

adapterSize → SupervisedHyperParameters_AdapterSize
Optional. Adapter size for tuning.
final
batchSize → int
Optional. Batch size for tuning. This feature is only available for open source models.
final
epochCount → int
Optional. Number of complete passes the model makes over the entire training dataset during training.
final
hashCode → int
The hash code for this object.
no setterinherited
learningRate → double
Optional. Learning rate for tuning. Mutually exclusive with learning_rate_multiplier. This feature is only available for open source models.
final
learningRateMultiplier → double
Optional. Multiplier for adjusting the default learning rate. Mutually exclusive with learning_rate.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String