SupervisedTuningDataStats class final

Tuning data statistics for Supervised Tuning.

Constructors

SupervisedTuningDataStats({int tuningDatasetExampleCount = 0, int totalTuningCharacterCount = 0, int totalBillableCharacterCount = 0, int totalBillableTokenCount = 0, int tuningStepCount = 0, SupervisedTuningDatasetDistribution? userInputTokenDistribution, SupervisedTuningDatasetDistribution? userOutputTokenDistribution, SupervisedTuningDatasetDistribution? userMessagePerExampleDistribution, List<Content> userDatasetExamples = const [], int totalTruncatedExampleCount = 0, List<int> truncatedExampleIndices = const [], List<String> droppedExampleReasons = const []})
SupervisedTuningDataStats.fromJson(Object? j)
factory

Properties

droppedExampleReasons → List<String>
Output only. For each index in truncated_example_indices, the user-facing reason why the example was dropped.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalBillableCharacterCount → int
Output only. Number of billable characters in the tuning dataset.
final
totalBillableTokenCount → int
Output only. Number of billable tokens in the tuning dataset.
final
totalTruncatedExampleCount → int
Output only. The number of examples in the dataset that have been dropped. An example can be dropped for reasons including: too many tokens, contains an invalid image, contains too many images, etc.
final
totalTuningCharacterCount → int
Output only. Number of tuning characters in the tuning dataset.
final
truncatedExampleIndices → List<int>
Output only. A partial sample of the indices (starting from 1) of the dropped examples.
final
tuningDatasetExampleCount → int
Output only. Number of examples in the tuning dataset.
final
tuningStepCount → int
Output only. Number of tuning steps for this Tuning Job.
final
userDatasetExamples → List<Content>
Output only. Sample user messages in the training dataset uri.
final
userInputTokenDistribution → SupervisedTuningDatasetDistribution?
Output only. Dataset distributions for the user input tokens.
final
userMessagePerExampleDistribution → SupervisedTuningDatasetDistribution?
Output only. Dataset distributions for the messages per example.
final
userOutputTokenDistribution → SupervisedTuningDatasetDistribution?
Output only. Dataset distributions for the user output tokens.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String