SupervisedTuningDatasetDistribution class final

Dataset distribution for Supervised Tuning.

Constructors

SupervisedTuningDatasetDistribution({int sum = 0, int billableSum = 0, double min = 0, double max = 0, double mean = 0, double median = 0, double p5 = 0, double p95 = 0, List<SupervisedTuningDatasetDistribution_DatasetBucket> buckets = const []})
SupervisedTuningDatasetDistribution.fromJson(Object? j)
factory

Properties

billableSum → int
Output only. Sum of a given population of values that are billable.
final
buckets → List<SupervisedTuningDatasetDistribution_DatasetBucket>
Output only. Defines the histogram bucket.
final
hashCode → int
The hash code for this object.
no setterinherited
max → double
Output only. The maximum of the population values.
final
mean → double
Output only. The arithmetic mean of the values in the population.
final
median → double
Output only. The median of the values in the population.
final
min → double
Output only. The minimum of the population values.
final
p5 → double
Output only. The 5th percentile of the values in the population.
final
p95 → double
Output only. The 95th percentile of the values in the population.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sum → int
Output only. Sum of a given population of values.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String