SupervisedTuningSpec class final

Tuning Spec for Supervised Tuning for first party models.

Constructors

SupervisedTuningSpec({required String trainingDatasetUri, String validationDatasetUri = '', SupervisedHyperParameters? hyperParameters, bool exportLastCheckpointOnly = false, EvaluationConfig? evaluationConfig, SupervisedTuningSpec_TuningMode tuningMode = SupervisedTuningSpec_TuningMode.$default})
SupervisedTuningSpec.fromJson(Object? j)
factory

Properties

evaluationConfig → EvaluationConfig?
Optional. Evaluation Config for Tuning Job.
final
exportLastCheckpointOnly → bool
Optional. If set to true, disable intermediate checkpoints for SFT and only the last checkpoint will be exported. Otherwise, enable intermediate checkpoints for SFT. Default is false.
final
hashCode → int
The hash code for this object.
no setterinherited
hyperParameters → SupervisedHyperParameters?
Optional. Hyperparameters for SFT.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trainingDatasetUri → String
Required. Training dataset used for tuning. The dataset can be specified as either a Cloud Storage path to a JSONL file or as the resource name of a Vertex Multimodal Dataset.
final
tuningMode → SupervisedTuningSpec_TuningMode
Tuning mode.
final
validationDatasetUri → String
Optional. Validation dataset used for tuning. The dataset can be specified as either a Cloud Storage path to a JSONL file or as the resource name of a Vertex Multimodal Dataset.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String