Tensorboard class final

Tensorboard is a physical database that stores users' training metrics. A default Tensorboard is provided in each region of a Google Cloud project. If needed users can also create extra Tensorboards in their projects.

Constructors

Tensorboard({String name = '', required String displayName, String description = '', EncryptionSpec? encryptionSpec, String blobStoragePathPrefix = '', int runCount = 0, Timestamp? createTime, Timestamp? updateTime, Map<String, String> labels = const {}, String etag = '', bool isDefault = false, bool satisfiesPzs = false, bool satisfiesPzi = false})
Tensorboard.fromJson(Object? j)
factory

Properties

blobStoragePathPrefix → String
Output only. Consumer project Cloud Storage path prefix used to store blob data, which can either be a bucket or directory. Does not end with a '/'.
final
createTime → Timestamp?
Output only. Timestamp when this Tensorboard was created.
final
description → String
Description of this Tensorboard.
final
displayName → String
Required. User provided name of this Tensorboard.
final
encryptionSpec → EncryptionSpec?
Customer-managed encryption key spec for a Tensorboard. If set, this Tensorboard and all sub-resources of this Tensorboard will be secured by this key.
final
etag → String
Used to perform a consistent read-modify-write updates. If not set, a blind "overwrite" update happens.
final
hashCode → int
The hash code for this object.
no setterinherited
isDefault → bool
Used to indicate if the TensorBoard instance is the default one. Each project & region can have at most one default TensorBoard instance. Creation of a default TensorBoard instance and updating an existing TensorBoard instance to be default will mark all other TensorBoard instances (if any) as non default.
final
labels → Map<String, String>
The labels with user-defined metadata to organize your Tensorboards.
final
name → String
Output only. Name of the Tensorboard. Format: projects/{project}/locations/{location}/tensorboards/{tensorboard}
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runCount → int
Output only. The number of Runs stored in this Tensorboard.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
satisfiesPzi → bool
Output only. Reserved for future use.
final
satisfiesPzs → bool
Output only. Reserved for future use.
final
updateTime → Timestamp?
Output only. Timestamp when this Tensorboard was last updated.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String