TensorboardBlob class final

One blob (e.g, image, graph) viewable on a blob metric plot.

Constructors

TensorboardBlob({String id = '', Uint8List? data})
TensorboardBlob.fromJson(Object? j)
factory

Properties

data → Uint8List
Optional. The bytes of the blob is not present unless it's returned by the ReadTensorboardBlobData endpoint.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
Output only. A URI safe key uniquely identifying a blob. Can be used to locate the blob stored in the Cloud Storage bucket of the consumer project.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String