TensorboardExperiment class final

A TensorboardExperiment is a group of TensorboardRuns, that are typically the results of a training job run, in a Tensorboard.

Constructors

TensorboardExperiment({String name = '', String displayName = '', String description = '', Timestamp? createTime, Timestamp? updateTime, Map<String, String> labels = const {}, String etag = '', String source = ''})
TensorboardExperiment.fromJson(Object? j)
factory

Properties

createTime → Timestamp?
Output only. Timestamp when this TensorboardExperiment was created.
final
description → String
Description of this TensorboardExperiment.
final
displayName → String
User provided name of this TensorboardExperiment.
final
etag → String
Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens.
final
hashCode → int
The hash code for this object.
no setterinherited
labels → Map<String, String>
The labels with user-defined metadata to organize your TensorboardExperiment.
final
name → String
Output only. Name of the TensorboardExperiment. Format: projects/{project}/locations/{location}/tensorboards/{tensorboard}/experiments/{experiment}
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → String
Immutable. Source of the TensorboardExperiment. Example: a custom training job.
final
updateTime → Timestamp?
Output only. Timestamp when this TensorboardExperiment was last updated.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String