TensorboardTimeSeries class final

TensorboardTimeSeries maps to times series produced in training runs

Constructors

TensorboardTimeSeries({String name = '', required String displayName, String description = '', required TensorboardTimeSeries_ValueType valueType, Timestamp? createTime, Timestamp? updateTime, String etag = '', String pluginName = '', Uint8List? pluginData, TensorboardTimeSeries_Metadata? metadata})
TensorboardTimeSeries.fromJson(Object? j)
factory

Properties

createTime → Timestamp?
Output only. Timestamp when this TensorboardTimeSeries was created.
final
description → String
Description of this TensorboardTimeSeries.
final
displayName → String
Required. User provided name of this TensorboardTimeSeries. This value should be unique among all TensorboardTimeSeries resources belonging to the same TensorboardRun resource (parent resource).
final
etag → String
Used to perform a consistent read-modify-write updates. If not set, a blind "overwrite" update happens.
final
hashCode → int
The hash code for this object.
no setterinherited
metadata → TensorboardTimeSeries_Metadata?
Output only. Scalar, Tensor, or Blob metadata for this TensorboardTimeSeries.
final
name → String
Output only. Name of the TensorboardTimeSeries.
final
pluginData → Uint8List
Data of the current plugin, with the size limited to 65KB.
final
pluginName → String
Immutable. Name of the plugin this time series pertain to. Such as Scalar, Tensor, Blob
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateTime → Timestamp?
Output only. Timestamp when this TensorboardTimeSeries was last updated.
final
valueType → TensorboardTimeSeries_ValueType
Required. Immutable. Type of TensorboardTimeSeries value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String