TensorboardTimeSeries_Metadata class final

Describes metadata for a TensorboardTimeSeries.

Constructors

TensorboardTimeSeries_Metadata({int maxStep = 0, Timestamp? maxWallTime, int maxBlobSequenceLength = 0})
TensorboardTimeSeries_Metadata.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxBlobSequenceLength → int
Output only. The largest blob sequence length (number of blobs) of all data points in this time series, if its ValueType is BLOB_SEQUENCE.
final
maxStep → int
Output only. Max step index of all data points within a TensorboardTimeSeries.
final
maxWallTime → Timestamp?
Output only. Max wall clock timestamp of all data points within a TensorboardTimeSeries.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String