TimeSeriesData class final

All the data stored in a TensorboardTimeSeries.

Constructors

TimeSeriesData({required String tensorboardTimeSeriesId, required TensorboardTimeSeries_ValueType valueType, required List<TimeSeriesDataPoint> values})
TimeSeriesData.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tensorboardTimeSeriesId → String
Required. The ID of the TensorboardTimeSeries, which will become the final component of the TensorboardTimeSeries' resource name
final
values → List<TimeSeriesDataPoint>
Required. Data points in this time series.
final
valueType → TensorboardTimeSeries_ValueType
Required. Immutable. The value type of this time series. All the values in this time series data must match this value type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String