TimestampSplit class final

Assigns input data to training, validation, and test sets based on a provided timestamps. The youngest data pieces are assigned to training set, next to validation set, and the oldest to the test set.

Supported only for tabular Datasets.

Constructors

TimestampSplit({double trainingFraction = 0, double validationFraction = 0, double testFraction = 0, required String key})
TimestampSplit.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → String
Required. The key is a name of one of the Dataset's data columns. The values of the key (the values in the column) must be in RFC 3339 date-time format, where time-offset = "Z" (e.g. 1985-04-12T23:20:50.52Z). If for a piece of data the key is not present or has an invalid value, that piece is ignored by the pipeline.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
testFraction → double
The fraction of the input data that is to be used to evaluate the Model.
final
trainingFraction → double
The fraction of the input data that is to be used to train the Model.
final
validationFraction → double
The fraction of the input data that is to be used to validate the Model.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String