TokensInfo class final

Tokens info with a list of tokens and the corresponding list of token ids.

Constructors

TokensInfo({List<Uint8List> tokens = const [], List<int> tokenIds = const [], String role = ''})
TokensInfo.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
role → String
Optional. Optional fields for the role from the corresponding Content.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tokenIds → List<int>
A list of token ids from the input.
final
tokens → List<Uint8List>
A list of tokens from the input.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String