exaAiSearch property
Optional. Uses Exa.ai to search for information to answer user queries. The search results will be grounded on Exa.ai and presented to the model for response generation
Implementation
final Tool_ExaAiSearch? exaAiSearch;
Optional. Uses Exa.ai to search for information to answer user queries. The search results will be grounded on Exa.ai and presented to the model for response generation
final Tool_ExaAiSearch? exaAiSearch;