parallelAiSearch property
Optional. If specified, Vertex AI will use Parallel.ai to search for information to answer user queries. The search results will be grounded on Parallel.ai and presented to the model for response generation
Implementation
final Tool_ParallelAiSearch? parallelAiSearch;