ToolUseExample class final

A single example of the tool usage.

Constructors

ToolUseExample({ToolUseExample_ExtensionOperation? extensionOperation, String? functionName, required String displayName, required String query, Struct? requestParams, Struct? responseParams, String responseSummary = ''})
ToolUseExample.fromJson(Object? j)
factory

Properties

displayName → String
Required. The display name for example.
final
extensionOperation → ToolUseExample_ExtensionOperation?
Extension operation to call.
final
functionName → String?
Function name to call.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
query → String
Required. Query that should be routed to this tool.
final
requestParams → Struct?
Request parameters used for executing this tool.
final
responseParams → Struct?
Response parameters generated by this tool.
final
responseSummary → String
Summary of the tool response to the user query.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String