ToolUseExample_ExtensionOperation class final

Identifies one operation of the extension.

Constructors

ToolUseExample_ExtensionOperation({String extension = '', required String operationId})
ToolUseExample_ExtensionOperation.fromJson(Object? j)
factory

Properties

extension → String
Resource name of the extension.
final
hashCode → int
The hash code for this object.
no setterinherited
operationId → String
Required. Operation ID of the extension.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String