Tool_ComputerUse_Environment class final

Represents the environment being operated, such as a web browser.

Properties

hashCode → int
The hash code for this object.
no setterinherited
isNotDefault → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object?
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$default → const Tool_ComputerUse_Environment
The default value for Tool_ComputerUse_Environment.
environmentBrowser → const Tool_ComputerUse_Environment
Operates in a web browser.
environmentUnspecified → const Tool_ComputerUse_Environment
Defaults to browser.