Tool_ExaAiSearch class final

ExaAiSearch tool type. A tool that uses the Exa.ai search engine for grounding.

Constructors

Tool_ExaAiSearch({required String apiKey, Struct? customConfigs})
Tool_ExaAiSearch.fromJson(Object? j)
factory

Properties

apiKey String
Required. The API key for ExaAiSearch.
final
customConfigs → Struct?
Optional. This field can be used to pass any parameter from the Exa.ai Search API.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String