customConfigs property
Struct?
customConfigs
final
Optional. This field can be used to pass any parameter from the Exa.ai Search API.
Implementation
final protobuf.Struct? customConfigs;
Optional. This field can be used to pass any parameter from the Exa.ai Search API.
final protobuf.Struct? customConfigs;