Transcription class final

Audio transcription in Server Content.

Constructors

Transcription({String text = '', bool finished = false})
Transcription.fromJson(Object? j)
factory

Properties

finished bool
Optional. The bool indicates the end of the transcription.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
Optional. Transcription text.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String