Trial class final

A message representing a Trial. A Trial contains a unique set of Parameters that has been or will be evaluated, along with the objective metrics got by running the Trial.

Constructors

Trial({String name = '', String id = '', Trial_State state = Trial_State.$default, List<Trial_Parameter> parameters = const [], Measurement? finalMeasurement, List<Measurement> measurements = const [], Timestamp? startTime, Timestamp? endTime, String clientId = '', String infeasibleReason = '', String customJob = '', Map<String, String> webAccessUris = const {}})
Trial.fromJson(Object? j)
factory

Properties

clientId → String
Output only. The identifier of the client that originally requested this Trial. Each client is identified by a unique client_id. When a client asks for a suggestion, Vertex AI Vizier will assign it a Trial. The client should evaluate the Trial, complete it, and report back to Vertex AI Vizier. If suggestion is asked again by same client_id before the Trial is completed, the same Trial will be returned. Multiple clients with different client_ids can ask for suggestions simultaneously, each of them will get their own Trial.
final
customJob → String
Output only. The CustomJob name linked to the Trial. It's set for a HyperparameterTuningJob's Trial.
final
endTime → Timestamp?
Output only. Time when the Trial's status changed to SUCCEEDED or INFEASIBLE.
final
finalMeasurement → Measurement?
Output only. The final measurement containing the objective value.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
Output only. The identifier of the Trial assigned by the service.
final
infeasibleReason → String
Output only. A human readable string describing why the Trial is infeasible. This is set only if Trial state is INFEASIBLE.
final
measurements → List<Measurement>
Output only. A list of measurements that are strictly lexicographically ordered by their induced tuples (steps, elapsed_duration). These are used for early stopping computations.
final
name → String
Output only. Resource name of the Trial assigned by the service.
final
parameters → List<Trial_Parameter>
Output only. The parameters of the Trial.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime → Timestamp?
Output only. Time when the Trial was started.
final
state → Trial_State
Output only. The detailed state of the Trial.
final
webAccessUris → Map<String, String>
Output only. URIs for accessing interactive shells (one URI for each training node). Only available if this trial is part of a HyperparameterTuningJob and the job's trial_job_spec.enable_web_access field is true.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String