TunedModelRef class final

TunedModel Reference for legacy model migration.

Constructors

TunedModelRef({String? tunedModel, String? tuningJob, String? pipelineJob})
TunedModelRef.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
pipelineJob → String?
Support migration from tuning job list page, from bison model to gemini model.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tunedModel → String?
Support migration from model registry.
final
tuningJob → String?
Support migration from tuning job list page, from gemini-1.0-pro-002 to 1.5 and above.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String