UnmanagedContainerModel class final

Contains model information necessary to perform batch prediction without requiring a full model import.

Constructors

UnmanagedContainerModel({String artifactUri = '', PredictSchemata? predictSchemata, ModelContainerSpec? containerSpec})
UnmanagedContainerModel.fromJson(Object? j)
factory

Properties

artifactUri → String
The path to the directory containing the Model artifact and any of its supporting files.
final
containerSpec → ModelContainerSpec?
Input only. The specification of the container that is to be used when deploying this Model.
final
hashCode → int
The hash code for this object.
no setterinherited
predictSchemata → PredictSchemata?
Contains the schemata used in Model's predictions and explanations
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String