UpdateIndexEndpointRequest class final

Request message for IndexEndpointService.UpdateIndexEndpoint.

Constructors

UpdateIndexEndpointRequest({required IndexEndpoint? indexEndpoint, required FieldMask? updateMask})
UpdateIndexEndpointRequest.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
indexEndpoint → IndexEndpoint?
Required. The IndexEndpoint which replaces the resource on the server.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateMask → FieldMask?
Required. The update mask applies to the resource. See google.protobuf.FieldMask.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String