UpdateIndexOperationMetadata class final

Runtime operation information for IndexService.UpdateIndex.

Constructors

UpdateIndexOperationMetadata({GenericOperationMetadata? genericMetadata, NearestNeighborSearchOperationMetadata? nearestNeighborSearchOperationMetadata})
UpdateIndexOperationMetadata.fromJson(Object? j)
factory

Properties

genericMetadata → GenericOperationMetadata?
The operation generic information.
final
hashCode → int
The hash code for this object.
no setterinherited
nearestNeighborSearchOperationMetadata → NearestNeighborSearchOperationMetadata?
The operation metadata with regard to Matching Engine Index operation.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String