UpdateOnlineEvaluatorRequest class final

Request message for UpdateOnlineEvaluator.

Constructors

UpdateOnlineEvaluatorRequest({required OnlineEvaluator? onlineEvaluator, FieldMask? updateMask})
UpdateOnlineEvaluatorRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
onlineEvaluator OnlineEvaluator?
Required. The OnlineEvaluator to update. Format: projects/{project}/locations/{location}/onlineEvaluators/{id}.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updateMask → FieldMask?
Optional. Field mask is used to control which fields get updated. If the mask is not present, all fields will be updated.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String