UpdateRagMetadataRequest class final
Request message for
VertexRagDataService.UpdateRagMetadata.
Constructors
- UpdateRagMetadataRequest({required RagMetadata? ragMetadata})
- UpdateRagMetadataRequest.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - ragMetadata → RagMetadata?
-
Required. The RagMetadata which replaces the resource on the server.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String