UploadRagFileConfig class final

Config for uploading RagFile.

Constructors

UploadRagFileConfig({RagFileChunkingConfig? ragFileChunkingConfig, RagFileTransformationConfig? ragFileTransformationConfig, RagFileMetadataConfig? ragFileMetadataConfig, RagFileParsingConfig? ragFileParsingConfig})
UploadRagFileConfig.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
ragFileChunkingConfig → RagFileChunkingConfig?
Specifies the size and overlap of chunks after uploading RagFile.
final
ragFileMetadataConfig → RagFileMetadataConfig?
Optional. Specifies the metadata config for RagFiles. Including paths for metadata schema and metadata. Alteratively, inline metadata schema and metadata can be provided. Deprecated: Not in use.
final
ragFileParsingConfig → RagFileParsingConfig?
Optional. Specifies the parsing config for RagFiles. RAG will use the default parser if this field is not set.
final
ragFileTransformationConfig → RagFileTransformationConfig?
Specifies the transformation config for RagFiles.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String