candidatesTokensDetails property
Output only. A detailed breakdown of the token count for each modality in the generated candidates.
Implementation
final List<ModalityTokenCount> candidatesTokensDetails;
Output only. A detailed breakdown of the token count for each modality in the generated candidates.
final List<ModalityTokenCount> candidatesTokensDetails;