UserSpecifiedMetadata class final

Metadata provided by users.

Constructors

UserSpecifiedMetadata({required String key, MetadataValue? value})
UserSpecifiedMetadata.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
key String
Required. Key of the metadata. The key must be set with type by CreateRagDataSchema.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value MetadataValue?
Value of the metadata. The value must be able to convert to the type according to the data schema.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String