value property
Value of the metadata. The value must be able to convert to the type according to the data schema.
Implementation
final MetadataValue? value;
Value of the metadata. The value must be able to convert to the type according to the data schema.
final MetadataValue? value;