Value class final

Value is the value of the field.

Constructors

Value({int? intValue, double? doubleValue, String? stringValue})
Value.fromJson(Object? j)
factory

Properties

doubleValue → double?
A double value.
final
hashCode → int
The hash code for this object.
no setterinherited
intValue → int?
An integer value.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringValue → String?
A string value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String