VeoHyperParameters_AdapterSize class final

Adapter size for LoRA tuning.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const VeoHyperParameters_AdapterSize
The default value for VeoHyperParameters_AdapterSize.
adapterSizeEight → const VeoHyperParameters_AdapterSize
Adapter size 8. This is the default adapter size for Veo LoRA tuning.
adapterSizeSixteen → const VeoHyperParameters_AdapterSize
Adapter size 16.
adapterSizeThirtyTwo → const VeoHyperParameters_AdapterSize
Adapter size 32.
adapterSizeUnspecified → const VeoHyperParameters_AdapterSize
Adapter size is unspecified.