VeoHyperParameters_TuningTask class final

An enum defining the tuning task used for Veo.

Properties

hashCode → int
The hash code for this object.
no setterinherited
isNotDefault → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object?
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$default → const VeoHyperParameters_TuningTask
The default value for VeoHyperParameters_TuningTask.
tuningTaskI2V → const VeoHyperParameters_TuningTask
Tuning task for image to video.
tuningTaskR2V → const VeoHyperParameters_TuningTask
Tuning task for reference to video.
tuningTaskT2V → const VeoHyperParameters_TuningTask
Tuning task for text to video.
tuningTaskUnspecified → const VeoHyperParameters_TuningTask
Default value. This value is unused.