VertexMultimodalDatasetDestination class final

The details for a Vertex Multimodal Dataset output.

Constructors

VertexMultimodalDatasetDestination({BigQueryDestination? bigqueryDestination, String displayName = ''})
VertexMultimodalDatasetDestination.fromJson(Object? j)
factory

Properties

bigqueryDestination → BigQueryDestination?
Optional. The destination of the underlying BigQuery table that will be created for the output Multimodal Dataset. If not specified, the BigQuery table will be created in a default BigQuery dataset.
final
displayName → String
Optional. Display name of the output dataset.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String