VertexMultimodalDatasetSource class final

The Vertex Multimodal Dataset for the input content.

Inheritance
  • Object
  • ProtoMessage
  • VertexMultimodalDatasetSource

Constructors

VertexMultimodalDatasetSource({required String datasetName})
VertexMultimodalDatasetSource.fromJson(Object? j)
factory

Properties

datasetName String
Required. The resource name of the Vertex Dataset. Format: projects/{project}/locations/{location}/datasets/{dataset}
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String