batchCreateRagDataSchemas method

Batch Create one or more RagDataSchemas

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

Future<
  Operation<
    BatchCreateRagDataSchemasResponse,
    BatchCreateRagDataSchemasOperationMetadata
  >
>
batchCreateRagDataSchemas(BatchCreateRagDataSchemasRequest request) async {
  final url = _endPoint.replace(
    path: '/v1beta1/${request.parent}/ragDataSchemas:batchCreate',
  );
  final response = await _client.post(url, body: request);
  return Operation.fromJson(
    response,
    OperationHelper(
      BatchCreateRagDataSchemasResponse.fromJson,
      BatchCreateRagDataSchemasOperationMetadata.fromJson,
    ),
  );
}