asyncRetrieveContexts method

Asynchronous API to retrieves relevant contexts for a query.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

Future<
  Operation<
    AsyncRetrieveContextsResponse,
    AsyncRetrieveContextsOperationMetadata
  >
>
asyncRetrieveContexts(AsyncRetrieveContextsRequest request) async {
  final url = Uri.https(
    _host,
    '/v1beta1/${request.parent}:asyncRetrieveContexts',
  );
  final response = await _client.post(url, body: request);
  return Operation.fromJson(
    response,
    OperationHelper(
      AsyncRetrieveContextsResponse.fromJson,
      AsyncRetrieveContextsOperationMetadata.fromJson,
    ),
  );
}