VideoMetadata class final

Metadata describes the input video content.

Constructors

VideoMetadata({Duration? startOffset, Duration? endOffset})
VideoMetadata.fromJson(Object? j)
factory

Properties

endOffset → Duration?
Optional. The end offset of the video.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startOffset → Duration?
Optional. The start offset of the video.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String