listStudies method

Lists all the studies in a region for an associated project.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<ListStudiesResponse> listStudies(ListStudiesRequest request) async {
  final url = _endPoint.replace(
    path: '/v1beta1/${request.parent}/studies',
    queryParameters: {
      if (request.pageToken case final $1 when $1.isNotDefault)
        'pageToken': $1,
      if (request.pageSize case final $1 when $1.isNotDefault)
        'pageSize': '${$1}',
    },
  );
  final response = await _client.get(url);
  return ListStudiesResponse.fromJson(response);
}