assembleData method

Assembles each row of a multimodal dataset and writes the result into a BigQuery table.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<AssembleDataResponse, AssembleDataOperationMetadata>>
assembleData(AssembleDataRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_assembleData case final assembleData?) {
    return assembleData(request);
  }
  throw UnsupportedError('assembleData');
}