assessData method

  1. @override
Future<Operation<AssessDataResponse, AssessDataOperationMetadata>> assessData(
  1. AssessDataRequest request
)
override

Assesses the state or validity of the dataset with respect to a given use case.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<AssessDataResponse, AssessDataOperationMetadata>> assessData(
  AssessDataRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_assessData case final assessData?) {
    return assessData(request);
  }
  throw UnsupportedError('assessData');
}