importData method

  1. @override
Future<Operation<ImportDataResponse, ImportDataOperationMetadata>> importData(
  1. ImportDataRequest request
)
override

Imports data into a Dataset.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<ImportDataResponse, ImportDataOperationMetadata>> importData(
  ImportDataRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_importData case final importData?) {
    return importData(request);
  }
  throw UnsupportedError('importData');
}