restoreDatasetVersion method

Restores a dataset version.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<DatasetVersion, RestoreDatasetVersionOperationMetadata>>
restoreDatasetVersion(RestoreDatasetVersionRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_restoreDatasetVersion case final restoreDatasetVersion?) {
    return restoreDatasetVersion(request);
  }
  throw UnsupportedError('restoreDatasetVersion');
}