createEndpoint method

  1. @override
Future<Operation<Endpoint, CreateEndpointOperationMetadata>> createEndpoint(
  1. CreateEndpointRequest request
)
override

Creates an Endpoint.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<Endpoint, CreateEndpointOperationMetadata>> createEndpoint(
  CreateEndpointRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_createEndpoint case final createEndpoint?) {
    return createEndpoint(request);
  }
  throw UnsupportedError('createEndpoint');
}