deleteEndpoint method

  1. @override
Future<Operation<Empty, DeleteOperationMetadata>> deleteEndpoint(
  1. DeleteEndpointRequest request
)
override

Deletes an Endpoint.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<protobuf.Empty, DeleteOperationMetadata>> deleteEndpoint(
  DeleteEndpointRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_deleteEndpoint case final deleteEndpoint?) {
    return deleteEndpoint(request);
  }
  throw UnsupportedError('deleteEndpoint');
}