deployModel method
Future<Operation<DeployModelResponse, DeployModelOperationMetadata> >
deployModel(
- DeployModelRequest request
override
Deploys a Model into this Endpoint, creating a DeployedModel within it.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Returns an Operation representing the status of the long-running
operation.
When complete, Operation.done will be true. If successful,
Operation.responseAsMessage will contain the operation's result.
Implementation
@override
Future<Operation<DeployModelResponse, DeployModelOperationMetadata>>
deployModel(DeployModelRequest request) async {
if (isClosed) throw StateError('Service is closed');
if (_deployModel case final deployModel?) {
return deployModel(request);
}
throw UnsupportedError('deployModel');
}