mutateDeployedModel method

Updates an existing deployed model. Updatable fields include min_replica_count, max_replica_count, required_replica_count, autoscaling_metric_specs, disable_container_logging (v1 only), and enable_container_logging (v1beta1 only).

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<
  Operation<MutateDeployedModelResponse, MutateDeployedModelOperationMetadata>
>
mutateDeployedModel(MutateDeployedModelRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_mutateDeployedModel case final mutateDeployedModel?) {
    return mutateDeployedModel(request);
  }
  throw UnsupportedError('mutateDeployedModel');
}