setPublisherModelConfig method

Sets (creates or updates) configs of publisher models. For example, sets the request/response logging config.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<
  Operation<PublisherModelConfig, SetPublisherModelConfigOperationMetadata>
>
setPublisherModelConfig(SetPublisherModelConfigRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_setPublisherModelConfig case final setPublisherModelConfig?) {
    return setPublisherModelConfig(request);
  }
  throw UnsupportedError('setPublisherModelConfig');
}