undeployModel method
Future<Operation<UndeployModelResponse, UndeployModelOperationMetadata> >
undeployModel(
- UndeployModelRequest request
override
Undeploys a Model from an Endpoint, removing a DeployedModel from it, and freeing all resources it's using.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Returns an Operation representing the status of the long-running
operation.
When complete, Operation.done will be true. If successful,
Operation.responseAsMessage will contain the operation's result.
Implementation
@override
Future<Operation<UndeployModelResponse, UndeployModelOperationMetadata>>
undeployModel(UndeployModelRequest request) async {
if (isClosed) throw StateError('Service is closed');
if (_undeployModel case final undeployModel?) {
return undeployModel(request);
}
throw UnsupportedError('undeployModel');
}