evaluateDataset method

Evaluates a dataset based on a set of given metrics.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<EvaluateDatasetResponse, EvaluateDatasetOperationMetadata>>
evaluateDataset(EvaluateDatasetRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_evaluateDataset case final evaluateDataset?) {
    return evaluateDataset(request);
  }
  throw UnsupportedError('evaluateDataset');
}