importExtension method

  1. @override
Future<Operation<Extension, ImportExtensionOperationMetadata>> importExtension(
  1. ImportExtensionRequest request
)
override

Imports an Extension.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<Extension, ImportExtensionOperationMetadata>>
importExtension(ImportExtensionRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_importExtension case final importExtension?) {
    return importExtension(request);
  }
  throw UnsupportedError('importExtension');
}