createFeatureView method

  1. @override
Future<Operation<FeatureView, CreateFeatureViewOperationMetadata>> createFeatureView(
  1. CreateFeatureViewRequest request
)
override

Creates a new FeatureView in a given FeatureOnlineStore.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<FeatureView, CreateFeatureViewOperationMetadata>>
createFeatureView(CreateFeatureViewRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_createFeatureView case final createFeatureView?) {
    return createFeatureView(request);
  }
  throw UnsupportedError('createFeatureView');
}