updateFeatureOnlineStore method

Updates the parameters of a single FeatureOnlineStore.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<
  Operation<FeatureOnlineStore, UpdateFeatureOnlineStoreOperationMetadata>
>
updateFeatureOnlineStore(UpdateFeatureOnlineStoreRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_updateFeatureOnlineStore case final updateFeatureOnlineStore?) {
    return updateFeatureOnlineStore(request);
  }
  throw UnsupportedError('updateFeatureOnlineStore');
}