updateFeatureView method

  1. @override
Future<Operation<FeatureView, UpdateFeatureViewOperationMetadata>> updateFeatureView(
  1. UpdateFeatureViewRequest request
)
override

Updates the parameters of a single FeatureView.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<FeatureView, UpdateFeatureViewOperationMetadata>>
updateFeatureView(UpdateFeatureViewRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_updateFeatureView case final updateFeatureView?) {
    return updateFeatureView(request);
  }
  throw UnsupportedError('updateFeatureView');
}