generateFetchAccessToken method

  1. @override
Future<GenerateFetchAccessTokenResponse> generateFetchAccessToken(
  1. GenerateFetchAccessTokenRequest request
)
override

RPC to generate an access token for the given feature view. FeatureViews under the same FeatureOnlineStore share the same access token.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<GenerateFetchAccessTokenResponse> generateFetchAccessToken(
  GenerateFetchAccessTokenRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_generateFetchAccessToken case final generateFetchAccessToken?) {
    return generateFetchAccessToken(request);
  }
  throw UnsupportedError('generateFetchAccessToken');
}