createFeatureGroup method

  1. @override
Future<Operation<FeatureGroup, CreateFeatureGroupOperationMetadata>> createFeatureGroup(
  1. CreateFeatureGroupRequest request
)
override

Creates a new FeatureGroup in a given project and location.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<FeatureGroup, CreateFeatureGroupOperationMetadata>>
createFeatureGroup(CreateFeatureGroupRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_createFeatureGroup case final createFeatureGroup?) {
    return createFeatureGroup(request);
  }
  throw UnsupportedError('createFeatureGroup');
}