deleteFeatureMonitor method

  1. @override
Future<Operation<Empty, DeleteOperationMetadata>> deleteFeatureMonitor(
  1. DeleteFeatureMonitorRequest request
)
override

Deletes a single FeatureMonitor.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<protobuf.Empty, DeleteOperationMetadata>>
deleteFeatureMonitor(DeleteFeatureMonitorRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_deleteFeatureMonitor case final deleteFeatureMonitor?) {
    return deleteFeatureMonitor(request);
  }
  throw UnsupportedError('deleteFeatureMonitor');
}