readFeatureValues method

  1. @override
Future<ReadFeatureValuesResponse> readFeatureValues(
  1. ReadFeatureValuesRequest request
)
override

Reads Feature values of a specific entity of an EntityType. For reading feature values of multiple entities of an EntityType, please use StreamingReadFeatureValues.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<ReadFeatureValuesResponse> readFeatureValues(
  ReadFeatureValuesRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_readFeatureValues case final readFeatureValues?) {
    return readFeatureValues(request);
  }
  throw UnsupportedError('readFeatureValues');
}