streamingReadFeatureValues method

  1. @override
Stream<ReadFeatureValuesResponse> streamingReadFeatureValues(
  1. StreamingReadFeatureValuesRequest request
)
override

Reads Feature values for multiple entities. Depending on their size, data for different entities may be broken up across multiple responses.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Stream<ReadFeatureValuesResponse> streamingReadFeatureValues(
  StreamingReadFeatureValuesRequest request,
) {
  if (isClosed) throw StateError('Service is closed');
  if (_streamingReadFeatureValues case final streamingReadFeatureValues?) {
    return streamingReadFeatureValues(request);
  }
  throw UnsupportedError('streamingReadFeatureValues');
}