batchCreateFeatures method
Future<Operation<BatchCreateFeaturesResponse, BatchCreateFeaturesOperationMetadata> >
batchCreateFeatures(
- BatchCreateFeaturesRequest request
override
Creates a batch of Features in a given EntityType.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Returns an Operation representing the status of the long-running
operation.
When complete, Operation.done will be true. If successful,
Operation.responseAsMessage will contain the operation's result.
Implementation
@override
Future<
Operation<BatchCreateFeaturesResponse, BatchCreateFeaturesOperationMetadata>
>
batchCreateFeatures(BatchCreateFeaturesRequest request) async {
if (isClosed) throw StateError('Service is closed');
if (_batchCreateFeatures case final batchCreateFeatures?) {
return batchCreateFeatures(request);
}
throw UnsupportedError('batchCreateFeatures');
}