createFeature method

  1. @override
Future<Operation<Feature, CreateFeatureOperationMetadata>> createFeature(
  1. CreateFeatureRequest request
)
override

Creates a new Feature in a given EntityType.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<Feature, CreateFeatureOperationMetadata>> createFeature(
  CreateFeatureRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_createFeature case final createFeature?) {
    return createFeature(request);
  }
  throw UnsupportedError('createFeature');
}