createFeaturestore method
Future<Operation<Featurestore, CreateFeaturestoreOperationMetadata> >
createFeaturestore(
- CreateFeaturestoreRequest request
override
Creates a new Featurestore in a given project and location.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Returns an Operation representing the status of the long-running
operation.
When complete, Operation.done will be true. If successful,
Operation.responseAsMessage will contain the operation's result.
Implementation
@override
Future<Operation<Featurestore, CreateFeaturestoreOperationMetadata>>
createFeaturestore(CreateFeaturestoreRequest request) async {
if (isClosed) throw StateError('Service is closed');
if (_createFeaturestore case final createFeaturestore?) {
return createFeaturestore(request);
}
throw UnsupportedError('createFeaturestore');
}