deleteFeaturestore method
Future<Operation<Empty, DeleteOperationMetadata> >
deleteFeaturestore(
- DeleteFeaturestoreRequest request
override
Deletes a single Featurestore. The Featurestore must not contain any
EntityTypes or force must be set to true for the request to succeed.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Returns an Operation representing the status of the long-running
operation.
When complete, Operation.done will be true. If successful,
Operation.responseAsMessage will contain the operation's result.
Implementation
@override
Future<Operation<protobuf.Empty, DeleteOperationMetadata>> deleteFeaturestore(
DeleteFeaturestoreRequest request,
) async {
if (isClosed) throw StateError('Service is closed');
if (_deleteFeaturestore case final deleteFeaturestore?) {
return deleteFeaturestore(request);
}
throw UnsupportedError('deleteFeaturestore');
}