exportFeatureValues method

Exports Feature values from all the entities of a target EntityType.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<
  Operation<ExportFeatureValuesResponse, ExportFeatureValuesOperationMetadata>
>
exportFeatureValues(ExportFeatureValuesRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_exportFeatureValues case final exportFeatureValues?) {
    return exportFeatureValues(request);
  }
  throw UnsupportedError('exportFeatureValues');
}