searchFeatures method

  1. @override
Future<SearchFeaturesResponse> searchFeatures(
  1. SearchFeaturesRequest request
)
override

Searches Features matching a query in a given project.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<SearchFeaturesResponse> searchFeatures(
  SearchFeaturesRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_searchFeatures case final searchFeatures?) {
    return searchFeatures(request);
  }
  throw UnsupportedError('searchFeatures');
}