FakeGenAiCacheService class base
Testing fake for GenAiCacheService.
- Implemented types
Constructors
-
FakeGenAiCacheService({Future<
CachedContent> createCachedContent(CreateCachedContentRequest request)?, Future<CachedContent> getCachedContent(GetCachedContentRequest request)?, Future<CachedContent> updateCachedContent(UpdateCachedContentRequest request)?, Future<void> deleteCachedContent(DeleteCachedContentRequest request)?, Future<ListCachedContentsResponse> listCachedContents(ListCachedContentsRequest request)?, Future<ListLocationsResponse> listLocations(ListLocationsRequest request)?, Future<Location> getLocation(GetLocationRequest request)?, Future<Policy> setIamPolicy(SetIamPolicyRequest request)?, Future<Policy> getIamPolicy(GetIamPolicyRequest request)?, Future<TestIamPermissionsResponse> testIamPermissions(TestIamPermissionsRequest request)?, Future<ListOperationsResponse> listOperations(ListOperationsRequest request)?, Future<Operation< getOperation<T, S> >T extends ProtoMessage, S extends ProtoMessage>(Operation< Future<T, S> request)?,void> deleteOperation(DeleteOperationRequest request)?, Future<void> cancelOperation(CancelOperationRequest request)?, Future<Operation< waitOperation(WaitOperationRequest request)?})ProtoMessage, ProtoMessage> >
Properties
Methods
-
cancelOperation(
CancelOperationRequest request) → Future< void> -
Provides the
Operationsservice functionality in this service.override -
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
createCachedContent(
CreateCachedContentRequest request) → Future< CachedContent> -
Creates cached content, this call will initialize the cached content in the
data storage, and users need to pay for the cache data storage.
override
-
deleteCachedContent(
DeleteCachedContentRequest request) → Future< void> -
Deletes cached content
override
-
deleteOperation(
DeleteOperationRequest request) → Future< void> -
Provides the
Operationsservice functionality in this service.override -
getCachedContent(
GetCachedContentRequest request) → Future< CachedContent> -
Gets cached content configurations
override
-
getIamPolicy(
GetIamPolicyRequest request) → Future< Policy> -
Gets the access control policy for a resource. Returns an empty policy
if the resource exists and does not have a policy set.
override
-
getLocation(
GetLocationRequest request) → Future< Location> -
Gets information about a location.
override
-
getOperation<
T extends ProtoMessage, S extends ProtoMessage> (Operation< T, S> request) → Future<Operation< T, S> > -
Provides the
Operationsservice functionality in this service.override -
listCachedContents(
ListCachedContentsRequest request) → Future< ListCachedContentsResponse> -
Lists cached contents in a project
override
-
listLocations(
ListLocationsRequest request) → Future< ListLocationsResponse> -
Lists information about the supported locations for this service.
override
-
listOperations(
ListOperationsRequest request) → Future< ListOperationsResponse> -
Provides the
Operationsservice functionality in this service.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setIamPolicy(
SetIamPolicyRequest request) → Future< Policy> -
Sets the access control policy on the specified resource. Replaces
any existing policy.
override
-
testIamPermissions(
TestIamPermissionsRequest request) → Future< TestIamPermissionsResponse> -
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of
permissions, not a
NOT_FOUNDerror.override -
toString(
) → String -
A string representation of this object.
inherited
-
updateCachedContent(
UpdateCachedContentRequest request) → Future< CachedContent> -
Updates cached content configurations
override
-
waitOperation(
WaitOperationRequest request) → Future< Operation< ProtoMessage, ProtoMessage> > -
Provides the
Operationsservice functionality in this service.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited