FakeGenAiTuningService class base

Testing fake for GenAiTuningService.

Implemented types

Constructors

FakeGenAiTuningService({Future<TuningJob> createTuningJob(CreateTuningJobRequest request)?, Future<TuningJob> getTuningJob(GetTuningJobRequest request)?, Future<ListTuningJobsResponse> listTuningJobs(ListTuningJobsRequest request)?, Future<void> cancelTuningJob(CancelTuningJobRequest request)?, Future<Operation<TuningJob, RebaseTunedModelOperationMetadata>> rebaseTunedModel(RebaseTunedModelRequest request)?, Future<ListLocationsResponse> listLocations(ListLocationsRequest request)?, Future<Location> getLocation(GetLocationRequest request)?, Future<Policy> setIamPolicy(SetIamPolicyRequest request)?, Future<Policy> getIamPolicy(GetIamPolicyRequest request)?, Future<TestIamPermissionsResponse> testIamPermissions(TestIamPermissionsRequest request)?, Future<ListOperationsResponse> listOperations(ListOperationsRequest request)?, Future<Operation<T, S>> getOperation<T extends ProtoMessage, S extends ProtoMessage>(Operation<T, S> request)?, Future<void> deleteOperation(DeleteOperationRequest request)?, Future<void> cancelOperation(CancelOperationRequest request)?, Future<Operation<ProtoMessage, ProtoMessage>> waitOperation(WaitOperationRequest request)?})

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancelOperation(CancelOperationRequest request) Future<void>
Provides the Operations service functionality in this service.
override
cancelTuningJob(CancelTuningJobRequest request) Future<void>
Cancels a TuningJob. Starts asynchronous cancellation on the TuningJob. The server makes a best effort to cancel the job, but success is not guaranteed. Clients can use GenAiTuningService.GetTuningJob or other methods to check whether the cancellation succeeded or whether the job completed despite cancellation. On successful cancellation, the TuningJob is not deleted; instead it becomes a job with a TuningJob.error value with a google.rpc.Status.code of 1, corresponding to Code.CANCELLED, and TuningJob.state is set to CANCELLED.
override
close() → void
Closes the client and cleans up any resources associated with it.
override
createTuningJob(CreateTuningJobRequest request) Future<TuningJob>
Creates a TuningJob. A created TuningJob right away will be attempted to be run.
override
deleteOperation(DeleteOperationRequest request) Future<void>
Provides the Operations service functionality in this service.
override
getIamPolicy(GetIamPolicyRequest request) Future<Policy>
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
override
getLocation(GetLocationRequest request) Future<Location>
Gets information about a location.
override
getOperation<T extends ProtoMessage, S extends ProtoMessage>(Operation<T, S> request) Future<Operation<T, S>>
Provides the Operations service functionality in this service.
override
getTuningJob(GetTuningJobRequest request) Future<TuningJob>
Gets a TuningJob.
override
listLocations(ListLocationsRequest request) Future<ListLocationsResponse>
Lists information about the supported locations for this service.
override
listOperations(ListOperationsRequest request) Future<ListOperationsResponse>
Provides the Operations service functionality in this service.
override
listTuningJobs(ListTuningJobsRequest request) Future<ListTuningJobsResponse>
Lists TuningJobs in a Location.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebaseTunedModel(RebaseTunedModelRequest request) Future<Operation<TuningJob, RebaseTunedModelOperationMetadata>>
Rebase a TunedModel. Creates a LongRunningOperation that takes a legacy Tuned GenAI model Reference and creates a TuningJob based on newly available model.
override
setIamPolicy(SetIamPolicyRequest request) Future<Policy>
Sets the access control policy on the specified resource. Replaces any existing policy.
override
testIamPermissions(TestIamPermissionsRequest request) Future<TestIamPermissionsResponse>
Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a NOT_FOUND error.
override
toString() String
A string representation of this object.
inherited
waitOperation(WaitOperationRequest request) Future<Operation<ProtoMessage, ProtoMessage>>
Provides the Operations service functionality in this service.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited