createTuningJob method

  1. @override
Future<TuningJob> createTuningJob(
  1. CreateTuningJobRequest request
)
override

Creates a TuningJob. A created TuningJob right away will be attempted to be run.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<TuningJob> createTuningJob(CreateTuningJobRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_createTuningJob case final createTuningJob?) {
    return createTuningJob(request);
  }
  throw UnsupportedError('createTuningJob');
}