rebaseTunedModel method

  1. @override
Future<Operation<TuningJob, RebaseTunedModelOperationMetadata>> rebaseTunedModel(
  1. RebaseTunedModelRequest request
)
override

Rebase a TunedModel. Creates a LongRunningOperation that takes a legacy Tuned GenAI model Reference and creates a TuningJob based on newly available model.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<TuningJob, RebaseTunedModelOperationMetadata>>
rebaseTunedModel(RebaseTunedModelRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_rebaseTunedModel case final rebaseTunedModel?) {
    return rebaseTunedModel(request);
  }
  throw UnsupportedError('rebaseTunedModel');
}