FakeIndexEndpointService class base
Testing fake for IndexEndpointService.
- Implemented types
Constructors
-
FakeIndexEndpointService({Future<
Operation< createIndexEndpoint(CreateIndexEndpointRequest request)?, Future<IndexEndpoint, CreateIndexEndpointOperationMetadata> >IndexEndpoint> getIndexEndpoint(GetIndexEndpointRequest request)?, Future<ListIndexEndpointsResponse> listIndexEndpoints(ListIndexEndpointsRequest request)?, Future<IndexEndpoint> updateIndexEndpoint(UpdateIndexEndpointRequest request)?, Future<Operation< deleteIndexEndpoint(DeleteIndexEndpointRequest request)?, Future<Empty, DeleteOperationMetadata> >Operation< deployIndex(DeployIndexRequest request)?, Future<DeployIndexResponse, DeployIndexOperationMetadata> >Operation< undeployIndex(UndeployIndexRequest request)?, Future<UndeployIndexResponse, UndeployIndexOperationMetadata> >Operation< mutateDeployedIndex(MutateDeployedIndexRequest request)?, Future<MutateDeployedIndexResponse, MutateDeployedIndexOperationMetadata> >ListLocationsResponse> listLocations(ListLocationsRequest request)?, Future<Location> getLocation(GetLocationRequest request)?, Future<Policy> setIamPolicy(SetIamPolicyRequest request)?, Future<Policy> getIamPolicy(GetIamPolicyRequest request)?, Future<TestIamPermissionsResponse> testIamPermissions(TestIamPermissionsRequest request)?, Future<ListOperationsResponse> listOperations(ListOperationsRequest request)?, Future<Operation< getOperation<T, S> >T extends ProtoMessage, S extends ProtoMessage>(Operation< Future<T, S> request)?,void> deleteOperation(DeleteOperationRequest request)?, Future<void> cancelOperation(CancelOperationRequest request)?, Future<Operation< waitOperation(WaitOperationRequest request)?})ProtoMessage, ProtoMessage> >
Properties
Methods
-
cancelOperation(
CancelOperationRequest request) → Future< void> -
Provides the
Operationsservice functionality in this service.override -
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
createIndexEndpoint(
CreateIndexEndpointRequest request) → Future< Operation< IndexEndpoint, CreateIndexEndpointOperationMetadata> > -
Creates an IndexEndpoint.
override
-
deleteIndexEndpoint(
DeleteIndexEndpointRequest request) → Future< Operation< Empty, DeleteOperationMetadata> > -
Deletes an IndexEndpoint.
override
-
deleteOperation(
DeleteOperationRequest request) → Future< void> -
Provides the
Operationsservice functionality in this service.override -
deployIndex(
DeployIndexRequest request) → Future< Operation< DeployIndexResponse, DeployIndexOperationMetadata> > -
Deploys an Index into this IndexEndpoint, creating a DeployedIndex within
it.
Only non-empty Indexes can be deployed.
override
-
getIamPolicy(
GetIamPolicyRequest request) → Future< Policy> -
Gets the access control policy for a resource. Returns an empty policy
if the resource exists and does not have a policy set.
override
-
getIndexEndpoint(
GetIndexEndpointRequest request) → Future< IndexEndpoint> -
Gets an IndexEndpoint.
override
-
getLocation(
GetLocationRequest request) → Future< Location> -
Gets information about a location.
override
-
getOperation<
T extends ProtoMessage, S extends ProtoMessage> (Operation< T, S> request) → Future<Operation< T, S> > -
Provides the
Operationsservice functionality in this service.override -
listIndexEndpoints(
ListIndexEndpointsRequest request) → Future< ListIndexEndpointsResponse> -
Lists IndexEndpoints in a Location.
override
-
listLocations(
ListLocationsRequest request) → Future< ListLocationsResponse> -
Lists information about the supported locations for this service.
override
-
listOperations(
ListOperationsRequest request) → Future< ListOperationsResponse> -
Provides the
Operationsservice functionality in this service.override -
mutateDeployedIndex(
MutateDeployedIndexRequest request) → Future< Operation< MutateDeployedIndexResponse, MutateDeployedIndexOperationMetadata> > -
Update an existing DeployedIndex under an IndexEndpoint.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setIamPolicy(
SetIamPolicyRequest request) → Future< Policy> -
Sets the access control policy on the specified resource. Replaces
any existing policy.
override
-
testIamPermissions(
TestIamPermissionsRequest request) → Future< TestIamPermissionsResponse> -
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of
permissions, not a
NOT_FOUNDerror.override -
toString(
) → String -
A string representation of this object.
inherited
-
undeployIndex(
UndeployIndexRequest request) → Future< Operation< UndeployIndexResponse, UndeployIndexOperationMetadata> > -
Undeploys an Index from an IndexEndpoint, removing a DeployedIndex from it,
and freeing all resources it's using.
override
-
updateIndexEndpoint(
UpdateIndexEndpointRequest request) → Future< IndexEndpoint> -
Updates an IndexEndpoint.
override
-
waitOperation(
WaitOperationRequest request) → Future< Operation< ProtoMessage, ProtoMessage> > -
Provides the
Operationsservice functionality in this service.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited