undeployIndex method

Undeploys an Index from an IndexEndpoint, removing a DeployedIndex from it, and freeing all resources it's using.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<UndeployIndexResponse, UndeployIndexOperationMetadata>>
undeployIndex(UndeployIndexRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_undeployIndex case final undeployIndex?) {
    return undeployIndex(request);
  }
  throw UnsupportedError('undeployIndex');
}