FakeIndexService class base

Testing fake for IndexService.

Implemented types

Constructors

FakeIndexService({Future<Operation<Index, CreateIndexOperationMetadata>> createIndex(CreateIndexRequest request)?, Future<Index> getIndex(GetIndexRequest request)?, Future<Operation<Index, ImportIndexOperationMetadata>> importIndex(ImportIndexRequest request)?, Future<ListIndexesResponse> listIndexes(ListIndexesRequest request)?, Future<Operation<Index, UpdateIndexOperationMetadata>> updateIndex(UpdateIndexRequest request)?, Future<Operation<Empty, DeleteOperationMetadata>> deleteIndex(DeleteIndexRequest request)?, Future<UpsertDatapointsResponse> upsertDatapoints(UpsertDatapointsRequest request)?, Future<RemoveDatapointsResponse> removeDatapoints(RemoveDatapointsRequest request)?, Future<ListLocationsResponse> listLocations(ListLocationsRequest request)?, Future<Location> getLocation(GetLocationRequest request)?, Future<Policy> setIamPolicy(SetIamPolicyRequest request)?, Future<Policy> getIamPolicy(GetIamPolicyRequest request)?, Future<TestIamPermissionsResponse> testIamPermissions(TestIamPermissionsRequest request)?, Future<ListOperationsResponse> listOperations(ListOperationsRequest request)?, Future<Operation<T, S>> getOperation<T extends ProtoMessage, S extends ProtoMessage>(Operation<T, S> request)?, Future<void> deleteOperation(DeleteOperationRequest request)?, Future<void> cancelOperation(CancelOperationRequest request)?, Future<Operation<ProtoMessage, ProtoMessage>> waitOperation(WaitOperationRequest request)?})

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancelOperation(CancelOperationRequest request) Future<void>
Provides the Operations service functionality in this service.
override
close() → void
Closes the client and cleans up any resources associated with it.
override
createIndex(CreateIndexRequest request) Future<Operation<Index, CreateIndexOperationMetadata>>
Creates an Index.
override
deleteIndex(DeleteIndexRequest request) Future<Operation<Empty, DeleteOperationMetadata>>
Deletes an Index. An Index can only be deleted when all its DeployedIndexes had been undeployed.
override
deleteOperation(DeleteOperationRequest request) Future<void>
Provides the Operations service functionality in this service.
override
getIamPolicy(GetIamPolicyRequest request) Future<Policy>
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
override
getIndex(GetIndexRequest request) Future<Index>
Gets an Index.
override
getLocation(GetLocationRequest request) Future<Location>
Gets information about a location.
override
getOperation<T extends ProtoMessage, S extends ProtoMessage>(Operation<T, S> request) Future<Operation<T, S>>
Provides the Operations service functionality in this service.
override
importIndex(ImportIndexRequest request) Future<Operation<Index, ImportIndexOperationMetadata>>
Imports an Index from an external source (e.g., BigQuery).
override
listIndexes(ListIndexesRequest request) Future<ListIndexesResponse>
Lists Indexes in a Location.
override
listLocations(ListLocationsRequest request) Future<ListLocationsResponse>
Lists information about the supported locations for this service.
override
listOperations(ListOperationsRequest request) Future<ListOperationsResponse>
Provides the Operations service functionality in this service.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeDatapoints(RemoveDatapointsRequest request) Future<RemoveDatapointsResponse>
Remove Datapoints from an Index.
override
setIamPolicy(SetIamPolicyRequest request) Future<Policy>
Sets the access control policy on the specified resource. Replaces any existing policy.
override
testIamPermissions(TestIamPermissionsRequest request) Future<TestIamPermissionsResponse>
Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a NOT_FOUND error.
override
toString() String
A string representation of this object.
inherited
updateIndex(UpdateIndexRequest request) Future<Operation<Index, UpdateIndexOperationMetadata>>
Updates an Index.
override
upsertDatapoints(UpsertDatapointsRequest request) Future<UpsertDatapointsResponse>
Add/update Datapoints into an Index.
override
waitOperation(WaitOperationRequest request) Future<Operation<ProtoMessage, ProtoMessage>>
Provides the Operations service functionality in this service.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited