importIndex method

  1. @override
Future<Operation<Index, ImportIndexOperationMetadata>> importIndex(
  1. ImportIndexRequest request
)
override

Imports an Index from an external source (e.g., BigQuery).

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<Index, ImportIndexOperationMetadata>> importIndex(
  ImportIndexRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_importIndex case final importIndex?) {
    return importIndex(request);
  }
  throw UnsupportedError('importIndex');
}