updateIndex method

  1. @override
Future<Operation<Index, UpdateIndexOperationMetadata>> updateIndex(
  1. UpdateIndexRequest request
)
override

Updates an Index.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<Index, UpdateIndexOperationMetadata>> updateIndex(
  UpdateIndexRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_updateIndex case final updateIndex?) {
    return updateIndex(request);
  }
  throw UnsupportedError('updateIndex');
}