createBatchPredictionJob method

  1. @override
Future<BatchPredictionJob> createBatchPredictionJob(
  1. CreateBatchPredictionJobRequest request
)
override

Creates a BatchPredictionJob. A BatchPredictionJob once created will right away be attempted to start.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<BatchPredictionJob> createBatchPredictionJob(
  CreateBatchPredictionJobRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_createBatchPredictionJob case final createBatchPredictionJob?) {
    return createBatchPredictionJob(request);
  }
  throw UnsupportedError('createBatchPredictionJob');
}