createCustomJob method

  1. @override
Future<CustomJob> createCustomJob(
  1. CreateCustomJobRequest request
)
override

Creates a CustomJob. A created CustomJob right away will be attempted to be run.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<CustomJob> createCustomJob(CreateCustomJobRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_createCustomJob case final createCustomJob?) {
    return createCustomJob(request);
  }
  throw UnsupportedError('createCustomJob');
}