deleteBatchPredictionJob method

  1. @override
Future<Operation<Empty, DeleteOperationMetadata>> deleteBatchPredictionJob(
  1. DeleteBatchPredictionJobRequest request
)
override

Deletes a BatchPredictionJob. Can only be called on jobs that already finished.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<protobuf.Empty, DeleteOperationMetadata>>
deleteBatchPredictionJob(DeleteBatchPredictionJobRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_deleteBatchPredictionJob case final deleteBatchPredictionJob?) {
    return deleteBatchPredictionJob(request);
  }
  throw UnsupportedError('deleteBatchPredictionJob');
}