deleteDataLabelingJob method

  1. @override
Future<Operation<Empty, DeleteOperationMetadata>> deleteDataLabelingJob(
  1. DeleteDataLabelingJobRequest request
)
override

Deletes a DataLabelingJob.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<protobuf.Empty, DeleteOperationMetadata>>
deleteDataLabelingJob(DeleteDataLabelingJobRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_deleteDataLabelingJob case final deleteDataLabelingJob?) {
    return deleteDataLabelingJob(request);
  }
  throw UnsupportedError('deleteDataLabelingJob');
}