deleteModelDeploymentMonitoringJob method

  1. @override
Future<Operation<Empty, DeleteOperationMetadata>> deleteModelDeploymentMonitoringJob(
  1. DeleteModelDeploymentMonitoringJobRequest request
)
override

Deletes a ModelDeploymentMonitoringJob.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<protobuf.Empty, DeleteOperationMetadata>>
deleteModelDeploymentMonitoringJob(
  DeleteModelDeploymentMonitoringJobRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_deleteModelDeploymentMonitoringJob
      case final deleteModelDeploymentMonitoringJob?) {
    return deleteModelDeploymentMonitoringJob(request);
  }
  throw UnsupportedError('deleteModelDeploymentMonitoringJob');
}