pauseModelDeploymentMonitoringJob method

  1. @override
Future<void> pauseModelDeploymentMonitoringJob(
  1. PauseModelDeploymentMonitoringJobRequest request
)
override

Pauses a ModelDeploymentMonitoringJob. If the job is running, the server makes a best effort to cancel the job. Will mark ModelDeploymentMonitoringJob.state to 'PAUSED'.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<void> pauseModelDeploymentMonitoringJob(
  PauseModelDeploymentMonitoringJobRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_pauseModelDeploymentMonitoringJob
      case final pauseModelDeploymentMonitoringJob?) {
    return pauseModelDeploymentMonitoringJob(request);
  }
  throw UnsupportedError('pauseModelDeploymentMonitoringJob');
}