resumeModelDeploymentMonitoringJob method

  1. @override
Future<void> resumeModelDeploymentMonitoringJob(
  1. ResumeModelDeploymentMonitoringJobRequest request
)
override

Resumes a paused ModelDeploymentMonitoringJob. It will start to run from next scheduled time. A deleted ModelDeploymentMonitoringJob can't be resumed.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<void> resumeModelDeploymentMonitoringJob(
  ResumeModelDeploymentMonitoringJobRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_resumeModelDeploymentMonitoringJob
      case final resumeModelDeploymentMonitoringJob?) {
    return resumeModelDeploymentMonitoringJob(request);
  }
  throw UnsupportedError('resumeModelDeploymentMonitoringJob');
}