searchModelDeploymentMonitoringStatsAnomalies method

Searches Model Monitoring Statistics generated within a given time window.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<SearchModelDeploymentMonitoringStatsAnomaliesResponse>
searchModelDeploymentMonitoringStatsAnomalies(
  SearchModelDeploymentMonitoringStatsAnomaliesRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_searchModelDeploymentMonitoringStatsAnomalies
      case final searchModelDeploymentMonitoringStatsAnomalies?) {
    return searchModelDeploymentMonitoringStatsAnomalies(request);
  }
  throw UnsupportedError('searchModelDeploymentMonitoringStatsAnomalies');
}