findNeighbors method

  1. @override
Future<FindNeighborsResponse> findNeighbors(
  1. FindNeighborsRequest request
)
override

Finds the nearest neighbors of each vector within the request.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<FindNeighborsResponse> findNeighbors(
  FindNeighborsRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_findNeighbors case final findNeighbors?) {
    return findNeighbors(request);
  }
  throw UnsupportedError('findNeighbors');
}