createMemory method

  1. @override
Future<Operation<Memory, CreateMemoryOperationMetadata>> createMemory(
  1. CreateMemoryRequest request
)
override

Create a Memory.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<Memory, CreateMemoryOperationMetadata>> createMemory(
  CreateMemoryRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_createMemory case final createMemory?) {
    return createMemory(request);
  }
  throw UnsupportedError('createMemory');
}