updateMemory method

  1. @override
Future<Operation<Memory, UpdateMemoryOperationMetadata>> updateMemory(
  1. UpdateMemoryRequest request
)
override

Update a Memory.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<Memory, UpdateMemoryOperationMetadata>> updateMemory(
  UpdateMemoryRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_updateMemory case final updateMemory?) {
    return updateMemory(request);
  }
  throw UnsupportedError('updateMemory');
}