addExecutionEvents method

  1. @override
Future<AddExecutionEventsResponse> addExecutionEvents(
  1. AddExecutionEventsRequest request
)
override

Adds Events to the specified Execution. An Event indicates whether an Artifact was used as an input or output for an Execution. If an Event already exists between the Execution and the Artifact, the Event is skipped.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<AddExecutionEventsResponse> addExecutionEvents(
  AddExecutionEventsRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_addExecutionEvents case final addExecutionEvents?) {
    return addExecutionEvents(request);
  }
  throw UnsupportedError('addExecutionEvents');
}