createMetadataStore method

  1. @override
Future<Operation<MetadataStore, CreateMetadataStoreOperationMetadata>> createMetadataStore(
  1. CreateMetadataStoreRequest request
)
override

Initializes a MetadataStore, including allocation of resources.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<MetadataStore, CreateMetadataStoreOperationMetadata>>
createMetadataStore(CreateMetadataStoreRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_createMetadataStore case final createMetadataStore?) {
    return createMetadataStore(request);
  }
  throw UnsupportedError('createMetadataStore');
}