deleteArtifact method

  1. @override
Future<Operation<Empty, DeleteOperationMetadata>> deleteArtifact(
  1. DeleteArtifactRequest request
)
override

Deletes an Artifact.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<protobuf.Empty, DeleteOperationMetadata>> deleteArtifact(
  DeleteArtifactRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_deleteArtifact case final deleteArtifact?) {
    return deleteArtifact(request);
  }
  throw UnsupportedError('deleteArtifact');
}