deleteExecution method

  1. @override
Future<Operation<Empty, DeleteOperationMetadata>> deleteExecution(
  1. DeleteExecutionRequest request
)
override

Deletes an Execution.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<protobuf.Empty, DeleteOperationMetadata>> deleteExecution(
  DeleteExecutionRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_deleteExecution case final deleteExecution?) {
    return deleteExecution(request);
  }
  throw UnsupportedError('deleteExecution');
}