deleteMetadataStore method

  1. @override
Future<Operation<Empty, DeleteMetadataStoreOperationMetadata>> deleteMetadataStore(
  1. DeleteMetadataStoreRequest request
)
override

Deletes a single MetadataStore and all its child resources (Artifacts, Executions, and Contexts).

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<protobuf.Empty, DeleteMetadataStoreOperationMetadata>>
deleteMetadataStore(DeleteMetadataStoreRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_deleteMetadataStore case final deleteMetadataStore?) {
    return deleteMetadataStore(request);
  }
  throw UnsupportedError('deleteMetadataStore');
}