purgeArtifacts method

  1. @override
Future<Operation<PurgeArtifactsResponse, PurgeArtifactsMetadata>> purgeArtifacts(
  1. PurgeArtifactsRequest request
)
override

Purges Artifacts.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<PurgeArtifactsResponse, PurgeArtifactsMetadata>>
purgeArtifacts(PurgeArtifactsRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_purgeArtifacts case final purgeArtifacts?) {
    return purgeArtifacts(request);
  }
  throw UnsupportedError('purgeArtifacts');
}