purgeContexts method

  1. @override
Future<Operation<PurgeContextsResponse, PurgeContextsMetadata>> purgeContexts(
  1. PurgeContextsRequest request
)
override

Purges Contexts.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<PurgeContextsResponse, PurgeContextsMetadata>> purgeContexts(
  PurgeContextsRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_purgeContexts case final purgeContexts?) {
    return purgeContexts(request);
  }
  throw UnsupportedError('purgeContexts');
}