purgeExecutions method

  1. @override
Future<Operation<PurgeExecutionsResponse, PurgeExecutionsMetadata>> purgeExecutions(
  1. PurgeExecutionsRequest request
)
override

Purges Executions.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<PurgeExecutionsResponse, PurgeExecutionsMetadata>>
purgeExecutions(PurgeExecutionsRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_purgeExecutions case final purgeExecutions?) {
    return purgeExecutions(request);
  }
  throw UnsupportedError('purgeExecutions');
}