queryContextLineageSubgraph method

  1. @override
Future<LineageSubgraph> queryContextLineageSubgraph(
  1. QueryContextLineageSubgraphRequest request
)
override

Retrieves Artifacts and Executions within the specified Context, connected by Event edges and returned as a LineageSubgraph.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<LineageSubgraph> queryContextLineageSubgraph(
  QueryContextLineageSubgraphRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_queryContextLineageSubgraph case final queryContextLineageSubgraph?) {
    return queryContextLineageSubgraph(request);
  }
  throw UnsupportedError('queryContextLineageSubgraph');
}