batchMigrateResources method

Batch migrates resources from ml.googleapis.com, automl.googleapis.com, and datalabeling.googleapis.com to Vertex AI.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<
  Operation<
    BatchMigrateResourcesResponse,
    BatchMigrateResourcesOperationMetadata
  >
>
batchMigrateResources(BatchMigrateResourcesRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_batchMigrateResources case final batchMigrateResources?) {
    return batchMigrateResources(request);
  }
  throw UnsupportedError('batchMigrateResources');
}