deploy method

  1. @override
Future<Operation<DeployResponse, DeployOperationMetadata>> deploy(
  1. DeployRequest request
)
override

Deploys a model to a new endpoint.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<DeployResponse, DeployOperationMetadata>> deploy(
  DeployRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_deploy case final deploy?) {
    return deploy(request);
  }
  throw UnsupportedError('deploy');
}