createModelMonitor method

  1. @override
Future<Operation<ModelMonitor, CreateModelMonitorOperationMetadata>> createModelMonitor(
  1. CreateModelMonitorRequest request
)
override

Creates a ModelMonitor.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<ModelMonitor, CreateModelMonitorOperationMetadata>>
createModelMonitor(CreateModelMonitorRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_createModelMonitor case final createModelMonitor?) {
    return createModelMonitor(request);
  }
  throw UnsupportedError('createModelMonitor');
}