listModelMonitoringJobs method

  1. @override
Future<ListModelMonitoringJobsResponse> listModelMonitoringJobs(
  1. ListModelMonitoringJobsRequest request
)
override

Lists ModelMonitoringJobs. Callers may choose to read across multiple Monitors as per AIP-159 by using '-' (the hyphen or dash character) as a wildcard character instead of modelMonitor id in the parent. Format projects/{project_id}/locations/{location}/moodelMonitors/-/modelMonitoringJobs

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<ListModelMonitoringJobsResponse> listModelMonitoringJobs(
  ListModelMonitoringJobsRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_listModelMonitoringJobs case final listModelMonitoringJobs?) {
    return listModelMonitoringJobs(request);
  }
  throw UnsupportedError('listModelMonitoringJobs');
}