searchModelMonitoringStats method

  1. @override
Future<SearchModelMonitoringStatsResponse> searchModelMonitoringStats(
  1. SearchModelMonitoringStatsRequest request
)
override

Searches Model Monitoring Stats generated within a given time window.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<SearchModelMonitoringStatsResponse> searchModelMonitoringStats(
  SearchModelMonitoringStatsRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_searchModelMonitoringStats case final searchModelMonitoringStats?) {
    return searchModelMonitoringStats(request);
  }
  throw UnsupportedError('searchModelMonitoringStats');
}