updateModelMonitor method

  1. @override
Future<Operation<ModelMonitor, UpdateModelMonitorOperationMetadata>> updateModelMonitor(
  1. UpdateModelMonitorRequest request
)
override

Updates a ModelMonitor.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<ModelMonitor, UpdateModelMonitorOperationMetadata>>
updateModelMonitor(UpdateModelMonitorRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_updateModelMonitor case final updateModelMonitor?) {
    return updateModelMonitor(request);
  }
  throw UnsupportedError('updateModelMonitor');
}