copyModel method

  1. @override
Future<Operation<CopyModelResponse, CopyModelOperationMetadata>> copyModel(
  1. CopyModelRequest request
)
override

Copies an already existing Vertex AI Model into the specified Location. The source Model must exist in the same Project. When copying custom Models, the users themselves are responsible for Model.metadata content to be region-agnostic, as well as making sure that any resources (e.g. files) it depends on remain accessible.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<CopyModelResponse, CopyModelOperationMetadata>> copyModel(
  CopyModelRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_copyModel case final copyModel?) {
    return copyModel(request);
  }
  throw UnsupportedError('copyModel');
}