deleteModelVersion method

  1. @override
Future<Operation<Empty, DeleteOperationMetadata>> deleteModelVersion(
  1. DeleteModelVersionRequest request
)
override

Deletes a Model version.

Model version can only be deleted if there are no DeployedModels created from it. Deleting the only version in the Model is not allowed. Use DeleteModel for deleting the Model instead.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<protobuf.Empty, DeleteOperationMetadata>> deleteModelVersion(
  DeleteModelVersionRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_deleteModelVersion case final deleteModelVersion?) {
    return deleteModelVersion(request);
  }
  throw UnsupportedError('deleteModelVersion');
}