exportModel method

Exports a trained, exportable Model to a location specified by the user. A Model is considered to be exportable if it has at least one google.cloud.aiplatform.v1beta1.Model.supported_export_formats.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<ExportModelResponse, ExportModelOperationMetadata>>
exportModel(ExportModelRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_exportModel case final exportModel?) {
    return exportModel(request);
  }
  throw UnsupportedError('exportModel');
}