updateExplanationDataset method

Incrementally update the dataset used for an examples model.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<
  Operation<
    UpdateExplanationDatasetResponse,
    UpdateExplanationDatasetOperationMetadata
  >
>
updateExplanationDataset(UpdateExplanationDatasetRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_updateExplanationDataset case final updateExplanationDataset?) {
    return updateExplanationDataset(request);
  }
  throw UnsupportedError('updateExplanationDataset');
}