batchCancelPipelineJobs method
Future<Operation<BatchCancelPipelineJobsResponse, BatchCancelPipelineJobsOperationMetadata> >
batchCancelPipelineJobs(
- BatchCancelPipelineJobsRequest request
override
Batch cancel PipelineJobs. Firstly the server will check if all the jobs are in non-terminal states, and skip the jobs that are already terminated. If the operation failed, none of the pipeline jobs are cancelled. The server will poll the states of all the pipeline jobs periodically to check the cancellation status. This operation will return an LRO.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Returns an Operation representing the status of the long-running
operation.
When complete, Operation.done will be true. If successful,
Operation.responseAsMessage will contain the operation's result.
Implementation
@override
Future<
Operation<
BatchCancelPipelineJobsResponse,
BatchCancelPipelineJobsOperationMetadata
>
>
batchCancelPipelineJobs(BatchCancelPipelineJobsRequest request) async {
if (isClosed) throw StateError('Service is closed');
if (_batchCancelPipelineJobs case final batchCancelPipelineJobs?) {
return batchCancelPipelineJobs(request);
}
throw UnsupportedError('batchCancelPipelineJobs');
}