batchDeletePipelineJobs method

Batch deletes PipelineJobs The Operation is atomic. If it fails, none of the PipelineJobs are deleted. If it succeeds, all of the PipelineJobs are deleted.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<BatchDeletePipelineJobsResponse, DeleteOperationMetadata>>
batchDeletePipelineJobs(BatchDeletePipelineJobsRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_batchDeletePipelineJobs case final batchDeletePipelineJobs?) {
    return batchDeletePipelineJobs(request);
  }
  throw UnsupportedError('batchDeletePipelineJobs');
}