cancelPipelineJob method

  1. @override
Future<void> cancelPipelineJob(
  1. CancelPipelineJobRequest request
)
override

Cancels a PipelineJob. Starts asynchronous cancellation on the PipelineJob. The server makes a best effort to cancel the pipeline, but success is not guaranteed. Clients can use PipelineService.GetPipelineJob or other methods to check whether the cancellation succeeded or whether the pipeline completed despite cancellation. On successful cancellation, the PipelineJob is not deleted; instead it becomes a pipeline with a PipelineJob.error value with a google.rpc.Status.code of 1, corresponding to Code.CANCELLED, and PipelineJob.state is set to CANCELLED.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<void> cancelPipelineJob(CancelPipelineJobRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_cancelPipelineJob case final cancelPipelineJob?) {
    return cancelPipelineJob(request);
  }
  throw UnsupportedError('cancelPipelineJob');
}