directRawPredict method

  1. @override
Future<DirectRawPredictResponse> directRawPredict(
  1. DirectRawPredictRequest request
)
override

Perform an unary online prediction request to a gRPC model server for custom containers.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<DirectRawPredictResponse> directRawPredict(
  DirectRawPredictRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_directRawPredict case final directRawPredict?) {
    return directRawPredict(request);
  }
  throw UnsupportedError('directRawPredict');
}