streamRawPredict method

  1. @override
Stream<HttpBody> streamRawPredict(
  1. StreamRawPredictRequest request
)
override

Perform a streaming online prediction with an arbitrary HTTP payload.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Stream<HttpBody> streamRawPredict(StreamRawPredictRequest request) {
  if (isClosed) throw StateError('Service is closed');
  if (_streamRawPredict case final streamRawPredict?) {
    return streamRawPredict(request);
  }
  throw UnsupportedError('streamRawPredict');
}