FakeReasoningEngineService class base

Testing fake for ReasoningEngineService.

Implemented types

Constructors

FakeReasoningEngineService({Future<Operation<ReasoningEngine, CreateReasoningEngineOperationMetadata>> createReasoningEngine(CreateReasoningEngineRequest request)?, Future<ReasoningEngine> getReasoningEngine(GetReasoningEngineRequest request)?, Future<ListReasoningEnginesResponse> listReasoningEngines(ListReasoningEnginesRequest request)?, Future<Operation<ReasoningEngine, UpdateReasoningEngineOperationMetadata>> updateReasoningEngine(UpdateReasoningEngineRequest request)?, Future<Operation<Empty, DeleteOperationMetadata>> deleteReasoningEngine(DeleteReasoningEngineRequest request)?, Future<ListLocationsResponse> listLocations(ListLocationsRequest request)?, Future<Location> getLocation(GetLocationRequest request)?, Future<Policy> setIamPolicy(SetIamPolicyRequest request)?, Future<Policy> getIamPolicy(GetIamPolicyRequest request)?, Future<TestIamPermissionsResponse> testIamPermissions(TestIamPermissionsRequest request)?, Future<ListOperationsResponse> listOperations(ListOperationsRequest request)?, Future<Operation<T, S>> getOperation<T extends ProtoMessage, S extends ProtoMessage>(Operation<T, S> request)?, Future<void> deleteOperation(DeleteOperationRequest request)?, Future<void> cancelOperation(CancelOperationRequest request)?, Future<Operation<ProtoMessage, ProtoMessage>> waitOperation(WaitOperationRequest request)?})

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancelOperation(CancelOperationRequest request) Future<void>
Provides the Operations service functionality in this service.
override
close() → void
Closes the client and cleans up any resources associated with it.
override
createReasoningEngine(CreateReasoningEngineRequest request) Future<Operation<ReasoningEngine, CreateReasoningEngineOperationMetadata>>
Creates a reasoning engine.
override
deleteOperation(DeleteOperationRequest request) Future<void>
Provides the Operations service functionality in this service.
override
deleteReasoningEngine(DeleteReasoningEngineRequest request) Future<Operation<Empty, DeleteOperationMetadata>>
Deletes a reasoning engine.
override
getIamPolicy(GetIamPolicyRequest request) Future<Policy>
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
override
getLocation(GetLocationRequest request) Future<Location>
Gets information about a location.
override
getOperation<T extends ProtoMessage, S extends ProtoMessage>(Operation<T, S> request) Future<Operation<T, S>>
Provides the Operations service functionality in this service.
override
getReasoningEngine(GetReasoningEngineRequest request) Future<ReasoningEngine>
Gets a reasoning engine.
override
listLocations(ListLocationsRequest request) Future<ListLocationsResponse>
Lists information about the supported locations for this service.
override
listOperations(ListOperationsRequest request) Future<ListOperationsResponse>
Provides the Operations service functionality in this service.
override
listReasoningEngines(ListReasoningEnginesRequest request) Future<ListReasoningEnginesResponse>
Lists reasoning engines in a location.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setIamPolicy(SetIamPolicyRequest request) Future<Policy>
Sets the access control policy on the specified resource. Replaces any existing policy.
override
testIamPermissions(TestIamPermissionsRequest request) Future<TestIamPermissionsResponse>
Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a NOT_FOUND error.
override
toString() String
A string representation of this object.
inherited
updateReasoningEngine(UpdateReasoningEngineRequest request) Future<Operation<ReasoningEngine, UpdateReasoningEngineOperationMetadata>>
Updates a reasoning engine.
override
waitOperation(WaitOperationRequest request) Future<Operation<ProtoMessage, ProtoMessage>>
Provides the Operations service functionality in this service.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited