deleteSchedule method

  1. @override
Future<Operation<Empty, DeleteOperationMetadata>> deleteSchedule(
  1. DeleteScheduleRequest request
)
override

Deletes a Schedule.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<protobuf.Empty, DeleteOperationMetadata>> deleteSchedule(
  DeleteScheduleRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_deleteSchedule case final deleteSchedule?) {
    return deleteSchedule(request);
  }
  throw UnsupportedError('deleteSchedule');
}