FakeSessionService class base

Testing fake for SessionService.

Implemented types

Constructors

FakeSessionService({Future<Operation<Session, CreateSessionOperationMetadata>> createSession(CreateSessionRequest request)?, Future<Session> getSession(GetSessionRequest request)?, Future<ListSessionsResponse> listSessions(ListSessionsRequest request)?, Future<Session> updateSession(UpdateSessionRequest request)?, Future<Operation<Empty, DeleteOperationMetadata>> deleteSession(DeleteSessionRequest request)?, Future<ListEventsResponse> listEvents(ListEventsRequest request)?, Future<AppendEventResponse> appendEvent(AppendEventRequest request)?, Future<ListLocationsResponse> listLocations(ListLocationsRequest request)?, Future<Location> getLocation(GetLocationRequest request)?, Future<Policy> setIamPolicy(SetIamPolicyRequest request)?, Future<Policy> getIamPolicy(GetIamPolicyRequest request)?, Future<TestIamPermissionsResponse> testIamPermissions(TestIamPermissionsRequest request)?, Future<ListOperationsResponse> listOperations(ListOperationsRequest request)?, Future<Operation<T, S>> getOperation<T extends ProtoMessage, S extends ProtoMessage>(Operation<T, S> request)?, Future<void> deleteOperation(DeleteOperationRequest request)?, Future<void> cancelOperation(CancelOperationRequest request)?, Future<Operation<ProtoMessage, ProtoMessage>> waitOperation(WaitOperationRequest request)?})

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

appendEvent(AppendEventRequest request) Future<AppendEventResponse>
Appends an event to a given session.
override
cancelOperation(CancelOperationRequest request) Future<void>
Provides the Operations service functionality in this service.
override
close() → void
Closes the client and cleans up any resources associated with it.
override
createSession(CreateSessionRequest request) Future<Operation<Session, CreateSessionOperationMetadata>>
Creates a new Session.
override
deleteOperation(DeleteOperationRequest request) Future<void>
Provides the Operations service functionality in this service.
override
deleteSession(DeleteSessionRequest request) Future<Operation<Empty, DeleteOperationMetadata>>
Deletes details of the specific Session.
override
getIamPolicy(GetIamPolicyRequest request) Future<Policy>
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
override
getLocation(GetLocationRequest request) Future<Location>
Gets information about a location.
override
getOperation<T extends ProtoMessage, S extends ProtoMessage>(Operation<T, S> request) Future<Operation<T, S>>
Provides the Operations service functionality in this service.
override
getSession(GetSessionRequest request) Future<Session>
Gets details of the specific Session.
override
listEvents(ListEventsRequest request) Future<ListEventsResponse>
Lists Events in a given session.
override
listLocations(ListLocationsRequest request) Future<ListLocationsResponse>
Lists information about the supported locations for this service.
override
listOperations(ListOperationsRequest request) Future<ListOperationsResponse>
Provides the Operations service functionality in this service.
override
listSessions(ListSessionsRequest request) Future<ListSessionsResponse>
Lists Sessions in a given reasoning engine.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setIamPolicy(SetIamPolicyRequest request) Future<Policy>
Sets the access control policy on the specified resource. Replaces any existing policy.
override
testIamPermissions(TestIamPermissionsRequest request) Future<TestIamPermissionsResponse>
Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a NOT_FOUND error.
override
toString() String
A string representation of this object.
inherited
updateSession(UpdateSessionRequest request) Future<Session>
Updates the specific Session.
override
waitOperation(WaitOperationRequest request) Future<Operation<ProtoMessage, ProtoMessage>>
Provides the Operations service functionality in this service.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited