createSession method

  1. @override
Future<Operation<Session, CreateSessionOperationMetadata>> createSession(
  1. CreateSessionRequest request
)
override

Creates a new Session.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<Session, CreateSessionOperationMetadata>> createSession(
  CreateSessionRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_createSession case final createSession?) {
    return createSession(request);
  }
  throw UnsupportedError('createSession');
}