FakeSpecialistPoolService class base
Testing fake for SpecialistPoolService.
- Implemented types
Constructors
-
FakeSpecialistPoolService({Future<
Operation< createSpecialistPool(CreateSpecialistPoolRequest request)?, Future<SpecialistPool, CreateSpecialistPoolOperationMetadata> >SpecialistPool> getSpecialistPool(GetSpecialistPoolRequest request)?, Future<ListSpecialistPoolsResponse> listSpecialistPools(ListSpecialistPoolsRequest request)?, Future<Operation< deleteSpecialistPool(DeleteSpecialistPoolRequest request)?, Future<Empty, DeleteOperationMetadata> >Operation< updateSpecialistPool(UpdateSpecialistPoolRequest request)?, Future<SpecialistPool, UpdateSpecialistPoolOperationMetadata> >ListLocationsResponse> listLocations(ListLocationsRequest request)?, Future<Location> getLocation(GetLocationRequest request)?, Future<Policy> setIamPolicy(SetIamPolicyRequest request)?, Future<Policy> getIamPolicy(GetIamPolicyRequest request)?, Future<TestIamPermissionsResponse> testIamPermissions(TestIamPermissionsRequest request)?, Future<ListOperationsResponse> listOperations(ListOperationsRequest request)?, Future<Operation< getOperation<T, S> >T extends ProtoMessage, S extends ProtoMessage>(Operation< Future<T, S> request)?,void> deleteOperation(DeleteOperationRequest request)?, Future<void> cancelOperation(CancelOperationRequest request)?, Future<Operation< waitOperation(WaitOperationRequest request)?})ProtoMessage, ProtoMessage> >
Properties
Methods
-
cancelOperation(
CancelOperationRequest request) → Future< void> -
Provides the
Operationsservice functionality in this service.override -
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
createSpecialistPool(
CreateSpecialistPoolRequest request) → Future< Operation< SpecialistPool, CreateSpecialistPoolOperationMetadata> > -
Creates a SpecialistPool.
override
-
deleteOperation(
DeleteOperationRequest request) → Future< void> -
Provides the
Operationsservice functionality in this service.override -
deleteSpecialistPool(
DeleteSpecialistPoolRequest request) → Future< Operation< Empty, DeleteOperationMetadata> > -
Deletes a SpecialistPool as well as all Specialists in the pool.
override
-
getIamPolicy(
GetIamPolicyRequest request) → Future< Policy> -
Gets the access control policy for a resource. Returns an empty policy
if the resource exists and does not have a policy set.
override
-
getLocation(
GetLocationRequest request) → Future< Location> -
Gets information about a location.
override
-
getOperation<
T extends ProtoMessage, S extends ProtoMessage> (Operation< T, S> request) → Future<Operation< T, S> > -
Provides the
Operationsservice functionality in this service.override -
getSpecialistPool(
GetSpecialistPoolRequest request) → Future< SpecialistPool> -
Gets a SpecialistPool.
override
-
listLocations(
ListLocationsRequest request) → Future< ListLocationsResponse> -
Lists information about the supported locations for this service.
override
-
listOperations(
ListOperationsRequest request) → Future< ListOperationsResponse> -
Provides the
Operationsservice functionality in this service.override -
listSpecialistPools(
ListSpecialistPoolsRequest request) → Future< ListSpecialistPoolsResponse> -
Lists SpecialistPools in a Location.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setIamPolicy(
SetIamPolicyRequest request) → Future< Policy> -
Sets the access control policy on the specified resource. Replaces
any existing policy.
override
-
testIamPermissions(
TestIamPermissionsRequest request) → Future< TestIamPermissionsResponse> -
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of
permissions, not a
NOT_FOUNDerror.override -
toString(
) → String -
A string representation of this object.
inherited
-
updateSpecialistPool(
UpdateSpecialistPoolRequest request) → Future< Operation< SpecialistPool, UpdateSpecialistPoolOperationMetadata> > -
Updates a SpecialistPool.
override
-
waitOperation(
WaitOperationRequest request) → Future< Operation< ProtoMessage, ProtoMessage> > -
Provides the
Operationsservice functionality in this service.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited