createSpecialistPool method

Creates a SpecialistPool.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<SpecialistPool, CreateSpecialistPoolOperationMetadata>>
createSpecialistPool(CreateSpecialistPoolRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_createSpecialistPool case final createSpecialistPool?) {
    return createSpecialistPool(request);
  }
  throw UnsupportedError('createSpecialistPool');
}