deleteSpecialistPool method
Future<Operation<Empty, DeleteOperationMetadata> >
deleteSpecialistPool(
- DeleteSpecialistPoolRequest request
override
Deletes a SpecialistPool as well as all Specialists in the pool.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Returns an Operation representing the status of the long-running
operation.
When complete, Operation.done will be true. If successful,
Operation.responseAsMessage will contain the operation's result.
Implementation
@override
Future<Operation<protobuf.Empty, DeleteOperationMetadata>>
deleteSpecialistPool(DeleteSpecialistPoolRequest request) async {
if (isClosed) throw StateError('Service is closed');
if (_deleteSpecialistPool case final deleteSpecialistPool?) {
return deleteSpecialistPool(request);
}
throw UnsupportedError('deleteSpecialistPool');
}