batchReadTensorboardTimeSeriesData method

Reads multiple TensorboardTimeSeries' data. The data point number limit is 1000 for scalars, 100 for tensors and blob references. If the number of data points stored is less than the limit, all data is returned. Otherwise, the number limit of data points is randomly selected from this time series and returned.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<BatchReadTensorboardTimeSeriesDataResponse>
batchReadTensorboardTimeSeriesData(
  BatchReadTensorboardTimeSeriesDataRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_batchReadTensorboardTimeSeriesData
      case final batchReadTensorboardTimeSeriesData?) {
    return batchReadTensorboardTimeSeriesData(request);
  }
  throw UnsupportedError('batchReadTensorboardTimeSeriesData');
}