readTensorboardBlobData method

  1. @override
Stream<ReadTensorboardBlobDataResponse> readTensorboardBlobData(
  1. ReadTensorboardBlobDataRequest request
)
override

Gets bytes of TensorboardBlobs. This is to allow reading blob data stored in consumer project's Cloud Storage bucket without users having to obtain Cloud Storage access permission.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Stream<ReadTensorboardBlobDataResponse> readTensorboardBlobData(
  ReadTensorboardBlobDataRequest request,
) {
  if (isClosed) throw StateError('Service is closed');
  if (_readTensorboardBlobData case final readTensorboardBlobData?) {
    return readTensorboardBlobData(request);
  }
  throw UnsupportedError('readTensorboardBlobData');
}