readTensorboardUsage method

  1. @override
Future<ReadTensorboardUsageResponse> readTensorboardUsage(
  1. ReadTensorboardUsageRequest request
)
override

Returns a list of monthly active users for a given TensorBoard instance.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<ReadTensorboardUsageResponse> readTensorboardUsage(
  ReadTensorboardUsageRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_readTensorboardUsage case final readTensorboardUsage?) {
    return readTensorboardUsage(request);
  }
  throw UnsupportedError('readTensorboardUsage');
}