updateTensorboard method

  1. @override
Future<Operation<Tensorboard, UpdateTensorboardOperationMetadata>> updateTensorboard(
  1. UpdateTensorboardRequest request
)
override

Updates a Tensorboard.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<Tensorboard, UpdateTensorboardOperationMetadata>>
updateTensorboard(UpdateTensorboardRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_updateTensorboard case final updateTensorboard?) {
    return updateTensorboard(request);
  }
  throw UnsupportedError('updateTensorboard');
}