writeTensorboardExperimentData method

Write time series data points of multiple TensorboardTimeSeries in multiple TensorboardRun's. If any data fail to be ingested, an error is returned.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<WriteTensorboardExperimentDataResponse> writeTensorboardExperimentData(
  WriteTensorboardExperimentDataRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_writeTensorboardExperimentData
      case final writeTensorboardExperimentData?) {
    return writeTensorboardExperimentData(request);
  }
  throw UnsupportedError('writeTensorboardExperimentData');
}