batchCreateRagDataSchemas method

Batch Create one or more RagDataSchemas

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<
  Operation<
    BatchCreateRagDataSchemasResponse,
    BatchCreateRagDataSchemasOperationMetadata
  >
>
batchCreateRagDataSchemas(BatchCreateRagDataSchemasRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_batchCreateRagDataSchemas case final batchCreateRagDataSchemas?) {
    return batchCreateRagDataSchemas(request);
  }
  throw UnsupportedError('batchCreateRagDataSchemas');
}