batchDeleteRagMetadata method

  1. @override
Future<Operation<Empty, DeleteOperationMetadata>> batchDeleteRagMetadata(
  1. BatchDeleteRagMetadataRequest request
)
override

Batch Deletes one or more RagMetadata.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<protobuf.Empty, DeleteOperationMetadata>>
batchDeleteRagMetadata(BatchDeleteRagMetadataRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_batchDeleteRagMetadata case final batchDeleteRagMetadata?) {
    return batchDeleteRagMetadata(request);
  }
  throw UnsupportedError('batchDeleteRagMetadata');
}