deleteRagCorpus method

  1. @override
Future<Operation<Empty, DeleteOperationMetadata>> deleteRagCorpus(
  1. DeleteRagCorpusRequest request
)
override

Deletes a RagCorpus.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<protobuf.Empty, DeleteOperationMetadata>> deleteRagCorpus(
  DeleteRagCorpusRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_deleteRagCorpus case final deleteRagCorpus?) {
    return deleteRagCorpus(request);
  }
  throw UnsupportedError('deleteRagCorpus');
}