updateRagCorpus method

  1. @override
Future<Operation<RagCorpus, UpdateRagCorpusOperationMetadata>> updateRagCorpus(
  1. UpdateRagCorpusRequest request
)
override

Updates a RagCorpus.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<RagCorpus, UpdateRagCorpusOperationMetadata>>
updateRagCorpus(UpdateRagCorpusRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_updateRagCorpus case final updateRagCorpus?) {
    return updateRagCorpus(request);
  }
  throw UnsupportedError('updateRagCorpus');
}