asyncRetrieveContexts method

Asynchronous API to retrieves relevant contexts for a query.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<
  Operation<
    AsyncRetrieveContextsResponse,
    AsyncRetrieveContextsOperationMetadata
  >
>
asyncRetrieveContexts(AsyncRetrieveContextsRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_asyncRetrieveContexts case final asyncRetrieveContexts?) {
    return asyncRetrieveContexts(request);
  }
  throw UnsupportedError('asyncRetrieveContexts');
}