augmentPrompt method

  1. @override
Future<AugmentPromptResponse> augmentPrompt(
  1. AugmentPromptRequest request
)
override

Given an input prompt, it returns augmented prompt from vertex rag store to guide LLM towards generating grounded responses.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<AugmentPromptResponse> augmentPrompt(
  AugmentPromptRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_augmentPrompt case final augmentPrompt?) {
    return augmentPrompt(request);
  }
  throw UnsupportedError('augmentPrompt');
}