FakeVizierService class base

Testing fake for VizierService.

Implemented types

Constructors

FakeVizierService({Future<Study> createStudy(CreateStudyRequest request)?, Future<Study> getStudy(GetStudyRequest request)?, Future<ListStudiesResponse> listStudies(ListStudiesRequest request)?, Future<void> deleteStudy(DeleteStudyRequest request)?, Future<Study> lookupStudy(LookupStudyRequest request)?, Future<Operation<SuggestTrialsResponse, SuggestTrialsMetadata>> suggestTrials(SuggestTrialsRequest request)?, Future<Trial> createTrial(CreateTrialRequest request)?, Future<Trial> getTrial(GetTrialRequest request)?, Future<ListTrialsResponse> listTrials(ListTrialsRequest request)?, Future<Trial> addTrialMeasurement(AddTrialMeasurementRequest request)?, Future<Trial> completeTrial(CompleteTrialRequest request)?, Future<void> deleteTrial(DeleteTrialRequest request)?, Future<Operation<CheckTrialEarlyStoppingStateResponse, CheckTrialEarlyStoppingStateMetatdata>> checkTrialEarlyStoppingState(CheckTrialEarlyStoppingStateRequest request)?, Future<Trial> stopTrial(StopTrialRequest request)?, Future<ListOptimalTrialsResponse> listOptimalTrials(ListOptimalTrialsRequest request)?, Future<ListLocationsResponse> listLocations(ListLocationsRequest request)?, Future<Location> getLocation(GetLocationRequest request)?, Future<Policy> setIamPolicy(SetIamPolicyRequest request)?, Future<Policy> getIamPolicy(GetIamPolicyRequest request)?, Future<TestIamPermissionsResponse> testIamPermissions(TestIamPermissionsRequest request)?, Future<ListOperationsResponse> listOperations(ListOperationsRequest request)?, Future<Operation<T, S>> getOperation<T extends ProtoMessage, S extends ProtoMessage>(Operation<T, S> request)?, Future<void> deleteOperation(DeleteOperationRequest request)?, Future<void> cancelOperation(CancelOperationRequest request)?, Future<Operation<ProtoMessage, ProtoMessage>> waitOperation(WaitOperationRequest request)?})

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addTrialMeasurement(AddTrialMeasurementRequest request) Future<Trial>
Adds a measurement of the objective metrics to a Trial. This measurement is assumed to have been taken before the Trial is complete.
override
cancelOperation(CancelOperationRequest request) Future<void>
Provides the Operations service functionality in this service.
override
checkTrialEarlyStoppingState(CheckTrialEarlyStoppingStateRequest request) Future<Operation<CheckTrialEarlyStoppingStateResponse, CheckTrialEarlyStoppingStateMetatdata>>
Checks whether a Trial should stop or not. Returns a long-running operation. When the operation is successful, it will contain a CheckTrialEarlyStoppingStateResponse.
override
close() → void
Closes the client and cleans up any resources associated with it.
override
completeTrial(CompleteTrialRequest request) Future<Trial>
Marks a Trial as complete.
override
createStudy(CreateStudyRequest request) Future<Study>
Creates a Study. A resource name will be generated after creation of the Study.
override
createTrial(CreateTrialRequest request) Future<Trial>
Adds a user provided Trial to a Study.
override
deleteOperation(DeleteOperationRequest request) Future<void>
Provides the Operations service functionality in this service.
override
deleteStudy(DeleteStudyRequest request) Future<void>
Deletes a Study.
override
deleteTrial(DeleteTrialRequest request) Future<void>
Deletes a Trial.
override
getIamPolicy(GetIamPolicyRequest request) Future<Policy>
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
override
getLocation(GetLocationRequest request) Future<Location>
Gets information about a location.
override
getOperation<T extends ProtoMessage, S extends ProtoMessage>(Operation<T, S> request) Future<Operation<T, S>>
Provides the Operations service functionality in this service.
override
getStudy(GetStudyRequest request) Future<Study>
Gets a Study by name.
override
getTrial(GetTrialRequest request) Future<Trial>
Gets a Trial.
override
listLocations(ListLocationsRequest request) Future<ListLocationsResponse>
Lists information about the supported locations for this service.
override
listOperations(ListOperationsRequest request) Future<ListOperationsResponse>
Provides the Operations service functionality in this service.
override
listOptimalTrials(ListOptimalTrialsRequest request) Future<ListOptimalTrialsResponse>
Lists the pareto-optimal Trials for multi-objective Study or the optimal Trials for single-objective Study. The definition of pareto-optimal can be checked in wiki page. https://en.wikipedia.org/wiki/Pareto_efficiency
override
listStudies(ListStudiesRequest request) Future<ListStudiesResponse>
Lists all the studies in a region for an associated project.
override
listTrials(ListTrialsRequest request) Future<ListTrialsResponse>
Lists the Trials associated with a Study.
override
lookupStudy(LookupStudyRequest request) Future<Study>
Looks a study up using the user-defined display_name field instead of the fully qualified resource name.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setIamPolicy(SetIamPolicyRequest request) Future<Policy>
Sets the access control policy on the specified resource. Replaces any existing policy.
override
stopTrial(StopTrialRequest request) Future<Trial>
Stops a Trial.
override
suggestTrials(SuggestTrialsRequest request) Future<Operation<SuggestTrialsResponse, SuggestTrialsMetadata>>
Adds one or more Trials to a Study, with parameter values suggested by Vertex AI Vizier. Returns a long-running operation associated with the generation of Trial suggestions. When this long-running operation succeeds, it will contain a SuggestTrialsResponse.
override
testIamPermissions(TestIamPermissionsRequest request) Future<TestIamPermissionsResponse>
Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a NOT_FOUND error.
override
toString() String
A string representation of this object.
inherited
waitOperation(WaitOperationRequest request) Future<Operation<ProtoMessage, ProtoMessage>>
Provides the Operations service functionality in this service.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited