checkTrialEarlyStoppingState method

Checks whether a Trial should stop or not. Returns a long-running operation. When the operation is successful, it will contain a CheckTrialEarlyStoppingStateResponse.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<
  Operation<
    CheckTrialEarlyStoppingStateResponse,
    CheckTrialEarlyStoppingStateMetatdata
  >
>
checkTrialEarlyStoppingState(
  CheckTrialEarlyStoppingStateRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_checkTrialEarlyStoppingState
      case final checkTrialEarlyStoppingState?) {
    return checkTrialEarlyStoppingState(request);
  }
  throw UnsupportedError('checkTrialEarlyStoppingState');
}