listStudies method

  1. @override
Future<ListStudiesResponse> listStudies(
  1. ListStudiesRequest request
)
override

Lists all the studies in a region for an associated project.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<ListStudiesResponse> listStudies(ListStudiesRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_listStudies case final listStudies?) {
    return listStudies(request);
  }
  throw UnsupportedError('listStudies');
}