lookupStudy method

  1. @override
Future<Study> lookupStudy(
  1. LookupStudyRequest request
)
override

Looks a study up using the user-defined display_name field instead of the fully qualified resource name.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Study> lookupStudy(LookupStudyRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_lookupStudy case final lookupStudy?) {
    return lookupStudy(request);
  }
  throw UnsupportedError('lookupStudy');
}