suggestTrials method

  1. @override
Future<Operation<SuggestTrialsResponse, SuggestTrialsMetadata>> suggestTrials(
  1. SuggestTrialsRequest request
)
override

Adds one or more Trials to a Study, with parameter values suggested by Vertex AI Vizier. Returns a long-running operation associated with the generation of Trial suggestions. When this long-running operation succeeds, it will contain a SuggestTrialsResponse.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<SuggestTrialsResponse, SuggestTrialsMetadata>> suggestTrials(
  SuggestTrialsRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_suggestTrials case final suggestTrials?) {
    return suggestTrials(request);
  }
  throw UnsupportedError('suggestTrials');
}