AgentConfig class final
Represents configuration for an Agent.
Constructors
Properties
- agentId → String?
-
Required. Unique identifier of the agent.
This ID is used to refer to this agent, e.g., in AgentEvent.author, or in
the
sub_agentsfield. It must be unique within theagentsmap.final - agentType → String
-
Optional. The type or class of the agent (e.g., "LlmAgent", "RouterAgent",
"ToolUseAgent"). Useful for the autorater to understand the expected
behavior of the agent.
final
- description → String
-
Optional. A high-level description of the agent's role and
responsibilities. Critical for evaluating if the agent is routing tasks
correctly.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- instruction → String
-
Optional. Provides instructions for the LLM model, guiding the agent's
behavior. Can be static or dynamic. Dynamic instructions can contain
placeholders like {variable_name} that will be resolved at runtime using
the
AgentEvent.state_deltafield.final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
subAgents
→ List<
String> -
Optional. The list of valid agent IDs that this agent can delegate to.
This defines the directed edges in the multi-agent system graph topology.
final
-
tools
→ List<
Tool> -
Optional. The list of tools available to this agent.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String