AgentData class final
Represents data specific to multi-turn agent evaluations.
Constructors
-
AgentData({Map<
String, AgentConfig> agents = const {}, List<ConversationTurn> turns = const []}) - AgentData.fromJson(Object? j)
-
factory
Properties
-
agents
→ Map<
String, AgentConfig> -
Optional. A map containing the static configurations for each agent in the
system. Key: agent_id (matches the
authorfield in events). Value: The static configuration of the agent.final - hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
turns
→ List<
ConversationTurn> -
Optional. A chronological list of conversation turns.
Each turn represents a logical execution cycle (e.g., User Input -> Agent
Response).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String