stateDelta property
Struct?
stateDelta
final
Optional. The change in the session state caused by this event. This is a key-value map of fields that were modified or added by the event.
Implementation
final protobuf.Struct? stateDelta;