BatchCreateRagDataSchemasRequest class final

Request message for VertexRagDataService.BatchCreateRagDataSchemas.

Properties

hashCode int
The hash code for this object.
no setterinherited
parent String
Required. The resource name of the RagCorpus to create the RagDataSchemas in. Format: projects/{project}/locations/{location}/ragCorpora/{rag_corpus}
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
requests List<CreateRagDataSchemaRequest>
Required. The request messages for VertexRagDataService.CreateRagDataSchema. A maximum of 500 schemas can be created in a batch.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String