BatchCreateRagMetadataRequest class final
Request message for
VertexRagDataService.BatchCreateRagMetadata.
Constructors
-
BatchCreateRagMetadataRequest({required String parent, required List<
CreateRagMetadataRequest> requests}) - BatchCreateRagMetadataRequest.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- parent → String
-
Required. The parent resource where the RagMetadata will be created.
Format:
projects/{project_number}/locations/{location_id}/ragCorpora/{rag_corpus}/ragFiles/{rag_file}final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited -
requests
→ List<
CreateRagMetadataRequest> -
Required. The request messages for
VertexRagDataService.CreateRagMetadata. A maximum of 500 rag file metadata can be created in a batch.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String