includedFields property
Fields that will be included in the prediction instance that is sent to the Model.
If
instance_type
is array, the order of field names in included_fields also determines
the order of the values in the array.
When included_fields is populated,
excluded_fields
must be empty.
The input must be JSONL with objects at each line, BigQuery or TfRecord.
Implementation
final List<String> includedFields;