EmbedContentRequest class final
Request message for
PredictionService.EmbedContent.
Constructors
- EmbedContentRequest({String? model, Content? content, String? title, EmbedContentRequest_EmbeddingTaskType? taskType, int? outputDimensionality, bool? autoTruncate, EmbedContentRequest_EmbedContentConfig? embedContentConfig})
- EmbedContentRequest.fromJson(Object? j)
-
factory
Properties
- autoTruncate → bool?
-
Optional. Deprecated: Please use EmbedContentConfig.auto_truncate instead.
Whether to silently truncate the input content if it's longer
than the maximum sequence length.
final
- content → Content?
-
Required. Input content to be embedded.
final
- embedContentConfig → EmbedContentRequest_EmbedContentConfig?
-
Optional. Configuration for the EmbedContent request.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- model → String?
-
Required. The name of the publisher model requested to serve the
prediction. Format:
projects/{project}/locations/{location}/publishers/*/models/*final - outputDimensionality → int?
-
Optional. Deprecated: Please use EmbedContentConfig.output_dimensionality
instead. Reduced dimension for the output embedding. If set, excessive
values in the output embedding are truncated from the end.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- taskType → EmbedContentRequest_EmbeddingTaskType?
-
Optional. Deprecated: Please use EmbedContentConfig.task_type instead.
The task type of the embedding.
final
- title → String?
-
Optional. Deprecated: Please use EmbedContentConfig.title instead.
The title for the text.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String