EmbedContentRequest_EmbedContentConfig class final
Configurations for the EmbedContent API.
Constructors
- EmbedContentRequest_EmbedContentConfig({String? title, EmbedContentRequest_EmbeddingTaskType? taskType, bool? autoTruncate, int? outputDimensionality, bool? documentOcr, bool? audioTrackExtraction})
- EmbedContentRequest_EmbedContentConfig.fromJson(Object? j)
-
factory
Properties
- audioTrackExtraction → bool?
-
Optional. Whether to extract audio from video content.
final
- autoTruncate → bool?
-
Optional. Whether to silently truncate the input content if it's longer
than the maximum sequence length.
final
- documentOcr → bool?
-
Optional. Whether to enable OCR for document content.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- outputDimensionality → int?
-
Optional. Reduced dimension for the output embedding. If set, excessive
values in the output embedding are truncated from the end.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- taskType → EmbedContentRequest_EmbeddingTaskType?
-
Optional. The task type of the embedding.
final
- title → String?
-
Optional. The title for the text.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String