EvaluationInstance_DeprecatedAgentData class final
Deprecated: Use agent_eval_data instead.
Contains data specific to agent evaluations.
Constructors
-
EvaluationInstance_DeprecatedAgentData({String? toolsText, EvaluationInstance_DeprecatedAgentData_Tools? tools, EvaluationInstance_DeprecatedAgentData_Events? events, Map<
String, EvaluationInstance_DeprecatedAgentConfig> agents = const {}, List<EvaluationInstance_DeprecatedAgentData_ConversationTurn> turns = const [], EvaluationInstance_InstanceData? developerInstruction, EvaluationInstance_DeprecatedAgentConfig? agentConfig}) - EvaluationInstance_DeprecatedAgentData.fromJson(Object? j)
-
factory
Properties
- agentConfig → EvaluationInstance_DeprecatedAgentConfig?
-
Optional. Deprecated: Use
agent_eval_datainstead. Agent configuration.final -
agents
→ Map<
String, EvaluationInstance_DeprecatedAgentConfig> -
Optional. The static Agent Configuration.
This map defines the graph structure of the agent system.
Key: agent_id (matches the
authorfield in events). Value: The static configuration of the agent (tools, instructions, sub-agents).final - developerInstruction → EvaluationInstance_InstanceData?
-
Optional. Deprecated: Use
agents.developer_instructionorturns.events.active_instructioninstead. A field containing instructions from the developer for the agent.final - events → EvaluationInstance_DeprecatedAgentData_Events?
-
A list of events.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tools → EvaluationInstance_DeprecatedAgentData_Tools?
-
List of tools.
final
- toolsText → String?
-
A JSON string containing a list of tools available to an agent with
info such as name, description, parameters and required parameters.
final
-
turns
→ List<
EvaluationInstance_DeprecatedAgentData_ConversationTurn> -
Optional. The chronological list of conversation turns.
Each turn represents a logical execution cycle (e.g., User Input -> Agent
Response).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String