EvaluationInstance_DeprecatedAgentData_ConversationTurn class final
Represents a single turn/invocation in the conversation.
Constructors
-
EvaluationInstance_DeprecatedAgentData_ConversationTurn({required int? turnIndex, String turnId = '', List<
EvaluationInstance_DeprecatedAgentData_AgentEvent> events = const []}) - EvaluationInstance_DeprecatedAgentData_ConversationTurn.fromJson(Object? j)
-
factory
Properties
-
events
→ List<
EvaluationInstance_DeprecatedAgentData_AgentEvent> -
Optional. The list of events that occurred during this turn.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- turnId → String
-
Optional. A unique identifier for the turn.
Useful for referencing specific turns across systems.
final
- turnIndex → int?
-
Required. The 0-based index of the turn in the conversation sequence.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String