EvaluationService class final
Vertex AI Online Evaluation Service.
- Implementers
Constructors
- EvaluationService({required Client client, Uri? endPoint})
-
Creates a
EvaluationServiceusingclientfor transport. - EvaluationService.fromApiKey([String? apiKey])
-
Creates a
EvaluationServicethat does authentication through an API key.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancelOperation(
CancelOperationRequest request) → Future< void> -
Provides the
Operationsservice functionality in this service. -
close(
) → void - Closes the client and cleans up any resources associated with it.
-
deleteOperation(
DeleteOperationRequest request) → Future< void> -
Provides the
Operationsservice functionality in this service. -
evaluateDataset(
EvaluateDatasetRequest request) → Future< Operation< EvaluateDatasetResponse, EvaluateDatasetOperationMetadata> > - Evaluates a dataset based on a set of given metrics.
-
evaluateInstances(
EvaluateInstancesRequest request) → Future< EvaluateInstancesResponse> - Evaluates instances based on a given metric.
-
generateInstanceRubrics(
GenerateInstanceRubricsRequest request) → Future< GenerateInstanceRubricsResponse> - Generates rubrics for a given prompt. A rubric represents a single testable criterion for evaluation. One input prompt could have multiple rubrics This RPC allows users to get suggested rubrics based on provided prompt, which can then be reviewed and used for subsequent evaluations.
-
getIamPolicy(
GetIamPolicyRequest request) → Future< Policy> - Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
-
getLocation(
GetLocationRequest request) → Future< Location> - Gets information about a location.
-
getOperation<
T extends ProtoMessage, S extends ProtoMessage> (Operation< T, S> request) → Future<Operation< T, S> > -
Provides the
Operationsservice functionality in this service. -
listLocations(
ListLocationsRequest request) → Future< ListLocationsResponse> - Lists information about the supported locations for this service.
-
listOperations(
ListOperationsRequest request) → Future< ListOperationsResponse> -
Provides the
Operationsservice functionality in this service. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setIamPolicy(
SetIamPolicyRequest request) → Future< Policy> - Sets the access control policy on the specified resource. Replaces any existing policy.
-
testIamPermissions(
TestIamPermissionsRequest request) → Future< TestIamPermissionsResponse> -
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of
permissions, not a
NOT_FOUNDerror. -
toString(
) → String -
A string representation of this object.
inherited
-
waitOperation(
WaitOperationRequest request) → Future< Operation< ProtoMessage, ProtoMessage> > -
Provides the
Operationsservice functionality in this service.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited