ExtensionOperation class final

Operation of an extension.

Constructors

ExtensionOperation({String operationId = '', FunctionDeclaration? functionDeclaration})
ExtensionOperation.fromJson(Object? j)
factory

Properties

functionDeclaration → FunctionDeclaration?
Output only. Structured representation of a function declaration as defined by the OpenAPI Spec.
final
hashCode → int
The hash code for this object.
no setterinherited
operationId → String
Operation ID that uniquely identifies the operations among the extension. See: "Operation Object" in https://swagger.io/specification/.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String