predefinedRubricGenerationSpec property
Optional. Specification for using the rubric generation configs of a
pre-defined metric, e.g. "generic_quality_v1" and
"instruction_following_v1". Some of the configs may be only used in rubric
generation and not supporting evaluation, e.g.
"fully_customized_generic_quality_v1". If this field is set, the
rubric_generation_spec field will be ignored.
Implementation
final PredefinedMetricSpec? predefinedRubricGenerationSpec;