ListOnlineEvaluatorsRequest class final
Request message for ListOnlineEvaluators.
Constructors
- ListOnlineEvaluatorsRequest({required String parent, int pageSize = 0, String pageToken = '', String filter = '', String orderBy = ''})
- ListOnlineEvaluatorsRequest.fromJson(Object? j)
-
factory
Properties
- filter → String
-
Optional. Standard list filter.
Supported fields:
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- orderBy → String
-
Optional. A comma-separated list of fields to order by. The default sorting
order is ascending. Use "desc" after a field name for descending. Supported
fields:
final
- pageSize → int
-
Optional. The maximum number of OnlineEvaluators to return. The service may
return fewer than this value. If unspecified, at most 50 OnlineEvaluators
will be returned. The maximum value is 100; values above 100 will be
coerced to 100. Based on aip.dev/158.
final
- pageToken → String
-
Optional. A token identifying a page of results the server should return.
Based on aip.dev/158.
final
- parent → String
-
Required. The parent resource of the OnlineEvaluators to list.
Format: projects/{project}/locations/{location}.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String