LlmbasedMetricSpec class final
Specification for an LLM based metric.
Constructors
- LlmbasedMetricSpec({String? rubricGroupKey, PredefinedMetricSpec? predefinedRubricGenerationSpec, required String? metricPromptTemplate, String? systemInstruction, AutoraterConfig? judgeAutoraterConfig, Struct? additionalConfig})
- LlmbasedMetricSpec.fromJson(Object? j)
-
factory
Properties
- additionalConfig → Struct?
-
Optional. Optional additional configuration for the metric.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- judgeAutoraterConfig → AutoraterConfig?
-
Optional. Optional configuration for the judge LLM (Autorater).
final
- metricPromptTemplate → String?
-
Required. Template for the prompt sent to the judge model.
final
- predefinedRubricGenerationSpec → PredefinedMetricSpec?
-
Dynamically generate rubrics using a predefined spec.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - rubricGroupKey → String?
-
Use a pre-defined group of rubrics associated with the input.
Refers to a key in the rubric_groups map of EvaluationInstance.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- systemInstruction → String?
-
Optional. System instructions for the judge model.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String