MetadataValue class final

Value of Metadata, including all types available in data schema.

Constructors

MetadataValue({int? intValue, double? floatValue, String? strValue, String? datetimeValue, bool? boolValue, MetadataList? listValue})
MetadataValue.fromJson(Object? j)
factory

Properties

boolValue → bool?
Value of boolean type metadata.
final
datetimeValue → String?
Value of date time type metadata.
final
floatValue → double?
Value of float type metadata.
final
hashCode → int
The hash code for this object.
no setterinherited
intValue → int?
Value of int type metadata.
final
listValue → MetadataList?
Value of list type metadata.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strValue → String?
Value of string type metadata.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String