MigrateResourceRequest_MigrateAutomlModelConfig class final

Config for migrating Model in automl.googleapis.com to Vertex AI's Model.

Properties

hashCode int
The hash code for this object.
no setterinherited
model String
Required. Full resource name of automl Model. Format: projects/{project}/locations/{location}/models/{model}.
final
modelDisplayName String
Optional. Display name of the model in Vertex AI. System will pick a display name if unspecified.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String