NotebookRuntime_RuntimeState class final

The substate of the NotebookRuntime to display state of runtime. The resource of NotebookRuntime is in ACTIVE state for these sub state.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const NotebookRuntime_RuntimeState
The default value for NotebookRuntime_RuntimeState.
beingStarted → const NotebookRuntime_RuntimeState
NotebookRuntime is in starting state. This is when the runtime is being started from a stopped state.
beingStopped → const NotebookRuntime_RuntimeState
NotebookRuntime is in stopping state.
beingUpgraded → const NotebookRuntime_RuntimeState
NotebookRuntime is in upgrading state. It is in the middle of upgrading process.
error → const NotebookRuntime_RuntimeState
NotebookRuntime was unable to start/stop properly.
invalid → const NotebookRuntime_RuntimeState
NotebookRuntime is in invalid state. Cannot be recovered.
running → const NotebookRuntime_RuntimeState
NotebookRuntime is in running state.
runtimeStateUnspecified → const NotebookRuntime_RuntimeState
Unspecified runtime state.
stopped → const NotebookRuntime_RuntimeState
NotebookRuntime is in stopped state.