OnlineEvaluator_CloudObservability_NumericPredicate class final
Defines a predicate for filtering based on a numeric value.
Constructors
- OnlineEvaluator_CloudObservability_NumericPredicate({required OnlineEvaluator_CloudObservability_NumericPredicate_ComparisonOperator comparisonOperator, required double value})
- OnlineEvaluator_CloudObservability_NumericPredicate.fromJson(Object? j)
-
factory
Properties
- comparisonOperator → OnlineEvaluator_CloudObservability_NumericPredicate_ComparisonOperator
-
Required. The comparison operator to apply.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → double
-
Required. The value to compare against.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String