PairwiseChoice class final

Pairwise prediction autorater preference.

Constructors

PairwiseChoice(String value)
const
PairwiseChoice.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const PairwiseChoice
The default value for PairwiseChoice.
baseline → const PairwiseChoice
Baseline prediction wins
candidate → const PairwiseChoice
Candidate prediction wins
pairwiseChoiceUnspecified → const PairwiseChoice
Unspecified prediction choice.
tie → const PairwiseChoice
Winner cannot be determined