dataSharingEnabledProvider property
Optional. The model provider (publisher) for which the customer has enabled data sharing. For publisher models that are configured to require data sharing, a prediction request is only allowed when the model's publisher matches this provider. Otherwise, the request is rejected.
Implementation
final PublisherModelConfig_ModelProvider dataSharingEnabledProvider;