RagDataSchema class final
The schema of the user specified metadata.
Constructors
- RagDataSchema({String name = '', required String key, RagMetadataSchemaDetails? schemaDetails})
- RagDataSchema.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String
-
Required. The key of this data schema. This key should be matching the key
of user specified metadata and unique inside corpus. This value can be up
to 63 characters, and valid characters are /
0-9-/. The first character must be a letter, the last could be a letter or a number.final - name → String
-
Identifier. Resource name of the data schema in the form of:
projects/{project_number}/locations/{location}/ragCorpora/{rag_corpus}/ragDataSchemas/{rag_data_schema}where the {rag_data_schema} part should be the same as thekeyfield below.final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schemaDetails → RagMetadataSchemaDetails?
-
The schema details mapping to the key.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String