name property
Identifier. Resource name of the data schema in the form of:
projects/{project_number}/locations/{location}/ragCorpora/{rag_corpus}/ragDataSchemas/{rag_data_schema}
where the {rag_data_schema} part should be the same as the key field
below.
Implementation
final String name;