RagManagedDbConfig class final

Configuration message for RagManagedDb used by RagEngine.

Inheritance
  • Object
  • ProtoMessage
  • RagManagedDbConfig

Properties

basic RagManagedDbConfig_Basic?
Deprecated: Use mode instead to set the tier under Spanner. Sets the RagManagedDb to the Basic tier.
final
enterprise RagManagedDbConfig_Enterprise?
Sets the RagManagedDb to the Enterprise tier.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scaled RagManagedDbConfig_Scaled?
Deprecated: Use mode instead to set the tier under Spanner. Sets the RagManagedDb to the Scaled tier.
final
serverless RagManagedDbConfig_Serverless?
Sets the backend to be the serverless mode offered by RAG Engine.
final
spanner RagManagedDbConfig_Spanner?
Sets the RAG Engine backend to be RagManagedDb, built on top of Spanner.
final
unprovisioned RagManagedDbConfig_Unprovisioned?
Deprecated: Use mode instead to set the tier under Spanner. Sets the RagManagedDb to the Unprovisioned tier.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String