ReasoningEngine_TrafficConfig class final
Traffic distribution configuration.
Constructors
- ReasoningEngine_TrafficConfig({ReasoningEngine_TrafficConfig_TrafficSplitManual? trafficSplitManual, ReasoningEngine_TrafficConfig_TrafficSplitAlwaysLatest? trafficSplitAlwaysLatest})
- ReasoningEngine_TrafficConfig.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- trafficSplitAlwaysLatest → ReasoningEngine_TrafficConfig_TrafficSplitAlwaysLatest?
-
Optional. Traffic distribution configuration, where all traffic is sent
to the latest Runtime Revision.
final
- trafficSplitManual → ReasoningEngine_TrafficConfig_TrafficSplitManual?
-
Optional. Manual traffic distribution configuration, where the user
specifies the Runtime Revision IDs and the percentage of traffic to
send to each.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String