ReasoningEngine_TrafficConfig_TrafficSplitManual_Target class final
A single target for the traffic split, specifying a Runtime Revision and the percentage of traffic to send to it.
Constructors
- ReasoningEngine_TrafficConfig_TrafficSplitManual_Target({required String runtimeRevisionName, required int percent})
- ReasoningEngine_TrafficConfig_TrafficSplitManual_Target.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- percent → int
-
Required. Specifies percent of the traffic to this Runtime Revision.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeRevisionName → String
-
Required. The Runtime Revision name to which to send this portion of
traffic, if traffic allocation is by Runtime Revision.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String