Rubric class final

Message representing a single testable criterion for evaluation. One input prompt could have multiple rubrics.

Constructors

Rubric({String rubricId = '', Rubric_Content? content, String? type, Rubric_Importance? importance})
Rubric.fromJson(Object? j)
factory

Properties

content Rubric_Content?
Required. The actual testable criteria for the rubric.
final
hashCode int
The hash code for this object.
no setterinherited
importance Rubric_Importance?
Optional. The relative importance of this rubric.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
rubricId String
Unique identifier for the rubric. This ID is used to refer to this rubric, e.g., in RubricVerdict.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
Optional. A type designator for the rubric, which can inform how it's evaluated or interpreted by systems or users. It's recommended to use consistent, well-defined, upper snake_case strings. Examples: "SUMMARIZATION_QUALITY", "SAFETY_HARMFUL_CONTENT", "INSTRUCTION_ADHERENCE".
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String