RubricGenerationSpec class final
Specification for how rubrics should be generated.
Constructors
-
RubricGenerationSpec({String promptTemplate = '', AutoraterConfig? modelConfig, RubricGenerationSpec_RubricContentType rubricContentType = RubricGenerationSpec_RubricContentType.$default, List<
String> rubricTypeOntology = const []}) - RubricGenerationSpec.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- modelConfig → AutoraterConfig?
-
Configuration for the model used in rubric generation.
Configs including sampling count and base model can be specified here.
Flipping is not supported for rubric generation.
final
- promptTemplate → String
-
Template for the prompt used to generate rubrics.
The details should be updated based on the most-recent recipe requirements.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - rubricContentType → RubricGenerationSpec_RubricContentType
-
The type of rubric content to be generated.
final
-
rubricTypeOntology
→ List<
String> -
Optional. An optional, pre-defined list of allowed types for generated
rubrics. If this field is provided, it implies
include_rubric_typeshould be true, and the generated rubric types should be chosen from this ontology.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String