RubricVerdict class final
Represents the verdict of an evaluation against a single rubric.
Constructors
- RubricVerdict({Rubric? evaluatedRubric, bool verdict = false, String? reasoning})
- RubricVerdict.fromJson(Object? j)
-
factory
Properties
- evaluatedRubric → Rubric?
-
Required. The full rubric definition that was evaluated.
Storing this ensures the verdict is self-contained and understandable,
especially if the original rubric definition changes or was dynamically
generated.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - reasoning → String?
-
Optional. Human-readable reasoning or explanation for the verdict.
This can include specific examples or details from the evaluated content
that justify the given verdict.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- verdict → bool
-
Required. Outcome of the evaluation against the rubric, represented as a
boolean.
trueindicates a "Pass",falseindicates a "Fail".final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String