StudySpec_ObservationNoise class final

Describes the noise level of the repeated observations.

"Noisy" means that the repeated observations with the same Trial parameters may lead to different metric evaluations.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const StudySpec_ObservationNoise
The default value for StudySpec_ObservationNoise.
high → const StudySpec_ObservationNoise
Vertex AI will estimate the amount of noise in metric evaluations, it may repeat the same Trial parameters more than once.
low → const StudySpec_ObservationNoise
Vertex AI assumes that the objective function is (nearly) perfectly reproducible, and will never repeat the same Trial parameters.
observationNoiseUnspecified → const StudySpec_ObservationNoise
The default noise level chosen by Vertex AI.