readTensorboardBlobData method

Gets bytes of TensorboardBlobs. This is to allow reading blob data stored in consumer project's Cloud Storage bucket without users having to obtain Cloud Storage access permission.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Stream<ReadTensorboardBlobDataResponse> readTensorboardBlobData(
  ReadTensorboardBlobDataRequest request,
) {
  final url = _endPoint.replace(
    path: '/v1beta1/${request.timeSeries}:readBlobData',
    queryParameters: {
      if (request.blobIds case final $1 when $1.isNotDefault) 'blobIds': $1,
    },
  );
  return _client
      .getStreaming(url, enableSse: true)
      .map(ReadTensorboardBlobDataResponse.fromJson);
}