Tool_ParallelAiSearch class final

ParallelAiSearch tool type. A tool that uses the Parallel.ai search engine for grounding.

Constructors

Tool_ParallelAiSearch({String apiKey = '', Struct? customConfigs})
Tool_ParallelAiSearch.fromJson(Object? j)
factory

Properties

apiKey String
Optional. The API key for ParallelAiSearch. If an API key is not provided, the system will attempt to verify access by checking for an active Parallel.ai subscription through the Google Cloud Marketplace. See https://docs.parallel.ai/search/search-quickstart for more details.
final
customConfigs → Struct?
Optional. Custom configs for ParallelAiSearch. This field can be used to pass any parameter from the Parallel.ai Search API. See the Parallel.ai documentation for the full list of available parameters and their usage: https://docs.parallel.ai/api-reference/search-beta/search Currently only source_policy, excerpts, max_results, mode, fetch_policy can be set via this field. For example: { "source_policy": { "include_domains": "google.com", "wikipedia.org", "exclude_domains": "example.com" }, "fetch_policy": { "max_age_seconds": 3600 } }
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String