VeoHyperParameters class final
Hyperparameters for Veo.
Constructors
- VeoHyperParameters({int epochCount = 0, double learningRateMultiplier = 0, VeoHyperParameters_TuningTask tuningTask = VeoHyperParameters_TuningTask.$default, double? veoDataMixtureRatio, VeoHyperParameters_TuningSpeed? tuningSpeed, VeoHyperParameters_AdapterSize adapterSize = VeoHyperParameters_AdapterSize.$default})
- VeoHyperParameters.fromJson(Object? j)
-
factory
Properties
- adapterSize → VeoHyperParameters_AdapterSize
-
Optional. The adapter size for LoRA tuning.
final
- epochCount → int
-
Optional. Number of complete passes the model makes over the entire
training dataset during training.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- learningRateMultiplier → double
-
Optional. Multiplier for adjusting the default learning rate.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tuningSpeed → VeoHyperParameters_TuningSpeed?
-
The speed of the tuning job. Only supported for Veo 3.0 models.
final
- tuningTask → VeoHyperParameters_TuningTask
-
Optional. The tuning task. Either I2V or T2V.
final
- veoDataMixtureRatio → double?
-
Optional. The ratio of Google internal dataset to use in the training
mixture, in range of
[0, 1). If0.2, it means 20% of Google internal dataset and 80% of user dataset will be used for training. If not set, the default value is 0.1.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String