VeoHyperParameters_TuningSpeed class final
The speed of the tuning job. Only supported for Veo 3.0 models.
Constructors
- VeoHyperParameters_TuningSpeed(String value)
-
const
- VeoHyperParameters_TuningSpeed.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const VeoHyperParameters_TuningSpeed
- The default value for VeoHyperParameters_TuningSpeed.
- fast → const VeoHyperParameters_TuningSpeed
- Fast tuning speed.
- regular → const VeoHyperParameters_TuningSpeed
- Regular tuning speed.
- tuningSpeedUnspecified → const VeoHyperParameters_TuningSpeed
- The default / unset value. For Veo 3.0 models, this defaults to FAST.