bigqueryDestination property
Optional. The destination of the underlying BigQuery table that will be created for the output Multimodal Dataset. If not specified, the BigQuery table will be created in a default BigQuery dataset.
Implementation
final BigQueryDestination? bigqueryDestination;