FakeExtensionExecutionService class base
Testing fake for ExtensionExecutionService.
- Implemented types
Constructors
-
FakeExtensionExecutionService({Future<
ExecuteExtensionResponse> executeExtension(ExecuteExtensionRequest request)?, Future<QueryExtensionResponse> queryExtension(QueryExtensionRequest request)?, Future<ListLocationsResponse> listLocations(ListLocationsRequest request)?, Future<Location> getLocation(GetLocationRequest request)?, Future<Policy> setIamPolicy(SetIamPolicyRequest request)?, Future<Policy> getIamPolicy(GetIamPolicyRequest request)?, Future<TestIamPermissionsResponse> testIamPermissions(TestIamPermissionsRequest request)?, Future<ListOperationsResponse> listOperations(ListOperationsRequest request)?, Future<Operation< getOperation<T, S> >T extends ProtoMessage, S extends ProtoMessage>(Operation< Future<T, S> request)?,void> deleteOperation(DeleteOperationRequest request)?, Future<void> cancelOperation(CancelOperationRequest request)?, Future<Operation< waitOperation(WaitOperationRequest request)?})ProtoMessage, ProtoMessage> >
Properties
Methods
-
cancelOperation(
CancelOperationRequest request) → Future< void> -
Provides the
Operationsservice functionality in this service.override -
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
deleteOperation(
DeleteOperationRequest request) → Future< void> -
Provides the
Operationsservice functionality in this service.override -
executeExtension(
ExecuteExtensionRequest request) → Future< ExecuteExtensionResponse> -
Executes the request against a given extension.
override
-
getIamPolicy(
GetIamPolicyRequest request) → Future< Policy> -
Gets the access control policy for a resource. Returns an empty policy
if the resource exists and does not have a policy set.
override
-
getLocation(
GetLocationRequest request) → Future< Location> -
Gets information about a location.
override
-
getOperation<
T extends ProtoMessage, S extends ProtoMessage> (Operation< T, S> request) → Future<Operation< T, S> > -
Provides the
Operationsservice functionality in this service.override -
listLocations(
ListLocationsRequest request) → Future< ListLocationsResponse> -
Lists information about the supported locations for this service.
override
-
listOperations(
ListOperationsRequest request) → Future< ListOperationsResponse> -
Provides the
Operationsservice functionality in this service.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryExtension(
QueryExtensionRequest request) → Future< QueryExtensionResponse> -
Queries an extension with a default controller.
override
-
setIamPolicy(
SetIamPolicyRequest request) → Future< Policy> -
Sets the access control policy on the specified resource. Replaces
any existing policy.
override
-
testIamPermissions(
TestIamPermissionsRequest request) → Future< TestIamPermissionsResponse> -
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of
permissions, not a
NOT_FOUNDerror.override -
toString(
) → String -
A string representation of this object.
inherited
-
waitOperation(
WaitOperationRequest request) → Future< Operation< ProtoMessage, ProtoMessage> > -
Provides the
Operationsservice functionality in this service.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited