writeFeatureValues method
Writes Feature values of one or more entities of an EntityType.
The Feature values are merged into existing entities if any. The Feature values to be written must have timestamp within the online storage retention.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
@override
Future<WriteFeatureValuesResponse> writeFeatureValues(
WriteFeatureValuesRequest request,
) async {
if (isClosed) throw StateError('Service is closed');
if (_writeFeatureValues case final writeFeatureValues?) {
return writeFeatureValues(request);
}
throw UnsupportedError('writeFeatureValues');
}