batchReadFeatureValues method
Future<Operation<BatchReadFeatureValuesResponse, BatchReadFeatureValuesOperationMetadata> >
batchReadFeatureValues(
- BatchReadFeatureValuesRequest request
override
Batch reads Feature values from a Featurestore.
This API enables batch reading Feature values, where each read instance in the batch may read Feature values of entities from one or more EntityTypes. Point-in-time correctness is guaranteed for Feature values of each read instance as of each instance's read timestamp.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Returns an Operation representing the status of the long-running
operation.
When complete, Operation.done will be true. If successful,
Operation.responseAsMessage will contain the operation's result.
Implementation
@override
Future<
Operation<
BatchReadFeatureValuesResponse,
BatchReadFeatureValuesOperationMetadata
>
>
batchReadFeatureValues(BatchReadFeatureValuesRequest request) async {
if (isClosed) throw StateError('Service is closed');
if (_batchReadFeatureValues case final batchReadFeatureValues?) {
return batchReadFeatureValues(request);
}
throw UnsupportedError('batchReadFeatureValues');
}