deleteIndex method
Future<Operation<Empty, DeleteOperationMetadata> >
deleteIndex(
- DeleteIndexRequest request
override
Deletes an Index.
An Index can only be deleted when all its
DeployedIndexes
had been undeployed.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Returns an Operation representing the status of the long-running
operation.
When complete, Operation.done will be true. If successful,
Operation.responseAsMessage will contain the operation's result.
Implementation
@override
Future<Operation<protobuf.Empty, DeleteOperationMetadata>> deleteIndex(
DeleteIndexRequest request,
) async {
if (isClosed) throw StateError('Service is closed');
if (_deleteIndex case final deleteIndex?) {
return deleteIndex(request);
}
throw UnsupportedError('deleteIndex');
}