addContextArtifactsAndExecutions method
Adds a set of Artifacts and Executions to a Context. If any of the Artifacts or Executions have already been added to a Context, they are simply skipped.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
@override
Future<AddContextArtifactsAndExecutionsResponse>
addContextArtifactsAndExecutions(
AddContextArtifactsAndExecutionsRequest request,
) async {
if (isClosed) throw StateError('Service is closed');
if (_addContextArtifactsAndExecutions
case final addContextArtifactsAndExecutions?) {
return addContextArtifactsAndExecutions(request);
}
throw UnsupportedError('addContextArtifactsAndExecutions');
}