queryArtifactLineageSubgraph method
Retrieves lineage of an Artifact represented through Artifacts and Executions connected by Event edges and returned as a LineageSubgraph.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
@override
Future<LineageSubgraph> queryArtifactLineageSubgraph(
QueryArtifactLineageSubgraphRequest request,
) async {
if (isClosed) throw StateError('Service is closed');
if (_queryArtifactLineageSubgraph
case final queryArtifactLineageSubgraph?) {
return queryArtifactLineageSubgraph(request);
}
throw UnsupportedError('queryArtifactLineageSubgraph');
}