queryExecutionInputsAndOutputs method
Obtains the set of input and output Artifacts for this Execution, in the form of LineageSubgraph that also contains the Execution and connecting Events.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
@override
Future<LineageSubgraph> queryExecutionInputsAndOutputs(
QueryExecutionInputsAndOutputsRequest request,
) async {
if (isClosed) throw StateError('Service is closed');
if (_queryExecutionInputsAndOutputs
case final queryExecutionInputsAndOutputs?) {
return queryExecutionInputsAndOutputs(request);
}
throw UnsupportedError('queryExecutionInputsAndOutputs');
}