removeContextChildren method
Future<RemoveContextChildrenResponse>
removeContextChildren(
- RemoveContextChildrenRequest request
override
Remove a set of children contexts from a parent Context. If any of the child Contexts were NOT added to the parent Context, they are simply skipped.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
@override
Future<RemoveContextChildrenResponse> removeContextChildren(
RemoveContextChildrenRequest request,
) async {
if (isClosed) throw StateError('Service is closed');
if (_removeContextChildren case final removeContextChildren?) {
return removeContextChildren(request);
}
throw UnsupportedError('removeContextChildren');
}