exportPublisherModel method
Future<Operation<ExportPublisherModelResponse, ExportPublisherModelOperationMetadata> >
exportPublisherModel(
- ExportPublisherModelRequest request
override
Exports a publisher model to a user provided Google Cloud Storage bucket.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Returns an Operation representing the status of the long-running
operation.
When complete, Operation.done will be true. If successful,
Operation.responseAsMessage will contain the operation's result.
Implementation
@override
Future<
Operation<
ExportPublisherModelResponse,
ExportPublisherModelOperationMetadata
>
>
exportPublisherModel(ExportPublisherModelRequest request) async {
if (isClosed) throw StateError('Service is closed');
if (_exportPublisherModel case final exportPublisherModel?) {
return exportPublisherModel(request);
}
throw UnsupportedError('exportPublisherModel');
}