FakeNotebookService class base

Testing fake for NotebookService.

Implemented types

Constructors

FakeNotebookService({Future<Operation<NotebookRuntimeTemplate, CreateNotebookRuntimeTemplateOperationMetadata>> createNotebookRuntimeTemplate(CreateNotebookRuntimeTemplateRequest request)?, Future<NotebookRuntimeTemplate> getNotebookRuntimeTemplate(GetNotebookRuntimeTemplateRequest request)?, Future<ListNotebookRuntimeTemplatesResponse> listNotebookRuntimeTemplates(ListNotebookRuntimeTemplatesRequest request)?, Future<Operation<Empty, DeleteOperationMetadata>> deleteNotebookRuntimeTemplate(DeleteNotebookRuntimeTemplateRequest request)?, Future<NotebookRuntimeTemplate> updateNotebookRuntimeTemplate(UpdateNotebookRuntimeTemplateRequest request)?, Future<Operation<NotebookRuntime, AssignNotebookRuntimeOperationMetadata>> assignNotebookRuntime(AssignNotebookRuntimeRequest request)?, Future<NotebookRuntime> getNotebookRuntime(GetNotebookRuntimeRequest request)?, Future<ListNotebookRuntimesResponse> listNotebookRuntimes(ListNotebookRuntimesRequest request)?, Future<Operation<Empty, DeleteOperationMetadata>> deleteNotebookRuntime(DeleteNotebookRuntimeRequest request)?, Future<Operation<UpgradeNotebookRuntimeResponse, UpgradeNotebookRuntimeOperationMetadata>> upgradeNotebookRuntime(UpgradeNotebookRuntimeRequest request)?, Future<Operation<StartNotebookRuntimeResponse, StartNotebookRuntimeOperationMetadata>> startNotebookRuntime(StartNotebookRuntimeRequest request)?, Future<Operation<StopNotebookRuntimeResponse, StopNotebookRuntimeOperationMetadata>> stopNotebookRuntime(StopNotebookRuntimeRequest request)?, Future<Operation<NotebookExecutionJob, CreateNotebookExecutionJobOperationMetadata>> createNotebookExecutionJob(CreateNotebookExecutionJobRequest request)?, Future<NotebookExecutionJob> getNotebookExecutionJob(GetNotebookExecutionJobRequest request)?, Future<ListNotebookExecutionJobsResponse> listNotebookExecutionJobs(ListNotebookExecutionJobsRequest request)?, Future<Operation<Empty, DeleteOperationMetadata>> deleteNotebookExecutionJob(DeleteNotebookExecutionJobRequest request)?, Future<ListLocationsResponse> listLocations(ListLocationsRequest request)?, Future<Location> getLocation(GetLocationRequest request)?, Future<Policy> setIamPolicy(SetIamPolicyRequest request)?, Future<Policy> getIamPolicy(GetIamPolicyRequest request)?, Future<TestIamPermissionsResponse> testIamPermissions(TestIamPermissionsRequest request)?, Future<ListOperationsResponse> listOperations(ListOperationsRequest request)?, Future<Operation<T, S>> getOperation<T extends ProtoMessage, S extends ProtoMessage>(Operation<T, S> request)?, Future<void> deleteOperation(DeleteOperationRequest request)?, Future<void> cancelOperation(CancelOperationRequest request)?, Future<Operation<ProtoMessage, ProtoMessage>> waitOperation(WaitOperationRequest request)?})

Properties

hashCode → int
The hash code for this object.
no setterinherited
isClosed ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

assignNotebookRuntime(AssignNotebookRuntimeRequest request) → Future<Operation<NotebookRuntime, AssignNotebookRuntimeOperationMetadata>>
Assigns a NotebookRuntime to a user for a particular Notebook file. This method will either returns an existing assignment or generates a new one.
override
cancelOperation(CancelOperationRequest request) → Future<void>
Provides the Operations service functionality in this service.
override
close() → void
Closes the client and cleans up any resources associated with it.
override
createNotebookExecutionJob(CreateNotebookExecutionJobRequest request) → Future<Operation<NotebookExecutionJob, CreateNotebookExecutionJobOperationMetadata>>
Creates a NotebookExecutionJob.
override
createNotebookRuntimeTemplate(CreateNotebookRuntimeTemplateRequest request) → Future<Operation<NotebookRuntimeTemplate, CreateNotebookRuntimeTemplateOperationMetadata>>
Creates a NotebookRuntimeTemplate.
override
deleteNotebookExecutionJob(DeleteNotebookExecutionJobRequest request) → Future<Operation<Empty, DeleteOperationMetadata>>
Deletes a NotebookExecutionJob.
override
deleteNotebookRuntime(DeleteNotebookRuntimeRequest request) → Future<Operation<Empty, DeleteOperationMetadata>>
Deletes a NotebookRuntime.
override
deleteNotebookRuntimeTemplate(DeleteNotebookRuntimeTemplateRequest request) → Future<Operation<Empty, DeleteOperationMetadata>>
Deletes a NotebookRuntimeTemplate.
override
deleteOperation(DeleteOperationRequest request) → Future<void>
Provides the Operations service functionality in this service.
override
getIamPolicy(GetIamPolicyRequest request) → Future<Policy>
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
override
getLocation(GetLocationRequest request) → Future<Location>
Gets information about a location.
override
getNotebookExecutionJob(GetNotebookExecutionJobRequest request) → Future<NotebookExecutionJob>
Gets a NotebookExecutionJob.
override
getNotebookRuntime(GetNotebookRuntimeRequest request) → Future<NotebookRuntime>
Gets a NotebookRuntime.
override
getNotebookRuntimeTemplate(GetNotebookRuntimeTemplateRequest request) → Future<NotebookRuntimeTemplate>
Gets a NotebookRuntimeTemplate.
override
getOperation<T extends ProtoMessage, S extends ProtoMessage>(Operation<T, S> request) → Future<Operation<T, S>>
Provides the Operations service functionality in this service.
override
listLocations(ListLocationsRequest request) → Future<ListLocationsResponse>
Lists information about the supported locations for this service.
override
listNotebookExecutionJobs(ListNotebookExecutionJobsRequest request) → Future<ListNotebookExecutionJobsResponse>
Lists NotebookExecutionJobs in a Location.
override
listNotebookRuntimes(ListNotebookRuntimesRequest request) → Future<ListNotebookRuntimesResponse>
Lists NotebookRuntimes in a Location.
override
listNotebookRuntimeTemplates(ListNotebookRuntimeTemplatesRequest request) → Future<ListNotebookRuntimeTemplatesResponse>
Lists NotebookRuntimeTemplates in a Location.
override
listOperations(ListOperationsRequest request) → Future<ListOperationsResponse>
Provides the Operations service functionality in this service.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setIamPolicy(SetIamPolicyRequest request) → Future<Policy>
Sets the access control policy on the specified resource. Replaces any existing policy.
override
startNotebookRuntime(StartNotebookRuntimeRequest request) → Future<Operation<StartNotebookRuntimeResponse, StartNotebookRuntimeOperationMetadata>>
Starts a NotebookRuntime.
override
stopNotebookRuntime(StopNotebookRuntimeRequest request) → Future<Operation<StopNotebookRuntimeResponse, StopNotebookRuntimeOperationMetadata>>
Stops a NotebookRuntime.
override
testIamPermissions(TestIamPermissionsRequest request) → Future<TestIamPermissionsResponse>
Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a NOT_FOUND error.
override
toString() → String
A string representation of this object.
inherited
updateNotebookRuntimeTemplate(UpdateNotebookRuntimeTemplateRequest request) → Future<NotebookRuntimeTemplate>
Updates a NotebookRuntimeTemplate.
override
upgradeNotebookRuntime(UpgradeNotebookRuntimeRequest request) → Future<Operation<UpgradeNotebookRuntimeResponse, UpgradeNotebookRuntimeOperationMetadata>>
Upgrades a NotebookRuntime.
override
waitOperation(WaitOperationRequest request) → Future<Operation<ProtoMessage, ProtoMessage>>
Provides the Operations service functionality in this service.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited