assignNotebookRuntime method
Future<Operation<NotebookRuntime, AssignNotebookRuntimeOperationMetadata> >
assignNotebookRuntime(
- AssignNotebookRuntimeRequest request
override
Assigns a NotebookRuntime to a user for a particular Notebook file. This method will either returns an existing assignment or generates a new one.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Returns an Operation representing the status of the long-running
operation.
When complete, Operation.done will be true. If successful,
Operation.responseAsMessage will contain the operation's result.
Implementation
@override
Future<Operation<NotebookRuntime, AssignNotebookRuntimeOperationMetadata>>
assignNotebookRuntime(AssignNotebookRuntimeRequest request) async {
if (isClosed) throw StateError('Service is closed');
if (_assignNotebookRuntime case final assignNotebookRuntime?) {
return assignNotebookRuntime(request);
}
throw UnsupportedError('assignNotebookRuntime');
}