importRagFiles method
Future<Operation<ImportRagFilesResponse, ImportRagFilesOperationMetadata> >
importRagFiles(
- ImportRagFilesRequest request
override
Import files from Google Cloud Storage or Google Drive into a RagCorpus.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Returns an Operation representing the status of the long-running
operation.
When complete, Operation.done will be true. If successful,
Operation.responseAsMessage will contain the operation's result.
Implementation
@override
Future<Operation<ImportRagFilesResponse, ImportRagFilesOperationMetadata>>
importRagFiles(ImportRagFilesRequest request) async {
if (isClosed) throw StateError('Service is closed');
if (_importRagFiles case final importRagFiles?) {
return importRagFiles(request);
}
throw UnsupportedError('importRagFiles');
}