corroborateContent method

  1. @override
Future<CorroborateContentResponse> corroborateContent(
  1. CorroborateContentRequest request
)
override

Given an input text, it returns a score that evaluates the factuality of the text. It also extracts and returns claims from the text and provides supporting facts.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<CorroborateContentResponse> corroborateContent(
  CorroborateContentRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_corroborateContent case final corroborateContent?) {
    return corroborateContent(request);
  }
  throw UnsupportedError('corroborateContent');
}